% File src/library/base/man/EnvVar.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2007-2014 R Core Team
% Distributed under GPL 2 or later

\name{EnvVar}
\alias{environment variables}
\alias{HOME}
\alias{LANGUAGE}
\alias{R_BATCH}
\alias{R_BROWSER}
\alias{R_COMPLETION}
\alias{R_DOC_DIR}
\alias{R_GSCMD}
\alias{R_HISTFILE}
\alias{R_HISTSIZE}
\alias{R_INCLUDE_DIR}
\alias{MAKEINDEX}
\alias{R_PAPERSIZE}
\alias{R_PDFVIEWER}
\alias{R_PLATFORM}
\alias{R_RD4PDF}
\alias{R_SHARE_DIR}
\alias{R_TEXI2DVICMD}
\alias{R_UNZIPCMD}
\alias{R_ZIPCMD}
\alias{TMPDIR}

% R_PROFILE, R_ENVIRON are in ?Startup
% R_LIBS* are in ?.libPaths
% TZ, TZDIR are in ?Sys.timezone
% R_HOME is in ?R.home.

#ifdef unix
\alias{DISPLAY}
\alias{EDITOR}
\alias{PAGER}
\alias{R_PRINTCMD}
#endif

#ifdef windows
\alias{GSC}
\alias{R_USER}
#endif


\title{Environment Variables}
\description{
  \R セッションに影響する環境変数の幾つかの詳細．
}
\details{
\R セッションに影響を与える可能性がある環境変数をすべて列挙するのは
不可能である．\R が使用する OS 関数に影響を与えるものがある．
そしてアドオンパッケージに影響するものもある．しかしより重要なものの幾つか
に対するノートをここで与える．これらは(他の幾つかと同様に)開始時のみ
に参照されるオプションの規定値を設定する．
  \describe{
    \item{\env{HOME}:}{ユーザーの \sQuote{ホーム} ディレクトリ．}
    \item{\env{LANGUAGE}:}{オプション．メッセージの翻訳に使われる言語．
    これは必要に応じて参照される．}
    \item{\env{LC_ALL}:}{(等) オプション．ロケールの様々な様相を設定するのに使う
    -- \code{\link{Sys.getlocale}} を見よ．起動時に参照される．}
    \item{\env{MAKEINDEX}:}{\command{makeindex} へのパス．
      未設定なら \R が構築された際に決められた値．
      \code{\link{texi2dvi}} と \code{\link{texi2pdf}} のエミュレーションモードで使われる．}
    \item{\env{R_BATCH}:}{オプション -- バッチセッションで設定される．つまり
      \command{R CMD \link{BATCH}} で開始されるもの．最もしばしば 
      \code{""} と設定され，従って \code{!is.na(\link{Sys.getenv}("R_BATCH", NA))} のように
      検査する. }
    \item{\env{R_BROWSER}:}{既定ブラウザーへのパス．
      \code{\link{options}("browser")} の規定値を設定するのに使われる.}
    \item{\env{R_COMPLETION}:}{オプション.  もし \code{FALSE} に設定すると，
      コマンド行補完は使われない．(OS X GUI では使われない.)}
    \item{\env{R_DEFAULT_PACKAGES}:}{すべてのセッションで使われるパッケージの
      コンマで区切られたリスト． \code{\link{options}} を見よ．}
    \item{\env{R_DOC_DIR}:}{\R の \file{doc} ディレクトリの位置．
      \R により設定される．}
    \item{\env{R_ENVIRON}:}{オプション.  サイトの環境ファイルへのパス：
     \link{Startup} を見よ．起動時に参照される．}
    \item{\env{R_GSCMD}:}{オプション.  Ghostscript へのパスで， 
      \code{\link{dev2bitmap}}, \code{\link{bitmap}} そして 
      \code{\link{embedFonts}} で使われる．これらの関数が起動されるとき
      参照される．これは \code{\link{system}} に引き渡されるかのように扱われるため，
      空白やシェルのメタ文字はエスケープされなければならない．}
    \item{\env{R_HISTFILE}:}{オプション.  履歴ファイルへのパス：
      \link{Startup} を見よ．起動時と履歴が保存されるときに参照される..}
    \item{\env{R_HISTSIZE}:}{オプション.  履歴ファイルの最大行数．これが正確には
    どのように使われるかはインタフェイスによる．
#ifdef unix
      \code{readline} コマンド行インタフェイスでは履歴が保存されるとき
      (\code{\link{savehistory}} またはセッションの終了時に)効果を持つ．
#endif
#ifdef windows
      \command{Rgui} に対しては，履歴ファイルに保存される行数を制御する；
      セッション中で使われる履歴のサイズはコンソールのカスタマイズにより
      制御される： \code{\link{Rconsole}} を見よ．
#endif
    }
    \item{\env{R_HOME}:}{\R のインストールのトップディレクトリ：
      \code{\link{R.home}} を見よ．\R により設定される.}
    \item{\env{R_INCLUDE_DIR}:}{\R の \file{include} ディレクトリの位置．
     \R により設定される.}
    \item{\env{R_LIBS}:}{オプション.  \code{\link{.libPaths}} の初期設定のために使われる．}
    \item{\env{R_LIBS_SITE}:}{オプション.  \code{\link{.libPaths}} の初期設定のために使われる．}
    \item{\env{R_LIBS_USER}:}{オプション.  \code{\link{.libPaths}} の初期設定のために使われる．}
    \item{\env{R_PAPERSIZE}:}{オプション. \code{\link{options}("papersize")} の既定を設定するために
      使われる．つまり \code{\link{pdf}} と \code{\link{postscript}} により使われる．}
    \item{\env{R_PDFVIEWER}:}{既定の PDF ビューアーのパス．
      \command{R CMD Rd2pdf} により使われる．}
    \item{\env{R_PLATFORM}:}{プラットフォーム --  
      \code{\var{cpu}-\var{vendor}-\var{os}} の形の文字列，\code{\link{R.Version}} を見よ．}
    \item{\env{R_PROFILE}:}{オプション.  サイトのプロファイルファイルへのパス．
      \link{Startup} を見よ．起動時に参照される．}
    \item{\env{R_RD4PDF}:}{\code{Rd} ファイルを \command{pdflatex} で処理する際の
      オプション．\command{R CMD Rd2pdf} により使われる．}
    \item{\env{R_SHARE_DIR}:}{\R の \file{share} ディレクトリ．\R により設定される．}
    \item{\env{R_TEXI2DVICMD}:}{\command{texi2dvi} へのパス．
      既定値は \env{TEXI2DVI}，そしてもし未設定なら \R が構築された時の値とされる．
#ifdef unix
      起動時に \code{\link{options}("texi2dvi")} に対する既定値を設定するために
      参照される．これはパッケージ \pkg{tools} 中の \code{\link{texi2dvi}} と
      \code{\link{texi2pdf}} により使われる．
#endif
    }
    \item{\env{R_UNZIPCMD}:}{\command{unzip} へのパス．
       名前空間 \pkg{utils} が読み込まれるときに Unix 風システムで
        \code{\link{options}("unzip")} に対する初期値を設定する．}
    \item{\env{R_ZIPCMD}:}{\command{zip} へのパス． \code{\link{zip}} と
    Windows で \command{R CMD INSTALL --build} により使われる．}
    \item{\env{TMPDIR}, \env{TMP}, \env{TEMP}:}{(この順で)セッションの一時ファイルを
      設定する際に参照される： \code{\link{tempdir}} を見よ．
      \env{TMPDIR} がまた幾つかのユーティリティで使われる．
      \code{\link{build}} に対するヘルプを見よ．}
    \item{\env{TZ}:}{オプション.  現在のタイムゾーン．システム固有の書式については
      \code{\link{Sys.timezone}}  を見よ．必要に応じて参照される．}
    \item{\env{no_proxy}, \env{http_proxy}, \env{ftp_proxy}:}{
      (そしてそれ以上)． オプション． \code{\link{download.file}} に対する設定：
      詳細はそのヘルプを見よ．}
  }
}

#ifdef unix
\section{Unix 固有}{
  Unix 風システムで設定されるが，(一般に) Windows では設定されない変数．
  \describe{
    \item{\env{DISPLAY}:}{オプション: \code{\link{X11}}, Tk (パッケージ 
      \pkg{tcltk} 中), そしてデータエディターと様々なパッケージで使われる．}
    \item{\env{EDITOR}:}{既定エディターへのパス： 名前空間 \pkg{utils} が読み込まれるとき
      \code{\link{options}("editor")} に対する規定値を設定する．}
    \item{\env{PAGER}:}{既定設定値が \code{\link{options}("pager")} である
    ページャへのパス．規定値はコンフィギュレーションの際に選ばれ，普通 
    \command{less} へのパス．}
    \item{\env{R_PRINTCMD}:}{\code{\link{options}("printcmd")} に対する既定
      を設定する．これは \code{\link{postscript}} が使用する既定プリント命令を
      設定する．}
  }
}
#endif

#ifdef windows
\section{Windows 固有}{
  幾つかの Windows 固有のもの
  \describe{
    \item{\env{GSC}:}{オプション: Ghostscript へのパス．
      \env{R_GSCMD} が設定されていない時使われる．}
    \item{\env{R_USER}:}{ユーザの \sQuote{ホーム} ディレクトリ．
      \R により設定される．(もしまだ設定されていなければ \env{HOME} が同じ値に
      設定する．)}
    \item{\env{TZDIR}:}{オプション.  タイームゾーンデータベースのトップレベルの
      ディレクトリ．\code{\link{Sys.timezone}} を見よ.}
  }
}
#endif

\seealso{
\R セッション中で読まれ設定される \code{\link{Sys.getenv}} と \code{\link{Sys.setenv}}．

ガベージコレクションを制御する環境変数については {\link{gctorture}}．
}
\keyword{utilities}

%% File src/library/base/man/EnvVar.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2007-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{EnvVar}
%\alias{environment variables}
%\alias{HOME}
%\alias{LANGUAGE}
%\alias{R_BATCH}
%\alias{R_BROWSER}
%\alias{R_COMPLETION}
%\alias{R_DOC_DIR}
%\alias{R_GSCMD}
%\alias{R_HISTFILE}
%\alias{R_HISTSIZE}
%\alias{R_INCLUDE_DIR}
%\alias{MAKEINDEX}
%\alias{R_PAPERSIZE}
%\alias{R_PDFVIEWER}
%\alias{R_PLATFORM}
%\alias{R_RD4PDF}
%\alias{R_SHARE_DIR}
%\alias{R_TEXI2DVICMD}
%\alias{R_UNZIPCMD}
%\alias{R_ZIPCMD}
%\alias{TMPDIR}
%
%% R_PROFILE, R_ENVIRON are in ?Startup
%% R_LIBS* are in ?.libPaths
%% TZ, TZDIR are in ?Sys.timezone
%% R_HOME is in ?R.home.
%
%#ifdef unix
%\alias{DISPLAY}
%\alias{EDITOR}
%\alias{PAGER}
%\alias{R_PRINTCMD}
%#endif
%
%#ifdef windows
%\alias{GSC}
%\alias{R_USER}
%#endif
%
%
%\title{Environment Variables}
%\description{
%  Details of some of the environment variables which affect an \R session.
%}
%\details{
%  It is impossible to list all the environment variables which can
%  affect an \R session: some affect the OS system functions which \R
%  uses, and others will affect add-on packages.  But here are notes on
%  some of the more important ones.  Those that set the defaults for
%  options are consulted only at startup (as are some of the others).
%  \describe{
%    \item{\env{HOME}:}{The user's \sQuote{home} directory.}
%    \item{\env{LANGUAGE}:}{Optional.  The language(s) to be used for
%      message translations.  This is consulted when needed.}
%    \item{\env{LC_ALL}:}{(etc) Optional.  Use to set various aspects of
%      the locale -- see \code{\link{Sys.getlocale}}.  Consulted at startup.}
%    \item{\env{MAKEINDEX}:}{The path to \command{makeindex}.
%      If unset to a value determined when \R was built.
%      Used by the emulation mode of \code{\link{texi2dvi}} and
%      \code{\link{texi2pdf}}.}
%    \item{\env{R_BATCH}:}{Optional -- set in a batch session, that is
%      one started by \command{R CMD \link{BATCH}}.  Most often set to
%      \code{""}, so test by something like
%      \code{!is.na(\link{Sys.getenv}("R_BATCH", NA))}.}
%    \item{\env{R_BROWSER}:}{The path to the default browser.  Used to
%      set the default value of \code{\link{options}("browser")}.}
%    \item{\env{R_COMPLETION}:}{Optional.  If set to \code{FALSE},
%      command-line completion is not used.  (Not used by OS X GUI.)}
%    \item{\env{R_DEFAULT_PACKAGES}:}{A comma-separated list of packages
%      which are to be attached in every session.  See \code{\link{options}}.}
%    \item{\env{R_DOC_DIR}:}{The location of the \R \file{doc}
%      directory.  Set by \R.}
%    \item{\env{R_ENVIRON}:}{Optional.  The path to the site environment
%      file: see \link{Startup}.  Consulted at startup.}
%    \item{\env{R_GSCMD}:}{Optional.  The path to Ghostscript, used by
%      \code{\link{dev2bitmap}}, \code{\link{bitmap}} and
%      \code{\link{embedFonts}}.  Consulted when those functions are
%      invoked.  Since it will be treated as if passed to
%      \code{\link{system}}, spaces and shell metacharacters should be escaped.}
%    \item{\env{R_HISTFILE}:}{Optional.  The path of the history file:
%      see \link{Startup}.  Consulted at startup and when the history is
%      saved.}
%    \item{\env{R_HISTSIZE}:}{Optional.  The maximum size of the history
%      file, in lines.  Exactly how this is used depends on the
%      interface.
%#ifdef unix
%      For the \code{readline} command-line interface it takes effect
%      when the history is saved (by \code{\link{savehistory}} or at the
%      end of a session).
%#endif
%#ifdef windows
%      For \command{Rgui} it controls the number of lines saved to the
%      history file: the size of the history used in the session is
%      controlled by the console customization: see \code{\link{Rconsole}}.
%#endif
%    }
%    \item{\env{R_HOME}:}{The top-level directory of the \R
%      installation: see \code{\link{R.home}}.  Set by \R.}
%    \item{\env{R_INCLUDE_DIR}:}{The location of the \R \file{include}
%      directory.  Set by \R.}
%    \item{\env{R_LIBS}:}{Optional.  Used for initial setting of
%      \code{\link{.libPaths}}.}
%    \item{\env{R_LIBS_SITE}:}{Optional.  Used for initial setting of
%      \code{\link{.libPaths}}.}
%    \item{\env{R_LIBS_USER}:}{Optional.  Used for initial setting of
%      \code{\link{.libPaths}}.}
%    \item{\env{R_PAPERSIZE}:}{Optional.  Used to set the default for
%      \code{\link{options}("papersize")}, e.g.\sspace{}used by
%      \code{\link{pdf}} and \code{\link{postscript}}.}
%    \item{\env{R_PDFVIEWER}:}{The path to the default PDF viewer.  Used
%      by \command{R CMD Rd2pdf}.}
%    \item{\env{R_PLATFORM}:}{The platform -- a string of the form
%      \code{\var{cpu}-\var{vendor}-\var{os}}, see \code{\link{R.Version}}.}
%    \item{\env{R_PROFILE}:}{Optional.  The path to the site profile
%      file: see \link{Startup}.  Consulted at startup.}
%    \item{\env{R_RD4PDF}:}{Options for \command{pdflatex} processing of
%      \code{Rd} files.  Used by \command{R CMD Rd2pdf}.}
%    \item{\env{R_SHARE_DIR}:}{The location of the \R \file{share}
%      directory.  Set by \R.}
%    \item{\env{R_TEXI2DVICMD}:}{The path to \command{texi2dvi}.
%      Defaults to the value of \env{TEXI2DVI}, and if that is unset to a
%      value determined when \R was built.
%#ifdef unix
%      Consulted at startup to set the default for
%      \code{\link{options}("texi2dvi")}, used by
%      \code{\link{texi2dvi}} and \code{\link{texi2pdf}} in package \pkg{tools}.
%#endif
%    }
%    \item{\env{R_UNZIPCMD}:}{The path to \command{unzip}.  Sets the
%      initial value for \code{\link{options}("unzip")} on a Unix-alike
%      when namespace \pkg{utils} is loaded.}
%    \item{\env{R_ZIPCMD}:}{The path to \command{zip}. Used by
%      \code{\link{zip}} and by \command{R CMD INSTALL --build} on Windows.}
%    \item{\env{TMPDIR}, \env{TMP}, \env{TEMP}:}{Consulted (in that
%      order) when setting the temporary directory for the session: see
%      \code{\link{tempdir}}.  \env{TMPDIR} is also used by some of the
%      utilities see the help for \code{\link{build}}.}
%    \item{\env{TZ}:}{Optional.  The current time zone.  See
%      \code{\link{Sys.timezone}} for the system-specific
%      formats.  Consulted as needed.}
%    \item{\env{no_proxy}, \env{http_proxy}, \env{ftp_proxy}:}{
%      (and more).  Optional.  Settings for \code{\link{download.file}}:
%      see its help for further details.}
%  }
%}
%
%#ifdef unix
%\section{Unix-specific}{
%  Some variables set on Unix-alikes, and not (in general) on Windows.
%  \describe{
%    \item{\env{DISPLAY}:}{Optional: used by \code{\link{X11}}, Tk (in
%      package \pkg{tcltk}), the data editor and various packages.}
%    \item{\env{EDITOR}:}{The path to the default editor: sets the
%      default for \code{\link{options}("editor")} when namespace
%      \pkg{utils} is loaded.}
%    \item{\env{PAGER}:}{The path to the pager with the default setting of
%      \code{\link{options}("pager")}. The default value is chosen at
%      configuration, usually as the path to \command{less}.}
%    \item{\env{R_PRINTCMD}:}{Sets the default for
%      \code{\link{options}("printcmd")}, which sets the default print
%      command to be used by \code{\link{postscript}}.}
%  }
%}
%#endif
%
%#ifdef windows
%\section{Windows-specific}{
%  Some Windows-specific variables are
%  \describe{
%    \item{\env{GSC}:}{Optional: the path to Ghostscript, used if
%      \env{R_GSCMD} is not set.}
%    \item{\env{R_USER}:}{The user's \sQuote{home} directory.  Set by
%      \R.  (\env{HOME} will be set to the same value if not already set.)}
%    \item{\env{TZDIR}:}{Optional.  The top-level directory of the
%      time-zone database.  See \code{\link{Sys.timezone}}.}
%  }
%}
%#endif
%
%\seealso{
%  \code{\link{Sys.getenv}} and \code{\link{Sys.setenv}} to read and set
%  environmental variables in an \R session.
%
%  \code{\link{gctorture}} for environment variables controlling garbage
%  collection.
%}
%\keyword{utilities}
%
\encoding{UTF8}
