% File src/library/base/man/Memory-limits.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{Memory-limits}
\alias{Memory-limits}
\concept{memory}
\concept{limits}
\title{Memory Limits in R}
\description{
  \R はオブジェクトを仮想メモリに保持する．このヘルプファイルは大規模オブジェクトの
現在のデザイン限界を説明する：これは \R を32ビットと64ビットのどちらで
構築したかで異なる．
}
\details{
現在 \R は32ビットと64ビットのOS上で稼働しており．殆どの64ビット
OS(Linux, Solaris, Windows そして OS X を含む)は \R の32ビットと64ビット版
のどちらも動かすことが出来る．メモリ限界は主に構築次第であるが，
Windows の \R の32ビット版はまた基礎にあるOSのバージョンにもよる．

\R はすべてのオブジェクトを仮想メモリ中に保持し，すべてのオブジェクトにより使用可能な
メモリ量には限界がある：
  \itemize{
    \item ヒープメモリのサイズと cons cell の数には上限があるかもしれない
-- \code{\link{Memory}} を見よ -- しかし普通は設けられていない．
    \item \R の実行プログラム等の単一プロセスの(ユーザ)アドレス空間に
制限がある．これはシステム固有であり，実行プログラムに依存する可能性がある．
    \item 環境が単一のプロセスが利用可能なリソースに限界を
課す可能性がある：\R の Windows 版がそれを直接に行う．
  }
\code{cannot allocate vector of size} で始まるメッセージは，
サイズがプロセスのアドレス空間を超えたか，よりありそうなこととして
システムがメモリを提供できなかったかで，
メモリを獲得するのに失敗したことを意味する．
32ビット版構築では，利用可能なフリーメモリが十分あるが，
それをアドレス空間の連続するブロックにマップ出来るほどではないことが起こりえる．

個々のオブジェクトに関する限界もある．保管空間はアドレス限界を超えることは
できず，もしそれを越えようとすると \code{cannot allocate vector of length} で
始まるエラーメッセージが出る．

一つの文字列中のバイト数は 
 \eqn{2^{31} - 1 \approx 2\thinspace 10^9}{2^31 - 1 ~ 2*10^9} に
 制限されているので，それがまた一つの配列の各次元の限界である．
}
\section{ユニックス}{
アドレス空間の限界はシステム固有である；32ビットOSは
4Gbを超えないという限界を課す：しばしばこれは3Gbである．
64ビットOS上で32ビットプログラムを実行する場合も同じような限界がある：
64ビットプログラムは本質的に無限のシステム固有限界を
持つであろう(例えば x86_64 CPU上の Linux に対しては128Tbとなる)．

単一プロセスで利用可能なリソースの限界をどのようにして課すかについては
 \code{limit} や \code{ulimit} のような命令を見よ．
例えばプロセスをCPU呼び出し時間を10分で仮想メモリを(約)4Gbにするには． 
\command{bash} ユーザは 
\preformatted{ulimit -t 600 -v 4000000} を，
 \command{csh} を使っていれば 
\preformatted{limit cputime 10m limit vmemoryuse 4096m} とすることが出来る．
(使用するRAMを設定する他のオプションがあるが，一般に勧められない．)
}
\section{Windows}{
32ビット Windows ではアドレス空間の限界は，OSの既定値がより多く(3Gbが上限)に
設定されていなければ2Gbである．
 \url{https://www.microsoft.com/whdc/system/platform/server/PAE/PAEmem.mspx}
 と
  \url{https://msdn.microsoft.com/en-us/library/bb613473(VS.85).aspx}
 を見よ．
Windows の殆どのバージョンでは \R の32ビット版の限界は4Gbである．
最も古いものではこれは2Gbであった．\R の64ビット版に対する(OSが課している)限界は8Tbである．

Windowsではアドレス空間の真ん中に事前確保されるため，
64ビットの Windows でも32ビット版 \R で一つのベクトルに2Gbものメモリを確保
することは普通不可能である．
Windows 下では，OSが方法を提供していないため，単一のセッションが
使用可能な全メモリ配置に \R は限界を設ける：
\code{\link{memory.size}} と \code{\link{memory.limit}} を見よ．
}
\seealso{
\R オブジェクト \code{a} の(近似的な)サイズは 
 \code{\link{object.size}(a)}．
}
\keyword{environment}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/Memory-limits.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Memory-limits}
%\alias{Memory-limits}
%\concept{memory}
%\concept{limits}
%\title{Memory Limits in R}
%\description{
%  \R holds objects it is using in virtual memory.  This help file
%  documents the current design limitations on large objects: these
%  differ between 32-bit and 64-bit builds of \R.
%}
%\details{
%  Currently \R runs on 32- and 64-bit operating systems, and most 64-bit
%  OSes (including Linux, Solaris, Windows and OS X) can run either
%  32- or 64-bit builds of \R.  The memory limits depends mainly on the
%  build, but for a 32-bit build of \R on Windows they also depend on the
%  underlying OS version.
%
%  \R holds all objects in virtual memory, and there are limits based on the
%  amount of memory that can be used by all objects:
%  \itemize{
%    \item There may be limits on the size of the heap and the number of
%    cons cells allowed -- see \code{\link{Memory}} -- but these are
%    usually not imposed.
%    \item There is a limit on the (user) address space of a single
%    process such as the \R executable.  This is system-specific, and can
%    depend on the executable.
%    \item The environment may impose limitations on the resources
%    available to a single process: Windows' versions of \R do so directly.
%  }
%  Error messages beginning \code{cannot allocate vector of size}
%  indicate a failure to obtain memory, either because the size exceeded
%  the address-space limit for a process or, more likely, because the
%  system was unable to provide the memory.  Note that on a 32-bit build
%  there may well be enough free memory available, but not a large enough
%  contiguous block of address space into which to map it.
%
%  There are also limits on individual objects. The storage space
%  cannot exceed the address limit, and if you try to exceed that limit,
%  the error message begins \code{cannot allocate vector of length}.
%  The number of bytes in a character string is limited to
%  \eqn{2^{31} - 1 \approx 2\thinspace 10^9}{2^31 - 1 ~ 2*10^9},
%  which is also the limit on each dimension of an array.
%}
%\section{Unix}{
%  The address-space limit is system-specific: 32-bit OSes
%  imposes a limit of no more than 4Gb: it is often 3Gb.  Running
%  32-bit executables on a 64-bit OS will have similar limits: 64-bit
%  executables will have an essentially infinite system-specific limit
%  (e.g., 128Tb for Linux on x86_64 cpus).
%
%  See the OS/shell's help on commands such as \code{limit} or
%  \code{ulimit} for how to impose limitations on the resources available
%  to a single process.  For example a \command{bash} user could use
%\preformatted{ulimit -t 600 -v 4000000
%}
%  whereas a \command{csh} user might use
%\preformatted{limit cputime 10m
%limit vmemoryuse 4096m
%}
%  to limit a process to 10 minutes of CPU time and (around) 4Gb of
%  virtual memory.  (There are other options to set the RAM in use, but they
%  are not generally honoured.)
%}
%\section{Windows}{
%  The address-space limit is 2Gb under 32-bit Windows unless the OS's
%  default has been changed to allow more (up to 3Gb).  See
%  \url{https://www.microsoft.com/whdc/system/platform/server/PAE/PAEmem.mspx}
%  and
%  \url{https://msdn.microsoft.com/en-us/library/bb613473(VS.85).aspx}.
%  Under most 64-bit versions of Windows the limit for a 32-bit build
%  of \R is 4Gb: for the oldest ones it is 2Gb.  The limit for a 64-bit
%  build of \R (imposed by the OS) is 8Tb.
%
%  It is not normally possible to allocate as much as 2Gb to a single
%  vector in a 32-bit build of \R even on 64-bit Windows because of
%  preallocations by Windows in the middle of the address space.
%
%  Under Windows, \R imposes limits on the total memory allocation
%  available to a single session as the OS provides no way to do so: see
%  \code{\link{memory.size}} and \code{\link{memory.limit}}.
%}
%\seealso{
%  \code{\link{object.size}(a)} for the (approximate) size of \R object
%  \code{a}.
%}
%\keyword{environment}
%
\encoding{UTF8}
