% File src/library/base/man/Round.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{Round}
\alias{ceiling}
\alias{floor}
\alias{round}
\alias{signif}
\alias{trunc}
%\title{数の丸め (Rounding of Numbers9}
\title{Rounding of Numbers}
\usage{
ceiling(x)
floor(x)
trunc(x, \dots)

round(x, digits = 0)
signif(x, digits = 6)
}
\description{
  \code{ceiling} は一つの数値引数 \code{x} を取り，\code{x} の
対応要素より小さくない最小の整数を含む数値ベクトルを返す．

  \code{fllor} は一つの数値引数 \code{x} を取り，\code{x} の
対応要素より大きくない最大の整数を含む数値ベクトルを返す．

  \code{trunc} は一つの数値引数 \code{x} を取り，\code{x} の
対応要素を \code{0} に向かって切り詰めることで得られる整数を含む数値ベクトルを返す．

  \code{round} はその最初の引数中の値を指定された数の
10進桁数(既定値 0)で丸める．

  \code{signif} はその最初の引数中の値を指定された有効桁数に丸める．
}
\arguments{
  \item{x}{数値ベクトル．または \code{round} と \code{signif} に対しては
複素数値ベクトル．}

  \item{digits}{10進桁数を指示する整数(\code{round})，または
使用する有効桁数(\code{signif})．
負の数が許される(\sQuote{詳細}) を見よ．}

  \item{\dots}{メソッドに引き渡される引数．}
}
\details{
  これらは総称的関数である：それらに対するメソッドを個別に，または
 the \code{\link[=S3groupGeneric]{Math}} グループ総称的経由で定義できる．

  5の丸めについては IEC 60559 標準 \sQuote{\emph{偶数に向かう}} が
使われることが期待されている．  
従って \code{round(0.5)} は \code{0} で，\code{round(-1.5)} は
  \code{-2} である．しかしながら，これは OS サービスと表現エラー
に依存している(例えば，\sspace{}\code{0.15} は正確に表現できないため，
丸め規則は表現された数に適用されプリントされる数に対してではない．従って
 \code{round(0.15, 1)} は \code{0.1} にも \code{0.2} にもなりえる)．

負の桁数への丸めは10の巾乗への丸めを意味する．従って例えば
 \code{round(x, digits = -2)} は一番近い100の倍数に丸められる．

\code{signif} に対しては認識される \code{digits} の値は
  \code{1...22} であり，非欠損数はこの範囲の最も近い値に
丸められる．複素数はより大きな成分中の指定桁数が保たれるように
丸められる．ベクトルの各要素はプリント時とは異なり個々に丸められる．

これらは皆プリミティブな関数である．
}
\section{S4 メソッド}{
  これらは皆(内部的に) S4 総称的である．

  \code{ceiling}, \code{floor} そして \code{trunc} は
  \code{\link[=S4groupGeneric]{Math}} グループ総称的関数のメンバーである．
S4 総称的であるため \code{trunc} はただひとつの引数を持つ．

  \code{round} と \code{signif} は
 \code{\link[=S4groupGeneric]{Math2}} グループ総称的関数のメンバーである．
}
\section{警告}{
計算機における算術の現実は予期せぬ結果を引き起こす可能性が
ある．特に \code{floor} と \code{ceiling} に関してである．例えば，
\code{x = 8} に対する \code{floor(log(x, base = 8))} は 
 \code{1} になるはずであるが，ある \R のプラットフォームでは \code{0}
 になることが知られている．普通ある許容度を用いることが必要である．
 }
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{as.integer}}.
}
\examples{
round(.5 + -2:4) # IEEE 式丸め: -2  0  0  2  2  4  4
( x1 <- seq(-2, 4, by = .5) )
round(x1) #-- IEEE 式丸め!
x1[trunc(x1) != floor(x1)]
x1[round(x1) != floor(x1 + .5)]
(non.int <- ceiling(x1) != floor(x1))

x2 <- pi * 100^(-1:3)
round(x2, 3)
signif(x2, 3)
}
\keyword{arith}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/Round.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Round}
%\alias{ceiling}
%\alias{floor}
%\alias{round}
%\alias{signif}
%\alias{trunc}
%\title{Rounding of Numbers}
%\usage{
%ceiling(x)
%floor(x)
%trunc(x, \dots)
%
%round(x, digits = 0)
%signif(x, digits = 6)
%}
%\description{
%  \code{ceiling} takes a single numeric argument \code{x} and returns a
%  numeric vector containing the smallest integers not less than the
%  corresponding elements of \code{x}.
%
%  \code{floor} takes a single numeric argument \code{x} and returns a
%  numeric vector containing the largest integers not greater than the
%  corresponding elements of \code{x}.
%
%  \code{trunc} takes a single numeric argument \code{x} and returns a
%  numeric vector containing the integers formed by truncating the values in
%  \code{x} toward \code{0}.
%
%  \code{round} rounds the values in its first argument to the specified
%  number of decimal places (default 0).
%
%  \code{signif} rounds the values in its first argument to the specified
%  number of significant digits.
%}
%\arguments{
%  \item{x}{a numeric vector.  Or, for \code{round} and \code{signif}, a
%    complex vector.}
%
%  \item{digits}{integer indicating the number of decimal places
%    (\code{round}) or significant digits (\code{signif}) to be used.
%    Negative values are allowed (see \sQuote{Details}).}
%
%  \item{\dots}{arguments to be passed to methods.}
%}
%\details{
%  These are generic functions: methods can be defined for them
%  individually or via the \code{\link[=S3groupGeneric]{Math}} group
%  generic.
%
%  Note that for rounding off a 5, the IEC 60559 standard is expected to
%  be used, \sQuote{\emph{go to the even digit}}.
%  Therefore \code{round(0.5)} is \code{0} and \code{round(-1.5)} is
%  \code{-2}.  However, this is dependent on OS services and on
%  representation error (since e.g.\sspace{}\code{0.15} is not represented
%  exactly, the rounding rule applies to the represented number and not
%  to the printed number, and so \code{round(0.15, 1)} could be either
%  \code{0.1} or \code{0.2}).
%
%  Rounding to a negative number of digits means rounding to a power of
%  ten, so for example \code{round(x, digits = -2)} rounds to the nearest
%  hundred.
%
%  For \code{signif} the recognized values of \code{digits} are
%  \code{1...22}, and non-missing values are rounded to the nearest
%  integer in that range.  Complex numbers are rounded to retain the
%  specified number of digits in the larger of the components.  Each
%  element of the vector is rounded individually, unlike printing.
%
%  These are all primitive functions.
%}
%\section{S4 methods}{
%  These are all (internally) S4 generic.
%
%  \code{ceiling}, \code{floor} and \code{trunc} are members of the
%  \code{\link[=S4groupGeneric]{Math}} group generic.  As an S4
%  generic, \code{trunc} has only one argument.
%
%  \code{round} and \code{signif} are members of the
%  \code{\link[=S4groupGeneric]{Math2}} group generic.
%}
%\section{Warning}{
%  The realities of computer arithmetic can cause unexpected results,
%  especially with \code{floor} and \code{ceiling}.  For example, we
%  \sQuote{know} that \code{floor(log(x, base = 8))} for \code{x = 8} is
%  \code{1}, but \code{0} has been seen on an \R platform.  It is
%  normally necessary to use a tolerance.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{as.integer}}.
%}
%\examples{
%round(.5 + -2:4) # IEEE rounding: -2  0  0  2  2  4  4
%( x1 <- seq(-2, 4, by = .5) )
%round(x1) #-- IEEE rounding !
%x1[trunc(x1) != floor(x1)]
%x1[round(x1) != floor(x1 + .5)]
%(non.int <- ceiling(x1) != floor(x1))
%
%x2 <- pi * 100^(-1:3)
%round(x2, 3)
%signif(x2, 3)
%}
%\keyword{arith}
%
\encoding{UTF8}
