% File src/library/base/man/Trig.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{Trig}
\title{Trigonometric Functions}
\alias{Trig}
\alias{cos}
\alias{sin}
\alias{tan}
\alias{acos}\alias{arccos}
\alias{asin}\alias{arcsin}
\alias{atan}\alias{arctan}
\alias{atan2}
\alias{cospi}
\alias{sinpi}
\alias{tanpi}
\description{
  これらの関数は当然三角関数を表す．それぞれ 
cosine, sine, tangent, arc-cosine, arc-sine,
  arc-tangent, そして2引数の arc-tangent を表す．

  \code{cospi(x)}, \code{sinpi(x)}, そして \code{tanpi(x)} は 
  \code{cos(pi*x)}, \code{sin(pi*x)}, そして \code{tan(pi*x)} を
計算する．
}
\usage{
cos(x)
sin(x)
tan(x)

acos(x)
asin(x)
atan(x)
atan2(y, x)

cospi(x)
sinpi(x)
tanpi(x)
}
\arguments{
   \item{x, y}{実数値もしくは複素数値ベクトル．}
}
\details{
  2変数アークタンジェント \code{atan2(y, x)} は x 軸と
原点から \eqn{(x, y)} を結ぶベクトル間の角度を与える．
つまり正の引数に対しては \code{atan2(y, x) == atan(y/x)}．

標準的バージョンでは角度単位はラジアンで度ではない
(つまり直角は \eqn{\pi/2}) で, \code{cospi} に対しては
\sQuote{半回転} 等．

  \code{cospi(x)}, \code{sinpi(x)} そして \code{tanpi(x)} は
0.5の倍数に対しては正確である．

\code{atan2} 以外は内部総称的でプリミティブな関数である：
メソッドを個別に，また
  \code{\link[=S3groupGeneric]{Math}} 経由でグループ総称的に書くことが出来る．
}

\value{
  \code{tanpi(0.5)} は \code{\link{NaN}} になる．少数部分 
\code{0.5} を持つ他の入力も同様である．
}

\section{複素数値}{
   逆三角関数に対してはブランチカットは
  Abramowitz and Stegun, figure 4.4, page 79 で定義されているものとされる．

\code{asin} と \code{acos} に対しては二つのカットがあり，
双方が実軸に沿う：
 \eqn{\left(-\infty, -1\right]}{(-Inf, -1]} そして
 \eqn{\left[1, \infty\right)}{[1, Inf)} である．

\code{atan} に対しては二つのカットがあり，双方が純虚数軸に沿う：
   \eqn{\left(-\infty i, -1i\right]}{(-1i*Inf, -1i]} そして
   \eqn{\left[1i, \infty i\right)}{[1i, 1i*Inf)} である.

カット上の実際の挙動は C99 標準に従い，
端点を反時計方向に連続的に巡ることを要求する．

 \code{cospi}, \code{sinpi}, そして \code{tanpi} に
対する複素数値引数はまだ実装されていない． 
}
\section{S4 メソッド}{
  \code{atan2} 以外は総称的関数である．
メソッドを個別に，また
  \code{\link[=S3groupGeneric]{Math}} 経由でグループ総称的に書くことが出来る．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.

  Abramowitz, M. and Stegun, I. A. (1972). \emph{Handbook of
    Mathematical Functions}. New York: Dover.\cr
  Chapter 4. Elementary Transcendental Functions: Logarithmic,
  Exponential, Circular and Hyperbolic Functions

  \code{cospi}, \code{sinpi}, そして \code{tanpi} はドラフト C11
  拡張 ISO/IEC TS 18661
  (\url{http://www.open-std.org/jtc1/sc22/wg14/www/docs/n1785.pdf}).
}
\examples{
x <- seq(-3, 7, by = 1/8)
tx <- cbind(x, cos(pi*x), cospi(x), sin(pi*x), sinpi(x),
               tan(pi*x), tanpi(x), deparse.level=2)
op <- options(digits = 4, width = 90) # 体裁の良い書式化のため
head(tx)
tx[ (x \%\% 1) \%in\% c(0, 0.5) ,]
options(op)
}
\keyword{math}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/Trig.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Trig}
%\title{Trigonometric Functions}
%\alias{Trig}
%\alias{cos}
%\alias{sin}
%\alias{tan}
%\alias{acos}\alias{arccos}
%\alias{asin}\alias{arcsin}
%\alias{atan}\alias{arctan}
%\alias{atan2}
%\alias{cospi}
%\alias{sinpi}
%\alias{tanpi}
%\description{
%  These functions give the obvious trigonometric functions.  They
%  respectively compute the cosine, sine, tangent, arc-cosine, arc-sine,
%  arc-tangent, and the two-argument arc-tangent.
%
%  \code{cospi(x)}, \code{sinpi(x)}, and \code{tanpi(x)}, compute
%  \code{cos(pi*x)}, \code{sin(pi*x)}, and \code{tan(pi*x)}.
%}
%\usage{
%cos(x)
%sin(x)
%tan(x)
%
%acos(x)
%asin(x)
%atan(x)
%atan2(y, x)
%
%cospi(x)
%sinpi(x)
%tanpi(x)
%}
%\arguments{
%   \item{x, y}{numeric or complex vectors.}
%}
%\details{
%  The arc-tangent of two arguments \code{atan2(y, x)} returns the angle
%  between the x-axis and the vector from the origin to \eqn{(x, y)},
%  i.e., for positive arguments \code{atan2(y, x) == atan(y/x)}.
%
%  Angles are in radians, not degrees, for the standard versions (i.e., a
%  right angle is \eqn{\pi/2}), and in \sQuote{half-rotations} for
%  \code{cospi} etc.
%
%  \code{cospi(x)}, \code{sinpi(x)}, and \code{tanpi(x)} are accurate
%  for \code{x} which are multiples of a half.
%
%  All except \code{atan2} are \link{internal generic} \link{primitive}
%  functions: methods can be defined for them individually or via the
%  \code{\link[=S3groupGeneric]{Math}} group generic.
%}
%
%\value{
%  \code{tanpi(0.5)} is \code{\link{NaN}}.  Similarly for other inputs
%  with fractional part \code{0.5}.
%}
%
%\section{Complex values}{
%   For the inverse trigonometric functions, branch cuts are defined as in
%   Abramowitz and Stegun, figure 4.4, page 79.
%
%   For \code{asin} and \code{acos}, there are two cuts, both along
%   the real axis: \eqn{\left(-\infty, -1\right]}{(-Inf, -1]} and
%   \eqn{\left[1, \infty\right)}{[1, Inf)}.
%
%   For \code{atan} there are two cuts, both along the pure imaginary
%   axis: \eqn{\left(-\infty i, -1i\right]}{(-1i*Inf, -1i]} and
%   \eqn{\left[1i, \infty i\right)}{[1i, 1i*Inf)}.
%
%   The behaviour actually on the cuts follows the C99 standard which
%   requires continuity coming round the endpoint in a counter-clockwise
%   direction.
%
%   Complex arguments for  \code{cospi}, \code{sinpi}, and \code{tanpi}
%   are not yet implemented.% but patches are welcome
%}
%\section{S4 methods}{
%  All except \code{atan2} are S4 generic functions: methods can be defined
%  for them individually or via the
%  \code{\link[=S4groupGeneric]{Math}} group generic.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%
%  Abramowitz, M. and Stegun, I. A. (1972). \emph{Handbook of
%    Mathematical Functions}. New York: Dover.\cr
%  Chapter 4. Elementary Transcendental Functions: Logarithmic,
%  Exponential, Circular and Hyperbolic Functions
%
%  For \code{cospi}, \code{sinpi}, and \code{tanpi} the draft C11
%  extension ISO/IEC TS 18661
%  (\url{http://www.open-std.org/jtc1/sc22/wg14/www/docs/n1785.pdf}).
%}
%\examples{
%x <- seq(-3, 7, by = 1/8)
%tx <- cbind(x, cos(pi*x), cospi(x), sin(pi*x), sinpi(x),
%               tan(pi*x), tanpi(x), deparse.level=2)
%op <- options(digits = 4, width = 90) # for nice formatting
%head(tx)
%tx[ (x \%\% 1) \%in\% c(0, 0.5) ,]
%options(op)
%}
%\keyword{math}
%
\encoding{UTF8}
