% File src/library/base/man/agrep.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{agrep}
\alias{agrep}
\alias{agrepl}
\alias{fuzzy matching}
\alias{.amatch_bounds}
\alias{.amatch_costs}
\title{Approximate String Matching (Fuzzy Matching)}
\description{
\code{pattern} (第一引数)に近似的にマッチする物を
 \code{x} (第二引数)の各要素中から探す．一般化 Levenshtein 編集距離
(一つの文字列を他に変換するのに必要な挿入，除去，そして代入の重み付き
回数の最小値)を使う．
}
\usage{
agrep(pattern, x, max.distance = 0.1, costs = NULL,
      ignore.case = FALSE, value = FALSE, fixed = TRUE,
      useBytes = FALSE)

agrepl(pattern, x, max.distance = 0.1, costs = NULL,
       ignore.case = FALSE, fixed = TRUE, useBytes = FALSE)
}
\arguments{
  \item{pattern}{(\code{fixed = FALSE} に対して)
  マッチされるべき空でない文字列もしくは正規表現を含む文字列．

もし可能なら \code{\link{as.character}} により文字列に変換される．}
  \item{x}{マッチが探される文字列ベクトル．
もし可能なら \code{\link{as.character}} により文字列に変換される．}
  \item{max.distance}{マッチに許される最大距離．整数か，
 \emph{pattern} の長さの最大変換コスト倍の分数(対応分数を下回らない最小整数で置き換えられる)，
もしくは可能な以下の成分を持つリスト
    \describe{
      \item{\code{cost}:}{最大回数/マッチコストの分数(一般化 Levenshtein 距離)}
      \item{\code{all}:}{最大回数/全ての変換(挿入，削除そして代入)の分数}
      \item{\code{insertions}:}{最大回数/挿入の分数}
      \item{\code{deletions}:}{最大回数/削除の分数}
      \item{\code{substitutions}:}{最大回数/代入の分数}
    }
もし \code{cost} が与えられないと，\code{all} の既定値は 10\% であり，他の変換数
は既定で \code{all} を超えない．成分名は省略できる．
  }
  \item{costs}{\samp{insertions}, \samp{deletions} そして \samp{substitutions}
に部分的にマッチする名前を持つ数値ベクトルかリストで，
一般化 Levenshtein 距離を計算する際の対応コストを与える．
もしくは \code{NULL} (既定)で三種類の変換に同じ単位コストを与えることを意味する．
可能ならば \code{\link{as.integer}} を使い整数に変換される．}
  \item{ignore.case}{もし \code{FALSE} ならばパターンマッチングは大・小文字を区別する．
もし \code{TRUE} ならばマッチングの間区別しない．}
  \item{value}{もし \code{FALSE} なら，決定されたマッチの添字(整数)を含むベクトルが
返され，またもし \code{TRUE} ならばマッチした要素自体が返される．}
  \item{fixed}{論理値．もし \code{TRUE} (既定値)ならばパターンは(そのまま)逐語的にマッチされる．
さもなければ，それは正規表現としてマッチされる．}
  \item{useBytes}{論理値．多バイトロケールで比較は文字毎に行うか(既定値)バイト毎に
行うか．}
}
\details{
  Levenshtein 編集距離は近さの目安として使われる：
これは一つの文字列を他に変換する際に必要とされた挿入，削除そして代入の総回数
(もしかするとコストで重みをつけた)である．

これは Ville Laurikari (\url{http://laurikari.net/tre/}) の \code{tre} を
使い，MBCS 文字マッチングをサポートする．

\code{useBytes} の主要効果は不正な入力やうわべだけのマッチに関するエラーや警告
を避けることである．
これはマークされたエンコーディングによる入力の変換を禁止し，
もし \code{"bytes"} とマークされた入力が見つかれば強制される
( \code{\link{Encoding}} を見よ)．
}
\note{
  解説を不注意に読んだ者からそれに対するバグレポートがあるが，
これは \code{x} の各要素の部分文字列にマッチする(丁度 \code{\link{grep}} がそうするように)
のであって，要素全体にマッチするのでは無いことを注意しよう．
パッケージ \pkg{utils} 中の \code{\link{adist}} を参照せよ．これはオプションで
マッチした部分文字列のオフセットを返す．
}
\value{
  \code{agrep} はマッチした要素の添字を与えるベクトル．
もしくは，もし \code{value} が \code{TRUE} ならば，マッチした
要素(強制返還後で，名前以外の属性を保存しない)．

  \code{agrepl} は論理値ベクトルを返す．
}
\author{
  \R < 2.10.0 のオリジナルバージョンは David Meyer による．
  現在のバージョンは Brian Ripley と Kurt Hornik による．
}
\seealso{
  \code{\link{grep}}, \code{\link{adist}}.
}
\examples{
agrep("lasy", "1 lazy 2")
agrep("lasy", c(" 1 lazy 2", "1 lasy 2"), max = list(sub = 0))
agrep("laysy", c("1 lazy", "1", "1 LAZY"), max = 2)
agrep("laysy", c("1 lazy", "1", "1 LAZY"), max = 2, value = TRUE)
agrep("laysy", c("1 lazy", "1", "1 LAZY"), max = 2, ignore.case = TRUE)
}
\keyword{character}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/agrep.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{agrep}
%\alias{agrep}
%\alias{agrepl}
%\alias{fuzzy matching}
%\alias{.amatch_bounds}
%\alias{.amatch_costs}
%\title{Approximate String Matching (Fuzzy Matching)}
%\description{
%  Searches for approximate matches to \code{pattern} (the first argument)
%  within each element of the string \code{x} (the second argument) using
%  the generalized Levenshtein edit distance (the minimal possibly
%  weighted number of insertions, deletions and substitutions needed to
%  transform one string into another).
%}
%\usage{
%agrep(pattern, x, max.distance = 0.1, costs = NULL,
%      ignore.case = FALSE, value = FALSE, fixed = TRUE,
%      useBytes = FALSE)
%
%agrepl(pattern, x, max.distance = 0.1, costs = NULL,
%       ignore.case = FALSE, fixed = TRUE, useBytes = FALSE)
%}
%\arguments{
%  \item{pattern}{a non-empty character string or a character string
%    containing a regular expression (for \code{fixed = FALSE}) to be
%    matched.
%    Coerced by \code{\link{as.character}} to a string if possible.}
%  \item{x}{character vector where matches are sought.
%    Coerced by \code{\link{as.character}} to a character vector if
%    possible.}
%  \item{max.distance}{Maximum distance allowed for a match.  Expressed
%    either as integer, or as a fraction of the \emph{pattern} length
%    times the maximal transformation cost (will be replaced by the
%    smallest integer not less than the corresponding fraction), or a
%    list with possible components
%    \describe{
%      \item{\code{cost}:}{maximum number/fraction of match cost
%	(generalized Levenshtein distance)}
%      \item{\code{all}:}{maximal number/fraction of \emph{all}
%	transformations (insertions, deletions and substitutions)}
%      \item{\code{insertions}:}{maximum number/fraction of insertions}
%      \item{\code{deletions}:}{maximum number/fraction of deletions}
%      \item{\code{substitutions}:}{maximum number/fraction of
%        substitutions}
%    }
%    If \code{cost} is not given, \code{all} defaults to 10\%, and the
%    other transformation number bounds default to \code{all}.
%    The component names can be abbreviated.
%  }
%  \item{costs}{a numeric vector or list with names partially matching
%    \samp{insertions}, \samp{deletions} and \samp{substitutions} giving
%    the respective costs for computing the generalized Levenshtein
%    distance, or \code{NULL} (default) indicating using unit cost for
%    all three possible transformations.
%    Coerced to integer via \code{\link{as.integer}} if possible.}
%  \item{ignore.case}{if \code{FALSE}, the pattern matching is \emph{case
%      sensitive} and if \code{TRUE}, case is ignored during matching.}
%  \item{value}{if \code{FALSE}, a vector containing the (integer)
%    indices of the matches determined is returned and if \code{TRUE}, a
%    vector containing the matching elements themselves is returned.}
%  \item{fixed}{logical.  If \code{TRUE} (default), the pattern is
%    matched literally (as is).  Otherwise, it is matched as a regular
%    expression.}
%  \item{useBytes}{logical. in a multibyte locale, should the comparison
%    be character-by-character (the default) or byte-by-byte.}
%}
%\details{
%  The Levenshtein edit distance is used as measure of approximateness:
%  it is the (possibly cost-weighted) total number of insertions,
%  deletions and substitutions required to transform one string into
%  another.
%
%  This uses \code{tre} by Ville Laurikari
%  (\url{http://laurikari.net/tre/}), which supports MBCS
%  character matching.
%
%  The main effect of \code{useBytes} is to avoid errors/warnings about
%  invalid inputs and spurious matches in multibyte locales.
%  It inhibits the conversion of inputs with marked encodings, and is
%  forced if any input is found which is marked as \code{"bytes"} (see
%  \code{\link{Encoding}}).
%}
%\note{
%  Since someone who read the description carelessly even filed a bug
%  report on it, do note that this matches substrings of each element of
%  \code{x} (just as \code{\link{grep}} does) and \bold{not} whole
%  elements.  See also \code{\link{adist}} in package \pkg{utils}, which
%  optionally returns the offsets of the matched substrings.
%}
%\value{
%  \code{agrep} returns a vector giving the indices of the elements that
%  yielded a match, or, if \code{value} is \code{TRUE}, the matched
%  elements (after coercion, preserving names but no other attributes).
%
%  \code{agrepl} returns a logical vector.
%}
%\author{
%  Original version in \R < 2.10.0 by David Meyer.
%  Current version by Brian Ripley and Kurt Hornik.
%}
%\seealso{
%  \code{\link{grep}}, \code{\link{adist}}.
%}
%\examples{
%agrep("lasy", "1 lazy 2")
%agrep("lasy", c(" 1 lazy 2", "1 lasy 2"), max = list(sub = 0))
%agrep("laysy", c("1 lazy", "1", "1 LAZY"), max = 2)
%agrep("laysy", c("1 lazy", "1", "1 LAZY"), max = 2, value = TRUE)
%agrep("laysy", c("1 lazy", "1", "1 LAZY"), max = 2, ignore.case = TRUE)
%}
%\keyword{character}
%
\encoding{UTF8}
