% File src/library/base/man/attributes.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{attributes}
\title{Object Attribute Lists}
\alias{attributes}
\alias{attributes<-}
\alias{mostattributes<-}
\description{
これらの関数はオブジェクトの属性にアクセスする．
以下の最初の形式はオブジェクトの属性のリストを返す．
置き換え形は付値の右側のチストをオブジェクトの属性として
利用する(もし適切ならば)．
}
\usage{
attributes(obj)
attributes(obj) <- value
mostattributes(obj) <- value
}
\arguments{
  \item{obj}{オブジェクト}
  \item{value}{適当な名前付きの属性のリスト，または \code{NULL}．}
}
\details{
  \code{\link{attr}} とは異なり \code{NULL} オブジェクトに属性を設定することが出来る：
それは先ず空リストに強制変換される．

幾つかの属性(つまり\code{\link{class}},
  \code{\link{comment}}, \code{\link{dim}}, \code{\link{dimnames}},
  \code{\link{names}}, \code{\link{row.names}} そして
  \code{\link{tsp}})は特別な扱いがされ，設定できる値に制限がある．
 (これは \code{levels} 置き換え関数によって因子に対して設定されるべき 
  \code{\link{levels}} に対しては真ではないことを注意する．

属性は内部的にリストとして保管されておらず，ベクトルではなく集合と考えるべきである．
それらはユニークな名前を持つべきである(そして \code{NA} は \code{"NA"}
であり，欠損値ではない)．

属性の付値はまずすべての属性を取り除き．それから
 \code{dim} 属性，そして残りの属性を与えられた順に設定する：
 これは \code{dim} 属性の設定が常に \code{dimnames} 属性に先立つことを
 保証する．

\code{mostattributes} による付値は 
  \code{\link{dim}}, \code{\link{names}} そして \code{\link{dimnames}}
属性を特別に扱う．そして適正と確認できた時だけそれらを付値する．
一方 \code{attributes} による付値はどれかが不適切ならエラーを与える．
これは主として配列用であり，クラス付きオブジェクトに対しては慎重に
使うべきである．例えば，これは
 \code{\link{row.names}} がデータフレームに対して正しく付値されているかどうかを
チェックしない．

対リストの名前は属性としては保管されていないが，あたかもそうであるかのように
報告される(そして  \code{attributes} の置き換え形で設定できる)．

 \code{attributes} の両方の付値と置き換え形はプリミティブな関数である．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{\code{\link{attr}}.
}
\examples{
x <- cbind(a = 1:3, pi = pi) # 次元名を持つ簡単な行列
attributes(x)

## オブジェクトの属性を剥ぎ取る：
attributes(x) <- NULL
x # 今や長さ6のベクトル

mostattributes(x) <- list(mycomment = "really special", dim = 3:2,
   dimnames = list(LETTERS[1:3], letters[1:5]), names = paste(1:6))
x # dim()，しかし {dim}names では無い
}
\keyword{attribute}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/attributes.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{attributes}
%\title{Object Attribute Lists}
%\alias{attributes}
%\alias{attributes<-}
%\alias{mostattributes<-}
%\description{
%  These functions access an object's attributes.
%  The first form below returns the object's attribute list.
%  The replacement forms uses the list on the right-hand
%  side of the assignment as the object's attributes (if appropriate).
%}
%\usage{
%attributes(obj)
%attributes(obj) <- value
%mostattributes(obj) <- value
%}
%\arguments{
%  \item{obj}{an object}
%  \item{value}{an appropriate named list of attributes, or \code{NULL}.}
%}
%\details{
%  Unlike \code{\link{attr}} it is possible to set attributes on a
%  \code{NULL} object: it will first be coerced to an empty list.
%
%  Note that some attributes (namely \code{\link{class}},
%  \code{\link{comment}}, \code{\link{dim}}, \code{\link{dimnames}},
%  \code{\link{names}}, \code{\link{row.names}} and
%  \code{\link{tsp}}) are treated specially and have restrictions on
%  the values which can be set.  (Note that this is not true of
%  \code{\link{levels}} which should be set for factors via the
%  \code{levels} replacement function.)
%
%  Attributes are not stored internally as a list and should be thought
%  of as a set and not a vector.  They must have unique
%  names (and \code{NA} is taken as \code{"NA"}, not a missing value).
%
%  Assigning attributes first removes all attributes, then sets any
%  \code{dim} attribute and then the remaining attributes in the order
%  given: this ensures that setting a \code{dim} attribute always precedes
%  the \code{dimnames} attribute.
%
%  The \code{mostattributes} assignment takes special care for the
%  \code{\link{dim}}, \code{\link{names}} and \code{\link{dimnames}}
%  attributes, and assigns them only when known to be valid whereas an
%  \code{attributes} assignment would give an error if any are not.  It
%  is principally intended for arrays, and should be used with care on
%  classed objects.  For example, it does not check that
%  \code{\link{row.names}} are assigned correctly for data frames.
%
%  The names of a pairlist are not stored as attributes, but are reported
%  as if they were (and can be set by the replacement form of
%  \code{attributes}).
%
%  Both assignment and replacement forms of \code{attributes} are
%  \link{primitive} functions.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{\code{\link{attr}}.
%}
%\examples{
%x <- cbind(a = 1:3, pi = pi) # simple matrix with dimnames
%attributes(x)
%
%## strip an object's attributes:
%attributes(x) <- NULL
%x # now just a vector of length 6
%
%mostattributes(x) <- list(mycomment = "really special", dim = 3:2,
%   dimnames = list(LETTERS[1:3], letters[1:5]), names = paste(1:6))
%x # dim(), but not {dim}names
%}
%\keyword{attribute}
%
\encoding{UTF8}
