% File src/library/base/man/double.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{double}
\title{Double-Precision Vectors}
\alias{double}
\alias{as.double}
\alias{is.double}
\alias{single}
\alias{as.single}
\alias{as.single.default}
\description{
  倍精度実数ベクトルを作る，強制変換する，または検査する．
}
\usage{
double(length = 0)
as.double(x, \dots)
is.double(x)

single(length = 0)
as.single(x, \dots)
}
\arguments{
  \item{length}{希望の長さを指定する非負整数．
    倍精度値は整数に強制変換される：
    長さ1以外の引数を与えるのはエラーになる．}
  \item{x}{変換もしく検査されるオブジェクト．}
  \item{\dots}{他のメソッドに・から渡される追加引数．}
}
\details{
  \code{double} は指定された長さの倍精度実数ベクトルを作る．
  ベクトルの要素はすべて \code{0} に等しい．
  これは \code{\link{numeric}} と同等である．

  \code{as.double} は総称的関数である．これは
  \code{as.numeric} と同等である．メソッドは基本タイプ
  \code{"double"} のオブジェクトを返すべきである．

  \code{is.double} 倍精度型の検査関数である．

  \R は単精度データ型を持たない．すべての実数は倍精度書式で保管される．
  関数 \code{as.single} と \code{single} は属性 \code{Csingle} を
  設定することを除いて \code{as.double} 及び \code{double} と
  同等であり
  \code{\link{.C}} と \code{\link{.Fortran}} インタフェイスで使われるが，
  そうした文脈だけで使われることを意図している．
}
\value{
  \code{double} は指定された長さの倍精度実数ベクトルを作る．
  ベクトルの要素はすべて \code{0} に等しい．

  \code{as.double} はその引数を倍精度型に強制変換しようと試みる：
  \code{\link{as.vector}} と同様にこれは名前を含む属性を剥ぎ取る．
  (属性を取り除かずにオブジェクトを倍精度型にするには 
  \code{\link{storage.mode}} を使う．) オプションの空白に10進数表現か16進数表現
  (\code{0x} か \code{0X} で始まる)が続く文字列(大文字小文字にかかわらず)を
  変換することが出来，\code{"NA"}, \code{"NaN"}, \code{"Inf"} そして \code{"infinity"}
  といった特殊値も変換できる．

  因子に対する \code{as.double} は因子の水準の基礎にあるコードを
  作りだし，水準の数値表現ではない，\code{\link{factor}} も見よ．

  \code{is.double} はその引数が double 型かどうかに応じて \code{TRUE} か
  \code{FALSE} を取る．
}
\section{倍精度値}{
  すべての \R プラットフォームは
  IEC 60559 (IEEE 754 としても知られている)標準に準拠した値で動作することが
  要求されている．これは基本的に53ビットの精度で動作し，
  絶対値の範囲約 \eqn{2 \times 10^{-308}}{2e-308} から \eqn{2 \times 10^{308}}{2e+308}
  の精度を表現する．
  これは更に特殊値  \code{\link{NaN}} (何種類もある)，正負の無限大，正負のゼロ
  (\R はこれらを同じものとして扱う) を持つ． また絶対値が上の範囲の上や下にある
  \emph{非正規}(\emph{副正規})数があるが精度は劣る．

  これらの限界についての正確な情報は \code{\link{.Machine}} を見よ．
  倍精度実数がどのように扱われるかは最終的には
  CPU/FPU とコンパイラに任される．

  IEEE 754-2008/IEC60559:2011 ではこれは \sQuote{binary64} 書式と呼ばれる．
}
%% keep next the same in double.Rd & numeric.Rd
\section{名前に関する注意}{
  \R が浮動小数点ベクトルに対して
  \code{\link{double}} と \code{\link{numeric}}
  (そして以前は \code{real}) という二種類の名前を持つのには
  歴史的な混乱がある．

  \code{double} は \link{type} 名で，
  \code{numeric} は \link{mode} 名でまた暗黙のクラス 
  \link{class} である．S4 形式的クラスとしては \code{"numeric"} を使おう．

  可能性のある混乱は \R がモード
  \code{"numeric"} を\sQuote{倍精度実数か整数}の意味で使ってきたことで，
  これは S4 用法と矛盾する．このようにして \code{is.numeric} はクラスではなくモードを検査
  するが，\code{as.numeric} (これは \code{as.double} と同一)
  はそのクラスに強制変換する．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.

  \url{https://en.wikipedia.org/wiki/IEEE_754-1985},
  \url{https://en.wikipedia.org/wiki/IEEE_754-2008},
  \url{https://en.wikipedia.org/wiki/Double_precision},
  \url{https://en.wikipedia.org/wiki/Denormal_number}.

  標準に関する情報へのリンクは \url{http://grouper.ieee.org/groups/754/}．
}
\seealso{
  \code{\link{integer}}, \code{\link{numeric}}, \code{\link{storage.mode}}.
}
\examples{
is.double(1)
all(double(3) == 0)
}
\keyword{classes}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/double.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{double}
%\title{Double-Precision Vectors}
%\alias{double}
%\alias{as.double}
%\alias{is.double}
%\alias{single}
%\alias{as.single}
%\alias{as.single.default}
%\description{
%  Create, coerce to or test for a double-precision vector.
%}
%\usage{
%double(length = 0)
%as.double(x, \dots)
%is.double(x)
%
%single(length = 0)
%as.single(x, \dots)
%}
%\arguments{
%  \item{length}{A non-negative integer specifying the desired length.
%    Double values will be coerced to integer:
%    supplying an argument of length other than one is an error.}
%  \item{x}{object to be coerced or tested.}
%  \item{\dots}{further arguments passed to or from other methods.}
%}
%\details{
%  \code{double} creates a double-precision vector of the specified
%  length.  The elements of the vector are all equal to \code{0}.
%  It is identical to \code{\link{numeric}}.
%
%  \code{as.double} is a generic function.  It is identical to
%  \code{as.numeric}.  Methods should return an object of base type
%  \code{"double"}.
%
%  \code{is.double} is a test of double \link{type}.
%
%  \emph{\R has no single precision data type.  All real numbers are
%    stored in double precision format}.  The functions \code{as.single}
%  and \code{single} are identical to \code{as.double} and \code{double}
%  except they set the attribute \code{Csingle} that is used in the
%  \code{\link{.C}} and \code{\link{.Fortran}} interface, and they are
%  intended only to be used in that context.
%}
%\value{
%  \code{double} creates a double-precision vector of the specified
%  length.  The elements of the vector are all equal to \code{0}.
%
%  \code{as.double} attempts to coerce its argument to be of double type:
%  like \code{\link{as.vector}} it strips attributes including names.
%  (To ensure that an object is of double type without stripping
%  attributes, use \code{\link{storage.mode}}.)  Character strings
%  containing optional whitespace followed by either a decimal
%  representation or a hexadecimal representation (starting with
%  \code{0x} or \code{0X}) can be converted, as can special values such
%  as \code{"NA"}, \code{"NaN"}, \code{"Inf"} and \code{"infinity"},
%  irrespective of case.
%
%  \code{as.double} for factors yields the codes underlying the factor
%  levels, not the numeric representation of the labels, see also
%  \code{\link{factor}}.
%
%  \code{is.double} returns \code{TRUE} or \code{FALSE} depending on
%  whether its argument is of double \link{type} or not.
%}
%\section{Double-precision values}{
%  All \R platforms are required to work with values conforming to the
%  IEC 60559 (also known as IEEE 754) standard.  This basically works
%  with a precision of 53 bits, and represents to that precision a range
%  of absolute values from about \eqn{2 \times 10^{-308}}{2e-308} to
%  \eqn{2 \times 10^{308}}{2e+308}.  It also has special values
%  \code{\link{NaN}} (many of them), plus and minus infinity and plus and
%  minus zero (although \R acts as if these are the same).  There are
%  also \emph{denormal(ized)} (or \emph{subnormal}) numbers with absolute
%  values above or below the range given above but represented to less
%  precision.
%
%  See \code{\link{.Machine}} for precise information on these limits.
%  Note that ultimately how double precision numbers are handled is down
%  to the CPU/FPU and compiler.
%
%  In IEEE 754-2008/IEC60559:2011 this is called \sQuote{binary64} format.
%}
%%% keep next the same in double.Rd & numeric.Rd
%\section{Note on names}{
%  It is a historical anomaly that \R has two names for its
%  floating-point vectors, \code{\link{double}} and \code{\link{numeric}}
%  (and formerly had \code{real}).
%
%  \code{double} is the name of the \link{type}.
%  \code{numeric} is the name of the \link{mode} and also of the implicit
%  \link{class}.  As an S4 formal class, use \code{"numeric"}.
%
%  The potential confusion is that \R has used \emph{\link{mode}}
%  \code{"numeric"} to mean \sQuote{double or integer}, which conflicts
%  with the S4 usage.  Thus \code{is.numeric} tests the mode, not the
%  class, but \code{as.numeric} (which is identical to \code{as.double})
%  coerces to the class.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%
%  \url{https://en.wikipedia.org/wiki/IEEE_754-1985},
%  \url{https://en.wikipedia.org/wiki/IEEE_754-2008},
%  \url{https://en.wikipedia.org/wiki/Double_precision},
%  \url{https://en.wikipedia.org/wiki/Denormal_number}.
%
%  \url{http://grouper.ieee.org/groups/754/} for links to information
%  on the standards.
%}
%\seealso{
%  \code{\link{integer}}, \code{\link{numeric}}, \code{\link{storage.mode}}.
%}
%\examples{
%is.double(1)
%all(double(3) == 0)
%}
%\keyword{classes}
%
\encoding{UTF8}
