% File src/library/base/man/forceAndCall.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{forceAndCall}
\alias{forceAndCall}
\title{Call a function with Some Arguments Forced}
\description{
  もし関数が囲み環境である時，呼び出し前に指定された個数の先頭の引数を
  強制評価して関数を呼び出す．
}
\usage{
forceAndCall(n, FUN, ...)
}
\arguments{
  \item{n}{強制評価する先頭の引数の数．}
  \item{FUN}{呼び出す関数．}
  \item{\dots}{\code{FUN} への引数．}
}
\details{
  \code{forceAndCall} は \code{\dots} 中で指定された引数を持つ
  関数 \code{FUN} を呼び出す．もし \code{FUN} の値がクロージャなら
  関数への最初の \code{n} 個の引数が関数本体の実行前に評価される
  (つまり，それらの遅延評価予約が強制される)．
  もし \code{FUN} の値がプリミティブであれば
  呼び出し \code{FUN(\dots)} は通常の仕方で評価される．

  \code{forceAndCall} は \code{\link{apply}} のような，
  適用された関数が返す結果がその引数を取得するクロージャである時に，
  より合理的に振る舞う高次の関数を定義することを助けることを意図している．
}
\seealso{
  \code{\link{force}}, \code{\link{promise}}, \code{\link{closure}}.
}
\keyword{programming}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/forceAndCall.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{forceAndCall}
%\alias{forceAndCall}
%\title{Call a function with Some Arguments Forced}
%\description{
%  Call a function with a specified number of leading arguments forced
%  before the call if the function is a closure.
%}
%\usage{
%forceAndCall(n, FUN, ...)
%}
%\arguments{
%  \item{n}{number of leading arguments to force.}
%  \item{FUN}{function to call.}
%  \item{\dots}{arguments to \code{FUN}.}
%}
%\details{
%  \code{forceAndCall} calls the function \code{FUN} with arguments
%  specified in \code{\dots}.  If the value of \code{FUN} is a closure
%  then the first \code{n} arguments to the function are evaluated
%  (i.e. their delayed evaluation promises are forced) before executing
%  the function body.  If the value of \code{FUN} is a primitive then
%  the call \code{FUN(\dots)} is evaluated in the usual way.
%
%  \code{forceAndCall} is intended to help defining higher order
%  functions like \code{\link{apply}} to behave more reasonably when the
%  result returned by the function applied is a closure that captured its
%  arguments.
%}
%\seealso{
%  \code{\link{force}}, \code{\link{promise}}, \code{\link{closure}}.
%}
%\keyword{programming}
%
\encoding{UTF8}
