% File src/library/base/man/gctorture.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{gctorture}
\alias{gctorture}
\alias{gctorture2}
\alias{R_GCTORTURE}
\alias{R_GCTORTURE_WAIT}
\alias{R_GCTORTURE_INHIBIT_RELEASE}
\title{Torture Garbage Collector}
\usage{
gctorture(on = TRUE)
gctorture2(step, wait = step, inhibit_release = FALSE)
}
\arguments{
  \item{on}{論理値；それをオン/オフにする．}
  \item{step}{整数；GC をメモリ割り当て \code{step} 毎に実行する；
    \code{step = 0} は GC torture をオフにする．}
  \item{wait}{整数；GC torture を開始するまでに待つべきメモリ割り当ての数．}
  \item{inhibit_release}{論理値；再利用のためにフリーなオブジェクトを開放しない：
    注意して使うこと．}
}
\description{
  ガベージコレクションを(ほとんど)すべてのメモリ割り当て毎に起動する．
  メモリ保護のバグを探しだすことを意図している．不幸なことに，同時に
  \R の実行が非常に遅くなる．
}
\details{
  \code{gctorture(TRUE)} の呼び出しはメモリ管理器にすべてのメモリ
  割り当てのたびに完全な GC を矯正するように指示する．
  \code{gctorture2} はより改良されたインタフェイスを与え，
  GC torture の開始を遅らせたり，またメモリ割り当て \code{step} 毎に
  GC を実行するオプションを提供する．

  \code{gctorture2} の三つ目の引数は \R が strict write barrier を
  有効にしてコンフィギュアされている時だけ使われる．
  この場合すべてのガベージコレクションは完全回収で，メモリ管理器は
  フリーノードをマークし，フリーノードが使われた時エラー信号が出る多くの
  状況でチェックを可能にする．
  これは C コード中の保護されていない値を
  特定するのに非常に役立つ．ノードが自由になり再割り当てされるケースは
  検出されない．\code{inhibit_release} 引数はそうした再割り当てを禁止することに
  使うことが出来る．これは使用メモリの増加を招き，注意深くそしてプロセスメモリ
  使用量を監視し制限する OS の機能との関連で使うべきである．

  \code{gctorture2} はまた \R セッションの開始時に環境変数経由で
  起動できる．\env{R_GCTORTURE} は \code{step} 引数に，\env{R_GCTORTURE_WAIT}
  は \code{wait} に，そして
  \env{R_GCTORTURE_INHIBIT_RELEASE} は \code{inhibit_release} に対応する．
}
\value{
  最初の引数の前の値．
}
\author{Peter Dalgaard and Luke Tierney}
\keyword{environment}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/gctorture.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{gctorture}
%\alias{gctorture}
%\alias{gctorture2}
%\alias{R_GCTORTURE}
%\alias{R_GCTORTURE_WAIT}
%\alias{R_GCTORTURE_INHIBIT_RELEASE}
%\title{Torture Garbage Collector}
%\usage{
%gctorture(on = TRUE)
%gctorture2(step, wait = step, inhibit_release = FALSE)
%}
%\arguments{
%  \item{on}{logical; turning it on/off.}
%  \item{step}{integer; run GC every \code{step} allocations; \code{step
%      = 0} turns the GC torture off.}
%  \item{wait}{integer; number of allocations to wait before starting
%    GC torture.}
%  \item{inhibit_release}{logical; do not release free objects for
%    re-use: use with caution.}
%}
%\description{
%  Provokes garbage collection on (nearly) every memory allocation.
%  Intended to ferret out memory protection bugs.  Also makes \R run
%  \emph{very} slowly, unfortunately.
%}
%\details{
%  Calling \code{gctorture(TRUE)} instructs the memory manager to force a
%  full GC on every allocation. \code{gctorture2} provides a more refined
%  interface that allows the start of the GC torture to be deferred and
%  also gives the option of running a GC only every \code{step}
%  allocations.
%
%  The third argument to \code{gctorture2} is only used if R has been
%  configured with a strict write barrier enabled.  When this is the case
%  all garbage collections are full collections, and the memory manager
%  marks free nodes and enables checks in many situations that signal an
%  error when a free node is used.  This can help greatly in isolating
%  unprotected values in C code.  It does not detect the case where a
%  node becomes free and is reallocated.  The \code{inhibit_release}
%  argument can be used to prevent such reallocation.  This will cause
%  memory to grow and should be used with caution and in conjunction with
%  operating system facilities to monitor and limit process memory use.
%
%  \code{gctorture2} can also be invoked via environment variables at the
%  start of the \R session.  \env{R_GCTORTURE} corresponds to the
%  \code{step} argument, \env{R_GCTORTURE_WAIT} to \code{wait}, and
%  \env{R_GCTORTURE_INHIBIT_RELEASE} to \code{inhibit_release}.
%}
%\value{
%  Previous value of first argument.
%}
%\author{Peter Dalgaard and Luke Tierney}
%\keyword{environment}
%
%
\encoding{UTF8}
