% File src/library/base/man/lazyload.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{lazyLoad}
\alias{lazyLoad}
\alias{lazyLoadDBexec}
\title{Lazy Load a Database of R Objects}
\description{
  \R オブジェクトのデータベースを遅延ロードする内部関数．
}
\usage{
lazyLoad(filebase, envir = parent.frame(), filter)
lazyLoadDBexec(filebase, fun, filter)
}
\arguments{
  \item{filebase}{データベースへのファイルパスで拡張子を持たない．}
  \item{envir}{オブジェクトがロードされる環境．}
  \item{filter}{オプションの関数で，オブジェクト名の文字列ベクトルに
  対して呼び出されると論理値ベクトルを返す：
    これが真であるオブジェクトだけがロードされる．}
  \item{fun}{環境を一つの引数に持つ関数．}
}
\details{
  これらは \R 自体だけにより使われる内部関数である．

  関数 \code{lazyLoad} はデータベースからパッケージ用のコードを
  ロードするパッケージローダーから呼び出される実働関数である．
  データベースは二つのバイナリファイル \file{\var{filebase}.rdb} (オブジェクト)
  と \file{\var{filebase}.rdx} (索引)からなる．

  オブジェクトはそれ自体は \code{envir} にロードされない：
  代わりに最初にアクセスされた時データベースからオブジェクトをロードする
  予約が作られる．
  (\code{\link{delayedAssign}} を見よ．)

  関数 \code{lazyLoadDBexec} はコアになる実装を含み，
  処理されたヘルプファイルデータに対する機構でも使われる．
}
\author{Luke Tierney}
\keyword{internal}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/lazyload.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{lazyLoad}
%\alias{lazyLoad}
%\alias{lazyLoadDBexec}
%\title{Lazy Load a Database of R Objects}
%\description{
%  Internal functions to lazy load a database of \R objects.
%}
%\usage{
%lazyLoad(filebase, envir = parent.frame(), filter)
%lazyLoadDBexec(filebase, fun, filter)
%}
%\arguments{
%  \item{filebase}{The file path to the database, with no extension.}
%  \item{envir}{The environment into which objects are loaded.}
%  \item{filter}{An optional function which when called on a a character
%    vector of object names returns a logical vector: only objects for
%    which this is true will be loaded.}
%  \item{fun}{Function of one argument, an environment.}
%}
%\details{
%  These are internal functions for use only by \R itself.
%
%  The function \code{lazyLoad} is the workhorse function called by the
%  package loader to load the code for a package from a database.  The
%  database consists of two binary files, \file{\var{filebase}.rdb} (the
%  objects) and \file{\var{filebase}.rdx} (an index).
%
%  The objects are not themselves loaded into \code{envir}: rather
%  promises are created that will load the object from the database on
%  first access.  (See \code{\link{delayedAssign}}.)
%
%  The function \code{lazyLoadDBexec} contains the core implementation
%  and is also used by the mechanism for loading processed help file
%  data.
%}
%\author{Luke Tierney}
%\keyword{internal}
%
\encoding{UTF8}
