% File src/library/base/man/levels.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2010 R Core Team
% Distributed under GPL 2 or later

\name{levels}
\alias{levels}
\alias{levels.default}
\alias{levels<-}
\alias{levels<-.factor}
\title{Levels Attributes}
\description{
  \code{levels} は変数の水準属性へのアクセスを提供する．
  最初の形式はその引数の水準の値を返す．
  二つ目は属性を設定する．
}
\usage{
levels(x)
levels(x) <- value
}
\arguments{
  \item{x}{オブジェクト，例えば因子．}
  \item{value}{\code{levels(x)} に対する適正な値．
    既定のメソッドに対しては \code{NULL} か文字列ベクトル．
    \code{factor} メソッドに対しては長さが少なくとも \code{x} の水準数の
    文字列ベクトル．もしくは水準をどのように改名するかを指示する名前付きリスト．}
}
\details{
  抽出と置き換え形式は共に総称的でそれらに対して新しいメソッドを書くことが出来る．
  置き換え関数に対する最も重要なメソッドは因子に対するそれである．

  因子置き換えメソッドに対しては \code{value} 中の \code{NA} は 
  水準からその水準を取り除き，その水準を前に持っていた要素は
  \code{NA} で置き換えられる．

  因子に対しては水準を
  \code{levels(x) <- value} で置き換えることは
  \code{attr(x, "levels") <- value} と同値ではない(そしてより好ましい)．
  

  置き換え関数はプリミティブである．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{nlevels}}, \code{\link{relevel}}, \code{\link{reorder}}.
}
\examples{
## 個別の水準を付値
x <- gl(2, 4, 8)
levels(x)[1] <- "low"
levels(x)[2] <- "high"
x

## またはグループとして
y <- gl(2, 4, 8)
levels(y) <- c("low", "high")
y

## 幾つかの水準を連結
z <- gl(3, 2, 12)
levels(z) <- c("A", "B", "A")
z

## 同じ，名前付きリストを使う
z <- gl(3, 2, 12)
levels(z) <- list(A = c(1,3), B = 2)
z

## 水準を次のようにして加えられる：
f <- factor(c("a","b"))
levels(f) <- c("c", "a", "b")
f

f <- factor(c("a","b"))
levels(f) <- list(C = "C", A = "a", B = "b")
f
}
\keyword{category}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/levels.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2010 R Core Team
%% Distributed under GPL 2 or later
%
%\name{levels}
%\alias{levels}
%\alias{levels.default}
%\alias{levels<-}
%\alias{levels<-.factor}
%\title{Levels Attributes}
%\description{
%  \code{levels} provides access to the levels attribute of a variable.
%  The first form returns the value of the levels of its argument
%  and the second sets the attribute.
%}
%\usage{
%levels(x)
%levels(x) <- value
%}
%\arguments{
%  \item{x}{an object, for example a factor.}
%  \item{value}{A valid value for \code{levels(x)}.
%    For the default method, \code{NULL} or a character vector.  For the
%    \code{factor} method, a vector of character strings with length at
%    least the number of levels of \code{x}, or a named list specifying how to
%    rename the levels.}
%}
%\details{
%  Both the extractor and replacement forms are generic and new methods
%  can be written for them.  The most important method for the replacement
%  function is that for \code{\link{factor}}s.
%
%  For the factor replacement method, a \code{NA} in \code{value}
%  causes that level to be removed from the levels and the elements
%  formerly with that level to be replaced by \code{NA}.
%
%  Note that for a factor, replacing the levels via
%  \code{levels(x) <- value} is not the same as (and is preferred to)
%  \code{attr(x, "levels") <- value}.
%
%  The replacement function is \link{primitive}.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{nlevels}}, \code{\link{relevel}}, \code{\link{reorder}}.
%}
%\examples{
%## assign individual levels
%x <- gl(2, 4, 8)
%levels(x)[1] <- "low"
%levels(x)[2] <- "high"
%x
%
%## or as a group
%y <- gl(2, 4, 8)
%levels(y) <- c("low", "high")
%y
%
%## combine some levels
%z <- gl(3, 2, 12)
%levels(z) <- c("A", "B", "A")
%z
%
%## same, using a named list
%z <- gl(3, 2, 12)
%levels(z) <- list(A = c(1,3), B = 2)
%z
%
%## we can add levels this way:
%f <- factor(c("a","b"))
%levels(f) <- c("c", "a", "b")
%f
%
%f <- factor(c("a","b"))
%levels(f) <- list(C = "C", A = "a", B = "b")
%f
%}
%\keyword{category}
%
\encoding{UTF8}
