% File src/library/base/man/load.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{load}
\alias{load}
\title{Reload Saved Datasets}
\description{
  関数 \code{save} を用いて書かれたデータセットを再ロードする．
}
\usage{
load(file, envir = parent.frame(), verbose = FALSE)
}
\arguments{
  \item{file}{(読みだし可能でバイナリーモードの)コネクションかロードする
    ファイルの名前を与える文字列(チルド展開がされた時)．}
  \item{envir}{データをロードすべき環境．}
  \item{verbose}{ロード中に項目名をプリントするか?}
}
\details{
  \code{load} は現在もしくは以前の書式で保存された \R オブジェクトをロードできる．
  それは圧縮ファイル(\code{\link{save}} を見よ)をファイルから直接に，又は
  適当なコネクション(\code{\link{url}} への呼び出しを含む)からロードできる．

  未だ開かれていないコネクションはモード \code{"rb"} で開かれ，使用後は閉じられる．
  \code{\link{gzfile}} か \code{\link{gzcon}} コネクション以外の
  コネクションは圧縮保管が処理できるように \code{\link{gzcon}} 中に
  ラップされる：これはコネクションを変更された状態(特にバイナリオンリー)に
  したままにし，明示的に閉じられる必要がある
  (これはガベージコレクションされない)．

  現在の書式(\R 1.4.0 以来使用)で保存された \R オブジェクトだけが
  コネクションから読み取れる．コネクション上に入力がなければ
  警告が与えられるが，現在の書式出ない入力はエラーになる．

  以前のバージョンからのロードは\sQuote{マジックナンバー}に関する警告を
  与える：マジックナンバー \code{1971:1977} は \R < 0.99.0 のもので，
  \code{RD[ABX]1} は \R 0.99.0 から \R 1.3.1 までのものである．これらは
  全て時代遅れであり，現在の書式で再保存することを強く勧める．

  \code{verbose} 引数は主にデバッグ用を意図している．
  もしそれが \code{TRUE} ならば，オブジェクトがファイルからロードされるにつれ，
  それらの名前がコンソールにプリントされる．もし \code{verbose} が1より大きな
  整数に設定されると，属性に対応する追加の名前と個別のオブジェクトの他の部分も
  プリントされる．
  値が大きければ名前のより詳細がプリントされる．

  オブジェクトは，普通関数や公式の環境の一部として，名前空間への参照付きで保存できる．
  \R 3.1.0 以来そうしたオブジェクトは名前空間が利用できなくてもロードできるようになった：
  それは警告付きで大局的環境への参照に置き換えられる．
  警告はそうした参照を持つ最初のオブジェクトを特定する(しかし一つ以上あるかもしれない)．
}
\value{
  作られたオブジェクトの名前の文字列ベクトルで不可視．
}
\section{警告}{
  保存された \R オブジェクトは \code{ascii = TRUE}
  で保存した時すらバイナリーファイルであり，それらが行末マーカーの変換無しに
  移されることを保証する．\code{load} はそうした変換の検出を試み，
  情報付きのエラーメッセージを与える．

  \code{load(<file>)} は現在の環境(典型的に作業スペース \code{\link{.GlobalEnv}})
  中の同名の既存オブジェクトを置き換えるので，重要なデータを
  上書きする潜在的な可能性がある．
  \code{envir = } を使って異なった環境にロードするか，
  検索パス中の新しい項目にロードする \code{\link{attach}(file)} の使用が
  かなりより安全である．
}
#ifdef windows
\note{
  \code{file} は現在のロケールに翻訳されない UTF-8 でエンコードされたファイルパス
  かもしれない．
}
#endif
\seealso{
  \code{\link{save}}, \code{\link{download.file}}; 更に
  \code{load()} に対するラッパとしての \code{\link{attach}}．

  基礎にあるシリアル化書式への他のインタフェイスに付いては
  \code{\link{unserialize}} と \code{\link{readRDS}} を見よ．
}
\examples{
## 全てのデータを保存する
xx <- pi # データがあるかどうか確認するため
save(list = ls(all = TRUE), file= "all.RData")
rm(xx)

## 保存されたデータを現在の環境に復元
local({
   load("all.RData")
   ls()
})

xx <- exp(1:3)
## 保存データをユーザの作業空間に復元
load("all.RData") ## ここではこれは次と同値
## load("all.RData", .GlobalEnv)
## しかしながらこれは .GlobalEnv 中の同名オブジェクトを全て抹殺する!
xx # no longer exp(1:3)
rm(xx)
attach("all.RData") # より安全，.GlobalEnv 中の隠蔽される同名のオブジェクトを警告
ls(pos = 2)
##  また典型的には検索パスを掃除する必要がある
detach("file:all.RData")

## 掃除(一例):
unlink("all.RData")

\dontrun{
con <- url("http://some.where.net/R/data/example.rda")
## どのようなオブジェクトが作られたか見るために値をプリント
print(load(con))
close(con) # url() は常にコネクションを開く
}}
\keyword{file}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/load.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{load}
%\alias{load}
%\title{Reload Saved Datasets}
%\description{
%  Reload datasets written with the function \code{save}.
%}
%\usage{
%load(file, envir = parent.frame(), verbose = FALSE)
%}
%\arguments{
%  \item{file}{a (readable binary-mode) \link{connection} or a character string
%    giving the name of the file to load (when \link{tilde expansion}
%    is done).}
%  \item{envir}{the environment where the data should be loaded.}
%  \item{verbose}{should item names be printed during loading?}
%}
%\details{
%  \code{load} can load \R objects saved in the current or any earlier
%  format.  It can read a compressed file (see \code{\link{save}})
%  directly from a file or from a suitable connection (including a call
%  to \code{\link{url}}).
%
%  A not-open connection will be opened in mode \code{"rb"} and closed
%  after use.  Any connection other than a \code{\link{gzfile}} or
%  \code{\link{gzcon}} connection will be wrapped in \code{\link{gzcon}}
%  to allow compressed saves to be handled: note that this leaves the
%  connection in an altered state (in particular, binary-only), and that
%  it needs to be closed explicitly (it will not be garbage-collected).
%
%  Only \R objects saved in the current format (used since \R 1.4.0)
%  can be read from a connection.  If no input is available on a
%  connection a warning will be given, but any input not in the current
%  format will result in a error.
%
%  Loading from an earlier version will give a warning about the
%  \sQuote{magic number}: magic numbers \code{1971:1977} are from \R <
%  0.99.0, and \code{RD[ABX]1} from \R 0.99.0 to \R 1.3.1.  These are all
%  obsolete, and you are strongly recommended to re-save such files in a
%  current format.
%
%  The \code{verbose} argument is mainly intended for debugging.  If it
%  is \code{TRUE}, then as objects from the file are loaded, their
%  names will be printed to the console.  If \code{verbose} is set to
%  an integer value greater than one, additional names corresponding to
%  attributes and other parts of individual objects will also be printed.
%  Larger values will print names to a greater depth.
%
%  Objects can be saved with references to namespaces, usually as part of
%  the environment of a function or formula.  As from \R 3.1.0 such
%  objects can be loaded even if the namespace is not available: it is
%  replaced by a reference to the global environment with a warning.  The
%  warning identifies the first object with such a reference (but there
%  may be more than one).
%}
%\value{
%  A character vector of the names of objects created, invisibly.
%}
%\section{Warning}{
%  Saved \R objects are binary files, even those saved with
%  \code{ascii = TRUE}, so ensure that they are transferred without
%  conversion of end of line markers.  \code{load} tries to detect such a
%  conversion and gives an informative error message.
%
%  \code{load(<file>)} replaces all existing objects with the same names
%  in the current environment (typically your workspace,
%  \code{\link{.GlobalEnv}}) and hence potentially overwrites important data.
%  It is considerably safer to use \code{envir = } to load into a
%  different environment, or to \code{\link{attach}(file)} which
%  \code{load()}s into a new entry in the \code{\link{search}} path.
%}
%#ifdef windows
%\note{
%  \code{file} can be a UTF-8-encoded filepath that cannot be translated to
%  the current locale.
%}
%#endif
%\seealso{
%  \code{\link{save}}, \code{\link{download.file}}; further
%  \code{\link{attach}} as wrapper for \code{load()}.
%
%  For other interfaces to the underlying serialization format, see
%  \code{\link{unserialize}} and \code{\link{readRDS}}.
%}
%\examples{
%## save all data
%xx <- pi # to ensure there is some data
%save(list = ls(all = TRUE), file= "all.RData")
%rm(xx)
%
%## restore the saved values to the current environment
%local({
%   load("all.RData")
%   ls()
%})
%
%xx <- exp(1:3)
%## restore the saved values to the user's workspace
%load("all.RData") ## which is here *equivalent* to
%## load("all.RData", .GlobalEnv)
%## This however annihilates all objects in .GlobalEnv with the same names !
%xx # no longer exp(1:3)
%rm(xx)
%attach("all.RData") # safer and will warn about masked objects w/ same name in .GlobalEnv
%ls(pos = 2)
%##  also typically need to cleanup the search path:
%detach("file:all.RData")
%
%## clean up (the example):
%unlink("all.RData")
%
%\dontrun{
%con <- url("http://some.where.net/R/data/example.rda")
%## print the value to see what objects were created.
%print(load(con))
%close(con) # url() always opens the connection
%}}
%\keyword{file}
%
\encoding{UTF8}
