% File src/library/base/man/raw.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2004-2014 R Core Team
% Distributed under GPL 2 or later

\name{raw}
\alias{raw}
\alias{as.raw}
\alias{is.raw}
\title{Raw Vectors}
\description{
  型 \code{"raw"} のオブジェクトを作る，検査する．
}
\usage{
raw(length = 0)
as.raw(x)
is.raw(x)
}
\arguments{
  \item{length}{希望の長さ．}
  \item{x}{強制変換されるオブジェクト．}
}
\value{
  \code{raw} は指定された長さのバイト型ベクトルを作る．
  ベクトルの各要素は \code{0} に等しい．
  バイト型ベクトルは固定長のバイト列を保持するのに使われる．

  \code{as.raw} はその引数をバイト型に強制変換しようと試みる．
  (要素毎の)答は変換が成功しない限り \code{0} になる
  (もしくは元の値が正当に 0 に変換されても)．

  \code{is.raw} は \code{typeof(x) == "raw"} の時，そしてその時だけ
  真を返す．
}
\details{
  バイト型は生のバイトを保持することを意図している．
  バイト列の部分列を取り出すこと，要素を置き換える
  (しかしバイト型ベクトルの要素によってだけ)ことが出来る．
  関係演算子(\link{Comparison} を見よ，バイト表現の数値的順序を使う)
  がビット毎の論理演算子(\link{Logic} を見よ)のように提供できる．

  バイト型ベクトルは各バイトが個別に16進数の対としてプリントできる．
  もし文字表現が欲しければ(プリント不可能な文字はエスケープ列として)
  \code{\link{rawToChar}} を使う．

  バイト型への変換は入力値を小さな(10進法)整数として表現されているとして扱うので，
  入力は先ず整数に変換され，それから範囲 \code{[0 \dots 255]} 外や
  \code{NA} が \code{0} (\code{nul} バイト)とされる．

  \code{as.raw} と \code{is.raw} はプリミティブな関数である．
}
\seealso{
  \code{\link{charToRaw}}, \code{\link{rawShift}} 等．

  バイト型ベクトルに対するビット毎の演算には \code{\link{&}}．
}
\examples{
xx <- raw(2)
xx[1] <- as.raw(40)     # NB, 丁度 40 では無い.
xx[2] <- charToRaw("A")
xx

x <- "A test string"
(y <- charToRaw(x))
is.vector(y) # TRUE
rawToChar(y)
is.raw(x)
is.raw(y)

isASCII <-  function(txt) all(charToRaw(txt) <= as.raw(127))
isASCII(x)  # true
isASCII("\x9c25.63") # false (Latin-1 ではこれは UK ポンドでの額になる)
}
\keyword{classes}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/raw.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2004-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{raw}
%\alias{raw}
%\alias{as.raw}
%\alias{is.raw}
%\title{Raw Vectors}
%\description{
%  Creates or tests for objects of type \code{"raw"}.
%}
%\usage{
%raw(length = 0)
%as.raw(x)
%is.raw(x)
%}
%\arguments{
%  \item{length}{desired length.}
%  \item{x}{object to be coerced.}
%}
%\value{
%  \code{raw} creates a raw vector of the specified length.
%  Each element of the vector is equal to \code{0}.
%  Raw vectors are used to store fixed-length sequences of bytes.
%
%  \code{as.raw} attempts to coerce its argument to be of raw
%  type.  The (elementwise) answer will be \code{0} unless the
%  coercion succeeds (or if the original value successfully coerces to 0).
%
%  \code{is.raw} returns true if and only if \code{typeof(x) == "raw"}.
%}
%\details{
%  The raw type is intended to hold raw bytes.  It is possible to extract
%  subsequences of bytes, and to replace elements (but only by elements
%  of a raw vector).  The relational operators (see \link{Comparison},
%  using the numerical order of the byte representation) work, as do the
%  logical operators (see \link{Logic}) with a bitwise interpretation.
%
%  A raw vector is printed with each byte separately represented as a
%  pair of hex digits.  If you want to see a character representation
%  (with escape sequences for non-printing characters) use
%  \code{\link{rawToChar}}.
%
%  Coercion to raw treats the input values as representing small
%  (decimal) integers, so the input is first coerced to integer, and then
%  values which are outside the range \code{[0 \dots 255]} or are
%  \code{NA} are set to \code{0} (the \code{nul} byte).
%
%  \code{as.raw} and \code{is.raw} are \link{primitive} functions.
%}
%\seealso{
%  \code{\link{charToRaw}}, \code{\link{rawShift}}, etc.
%
%  \code{\link{&}} for bitwise operations on raw vectors.
%}
%\examples{
%xx <- raw(2)
%xx[1] <- as.raw(40)     # NB, not just 40.
%xx[2] <- charToRaw("A")
%xx
%
%x <- "A test string"
%(y <- charToRaw(x))
%is.vector(y) # TRUE
%rawToChar(y)
%is.raw(x)
%is.raw(y)
%
%isASCII <-  function(txt) all(charToRaw(txt) <= as.raw(127))
%isASCII(x)  # true
%isASCII("\x9c25.63") # false (in Latin-1, this is an amount in UK pounds)
%}
%\keyword{classes}
%
\encoding{UTF8}
