% File src/library/base/man/row.names.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2010 R Core Team
% Distributed under GPL 2 or later

\name{row.names}
\title{Get and Set Row Names for Data Frames}
\alias{row.names}
\alias{row.names.data.frame}
\alias{row.names.default}
\alias{row.names<-}
\alias{row.names<-.data.frame}
\alias{row.names<-.default}
\description{
  全てのデータフレームは行名属性を持つ．これは行数の長さの文字列ベクトルで
  重複や欠損は無い．

  便宜上これらは総称的な関数でユーザは他のメソッドを書くことが出来，
  配列に対する既定メソッドがある．
  ここでの説明はデータフレーム用のメソッドに対するものである．
}
\usage{
row.names(x)
row.names(x) <- value
}
\arguments{
  \item{x}{クラス \code{"data.frame"} のオブジェクト，又はメソッドが
    定義されている任意の他のクラス．}
  \item{value}{整数ベクトルで無い限り文字列に強制変換されるオブジェクト．
    これは(強制変換後に) \code{x} の行数と同じ長さを持ち，
    重複したり欠損した値があってはならない．
    \code{NULL} は許される：\sQuote{詳細}を見よ．}
}
\details{
  データフレームは(定義から)\emph{行名}を持ち，これは
  データフレームの行数の長さを持ち，欠損値や重複値を含んではならない．
  この要求を満たす行名がソフトウェアにより加えられれば，
  それらは \sQuote{automatic} と見做される．

  現在行名には整数か文字列が許されているが，
  過去との互換性のため(\R <= 2.4.0)，\code{row.names} は
  常に文字列ベクトルを返す．(もし整数値の行名のセットが
  欲しければ \code{attr(x, "row.names")} を使う．)

  値に対して \code{NULL} を使うと行名を
  \code{seq_len(nrow(x))} にリセットし，\sQuote{automatic} と見做される.
}
\value{
  \code{row.names} は文字列ベクトルを返す．

  \code{row.names<-} は行名が変更されたデータフレームを返す．
}
\note{
  \code{row.names} は配列に対する \code{\link{rownames}} に類似し，
  これは配列引数に対して \code{rownames} を呼び出すメソッドを持つ．

  \code{n > 2} に対して形式 \code{1:n} を持つ行名が内部的に
  コンパクトな形式で保管される．これらは C コードや逆構文解析で
  見ることができるが，\code{row.names} や \code{\link{attr}(x, "row.names")}
  では出来ない．
  加えてある種のこのタイプの名前は
  \sQuote{automatic} とマークされ，
  \code{\link{as.matrix}} と \code{\link{data.matrix}} (そして可能性として
  他の関数)により異なった扱いを受ける．
  (全ての列数がゼロのデータフレームは automatic row.names を持つと
  見做される．)
}
\references{
  Chambers, J. M. (1992)
  \emph{Data for models.}
  Chapter 3 of \emph{Statistical Models in S}
  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{data.frame}}, \code{\link{rownames}}, \code{\link{names}}.

  内部表現については \code{.row_names_info}．
}
\keyword{classes}
\keyword{methods}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/row.names.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2010 R Core Team
%% Distributed under GPL 2 or later
%
%\name{row.names}
%\title{Get and Set Row Names for Data Frames}
%\alias{row.names}
%\alias{row.names.data.frame}
%\alias{row.names.default}
%\alias{row.names<-}
%\alias{row.names<-.data.frame}
%\alias{row.names<-.default}
%\description{
%  All data frames have a row names attribute, a character vector of
%  length the number of rows with no duplicates nor missing values.
%
%  For convenience, these are generic functions for which users can write
%  other methods, and there are default methods for arrays.  The
%  description here is for the \code{data.frame} method.
%}
%\usage{
%row.names(x)
%row.names(x) <- value
%}
%\arguments{
%  \item{x}{object of class \code{"data.frame"}, or any other class for
%    which a method has been defined.}
%  \item{value}{an object to be coerced to character unless an integer
%    vector.  It should have (after coercion) the same length as the
%    number of rows of \code{x} with no duplicated nor missing values.
%    \code{NULL} is also allowed: see \sQuote{Details}.}
%}
%\details{
%  A data frame has (by definition) a vector of \emph{row names} which
%  has length the number of rows in the data frame, and contains neither
%  missing nor duplicated values.  Where a row names sequence has been
%  added by the software to meet this requirement, they are regarded as
%  \sQuote{automatic}.
%
%  Row names are currently allowed to be integer or character, but
%  for backwards compatibility (with \R <= 2.4.0) \code{row.names} will
%  always return a character vector.  (Use \code{attr(x, "row.names")} if
%  you need to retrieve an integer-valued set of row names.)
%
%  Using \code{NULL} for the value resets the row names to
%  \code{seq_len(nrow(x))}, regarded as \sQuote{automatic}.
%}
%\value{
%  \code{row.names} returns a character vector.
%
%  \code{row.names<-} returns a data frame with the row names changed.
%}
%\note{
%  \code{row.names} is similar to \code{\link{rownames}} for arrays, and
%  it has a method that calls \code{rownames} for an array argument.
%
%  Row names of the form \code{1:n} for \code{n > 2} are stored
%  internally in a compact form, which might be seen from C code or by
%  deparsing but never via \code{row.names} or
%  \code{\link{attr}(x, "row.names")}.  Additionally, some names of this
%  sort are marked as \sQuote{automatic} and handled differently by
%  \code{\link{as.matrix}} and \code{\link{data.matrix}} (and potentially
%  other functions).  (All zero-row data frames are regarded as having
%  automatic row.names.)
%}
%\references{
%  Chambers, J. M. (1992)
%  \emph{Data for models.}
%  Chapter 3 of \emph{Statistical Models in S}
%  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{data.frame}}, \code{\link{rownames}}, \code{\link{names}}.
%
%  \code{.row_names_info} for the internal representations.
%}
%\keyword{classes}
%\keyword{methods}
%
\encoding{UTF8}
