% File src/library/base/man/scan.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{scan}
\title{Read Data Values}
\alias{scan}
\description{
  コンソールかファイルからデータをベクトルやリストに読み込む．
}
\usage{
scan(file = "", what = double(), nmax = -1, n = -1, sep = "",
     quote = if(identical(sep, "\n")) "" else "'\"", dec = ".",
     skip = 0, nlines = 0, na.strings = "NA",
     flush = FALSE, fill = FALSE, strip.white = FALSE,
     quiet = FALSE, blank.lines.skip = TRUE, multi.line = TRUE,
     comment.char = "", allowEscapes = FALSE,
     fileEncoding = "", encoding = "unknown", text, skipNul = FALSE)
}
\arguments{
  \item{file}{データ値をそこから読み取るファイルの名前．もし
    指定されたファイルが \code{""} なら入力はキーボードから取られる
    (または，もし入力がリダイレクトされているか \R が埋め込みならば
    \code{\link{stdin}()} が読み取るもの)．
    (この場合入力は空白行か EOF シグナルで終了できる．EOF シグナルは
    Unix では \samp{Ctrl-D} で Windows では \samp{Ctrl-Z}．)

    さもなければ，
    それが\emph{絶対}パスを指定していない限りファイル名は現在のディレクトリ
    (\code{\link{getwd}()} で与えられる)と\emph{相対的}と解釈される．

    サポートされていればチルダ展開がされる．
    \R がスクリプトから実行されていれば，\code{file = "stdin"} が
    プロセスの \code{stdin} ファイルストリームを参照するのに使うことが出来る．

    これは圧縮ファイルでもよい(\code{\link{file}} を見よ)．

    別法として \code{file} は必要なら開かれるコネクションでもよく，
    そしてもしそうならば関数呼び出しの最後に閉じられる．
    コネクションが如何なるモードで開かれようと，
    LF, CRLF または CR のどれもが行の EOL マーカーとして受け入れられ，
    従って \code{sep = "\n"} にマッチする．

    \code{file} はまた完全な URL でも良い．(サポートされている
    URL スキームについては \code{\link{url}} に対するヘルプの
    \sQuote{URL}節を見よ．)

    現在のエンコーディングではないデータファイルを読み取る
    (例えば UTF-8 ロケールでの Latin-1 ファイル又はその逆)には
    その \code{encoding} 引数を設定した \code{\link{file}} コネクションを
    使う(または \code{scan} の \code{fileEncoding} 引数)．
  }

  \item{what}{\code{what} の型は読み取られるデータの型を与える．
    (ここで\sQuote{型}は \code{\link{typeof}} の意味で使われている．)
    サポートされている型は \code{logical}, \code{integer}, \code{numeric},
    \code{complex}, \code{character}, \code{raw} そして \code{\link{list}}．
    もし \code{what} がリストならそれは
    データファイルの行が各々が \code{length(what)} 個の項目(\sQuote{欄})
    の記録であることを仮定し，そしてリスト成分は上にあげた最初の6つの(原子的な)
    型か \code{NULL} を持たなければならない，下の\sQuote{詳細}節を見よ．}

  \item{nmax}{整数：読み込まれるデータ値の最大数か，
    もし \code{what} がリストなら読み込まれる記録の最大数．
    もし無いか，正でないか，または整数として不正
    (そして \code{nlines} が正の値に設定されていない)
    ならば \code{scan} は \code{file} の最後まで読み取る．}

  \item{n}{整数：読み取られるデータ値の最大数で，
    既定では制限なし．不正な値は無視される．}

  \item{sep}{既定では \code{scan} は入力欄を区切る
    \sQuote{空白}を読み取ることが期待されている．
    あるいは \code{sep} 欄を区切る文字を指定するのに使うことが出来る．
    引用化されていない限り，一つの欄は常に行末マーカーで区切られる．

    もし指定されるとこれは空の文字列(既定値)か
    \code{NULL} か唯一つの単バイト文字を含む文字列であるべきである．
  }

  \item{quote}{一つの文字列又は \code{NULL} としての引用符のセット．
    多バイトロケールでは引用符はアスキー(単バイト)で無ければならない．}

  \item{dec}{小数点文字．これは唯一つの単バイト文字を含む文字列でなければ
    ならない．(\code{NULL} と長さゼロの文字列ベクトルもまた受け入れられ，
    既定値とされる．)}

  \item{skip}{データ値を読み取り始める前にスキップする入力ファイルの行数．}

  \item{nlines}{もし正なら，読み取られる最大行数．}
  
  \item{na.strings}{文字列ベクトル．このベクトルの要素は欠損値
    (\code{\link{NA}}) として解釈される．空白欄は同様に
    論理値，整数，数値そして複素数欄で欠損値と考えられる．}

  \item{flush}{論理値：もし \code{TRUE} ならば \code{scan} は
    要求された欄の最後を読み取った後に行末にフラッシュされる．
    これは最後の欄の後にコメントを置くことを許すが，
    一行にその一つの記録以上を置くことを排除する．}

  \item{fill}{論理値：もし \code{TRUE} なら \code{scan} は
    暗黙のうちに \code{what} が示唆するよりも少ない欄の任意の行に
    空の欄を付け加える．}

    \item{strip.white}{\code{what} 引数中の項目に対応する論理値のベクトル．
    これは \code{sep} が指定されている時だけ使われ，文字の欄から
    先頭と末尾の \sQuote{空白} を剥ぎ取ることを許す
    (数値の欄からは常に剥ぎ取られる)．注意：引用符の中の空白は剥ぎ取られない．

    もし \code{strip.white} が長さ1なら，これは全ての欄に適用される；
    さもなければ，もし \code{strip.white[i]} が \code{TRUE} で
    \code{i} 番目の欄が文字列型なら(\code{what[i]} がそうだから)
    欄 \code{i} から引用化されていない先頭と末尾の空白が剥ぎ取られる．
  }

  \item{quiet}{論理値：もし \code{FALSE} なら(既定値)，scan() は
    どれだけの項目が読み取られたかを告げる行をプリントする．}

  \item{blank.lines.skip}{論理値：もし \code{TRUE} なら
    \code{skip} と \code{nlines} をカウントしている時を除き
    入力中の空白行は無視される．}

  \item{multi.line}{論理値．\code{what} がリストの時だけ使われる．もし
    \code{FALSE} ならば全ての記録は一つの行の上に現れなければならない
    (しかしながら一つ以上の記録が単一の行上に登場しても良い)．
    \code{fill = TRUE} の使用は一つの記録が行末で終了することを
    意味することを注意する．}

  \item{comment.char}{文字列：長さ 1 の文字列ベクトルで一つの文字か
    から文字列を含む．コメントの解釈を一切停止するには \code{""}
    を使う(既定)．}

  \item{allowEscapes}{論理値．\samp{\\n} のような C 風のエスケープ列を
    処理するか(既定)かそのままで読み込むかを指示する．
    もし引用符の中に無ければこれらは区切りと解釈されるかもしれないことを
    注意する(しかしコメント文字とは見做されない)．

    制御文字と見做されるエスケープ列は
    \samp{\\a, \\b, \\f, \\n, \\r, \\t, \\v} そして
    \samp{\\040} と \samp{\\0x2A} のような8進法と16進法表現である．
    他の任意のエスケープ列はそのものとして扱われ，
    バックスラッシュを含む．
    Unicode のエスケープ列(\samp{\\u} か \samp{\\U} で始まる：
    \link{Quotes} を見よ)は決して処理されない．
  }

  \item{fileEncoding}{文字列：もし空でなければファイルに対して使われる
    (コネクションでもキーボードでもない)
    エンコーディングを宣言するので文字列データは再エンコード出来る．
    \code{\link{file}} に対するヘルプの\sQuote{エンコーディング}節と
    マニュアル \sQuote{R Data Import/Export Manual} を見よ．
  }

  \item{encoding}{入力文字列に対して仮定されるエンコーディング．
    もし値が \code{"latin1"} か \code{"UTF-8"} ならば，それが
    文字列が Latin-1 や UTF-8 であることが知られているとマークするのに
    使われる：これは入力を再エンコードするのに使われない
    (\code{fileEncoding} を見よ)．
    \sQuote{詳細}も見よ．
  }

  \item{text}{文字列：もし \code{file} が与えられずこれが与えられると，
    データはテキストコネクションを使い \code{text} の値から読み取られる．
  }

  \item{skipNul}{論理値：文字欄を読み取る時 nul をスキップするか?}
}
\details{
  \code{what} の値は型のリストで良い．この場合
  \code{scan} は \code{what} 中の要素の型で与えられる型を持つベクトルの
  リストを返す．
  これは列状のデータを読み取る手段を与える．
  もし型どれかが \code{NULL} ならば対応する欄はスキップされる
  (しかし \code{NULL} 成分が結果に現れる)．

  \code{what} の型やリスト成分は6つの原子的型や \code{NULL} の
  一つが可能である(\code{\link{is.atomic}} を見よ)．

  \sQuote{空白}は
  一つ又はそれ以上の連続する文字，水平タブ，キャリッジ・リターン，
  ラインフィードのようなこの機能のために定義される．
  これはフォームフィードや垂直タブを含まないが，
   Latin-1 や Windows の 8 ビットロケール(UTF-8 ではない)の
  'スペース' は改行無しのスペース \samp{"\xa0"} を含む．

  空の数値欄は常に欠損値と見做される．
  空の文字列欄は \code{na.strings} が \code{""} を含まない限り
  空の文字列ベクトルとしてスキャンされ，さもなければ欠損値として扱われる．

  数値欄に許される入力はオプションの空白に続く
  \code{NA} か，オプションの符号に続く一つ又は複数の数字
  10進法数か16進法定数
  (\link{NumericConstants} を見よ)，又は \code{NaN}, \code{Inf} 又は
  \code{infinity} (大・小文字を区別しない)である．この範囲を外れる
  値は \code{Inf}, \code{-Inf} 又は \code{0} として記録される．

  整数欄に許される入力はオプションの空白に続く
  \code{NA} か，オプションの符号に続く一つもしくは複数の数字
  (\samp{0-9})である：全ての範囲外の値は
  \code{NA_integer_} に変換される．

  もし \code{sep} が既定値(\code{""})なら，引用化された文字列中の
  文字 \samp{\\} は引き続く文字をエスケープ化するので，
  引用符はそれらをエスケープ化することで文字列中に含めることが出来る．

  もし \code{sep} が非既定ならば，欄は \file{.csv} ファイルの
  スタイルで引用化出来るかもしれない．
  \file{.csv} ファイルでは引用符(\code{''} 又は \code{""})内部の
  分離記号は無視され，引用符を二重化することで文字列中に置くことが出来る．
  しかしながら，もし \code{sep = "\\n"} ならば既定で
  全ての行をそのまま読み取りたいと考えていると仮定される．

  引用化は文字列欄中と\code{NULL} 欄
  だけで解釈される(それはスキップされる文字列欄かもしれない)．

  \code{sep} は分離記号で終了記号ではなく
  \code{scan("foo", sep = "\\n", blank.lines.skip = FALSE)}
  でファイルを読み取ると，もし欄がラインフィードで終われば空の最終行を与え，
  さもなければ与えない．これは希望されたものではないかもしれない：
  \code{\link{readLines}} も見よ．

  もし \code{comment.char} が出現すると(引用化された文字欄の内部を除き)，
  それは行の残りをコメントと見做し捨て去る．
  コメント文字から始まる行
  (もしかすると既定の分離記号を持つ空白の後で)は空白行と見做される．

  コンソールから読み取る際は 4095 バイトの行長の制限がある
  (これは下限を課すかもしれない：
  \sQuote{An Introduction to R} を見よ)．

  もし \code{what} がリストならば 1000 行毎にユーザによる中断がないか
  チェックされる．さもなければ 1000 項目毎になる．

  もし \code{file} が文字列で \code{fileEncoding} が非既定，もしくは
  それが非既定の \code{encoding} 引数を持つまだ開かれていないコネクション
  ならば，テキストは UTF-8 に変換されそうしたものとしてマークされる
  (そして \code{scan} への \code{encoding} 引数は無視される)．
  \code{\link{readLines}} の例を見よ．

  入力ストリーム中の埋め込み nul は現在読み取られている欄を
  停止し，\code{scan} への呼び出し毎に一回の警告が出る．
    \code{skipNul = TRUE} と設定するとそれらは無視されるようになる．
}
\value{
  もし \code{what} がリストならば，\code{what} と
  同じ長さと同じ名前のリスト．
%  if \code{what} is a list, a list of the same length and same names (as
%  any) as \code{what}.

  さもなければ型 \code{what} のベクトル．

  結果中の文字列は，もし \code{encoding} が \code{"latin1"} か \code{"UTF-8"}
  ならば宣言されたエンコーディングを持つ．.
}
\note{
  \code{multi.line} に対する既定値は S と異なる．
  一行当たり一つの記録を読むには \code{flush = TRUE} と
  \code{multi.line = FALSE} を使う．
  (引用化された文字列は依然埋め込みの新行を含むことが出来る．)

  もし項目数が指定されないと，内部機構が2の巾乗単位でメモリを
  再配置し，必要なメモリ量の3倍まで使うことができる．
  (新旧のコピーのために必要になる．) もし可能なら大きなベクトルを入力する際は
  \code{n} か \code{nmax} を，大きなリストを入力する時は
  \code{nmax} か \code{nlines} を指定する．

  部分的な行を読み取るために開かれたコネクション上で \code{scan} を使うと
  文字を失う可能性がある：これを避けるために明示的な分離記号を使う．

  欄中に \code{nul} バイト(\samp{\\0} を含む)ことは，もし
  \code{allowEscapes = TRUE}) ならば欄が \code{nul} で
  終わっているという解釈に導くかもしれない．
  これらは普通テキストファイル中には存在しない
   -- \code{\link{readBin}} を見よ．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  データ行列のより使いやすい読み込みには \code{\link{read.table}}；
  ファイルを一回に一行を読み込む \code{\link{readLines}}．
  \code{\link{write}}.

  C 風のエスケープ列の詳細は \code{Quotes}．

  固定長もしくは可変長の文字列又は数値のバイナリ表現を
  コネクションから一回に少し読み込むには \code{\link{readChar}} と \code{\link{readBin}}．
}
\examples{
cat("TITLE extra line", "2 3 5 7", "11 13 17", file = "ex.data", sep = "\n")
pp <- scan("ex.data", skip = 1, quiet = TRUE)
scan("ex.data", skip = 1)
scan("ex.data", skip = 1, nlines = 1) # スキップした後は 1 行だけ
scan("ex.data", what = list("","","")) # flush は F -> "7" を読む
scan("ex.data", what = list("","",""), flush = TRUE)
unlink("ex.data") # 後片付け

## "inline" 使用
scan(text = "1 2 3")

}
\keyword{file}
\keyword{connection}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/scan.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{scan}
%\title{Read Data Values}
%\alias{scan}
%\description{
%  Read data into a vector or list from the console or file.
%}
%\usage{
%scan(file = "", what = double(), nmax = -1, n = -1, sep = "",
%     quote = if(identical(sep, "\n")) "" else "'\"", dec = ".",
%     skip = 0, nlines = 0, na.strings = "NA",
%     flush = FALSE, fill = FALSE, strip.white = FALSE,
%     quiet = FALSE, blank.lines.skip = TRUE, multi.line = TRUE,
%     comment.char = "", allowEscapes = FALSE,
%     fileEncoding = "", encoding = "unknown", text, skipNul = FALSE)
%}
%\arguments{
%  \item{file}{the name of a file to read data values from.  If the
%    specified file is \code{""}, then input is taken from the keyboard
%    (or whatever \code{\link{stdin}()} reads if input is redirected or
%    \R is embedded).
%    (In this case input can be terminated by a blank line or an EOF
%    signal, \samp{Ctrl-D} on Unix and \samp{Ctrl-Z} on Windows.)
%
%    Otherwise, the file name is interpreted \emph{relative} to the
%    current working directory (given by \code{\link{getwd}()}),
%    unless it specifies an \emph{absolute} path.
%    Tilde-expansion is performed where supported.
%    When running \R from a script, \code{file = "stdin"} can be used to
%    refer to the process's \code{stdin} file stream.
%
%    This can be a compressed file (see \code{\link{file}}).
%
%    Alternatively, \code{file} can be a \code{\link{connection}},
%    which will be opened if necessary, and if so closed at the end of
%    the function call.  Whatever mode the connection is opened in,
%    any of LF, CRLF or CR will be accepted as the EOL marker for a line
%    and so will match \code{sep = "\n"}.
%
%    \code{file} can also be a complete URL.  (For the supported URL
%    schemes, see the \sQuote{URLs} section of the help for
%    \code{\link{url}}.)
%
%    To read a data file not in the current encoding (for example a
%    Latin-1 file in a UTF-8 locale or conversely) use a
%    \code{\link{file}} connection setting its \code{encoding} argument
%    (or \code{scan}'s \code{fileEncoding} argument).
%  }
%
%  \item{what}{the \link{type} of \code{what} gives the type of data to
%    be read.  (Here \sQuote{type} is used in the sense of
%    \code{\link{typeof}}.)  The supported types are \code{logical},
%    \code{integer}, \code{numeric}, \code{complex}, \code{character},
%    \code{raw} and \code{\link{list}}.  If \code{what} is a list, it is
%    assumed that the lines of the data file are records each containing
%    \code{length(what)} items (\sQuote{fields}) and the list components
%    should have elements which are one of the first six (\link{atomic})
%    types listed or \code{NULL}, see section \sQuote{Details} below.}
%
%  \item{nmax}{integer: the maximum number of data values to be read, or if
%    \code{what} is a list, the maximum number of records to be read.  If
%    omitted or not positive or an invalid value for an integer
%    (and \code{nlines} is not set to a positive value), \code{scan} will
%    read to the end of \code{file}.}
%
%  \item{n}{integer: the maximum number of data values to be read, defaulting to
%    no limit.  Invalid values will be ignored.}
%
%  \item{sep}{by default, scan expects to read \sQuote{white-space}
%    delimited input fields.  Alternatively, \code{sep} can be used to
%    specify a character which delimits fields.  A field is always
%    delimited by an end-of-line marker unless it is quoted.
%
%    If specified this should be the empty character string (the default)
%    or \code{NULL} or a character string containing just one single-byte
%    character.
%  }
%
%  \item{quote}{the set of quoting characters as a single character
%    string or \code{NULL}.  In a multibyte locale the quoting characters
%    must be ASCII (single-byte).}
%
%  \item{dec}{decimal point character.  This should be a character string
%    containing just one single-byte character.  (\code{NULL} and a
%    zero-length character vector are also accepted, and taken as the
%    default.)}
%
%  \item{skip}{the number of  lines of the input file to skip before
%    beginning to read data values.}
%
%  \item{nlines}{if positive, the maximum number of lines of data to be read.}
%
%  \item{na.strings}{character vector.  Elements of this vector are to be
%    interpreted as missing (\code{\link{NA}}) values.  Blank fields are
%    also considered to be missing values in logical, integer, numeric
%    and complex fields.}
%
%  \item{flush}{logical: if \code{TRUE}, \code{scan} will flush to the
%    end of the line after reading the last of the fields requested.
%    This allows putting comments after the last field, but precludes
%    putting more that one record on a line.}
%
%  \item{fill}{logical: if \code{TRUE}, \code{scan} will implicitly add
%    empty fields to any lines with fewer fields than implied by
%    \code{what}.}
%
%  \item{strip.white}{vector of logical value(s) corresponding to items
%    in the \code{what} argument.  It is used only when \code{sep} has
%    been specified, and allows the stripping of leading and trailing
%    \sQuote{white space} from \code{character} fields (\code{numeric} fields
%    are always stripped).  Note: white space inside quoted strings is
%    not stripped.
%
%    If \code{strip.white} is of length 1, it applies to all fields;
%    otherwise, if \code{strip.white[i]} is \code{TRUE} \emph{and} the
%    \code{i}-th field is of mode character (because \code{what[i]} is)
%    then the leading and trailing unquoted white space from field \code{i} is
%    stripped.
%  }
%
%  \item{quiet}{logical: if \code{FALSE} (default), scan() will print a
%    line, saying how many items have been read.}
%
%  \item{blank.lines.skip}{logical: if \code{TRUE} blank lines in the
%    input are ignored, except when counting \code{skip} and \code{nlines}.}
%
%  \item{multi.line}{logical.  Only used if \code{what} is a list.  If
%    \code{FALSE}, all of a record must appear on one line (but more than
%    one record can appear on a single line).  Note that using \code{fill = TRUE}
%    implies that a record will be terminated at the end of a line.}
%
%  \item{comment.char}{character: a character vector of length one
%    containing a single character or an empty string.  Use \code{""} to
%    turn off the interpretation of comments altogether (the default).}
%
%  \item{allowEscapes}{logical.  Should C-style escapes such as
%    \samp{\\n} be processed (the default) or read verbatim?   Note that if
%    not within quotes these could be interpreted as a delimiter (but not
%    as a comment character).
%
%    The escapes which are interpreted are the control characters
%    \samp{\\a, \\b, \\f, \\n, \\r, \\t, \\v} and octal and
%    hexadecimal representations like \samp{\\040} and \samp{\\0x2A}.  Any
%    other escaped character is treated as itself, including backslash.
%    Note that Unicode escapes (starting \samp{\\u} or \samp{\\U}: see
%    \link{Quotes}) are never processed.
%  }
%
%  \item{fileEncoding}{character string: if non-empty declares the
%    encoding used on a file (not a connection nor the keyboard) so the
%    character data can be re-encoded.  See the \sQuote{Encoding} section
%    of the help for \code{\link{file}}, and the \sQuote{R Data
%      Import/Export Manual}.
%  }
%
%  \item{encoding}{encoding to be assumed for input strings.  If the
%    value is \code{"latin1"} or \code{"UTF-8"} it is used to mark
%    character strings as known to be in Latin-1 or UTF-8: it is not used
%    to re-encode the input (see \code{fileEncoding}).
%    See also \sQuote{Details}.
%  }
%
%  \item{text}{character string: if \code{file} is not supplied and this is,
%    then data are read from the value of \code{text} via a text connection.
%  }
%
%  \item{skipNul}{logical: should nuls be skipped when reading character
%    fields?}
%}
%\details{
%  The value of \code{what} can be a list of types, in which case
%  \code{scan} returns a list of vectors with the types given by the
%  types of the elements in \code{what}.  This provides a way of reading
%  columnar data.  If any of the types is \code{NULL}, the corresponding
%  field is skipped (but a \code{NULL} component appears in the result).
%
%  The type of \code{what} or its components can be one of the six
%  atomic vector types or \code{NULL} (see \code{\link{is.atomic}}).
%
%  \sQuote{White space} is defined for the purposes of this function as
%  one or more contiguous characters from the set space, horizontal tab,
%  carriage return and line feed.  It does not include form feed nor
%  vertical tab, but in Latin-1 and Windows 8-bit locales (but not UTF-8)
%  'space' includes the non-breaking space \samp{"\xa0"}.
%
%  Empty numeric fields are always regarded as missing values.
%  Empty character fields are scanned as empty character vectors, unless
%  \code{na.strings} contains \code{""} when they are regarded as missing
%  values.
%
%  The allowed input for a numeric field is optional whitespace followed
%  either \code{NA} or an optional sign followed by a decimal or
%  hexadecimal constant (see \link{NumericConstants}), or \code{NaN},
%  \code{Inf} or \code{infinity} (ignoring case).  Out-of-range values
%  are recorded as \code{Inf}, \code{-Inf} or \code{0}.
%
%  For an integer field the allowed input is optional whitespace,
%  followed by either \code{NA} or an optional sign and one or more
%  digits (\samp{0-9}): all out-of-range values are converted to
%  \code{NA_integer_}.
%
%  If \code{sep} is the default (\code{""}), the character \samp{\\}
%  in a quoted string escapes the following character, so quotes may be
%  included in the string by escaping them.
%
%  If \code{sep} is non-default, the fields may be quoted in the style of
%  \file{.csv} files where separators inside quotes (\code{''} or
%  \code{""}) are ignored and quotes may be put inside strings by
%  doubling them.  However, if \code{sep = "\\n"} it is assumed
%  by default that one wants to read entire lines verbatim.
%
%  Quoting is only interpreted in character fields and in \code{NULL}
%  fields (which might be skipping character fields).
%
%  Note that since \code{sep} is a separator and not a terminator,
%  reading a file by \code{scan("foo", sep = "\\n", blank.lines.skip = FALSE)}
%  will give an empty final line if the file ends in a linefeed and not if
%  it does not.  This might not be what you expected; see also
%  \code{\link{readLines}}.
%
%  If \code{comment.char} occurs (except inside a quoted character
%  field), it signals that the rest of the line should be regarded as a
%  comment and be discarded.  Lines beginning with a comment character
%  (possibly after white space with the default separator) are treated as
%  blank lines.
%
%  There is a line-length limit of 4095 bytes when reading from the
%  console (which may impose a lower limit: see \sQuote{An Introduction
%  to R}).
%
%  There is a check for a user interrupt every 1000 lines if \code{what}
%  is a list, otherwise every 10000 items.
%
%  If \code{file} is a character string and \code{fileEncoding} is
%  non-default, or if it is a not-already-open \link{connection} with a
%  non-default \code{encoding} argument, the text is converted to UTF-8
%  and declared as such (and the \code{encoding} argument to \code{scan}
%  is ignored).  See the examples of \code{\link{readLines}}.
%
%  Embedded nuls in the input stream will terminate the field currently
%  being read, with a warning once per call to \code{scan}.  Setting
%  \code{skipNul = TRUE} causes them to be ignored.
%}
%\value{
%  if \code{what} is a list, a list of the same length and same names (as
%  any) as \code{what}.
%
%  Otherwise, a vector of the type of \code{what}.
%
%  Character strings in the result will have a declared encoding if
%  \code{encoding} is \code{"latin1"} or \code{"UTF-8"}.
%}
%\note{
%  The default for \code{multi.line} differs from S.  To read one record
%  per line, use \code{flush = TRUE} and \code{multi.line = FALSE}.
%  (Note that quoted character strings can still include embedded newlines.)
%
%  If number of items is not specified, the internal
%  mechanism re-allocates memory in powers of two and so could use up
%  to three times as much memory as needed.  (It needs both old and new
%  copies.)  If you can, specify either \code{n} or \code{nmax} whenever
%  inputting a large vector, and \code{nmax} or \code{nlines} when
%  inputting a large list.
%
%  Using \code{scan} on an open connection to read partial lines can lose
%  chars: use an explicit separator to avoid this.
%
%  Having \code{nul} bytes in fields (including \samp{\\0} if
%  \code{allowEscapes = TRUE}) may lead to interpretation of the
%  field being terminated at the \code{nul}.  They not normally present
%  in text files -- see \code{\link{readBin}}.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{read.table}} for more user-friendly reading of data
%  matrices;
%  \code{\link{readLines}} to read a file a line at a time.
%  \code{\link{write}}.
%
%  \code{Quotes} for the details of C-style escape sequences.
%
%  \code{\link{readChar}} and \code{\link{readBin}} to read fixed or
%  variable length character strings or binary representations of numbers
%  a few at a time from a connection.
%}
%\examples{
%cat("TITLE extra line", "2 3 5 7", "11 13 17", file = "ex.data", sep = "\n")
%pp <- scan("ex.data", skip = 1, quiet = TRUE)
%scan("ex.data", skip = 1)
%scan("ex.data", skip = 1, nlines = 1) # only 1 line after the skipped one
%scan("ex.data", what = list("","","")) # flush is F -> read "7"
%scan("ex.data", what = list("","",""), flush = TRUE)
%unlink("ex.data") # tidy up
%
%## "inline" usage
%scan(text = "1 2 3")
%
%}
%\keyword{file}
%\keyword{connection}
%
\encoding{UTF8}
