% File src/library/base/man/slotOp.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{slotOp}
\title{Extract or Replace A Slot}
\alias{@}
\alias{@<-}
\description{
  形式的 (S4) クラス構造を持つオブジェクト中のスロットの内容を取り出す又は
  置き換える．
}
\usage{
object@name
object@name <- value
}
\arguments{
  \item{object}{形式的に定義される (S4) クラスからのオブジェクト．}
  \item{name}{スロットの文字列の名前，引用化されているかされていない．
      \code{object} のクラスの定義中のスロットの名前でなければならない．}
  \item{value}{スロットに対する置き換え値で，
      \code{object} のクラスの定義中の
      このスロットに対して定義されたクラスと両立するクラスからの
      ものでなければならない．}
}
\details{
  これらの演算子はパッケージ \pkg{methods} の形式的クラスをサポートし，
  パッケージ \pkg{methods} がロードされた時だけ(既定として)有効になる．
  これ以上の詳細，特に \code{slot()} と \code{@} 演算子の違い，に
  付いては \code{\link{slot}} を見よ．

  \code{object} が S4 オブジェクトかどうかがチェックされ(\code{\link{isS4}} を見よ),
  そして他のオブジェクトに対して \code{@} を使おうとするとエラーになる．
  (内部的使用に対してだけは名前 \code{.Data} に対する例外がある．)
  置き換え演算子はオブジェクトにスロットが既に存在するかどうかをチェックする
  (オブジェクトが実際に主張されているクラスからのものであれば存在する
  はずである)．

  \R 3.0.0 以前では置き換え演算子はパッケージ \pkg{methods} 中にあり，
  \code{name} の適正さに対する異なったテストを持っていた．

  これらは内部総称的演算子である：\link{InternalMethods} を見よ．
}
\value{
  スロットの現在の内容．
}
\seealso{
  \code{\link{Extract}}, \code{\link{slot}}
}
\keyword{manip}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/slotOp.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{slotOp}
%\title{Extract or Replace A Slot}
%\alias{@}
%\alias{@<-}
%\description{
%  Extract or replace the contents of a slot in a object with a
%  formal (S4) class structure.
%}
%\usage{
%object@name
%object@name <- value
%}
%\arguments{
%  \item{object}{An object from a formally defined (S4) class.}
%  \item{name}{The character-string name of the slot, quoted or
%      not.  Must be the name of a slot in the definition of the class
%      of \code{object}.}
%  \item{value}{A replacement value for the slot, which must be from a
%      class compatible with the class defined for this slot in the
%      definition of the class of  \code{object}.}
%}
%\details{
%  These operators support the formal classes of package \pkg{methods},
%  and are enabled only when package \pkg{methods} is loaded (as per
%  default).  See \code{\link{slot}} for further details, in particular
%  for the differences between \code{slot()} and the \code{@} operator.
%
%  It is checked that \code{object} is an S4 object (see
%  \code{\link{isS4}}), and it is an error to attempt to use \code{@} on
%  any other object.  (There is an exception for name \code{.Data} for
%  internal use only.)  The replacement operator checks that the slot
%  already exists on the object (which it should if the object is really
%  from the class it claims to be).
%
%  Prior to \R 3.0.0 the replacement operator was in package
%  \pkg{methods} and had a different test for validity of \code{name}.
%
%  These are internal generic operators: see \link{InternalMethods}.
%}
%\value{
%  The current contents of the slot.
%}
%\seealso{
%  \code{\link{Extract}}, \code{\link{slot}}
%}
%\keyword{manip}
%
\encoding{UTF8}
