% File src/library/base/man/sum.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{sum}
\alias{sum}
\title{Sum of Vector Elements}
\description{
  \code{sum} はその引数中に存在する全ての値の和を返す．
}
\usage{
sum(\dots, na.rm = FALSE)
}
\arguments{
  \item{\dots}{数値又は複素数又は論理値ベクトル．}
  \item{na.rm}{論理値．欠損値(\code{NaN} を含む)を除くか?}
}
\value{
  和．もし全ての \code{\dots} が型整数か論理値ならば，和は
  整数で，その場合整数が桁溢れすれば結果は \code{NA} になる．
  さもなければそれは長さ 1 の数値もしくは複素数値ベクトルになる．

  \strong{NB:} 空集合の和は定義からゼロになる．
}
\details{
  これは総称的関数である：それに対するメソッドを直接に又は
  \code{\link[=S3groupGeneric]{Summary}} グループ総称経由で定義できる．
  これが正しく動作するためには，引数 \code{\dots} は名前を持たず，
  選択適用は最初の引数に関して行われる．

  もし \code{na.rm} が \code{FALSE} ならばどれかの引数中の値 \code{NA} 又は
  \code{NaN} は値 \code{NA} か \code{NaN} を返す．
  さもなければ値 \code{NA} か \code{NaN} は無視される．

  論理値 \code{TRUE} は 1，\code{FLASE} は 0 と見做される．
  歴史的な理由から \code{NULL} は \code{integer(0)} であるかのように扱われる．

  異なった符号の値を加えると精度が低下する可能性がある：
  これはもし部分和が整数桁溢れを起こすならば十分長い整数入力に対してすら
  起きる可能性がある．可能ならば拡張精度の加算器が使われるが，
  これはプラットフォーム依存である．
}
\section{S4 メソッド}{
  これは S4 \code{\link[=S4groupGeneric]{Summary}} グループ総称関数の
  一部である．それに対するメソッドはシグネチャ
  \code{x, \dots, na.rm} を使う必要がある．

  プロット注釈に使うためには \sQuote{\link{plotmath}}．
}
\seealso{
  行和と列和に対しては \code{\link{colSums}}．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\examples{% for beginners
## ベクトルを sum に渡し，要素を一緒に加える．
sum(1:5)

## sum に複数の数を渡し，また要素を加える．
sum(1, 2, 3, 4, 5)

## 実際ベクトルを複数の引数として渡すことが出来，全てが加えられる．
sum(1:2, 3:5)

## もし欠損値があれば，和は未知である，つまりまた欠損値 ....
sum(1:5, NA)
## ... 欠損値を明示的に除外しない限り：
sum(1:5, NA, na.rm = TRUE)
}
\keyword{arith}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/sum.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{sum}
%\alias{sum}
%\title{Sum of Vector Elements}
%\description{
%  \code{sum} returns the sum of all the values
%  present in its arguments.
%}
%\usage{
%sum(\dots, na.rm = FALSE)
%}
%\arguments{
%  \item{\dots}{numeric or complex or logical vectors.}
%  \item{na.rm}{logical.  Should missing values (including \code{NaN}) be
%    removed?}
%}
%\value{
%  The sum. If all of \code{\dots} are of type integer or logical, then
%  the sum is integer, and in that case the result will be \code{NA} (with a
%  warning) if integer overflow occurs.  Otherwise it is a length-one
%  numeric or complex vector.
%
%  \strong{NB:} the sum of an empty set is zero, by definition.
%}
%\details{
%  This is a generic function: methods can be defined for it
%  directly or via the \code{\link[=S3groupGeneric]{Summary}} group generic.
%  For this to work properly, the arguments \code{\dots} should be
%  unnamed, and dispatch is on the first argument.
%
%  If \code{na.rm} is \code{FALSE} an \code{NA} or \code{NaN} value in
%  any of the arguments will cause a value of \code{NA} or \code{NaN} to
%  be returned, otherwise \code{NA} and \code{NaN} values are ignored.
%
%  Logical true values are regarded as one, false values as zero.
%  For historical reasons, \code{NULL} is accepted and treated as if it
%  were \code{integer(0)}.
%
%  Loss of accuracy can occur when summing values of different signs:
%  this can even occur for sufficiently long integer inputs if the
%  partial sums would cause integer overflow.  Where possible
%  extended-precision accumulators are used, but this is
%  platform-dependent.
%}
%\section{S4 methods}{
%  This is part of the S4 \code{\link[=S4groupGeneric]{Summary}}
%  group generic.  Methods for it must use the signature
%  \code{x, \dots, na.rm}.
%
%  \sQuote{\link{plotmath}} for the use of \code{sum} in plot annotation.
%}
%\seealso{
%  \code{\link{colSums}} for row and column sums.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\examples{% for beginners
%## Pass a vector to sum, and it will add the elements together.
%sum(1:5)
%
%## Pass several numbers to sum, and it also adds the elements.
%sum(1, 2, 3, 4, 5)
%
%## In fact, you can pass vectors into several arguments, and everything gets added.
%sum(1:2, 3:5)
%
%## If there are missing values, the sum is unknown, i.e., also missing, ....
%sum(1:5, NA)
%## ... unless  we exclude missing values explicitly:
%sum(1:5, NA, na.rm = TRUE)
%}
%\keyword{arith}
%
\encoding{UTF8}
