% File src/library/base/man/system.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{system2}
\alias{system2}
\title{Invoke a System Command}
\description{
  \code{system2} は \code{command} で指定される OS 命令を起動する．
}
\usage{
system2(command, args = character(),
        stdout = "", stderr = "", stdin = "", input = NULL,
        env = character(), wait = TRUE,
        minimized = FALSE, invisible = TRUE)
}
\arguments{
  \item{command}{文字列で与えるシステム命令．}
  \item{args}{\command{command} への引数の文字列ベクトル．}
  \item{stdout, stderr}{\file{stdout} や \file{stderr} への出力を
    どこへ送るか．可能な値は \code{""}, \R コンソール(既定)，\code{NULL}
    又は \code{FALSE} (出力を捨て去る)，
    \code{TRUE} (出力を文字列ベクトルに捕捉する)，又は
    ファイル名の文字列．}
  \item{stdin}{入力は転送されるべきか?  \code{""} は既定，
    又はファイル名の文字列．もし \code{input} が提供されると無視される．}
  \item{input}{もし文字列が提供されると，これは一時ファイルに
    一行につき一文字列コピーされ，そして \code{command} の標準入力は
    ファイルにリダイレクトされる．}
  \item{env}{環境変数を設定する name=value 形式の文字列のベクトル．}
  \item{wait}{\R インタプリタが命令が終了するのを待つべきかどうかを
    指示する論理値(\code{NA} でない)．又はそれを非同期的に実行する．
    これはもし \code{stdout = TRUE} ならば無視される(そしてインタプリタは常に
    待つ)．}
#ifdef unix
  \item{minimized, invisible}{Windows で受け入れられる引数であるが
    このプラットフォームでは警告と共に無視される．}
#endif
#ifdef windows
  \item{minimized}{命令のウィンドが最初縮小されたウィンドで表示すべきかどうか
    を指示する論理値(\code{NA} でない)．}
  \item{invisible}{l命令のウィンドが少なくとも上に見えるべきかどうかを
    指示する論理値(\code{NA} でない)．}
#endif
}
\details{
  \code{\link{system}} とは異なり \code{command} は常に \code{\link{shQuote}}
  で引用化されるので，それは引数無しの単一の命令でなければならない．

  \code{command} がどのようにして見つけられるかの詳細は
  \code{\link{system}} を見よ．

  Windows では \code{env} はそれらのコマンドラインで環境変数を受け入れる
  \command{R} と \command{make} のような命令に対してだけサポートされている．

  ある種の Unix の命令(\code{ls} のある実装のような)はそれらの出力を，もし
  それがパイプやリダイレクトされているとそれらが考えると変更する：
  \code{stdout = TRUE} はパイプを使うが，一方 \code{stdout = "some_file_name"} は
  リダイレクトを使う．
  
  それが実装されている仕方から，Unix 風システムでは \code{stderr = TRUE} は
  \code{stdout = TRUE} を意味する：もしこれが指定されたことでなければ警告が与えられる．
}
%% We use popen, and that pipes stdout only

\value{
  もし \code{stdout = TRUE} か \code{stderr = TRUE} ならば，命令の出力
  を与える文字列ベクトルで，文字列毎に一行になる．
  (8095 バイトを超える出力行は分割される．)  もし命令が実行できなければ
  \R のエラーが生成される．もし \code{command} が実行されるが
  ゼロでない終了状態を与えるならば，これは警告と共に結果の属性
  \code{"status"} 中に報告される：属性 \code{"errmsg"} もまた
  利用できる．

  他のケースでは，返り値は \link{invisible} 属性を与えられた
  エラーコード(成功ならば \code{0})である(従って明示的にプリントされる
  必要がある)．もし命令が何らかの理由で実行できなければ値は
  \code{127} になる．さもなければ，もし \code{wait = TRUE} ならば値は
  命令により返される終了状態である．そしてもし \code{wait = FALSE} ならば
  それは \code{0} (便宜的な成功値)になる．
#ifdef windows
  ある種の Windows の命令は範囲外の状態値(例えば \code{-1})を返すので，
  値の下位 16 ビットだけが使われる．
#endif
}

\note{
  \code{system2} は \code{\link{system}} よりも可搬性が高く柔軟なインタフェイスで
  \R 2.12.0 で導入された．それは Windows でシェルを起動する必要がない
  出力のリダイレクト，\code{command} の実行のための環境変数を設定する
  可搬性の高い方法，そして \code{stdout} と \code{stderr} のリダイレクトに
  対する肌理の細かな調整を可能にする．
  逆に \code{system} (そして Windows では \code{shell})は任意のコマンドライン
  の起動を許す．

  \code{stdout} と \code{stderr} が共に \code{TRUE} か同じファイルなら，
  二つのストリームが順に差し挟まれる保証は無い．
  これは命令と OS によって使われる双方のバッファリングに依存する．
}

\seealso{
  \code{\link{system}}.
#ifdef windows
  \code{\link{shell}} と \code{\link{shell.exec}}．
#endif
}
\keyword{interface}
\keyword{file}
\keyword{utilities}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/system.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{system2}
%\alias{system2}
%\title{Invoke a System Command}
%\description{
%  \code{system2} invokes the OS command specified by \code{command}.
%}
%\usage{
%system2(command, args = character(),
%        stdout = "", stderr = "", stdin = "", input = NULL,
%        env = character(), wait = TRUE,
%        minimized = FALSE, invisible = TRUE)
%}
%\arguments{
%  \item{command}{the system command to be invoked, as a character string.}
%  \item{args}{a character vector of arguments to \command{command}.}
%  \item{stdout, stderr}{where output to \file{stdout} or
%    \file{stderr} should be sent.  Possible values are \code{""}, to the \R
%    console (the default), \code{NULL} or \code{FALSE} (discard output),
%    \code{TRUE} (capture the output in a character vector) or a
%    character string naming a file.}
%  \item{stdin}{should input be diverted?  \code{""} means the default,
%    alternatively a character string naming a file.  Ignored
%    if \code{input} is supplied.}
%  \item{input}{if a character vector is supplied, this is copied one
%    string per line to a temporary file, and the standard input of
%    \code{command} is redirected to the file.}
%  \item{env}{character vector of name=value strings to set environment
%    variables.}
%  \item{wait}{a logical (not \code{NA}) indicating whether the \R
%    interpreter should wait for the command to finish, or run it
%    asynchronously.  This will be ignored (and the interpreter will
%    always wait) if \code{stdout = TRUE}.}
%#ifdef unix
%  \item{minimized, invisible}{arguments that are accepted on Windows but
%    ignored on this platform, with a warning.}
%#endif
%#ifdef windows
%  \item{minimized}{logical (not \code{NA}), indicates whether the
%    command window should be displayed initially as a minimized window.}
%  \item{invisible}{logical (not \code{NA}), indicates whether the
%    command window should be visible on the screen.}
%#endif
%}
%\details{
%  Unlike \code{\link{system}}, \code{command} is always quoted by
%  \code{\link{shQuote}}, so it must be a single command without arguments.
%
%  For details of how \code{command} is found see \code{\link{system}}.
%
%  On Windows, \code{env} is only supported for commands such as
%  \command{R} and \command{make} which accept environment variables on
%  their command line.
%
%  Some Unix commands (such as some implementations of \code{ls}) change
%  their output if they consider it to be piped or redirected:
%  \code{stdout = TRUE} uses a pipe whereas \code{stdout =
%  "some_file_name"} uses redirection.
%
%  Because of the way it is implemented, on a Unix-alike \code{stderr =
%    TRUE} implies \code{stdout = TRUE}: a warning is given if this is
%  not what was specified.
%}
%%% We use popen, and that pipes stdout only
%
%\value{
%  If \code{stdout = TRUE} or \code{stderr = TRUE}, a character vector
%  giving the output of the command, one line per character string.
%  (Output lines of more than 8095 bytes will be split.)  If the command
%  could not be run an \R error is generated.  If \code{command} runs but
%  gives a non-zero exit status this will be reported with a warning and
%  in the attribute \code{"status"} of the result: an attribute
%  \code{"errmsg"} may also be available.
%
%  In other cases, the return value is an error code (\code{0}
%  for success), given the \link{invisible} attribute (so needs to be printed
%  explicitly).  If the command could not be run for any reason, the
%  value is \code{127}.  Otherwise if \code{wait = TRUE} the value is the
%  exit status returned by the command, and if \code{wait = FALSE} it is
%  \code{0} (the conventional success value).
%#ifdef windows
%  Some Windows commands return out-of-range status values
%  (e.g., \code{-1}) and so only the bottom 16 bits of the value are used.
%#endif
%}
%
%\note{
%  \code{system2} is a more portable and flexible interface than
%  \code{\link{system}}, introduced in \R 2.12.0.  It allows redirection
%  of output without needing to invoke a shell on Windows, a portable way
%  to set environment variables for the execution of \code{command}, and
%  finer control over the redirection of \code{stdout} and \code{stderr}.
%  Conversely, \code{system} (and \code{shell} on Windows) allows the
%  invocation of arbitrary command lines.
%
%  There is no guarantee that if \code{stdout} and \code{stderr} are both
%  \code{TRUE} or the same file that the two streams will be interleaved
%  in order.  This depends on both the buffering used by the command and
%  the OS.
%}
%
%\seealso{
%  \code{\link{system}}.
%#ifdef windows
%
%  \code{\link{shell}} and \code{\link{shell.exec}}.
%#endif
%}
%\keyword{interface}
%\keyword{file}
%\keyword{utilities}
%\encoding{UTF8}

\encoding{UTF8}

