% File src/library/datasets/man/euro.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{euro}
\docType{data}
\title{ユーロ通貨の交換率データ}
\alias{euro}
\alias{euro.cross}
%%\title{Conversion Rates of Euro Currencies}
\description{様々なユーロ通貨間の交換レート．}
\usage{
euro
euro.cross
}
\format{
  \code{euro} は長さ11の名前付きベクトルで，
  \code{euro.cross} は次元名を持つ
  サイズ 11 掛ける 11 の行列である．
}
\details{
  データセット \code{euro} は 1 ユーロの
  ヨーロッパ金融共同体に参加している全ての通貨
  (オーストリア・シリング ATS，ベルギー・フラン BEF，ドイツ・マルク DEM，
  スペイン・ペセタ ESP，フィンランド・マルカ FIM，フランス・フラン FRF，
  アイルランド・プント IEP，イタリア・リラ ITL，ルクセンブルグ・フラン LUF，
  オランダ・ギルダー NLG そしてポルトガル・エスクード PTE)での値を持つ．
  これらの交換率はヨーロッパ共同体により
  December 31, 1998 に固定された．価格をユーロ価格に変換するには
  対応するレートで割り二桁に丸める．

  データセット \code{euro.cross} は様々なユーロ通貨間の交換レートを含む，
  つまり\cr
  \code{outer(1 / euro, euro)} の結果である．
}
\examples{
cbind(euro)

## これらの関係が成り立つ：
euro == signif(euro, 6) # [ユーロの定義では6桁の精度]
all(euro.cross == outer(1/euro, euro))

## 20ユーロをベルギー・フランに変換
20 * euro["BEF"]
## 20オーストリア・シリングをユーロに変換
20 / euro["ATS"]
## 20スペイン・ペセタをイタリア・リラに
20 * euro.cross["ESP", "ITL"]

require(graphics)
dotchart(euro,
         main = "euro data: 1 Euro in currency unit")
dotchart(1/euro,
         main = "euro data: 1 currency unit in Euros")
dotchart(log(euro, 10),
         main = "euro data: log10(1 Euro in currency unit)")
}
\keyword{datasets}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/datasets/man/euro.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{euro}
%\docType{data}
%\alias{euro}
%\alias{euro.cross}
%\title{Conversion Rates of Euro Currencies}
%\description{Conversion rates between the various Euro currencies.}
%\usage{
%euro
%euro.cross
%}
%\format{
%  \code{euro} is a named vector of length 11, \code{euro.cross} a
%  matrix of size 11 by 11, with dimnames.
%}
%\details{
%  The data set \code{euro} contains the value of 1 Euro in all
%  currencies participating in the European monetary union (Austrian
%  Schilling ATS, Belgian Franc BEF, German Mark DEM, Spanish Peseta ESP,
%  Finnish Markka FIM, French Franc FRF, Irish Punt IEP, Italian Lira
%  ITL, Luxembourg Franc LUF, Dutch Guilder NLG and Portuguese Escudo
%  PTE).  These conversion rates were fixed by the European Union on
%  December 31, 1998.  To convert old prices to Euro prices, divide by
%  the respective rate and round to 2 digits.
%
%  The data set \code{euro.cross} contains conversion rates between the
%  various Euro currencies, i.e., the result of
%  \code{outer(1 / euro, euro)}.
%}
%\examples{
%cbind(euro)
%
%## These relations hold:
%euro == signif(euro, 6) # [6 digit precision in Euro's definition]
%all(euro.cross == outer(1/euro, euro))
%
%## Convert 20 Euro to Belgian Franc
%20 * euro["BEF"]
%## Convert 20 Austrian Schilling to Euro
%20 / euro["ATS"]
%## Convert 20 Spanish Pesetas to Italian Lira
%20 * euro.cross["ESP", "ITL"]
%
%require(graphics)
%dotchart(euro,
%         main = "euro data: 1 Euro in currency unit")
%dotchart(1/euro,
%         main = "euro data: 1 currency unit in Euros")
%dotchart(log(euro, 10),
%         main = "euro data: log10(1 Euro in currency unit)")
%}
%\keyword{datasets}
%
%\encoding{UTF8}
%