% File src/library/grDevices/man/Devices.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{Devices}
%%\title{List of Graphical Devices}
\alias{Devices}
\title{グラフィックスデバイスの一覧}
\alias{device}
\description{以下のグラフィックスデバイスが現在利用できる：
  \itemize{
%#ifdef windows
    \item  \code{\link{windows}} (Windows 用)
    Windows に対するグラフィックスデバイス(スクリーン上，
    プリンターへ，そして Windows のメタファイルへ)．
%#endif
    \item \code{\link{pdf}} PDF グラフィックス命令をファイルに書き込む．
    \item \code{\link{postscript}}
      PostScript グラフィックス命令をファイルに書き込む．
    \item \code{\link{xfig}} XFIG グラフィックスファイル書式．
    \item \code{\link{bitmap}} bitmap pseudo-device via
    \code{Ghostscript} (もし利用できれば)を使ったビットマップ．
    \item \code{\link{pictex}} TeX/PicTeX グラフィックス命令を
      ファイルに書き込む(歴史的な興味だけ)．
  }
  以下のデバイスはもし \R がそれらを使うようにコンパイルされると
  機能する
  (それらは他のシステムでは存在するが警告と共に復帰する)：
  \itemize{
%#ifdef unix
    \item \code{\link{X11}} (Unix 用) X11 ウィンドシステムに
      対するグラフィックスデバイス．
%#endif
    \item \code{\link{cairo_pdf}}, カイログラフィックスに基づく
      \code{cairo_ps} PDF と PostScript デバイス．
    \item \code{\link{svg}} カイログラフィックスに基づく SVG デバイス．
    \item \code{\link{png}} PNG ビットマップデバイス．
    \item \code{\link{jpeg}} JPEG ビットマップデバイス．
    \item \code{\link{bmp}} BMP ビットマップデバイス．
    \item \code{\link{tiff}} TIFF ビットマップデバイス．
%#ifdef unix

    \item \code{\link{quartz}} (Unix 用)
    OS X のネイティブ二次元グラフィックスに対するグラフィックスデバイス．
    (これはそれが
    \code{R.app} GUI とコマンドラインから使える OS X 上でだけ機能する：
    しかしこれはリモートセッションに対してさえローカルのスクリーンに
    表示する．)
%#endif
  }
}
\details{
  もし如何なるデバイスを開かれていなければ，高水準のグラフィックス関数を使うと
  あるデバイスが開かれる．
  どのデバイスかは
  \code{\link{options}("device")} で与えられ，これは最初各プラットフォームに
  最も相応しい物に設定される：
  殆どの対話的な使用にはスクリーンデバイスでさもなければ
  \code{\link{pdf}} (もしくは \env{R_DEFAULT_DEVICE} の設定)．
  例外はUnixで，もし如何なるスクリーンデバイスも利用できなければ
  \code{pdf()} が使われる．

  \R パッケージに対してこれ以上のグラフィックスデバイスを提供することが可能で，
  CRAN にある幾つかのパッケージはそれをする．
  これらは
  SVG と PGF/TiKZ (TeX に基づくデバイス，\url{http://pgf.sourceforge.net/} を見よ)
  に出力する他のデバイスを含む．
}
\seealso{
  ここで挙げられた各デバイスに関するこれ以上の情報に対する
  ヘルプファイルは次にある；
  (Wwindows なら) \code{\link{windows.options}}．
  (Unix なら) \code{\link{X11}.options}, \code{\link{quartz.options}}．
  デバイスをどのようにカスタマイズするかについては
  \code{\link{ps.options}} と \code{\link{pdf.options}}．

  \code{\link{dev.interactive}},
  \code{\link{dev.cur}}, \code{\link{dev.print}},
  \code{\link{graphics.off}}, \code{\link{image}},
  \code{\link{dev2bitmap}}.
  (Uunix なら)
  \code{\link{X11}},
  \code{\link{jpeg}} \code{\link{png}}, \code{\link{tiff}},
  \code{\link{quartz}} そして cairo に基づくデバイスが利用可能かは
  \code{\link{capabilities}} を見よ．
}
\examples{\dontrun{
## もしこのプラットフォームで如何なるデバイスも開かれていなければ
## 既定のデバイスを開く
if(dev.cur() == 1) dev.new()
}}
\keyword{device}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/Devices.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Devices}
%\title{List of Graphical Devices}
%\alias{Devices}
%\alias{device}
%\description{The following graphics devices are currently available:
%  \itemize{
%#ifdef windows
%    \item \code{\link{windows}} The graphics device for Windows (on screen,
%    to printer and to Windows metafile).
%#endif
%    \item \code{\link{pdf}} Write PDF graphics commands to a file
%    \item \code{\link{postscript}} Writes PostScript graphics commands to
%    a file
%    \item \code{\link{xfig}} Device for XFIG graphics file format
%    \item \code{\link{bitmap}} bitmap pseudo-device via
%    \code{Ghostscript} (if available).
%    \item \code{\link{pictex}} Writes TeX/PicTeX graphics commands to a
%    file (of historical interest only)
%  }
%  The following devices will be functional if \R was compiled to use
%  them (they exist but will return with a warning on other systems):
%  \itemize{
%#ifdef unix
%    \item \code{\link{X11}} The graphics device for the X11 windowing system
%#endif
%    \item \code{\link{cairo_pdf}}, \code{cairo_ps} PDF and PostScript
%    devices based on cairo graphics.
%    \item \code{\link{svg}} SVG device based on cairo graphics.
%    \item \code{\link{png}} PNG bitmap device
%    \item \code{\link{jpeg}} JPEG bitmap device
%    \item \code{\link{bmp}} BMP bitmap device
%    \item \code{\link{tiff}} TIFF bitmap device
%#ifdef unix
%
%    \item \code{\link{quartz}} The graphics device for the OS X
%    native Quartz 2d graphics system.  (This is only functional on
%    OS X where it can be used from the \code{R.app} GUI and from the
%    command line: but it will display on the local screen even for a
%    remote session.)
%#endif
%  }
%}
%\details{
%  If no device is open, using a high-level graphics function will cause
%  a device to be opened.  Which device is given by
%  \code{\link{options}("device")} which is initially set as the most
%  appropriate for each platform: a screen device for most interactive use and
%  \code{\link{pdf}} (or the setting of \env{R_DEFAULT_DEVICE})
%  otherwise.  The exception is interactive use under Unix if no screen
%  device is known to be available, when \code{pdf()} is used.
%
%  It is possible for an \R package to provide further graphics devices
%  and several packages on CRAN do so.  These include other devices outputting
%  SVG and PGF/TiKZ (TeX-based graphics, see \url{http://pgf.sourceforge.net/}).
%}
%\seealso{
%  The individual help files for further information on any of the
%  devices listed here;
%#ifdef windows
%  \code{\link{windows.options}},
%#endif
%#ifdef unix
%  \code{\link{X11}.options}, \code{\link{quartz.options}},
%#endif
%  \code{\link{ps.options}} and \code{\link{pdf.options}} for how to
%  customize devices.
%
%  \code{\link{dev.interactive}},
%  \code{\link{dev.cur}}, \code{\link{dev.print}},
%  \code{\link{graphics.off}}, \code{\link{image}},
%  \code{\link{dev2bitmap}}.
%#ifdef unix
%
%  \code{\link{capabilities}} to see if \code{\link{X11}},
%  \code{\link{jpeg}} \code{\link{png}}, \code{\link{tiff}},
%  \code{\link{quartz}} and the cairo-based devices are available.
%#endif
%}
%\examples{\dontrun{
%## open the default screen device on this platform if no device is
%## open
%if(dev.cur() == 1) dev.new()
%}}
%\keyword{device}
%
%\encoding{UTF-8}
%