% File src/library/grDevices/man/Hershey.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2012 R Core Team
% Distributed under GPL 2 or later

\name{Hershey}
\alias{Hershey}
\title{Hershey ベクトルフォント}
%%\title{Hershey Vector Fonts in R}
\description{
  もしグラフィカルパラメータ \code{family} (\code{\link{par}} を見よ)
  が Hershey フォントのどれか一つに設定されていると(\sQuote{詳細}節を見よ)
  Hershey ベクトルフォントがテキストの表示に用いられる．

  \code{\link{text}} と \code{\link{contour}} 関数を使う時，
  Hershey フォントは
  \code{vfont} 引数を使って選択でき，これは
  長さ2の文字列ベクトルである
  (適正な値は\sQuote{詳細}節を見よ)．
  これはキリル文字の選択を許すが，フォントファミリ経由では
  利用できない．
}
\usage{
Hershey
}
\details{
  Hershey フォントは二つの利点を持つ：\cr
  \enumerate{
    \item ベクトルフォントは各文字を店の集まりで表現する；
    \R は文字を点を線で結んで構成する．
    この各文字の外形の詳しい知識は
    \R が文字を任意に変形可能であることを意味し，
    回転した文字でもベクトルフォントは良い見かけを持つことが出来る．
    \item この移植は非アスキー文字と非英語文字をサポートする
    GNU libplot ライブラリから取られた．これは，例えば，
    奇妙なシンボルや日本語文字のプロットを可能にする．
  }
  欠陥：\cr
数学表現(\code{\link{plotmath}})を
  Hershey フォントと一緒に使えない．

  Hershey 文字はフォントのセットで構成されている．
  特定のフォントは
  次のフォントファミリの一つを指定し，
  希望のフォントフェイス
  (プレーン，ボールド，イタリック，ボールドイタリック)を
  \code{par(font)} を使って指定することで選択できる．

%% The basic "table" is in  ../../../main/engine.c
  \tabular{ll}{
    ファミリ \tab 利用可能フェイス \cr
    \code{"HersheySerif"} \tab プレーン，ボールド，イタリック，ボールドイタリック\cr
    \code{"HersheySans"} \tab プレーン，ボールド，イタリック，ボールドイタリック \cr
    \code{"HersheyScript"} \tab プレーン，ボールド \cr
    \code{"HersheyGothicEnglish"} \tab プレーン\cr
    \code{"HersheyGothicGerman"} \tab プレーン\cr
    \code{"HersheyGothicItalian"} \tab プレーン\cr
    \code{"HersheySymbol"} \tab プレーン，ボールド，イタリック，ボールドイタリック \cr
    \code{"HersheySansSymbol"} \tab プレーン，イタリック \cr
  }

  \code{text} に対する \code{vfont} と \code{contour} 関数の指定中で，
  Hershey フォントはタイプフェイス
  (例えば \code{serif} か \code{sans serif}) とフォントインデックス
  又は\sQuote{スタイル} (例えば \code{plain} か \code{italic}) で
  指定される．
  \code{vfont} の最初の要素はタイプフェイスを二番目の要素は
  フォントインデックスを指定する．
  \code{demo(Hershey)} が作る最初の表は文字 \code{a} が
  異なったフォントの各々から作られることを示している．

  利用可能な \code{typeface} と \code{fontindex} 値は
  変数 \code{Hershey} のりスト成分として得られる．\cr
  \code{(typeface, fontindex)} に対する許される対は：
%% This is checked (via max{#}) in FixupVFont() ../../../main/plot.c
%% The basic "table" really is in  ../../../modules/vfonts/g_fontdb.c

  \tabular{ll}{
    serif \tab plain \cr
    serif \tab italic \cr
    serif \tab bold \cr
    serif \tab bold italic \cr
    serif \tab cyrillic \cr
    serif \tab oblique cyrillic \cr
    serif \tab EUC \cr
    sans serif \tab plain \cr
    sans serif \tab italic \cr
    sans serif \tab bold \cr
    sans serif \tab bold italic \cr
    script \tab plain \cr
    script \tab italic \cr
    script \tab bold \cr
    gothic english \tab plain \cr
    gothic german \tab plain \cr
    gothic italian \tab plain \cr
    serif symbol \tab plain \cr
    serif symbol \tab italic \cr
    serif symbol \tab bold \cr
    serif symbol \tab bold italic \cr
    sans serif symbol \tab plain \cr
    sans serif symbol \tab italic \cr
  }
  そしてこれらの添字は \code{Hershey$allowed} で得られる．

  \describe{
    \item{エスケープ列：}{
      描かれる文字列はエスケープ列を含んでも良い，これらは全て
      \samp{\\} で始まる．\R が \samp{\\} に出会うと
      \samp{\\} を描く代わりに，それを
      引き続く文字を描かれるべきもののコード記述と見做す．

      一つの有用なエスケープ列(現在の文脈で)は
      次の型式を持つ：\samp{\\123}．
      \samp{\\} に続く三つの数字は文字の8進法コードを指定する．
      例えば \code{p} に対する8進法コードは 160 であり，従って文字 \code{"p"} と
      \code{"\\160"} は同値になる．これはキーボードに適当なキーが
      無い時に文字を作るのに有用である．

      他の有用なエスケープ列はすべて \samp{\\\\} で始まる．
      これらは下で説明される．
      \R の文字列ではバックスラッシュは二重化される必要があり，
      従ってそれらは\emph{4つ}で入力される必要があることを注意する．
    }

    \item{シンボル：}{
      全てのギリシャ文字シンボルは
      HersheySymbol 又は HersheySansSymbol fファミリ，又は
      セリフシンボルまたはサンセリフシンボルのタイプフェイスを指定することで
      作ることが出来る．
      ギリシャ文字シンボルを非シンボルタイプフェイスを使う文字列に
      埋め込むことを許すために，
      型式 \samp{\\\\ab} のシンボルエスケープ列のセットがある.
      例えば，エスケープ列 \samp{\\\\*a} はギリシャ文字のアルファを
      生み出す．\code{demo(Hershey)} の二番目の表は全てのシンボルエスケープ列はと
      それらが生み出すシンボルを示す．
    }

    \item{ISO Latin-1:}{
      型式 \samp{\\\\ab} のエスケープ列が更に
      ISO Latin-1 文字を作るために用意されている．
      網に凸のオプションは適当な8進法コードを使うことである．
      (非アスキー) ISO Latin-1 文字はハンチ 241\dots{}377 にある．
      例えば，\samp{\\366} はウムラウト付きの o を作る．
      \code{demo(Hershey)} の三番目の表は全ての ISO
      Latin-1 エスケープ列を示す．

      これらの文字は直接使うことが出来る．
      (Latin-1 に無い文字はドットで置き換えられる．)

      幾つかの文字は欠けており，c-cedilla はセディーユを持たず，そして
      \sQuote{sharp s} (\samp{U+00DF}, \sQuote{esszett} として知られている)
      は \code{ss} と表示される．
    }

    \item{特殊文字：}{
      どの標準的フォントにも入らない文字のセットが提供されている．
      これらはエスケープ列としてだけアクセスできる．
      例えば \samp{\\\\LI} は天秤座に対する占星術文字で，
      そして \samp{\\\\JU} は木星に対する天文学記号である．
      \code{demo(Hershey)} の4番目の表は全ての特殊文字のエスケープ
      列を示す．
    }

    \item{キリル文字：}{
      キリル文字は
      K018-R エンコーディングに従って移植されており，
      そうしたロケールではセリフのタイプフェイスと
      キリル(又は斜体キリル)フォントインデクスで直接に使うことが出来る．
      別法としてそれらは小文字は範囲 300 から 337 ，又は大文字は
      範囲 340 から 377 の8進法コードとして指定できる．
      \code{demo(Hershey)} の5番目の表は利用可能なキリル文字に対する
      8進法コードを示す．

      キリル文字はフォントファミリではなく，
      対 \code{("serif", fontindex)} で指定されなければならない．
    }

    \item{日本語文字：}{83個の平仮名，86個の片仮名，そして603個の漢字文字が
      EUC-JP (Extended Unix Code) エンコーディングに従って移植されている．
      各文字は16進コードでユニークに特定できる．
      平仮名文字は
      範囲 0x2421 から 0x2473 に，片仮名は範囲 0x2521 から
      0x2576 に，そして漢字は範囲 0x3021 から 0x6d55 に(散らばって)ある．

      セリフタイプフェイスと EUC フォントインデックスを使うときは，
      これらの文字は8進コードの
      \emph{対}で作ることが出来る．
      16進コード(例えば 0x2421)をあたえた時，最初の二つの数字を取り，
      0x80 を加え，二番目の二つの数字にも同じことを行う
      (例えば，0x21 と 0x24 は 0xa4 と 0xa1 になる)，それから両者を
      8進法に変換する(例えば，
      0xa4 と 0xa1 は 244 と 241 になる)．例えば最初の平仮名は
      \samp{\\244\\241} で作られる．

      16進コードを直接使うこともまた可能である．
      これは \samp{\\\\#J1234} の形式のエスケープ列を指定することで
      全ての非EUCフォントに対して動作する．
      例えば最初の平仮名文字は \samp{\\\\#J2421} で作られる．

      漢字文字は三つ目の方法，
      \samp{\\\\#N1234} の形式のエスケープ列を指定する
      いわゆる "Nelson インデックス"
      ででも指定できる．
      例えば，\sQuote{1}に対する(旧式の)漢字は
      \samp{\\\\#N0001} で作られる．

      \code{demo(Japanese)} は利用可能な日本語文字を示す．
    }

    \item{生の Hershey 絵文字：}{
      Hershey フォント中の全ての文字は大きな配列中に保管されている．
      Hershey フォントのどれからもアクセスできないものもある．
      これらの文字は
      \samp{\\\\#H1234} 形式のエスケープ列によってだけアクセスできる．
      例えば百合紋章(fleur-de-lys)は \samp{\\\\#H0746} でアクセスできる．
      \code{demo(Hershey)} の6番目と7番目の表は利用可能な生の絵文字を
      示す．
    }
  }
}

\references{
  \url{https://www.gnu.org/software/plotutils/plotutils.html}.
}
\seealso{ \code{\link{demo}(Hershey)}, \code{\link{par}},
  \code{\link{text}}, \code{\link{contour}}.

  Hershey フォント中の日本語フォントに対しては \code{\link{Japanese}}．
}
\examples{
Hershey

## 例の表については demo(Hershey) を見よ．
}
\keyword{aplot}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/Hershey.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2012 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Hershey}
%\alias{Hershey}
%\title{Hershey Vector Fonts in R}
%\description{
%  If the \code{family} graphical parameter (see \code{\link{par}})
%  has been set to one of the Hershey fonts (see \sQuote{Details})
%  Hershey vector fonts are used to render text.
%
%  When using the \code{\link{text}} and \code{\link{contour}} functions
%  Hershey fonts may be selected via the \code{vfont} argument, which is
%  a character vector of length 2 (see \sQuote{Details} for valid
%  values).  This allows Cyrillic to be selected, which is not available
%  via the font families.
%}
%\usage{
%Hershey
%}
%\details{
%  The Hershey fonts have two advantages:\cr
%  \enumerate{
%    \item vector fonts describe each
%    character in terms of a set of points;  \R renders the character by
%    joining up the points with straight lines.  This intimate knowledge of
%    the outline of each character means that \R can arbitrarily transform
%    the characters, which can mean that the vector fonts look better
%    for rotated text.
%    \item this implementation was adapted from the GNU libplot library
%    which provides support for non-ASCII and non-English fonts.  This means
%    that it is possible, for example, to produce weird plotting symbols and
%    Japanese characters.
%  }
%  Drawback:\cr
%You cannot use mathematical expressions (\code{\link{plotmath}}) with
%  Hershey fonts.
%
%  The Hershey characters are organised into a set of fonts.  A
%  particular font is selected by specifying one of the following
%  font families via \code{par(family)} and specifying the desired font
%  face (plain, bold, italic, bold-italic) via \code{par(font)}.
%
%%% The basic "table" is in  ../../../main/engine.c
%  \tabular{ll}{
%    family \tab faces available \cr
%    \code{"HersheySerif"} \tab plain, bold, italic, bold-italic \cr
%    \code{"HersheySans"} \tab plain, bold, italic, bold-italic \cr
%    \code{"HersheyScript"} \tab plain, bold \cr
%    \code{"HersheyGothicEnglish"} \tab plain \cr
%    \code{"HersheyGothicGerman"} \tab plain \cr
%    \code{"HersheyGothicItalian"} \tab plain \cr
%    \code{"HersheySymbol"} \tab plain, bold, italic, bold-italic \cr
%    \code{"HersheySansSymbol"} \tab plain, italic \cr
%  }
%
%  In the \code{vfont} specification for the \code{text} and
%  \code{contour} functions, the Hershey font is specified by a typeface
%  (e.g., \code{serif} or \code{sans serif}) and a fontindex or
%  \sQuote{style} (e.g., \code{plain} or \code{italic}). The first
%  element of \code{vfont} specifies the typeface and the second element
%  specifies the fontindex.  The first table produced by
%  \code{demo(Hershey)} shows the character \code{a} produced by each of
%  the different fonts.
%
%  The available \code{typeface} and \code{fontindex} values are
%  available as list components of the variable \code{Hershey}.
%  The allowed pairs for \code{(typeface, fontindex)} are:
%%% This is checked (via max{#}) in FixupVFont() ../../../main/plot.c
%%% The basic "table" really is in  ../../../modules/vfonts/g_fontdb.c
%
%  \tabular{ll}{
%    serif \tab plain \cr
%    serif \tab italic \cr
%    serif \tab bold \cr
%    serif \tab bold italic \cr
%    serif \tab cyrillic \cr
%    serif \tab oblique cyrillic \cr
%    serif \tab EUC \cr
%    sans serif \tab plain \cr
%    sans serif \tab italic \cr
%    sans serif \tab bold \cr
%    sans serif \tab bold italic \cr
%    script \tab plain \cr
%    script \tab italic \cr
%    script \tab bold \cr
%    gothic english \tab plain \cr
%    gothic german \tab plain \cr
%    gothic italian \tab plain \cr
%    serif symbol \tab plain \cr
%    serif symbol \tab italic \cr
%    serif symbol \tab bold \cr
%    serif symbol \tab bold italic \cr
%    sans serif symbol \tab plain \cr
%    sans serif symbol \tab italic \cr
%  }
%  and the indices of these are available as \code{Hershey$allowed}.
%
%  \describe{
%    \item{Escape sequences:}{The string to be drawn can include escape
%      sequences, which all begin with a \samp{\\}.   When \R encounters a
%      \samp{\\}, rather than drawing the \samp{\\}, it treats the
%      subsequent character(s) as a coded description of what to draw.
%
%      One useful escape sequence (in the current context) is of the
%      form: \samp{\\123}.  The three digits following the \samp{\\}
%      specify an octal code for a character.  For example, the octal
%      code for \code{p} is 160 so the strings \code{"p"} and
%      \code{"\\160"} are equivalent. This is useful for producing
%      characters when there is not an appropriate key on your keyboard.
%
%      The other useful escape sequences all begin with \samp{\\\\}.
%      These are described below.  Remember that backslashes have to be
%      doubled in \R character strings, so they need to be entered with
%      \emph{four} backslashes.
%    }
%
%    \item{Symbols:}{an entire string of Greek symbols can be produced by
%      selecting the HersheySymbol or HersheySansSymbol family or the
%      Serif Symbol or Sans Serif Symbol typeface.  To allow Greek
%      symbols to be embedded in a string which uses a non-symbol
%      typeface, there are a set of symbol escape sequences of the form
%      \samp{\\\\ab}. For example, the escape sequence \samp{\\\\*a}
%      produces a Greek alpha.  The second table in \code{demo(Hershey)}
%      shows all of the symbol escape sequences and the symbols that they
%      produce.
%    }
%
%    \item{ISO Latin-1:}{further escape sequences of the form
%      \samp{\\\\ab} are provided for producing ISO Latin-1 characters.
%      Another option is to use the appropriate octal code.  The
%      (non-ASCII) ISO Latin-1 characters are in the range 241\dots{}377.
%      For example, \samp{\\366} produces the character o with an umlaut.
%      The third table in \code{demo(Hershey)} shows all of the ISO
%      Latin-1 escape sequences.
%
%      These characters can be used directly.  (Characters not in Latin-1
%      are replaced by a dot.)
%
%      Several characters are missing, c-cedilla has no cedilla and
%      \sQuote{sharp s} (\samp{U+00DF}, also known as \sQuote{esszett})
%      is rendered as \code{ss}.
%    }
%
%    \item{Special Characters:}{a set of characters are provided which
%      do not fall into any standard font.  These can only be accessed by
%      escape sequence.  For example, \samp{\\\\LI} produces the zodiac sign for
%      Libra, and \samp{\\\\JU} produces the astronomical sign for Jupiter.
%      The fourth table in \code{demo(Hershey)} shows all of the
%      special character escape sequences.
%    }
%
%    \item{Cyrillic Characters:}{cyrillic characters are implemented
%      according to the K018-R encoding, and can be used directly in such
%      a locale using the Serif typeface and Cyrillic (or Oblique Cyrillic)
%      fontindex.  Alternatively they can be specified via an octal code
%      in the range 300 to 337 for lower case characters or 340 to 377 for
%      upper case characters.  The fifth table in \code{demo(Hershey)} shows the
%      octal codes for the available Cyrillic characters.
%
%      Cyrillic has to be selected via a \code{("serif", fontindex)} pair
%      rather than via a font family.
%    }
%
%    \item{Japanese Characters:}{83 Hiragana, 86 Katakana, and 603 Kanji
%      characters are implemented according to the EUC-JP (Extended Unix Code)
%      encoding. Each character is identified by a unique hexadecimal code.
%      The Hiragana characters
%      are in the range 0x2421 to 0x2473, Katakana are in the range 0x2521 to
%      0x2576, and Kanji are (scattered about) in the range 0x3021 to 0x6d55.
%
%      When using the Serif typeface and EUC
%      fontindex, these characters can be produced by a \emph{pair} of octal
%      codes.  Given the hexadecimal code (e.g., 0x2421), take the first two
%      digits and add 0x80 and do the same to the second two digits (e.g.,
%      0x21 and 0x24 become 0xa4 and 0xa1), then convert both to octal (e.g.,
%      0xa4 and 0xa1 become 244 and 241).  For example, the first Hiragana
%      character is produced by \samp{\\244\\241}.
%
%      It is also possible to use the hexadecimal code directly.  This works
%      for all non-EUC fonts by specifying an escape sequence of the form
%      \samp{\\\\#J1234}.  For example, the first Hiragana character is produced
%      by \samp{\\\\#J2421}.
%
%      The Kanji characters may be specified in a third way, using the
%      so-called "Nelson Index", by specifying an escape sequence of the form
%      \samp{\\\\#N1234}.  For example, the (obsolete) Kanji for \sQuote{one} is
%      produced by \samp{\\\\#N0001}.
%
%      \code{demo(Japanese)} shows the available Japanese characters.
%    }
%
%    \item{Raw Hershey Glyphs:}{all of the characters in the Hershey
%      fonts are stored in a large array.  Some characters are not
%      accessible in any of the Hershey fonts.  These characters can only
%      be accessed via an escape sequence of the form \samp{\\\\#H1234}.
%      For example, the fleur-de-lys is produced by \samp{\\\\#H0746}.
%      The sixth and seventh tables of \code{demo(Hershey)} shows all of
%      the available raw glyphs.
%    }
%  }
%}
%
%\references{
%  \url{https://www.gnu.org/software/plotutils/plotutils.html}.
%}
%\seealso{ \code{\link{demo}(Hershey)}, \code{\link{par}},
%  \code{\link{text}}, \code{\link{contour}}.
%
%  \code{\link{Japanese}} for the Japanese characters in the Hershey fonts.
%}
%\examples{
%Hershey
%
%## for tables of examples, see demo(Hershey)
%}
%\keyword{aplot}
%
%\encoding{UTF-8}
%