% File src/library/grDevices/man/axisTicks.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2011-2013 R Core Team
% Distributed under GPL 2 or later

\name{axisTicks}
\alias{axisTicks}
\title{見栄えの良い軸チックスケールの計算}
\alias{.axisPars}
%%\title{Compute Pretty Axis Tick Scales}
\description{
  伝統的な \R グラフィックスが行うような，
  見栄えの良い軸スケールとチックマーク位置を計算する．
  これは特に対数スケール軸に対して興味深い．
}
\usage{
axisTicks(usr, log, axp = NULL, nint = 5)
 .axisPars(usr, log = FALSE, nintLog = 5)
}
\arguments{
  \item{usr}{長さ 2 の数値ベクトルで，
    軸範囲 \code{c(min, max)} を持つ．}
  \item{log}{対数スケールが使用される(予定)じかどうかを指示する論理値．}
  \item{axp}{長さ 3 の数値ベクトル \code{c(mi, ma, n.)} で，
    \code{\link{par}("?axp")} と同じ意味(ここで \code{?} は
    \code{x} か \code{y})を持つ，つまり
    \dQuote{見栄えの良い}軸範囲で，
    \code{n.} は整数\emph{コード}．
    %% FIXME: Explain meaning -- different for log and "not-log"
  }
  \item{nint, nintLog}{
    (\emph{おおよその})希望の区間数を指示する正整数．
    \code{nintLog} は
    \code{log = TRUE} の場合\bold{だけ}使われる．}
}
\details{
  \code{axisTicks(usr, *)} は
  \code{axp} が欠損している時
  \code{.axisPars(usr, ..)} を呼び出す．

% FIXME: say more
}
\value{
  \code{axisTicks()} は長さがおおよそ \code{nint+1} の
  可能な軸チックの数値ベクトルを返す．

  \code{.axisPars()} は次の成分を持つリストを返す
  \item{axp}{見栄えの良い軸範囲の長さ 2 の数値ベクトル \code{c(min., max.)}．}
  \item{n}{整数(コード)，\code{\link{par}("?axp")[3]} と同じ意味．}
}
\seealso{
  \code{\link{axTicks}};
  \code{\link[graphics]{axis}} そして \code{\link[graphics]{par}}
  (パッケージ \pkg{graphics} から)．
}
\examples{
##--- グラフィックスの axis() とグラフィックスエンジンと
##--- 独立な axisTicks() の比較 ：

require("graphics")
plot(10*(0:10)); (pu <- par("usr"))
aX <- function(side, at, ...)
    axis(side, at = at, labels = FALSE, lwd.ticks = 2, col.ticks = 2,
         tck = 0.05, ...)
aX(1, print(xa <- axisTicks(pu[1:2], log = FALSE)))  # x 軸
aX(2, print(ya <- axisTicks(pu[3:4], log = FALSE)))  # y 軸

axisTicks(pu[3:4], log = FALSE, n = 10)

plot(10*(0:10), log = "y"); (pu <- par("usr"))
aX(2, print(ya <- axisTicks(pu[3:4], log = TRUE)))  # y 軸

plot(2^(0:9), log = "y"); (pu <- par("usr"))
aX(2, print(ya <- axisTicks(pu[3:4], log = TRUE)))  # y 軸

}
\keyword{dplot}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/axisTicks.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2011-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{axisTicks}
%\alias{axisTicks}
%\alias{.axisPars}
%\title{Compute Pretty Axis Tick Scales}
%\description{
%  Compute pretty axis scales and tick mark locations, the same way as
%  traditional \R graphics do it.  This is interesting particularly for
%  log scale axes.
%}
%\usage{
%axisTicks(usr, log, axp = NULL, nint = 5)
% .axisPars(usr, log = FALSE, nintLog = 5)
%}
%\arguments{
%  \item{usr}{numeric vector of length 2, with \code{c(min, max)} axis
%    extents.}
%  \item{log}{logical indicating if a log scale is (thought to be) in
%    use.}
%  \item{axp}{numeric vector of length 3, \code{c(mi, ma, n.)}, with
%    identical meaning to \code{\link{par}("?axp")} (where \code{?} is
%    \code{x} or \code{y}), namely \dQuote{pretty} axis extents, and an
%    integer \emph{code} \code{n.}.
%    %% FIXME: Explain meaning -- different for log and "not-log"
%  }
%  \item{nint, nintLog}{positive integer value indicating
%    (\emph{approximately}) the desired number of intervals.
%    \code{nintLog} is used \bold{only} for the case \code{log = TRUE}.}
%}
%\details{
%  \code{axisTicks(usr, *)} calls \code{.axisPars(usr, ..)} when
%  \code{axp} is missing (or \code{NULL}).
%% FIXME: say more
%}
%\value{
%  \code{axisTicks()} returns a numeric vector of potential axis tick
%  locations, of length approximately \code{nint+1}.
%
%  \code{.axisPars()} returns a \code{\link{list}} with components
%  \item{axp}{numeric vector of length 2, \code{c(min., max.)}, of pretty
%    axis extents.}
%  \item{n}{integer (code), with the same meaning as
%    \code{\link{par}("?axp")[3]}.}
%}
%\seealso{
%  \code{\link{axTicks}};
%  \code{\link[graphics]{axis}}, and \code{\link[graphics]{par}} (from
%  the \pkg{graphics} package).
%}
%\examples{
%##--- Demonstrating correspondence between graphics'
%##--- axis() and the graphics-engine agnostic  axisTicks() :
%
%require("graphics")
%plot(10*(0:10)); (pu <- par("usr"))
%aX <- function(side, at, ...)
%    axis(side, at = at, labels = FALSE, lwd.ticks = 2, col.ticks = 2,
%         tck = 0.05, ...)
%aX(1, print(xa <- axisTicks(pu[1:2], log = FALSE)))  # x axis
%aX(2, print(ya <- axisTicks(pu[3:4], log = FALSE)))  # y axis
%
%axisTicks(pu[3:4], log = FALSE, n = 10)
%
%plot(10*(0:10), log = "y"); (pu <- par("usr"))
%aX(2, print(ya <- axisTicks(pu[3:4], log = TRUE)))  # y axis
%
%plot(2^(0:9), log = "y"); (pu <- par("usr"))
%aX(2, print(ya <- axisTicks(pu[3:4], log = TRUE)))  # y axis
%
%}
%\keyword{dplot}
%
%\encoding{UTF-8}
%