% File src/library/grDevices/man/convertColor.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{convertColor}
\alias{convertColor}
\title{色空間中の変換}
\alias{colorspaces}
%%\title{Convert between Colour Spaces}
\description{
  標準的な色空間の表現間で色を変換する．
}
\usage{
convertColor(color, from, to, from.ref.white, to.ref.white,
             scale.in = 1, scale.out = 1, clip = TRUE)
}
\arguments{
  \item{color}{行が色を指定する行列．}
  \item{from, to}{入力と出力色空間．下の\sQuote{詳細}節を見よ．}
  \item{from.ref.white, to.ref.white}{
    RGB空間のようにもしそれ等が定義に組み込まれているのなら
    参照白または \code{NULL}．
    \code{D65} が既定値．他については\sQuote{詳細}節を見よ．
  }
  \item{scale.in, scale.out}{
    入力は
    \code{scale.in} で割られ，出力は
    \code{scale.out} 倍される．入力や出力が数値で無ければスケーリングを
    抑制するには \code{NULL} を使う．}
  \item{clip}{もし \code{TRUE} なら，RGB 出力を [0,1] に
    切り詰める，
    \code{FALSE} は範囲外の RGB を返す，\code{NA} は範囲外の色を
    \code{NaN} に設定する．}
}
\details{
  色空間はクラス
  \code{colorConverter} のオブジェクトで指定され，
  \code{\link{colorConverter}} 又は \code{\link{make.rgb}} で
  作られる．組み込みの色空間は文字列で参照出来る：
  \code{"XYZ"}, \code{"sRGB"}, \code{"Apple RGB"}, \code{"CIE RGB"}, \code{"Lab"},
  \code{"Luv"}．これらの色空間に対する変換関数は
  オブジェクト \code{colorspaces} 中にある．

  \code{"sRGB"} 色空間は標準の PC モニターで使われるものである．
  \code{"Apple RGB"} は Apple モニターで使われる．\code{"Lab"} と
  \code{"Luv"} は Commission Internationale d'Eclairage で
  標準化されたおおよそ感覚的に一様な空間である．
  \code{XYZ} は 1931 CIE 標準で全ての可視の色を表現できるが，
  感覚的に一様ではない．

  \code{Lab} と \code{Luv} 空間はオブジェクトの色を記述し，
  従って
  \sQuote{白色}色を参照する必要がある．
  発光性の \code{D65} は標準の間接光の昼光色，
  発光性の \code{D50} は直射日光に近く，
  発光性の \code{A} 白熱電球からの光である．
  他の標準の CIE 発光色は \code{B}, \code{C}, \code{E} そして
  \code{D55} をサポートしている．RGB 色空間は特定の参照白色に関して
  定義されており，他の参照白色に近似的にしか変換できない．
  Bradford の色彩適合アルゴリズムがこれに対して使われる．

  RGB 色空間は特定のクラスのディスプレイに固有である．
  RGB 空間は全ての色を表現できず，
  \code{clip} オプションは範囲外の色をどうするかを制御する．
  
  名前付きの色空間に対しては \code{color} は
  \code{from} 色空間中の値の行列でなければならない：特に不透明色．
}
\value{
  行が色を指定する3列の行列．
}

\references{
  全ての変換式については \url{http://www.brucelindbloom.com/}．

  白点については
  \url{http://www.efg2.com/Lab/Graphics/Colors/Chromaticity.htm}．
}

\seealso{
  グラフィックス中の色の指定法は \code{\link{col2rgb}} と \code{\link{colors}}．

  他の色空間の指定には \code{\link{make.rgb}}．
}
\examples{
## Lab 空間の四つの平面からの表示可能な色
ab <- expand.grid(a = (-10:15)*10,
                  b = (-15:10)*10)
require(graphics); require(stats) # na.omit に対して
par(mfrow = c(2, 2), mar = .1+c(3, 3, 3, .5), mgp = c(2,  .8,  0))

Lab <- cbind(L = 20, ab)
srgb <- convertColor(Lab, from = "Lab", to = "sRGB", clip = NA)
clipped <- attr(na.omit(srgb), "na.action")
srgb[clipped, ] <- 0
cols <- rgb(srgb[, 1], srgb[, 2], srgb[, 3])
image((-10:15)*10, (-15:10)*10, matrix(1:(26*26), ncol = 26), col = cols,
  xlab = "a", ylab = "b", main = "Lab: L=20")

Lab <- cbind(L = 40, ab)
srgb <- convertColor(Lab, from = "Lab", to = "sRGB", clip = NA)
clipped <- attr(na.omit(srgb), "na.action")
srgb[clipped, ] <- 0
cols <- rgb(srgb[, 1], srgb[, 2], srgb[, 3])
image((-10:15)*10, (-15:10)*10, matrix(1:(26*26), ncol = 26), col = cols,
  xlab = "a", ylab = "b", main = "Lab: L=40")

Lab <- cbind(L = 60, ab)
srgb <- convertColor(Lab, from = "Lab", to = "sRGB", clip = NA)
clipped <- attr(na.omit(srgb), "na.action")
srgb[clipped, ] <- 0
cols <- rgb(srgb[, 1], srgb[, 2], srgb[, 3])
image((-10:15)*10, (-15:10)*10, matrix(1:(26*26), ncol = 26), col = cols,
  xlab = "a", ylab = "b", main = "Lab: L=60")

Lab <- cbind(L = 80, ab)
srgb <- convertColor(Lab, from = "Lab", to = "sRGB", clip = NA)
clipped <- attr(na.omit(srgb), "na.action")
srgb[clipped, ] <- 0
cols <- rgb(srgb[, 1], srgb[, 2], srgb[, 3])
image((-10:15)*10, (-15:10)*10, matrix(1:(26*26), ncol = 26), col = cols,
  xlab = "a", ylab = "b", main = "Lab: L=80")

cols <- t(col2rgb(palette())); rownames(cols) <- palette(); cols
zapsmall(lab <- convertColor(cols, from = "sRGB", to = "Lab", scale.in = 255))
stopifnot(all.equal(cols, # 元に変換し直す．オリジナルを得るｄ：
   round(convertColor(lab, from = "Lab", to = "sRGB", scale.out = 255)),
                    check.attributes = FALSE))
}
\keyword{color}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/convertColor.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{convertColor}
%\alias{convertColor}
%\alias{colorspaces}
%\title{Convert between Colour Spaces}
%\description{
%  Convert colours between their representations in standard
%  colour spaces.
%}
%\usage{
%convertColor(color, from, to, from.ref.white, to.ref.white,
%             scale.in = 1, scale.out = 1, clip = TRUE)
%}
%\arguments{
%  \item{color}{A matrix whose rows specify colors.}
%  \item{from, to}{Input and output color spaces.  See \sQuote{Details} below.}
%  \item{from.ref.white, to.ref.white}{Reference whites or \code{NULL}
%    if these are built in to the definition, as for RGB
%    spaces. \code{D65} is the default, see \sQuote{Details} for others.
%  }
%  \item{scale.in, scale.out}{Input is divided by \code{scale.in}, output
%    is multiplied by \code{scale.out}. Use \code{NULL} to suppress
%    scaling when input or output is not numeric.}
%  \item{clip}{If \code{TRUE}, truncate RGB output to [0,1],
%    \code{FALSE} return out-of-range RGB, \code{NA} set out of range
%    colors to \code{NaN}.}
%}
%\details{
%  Color spaces are specified by objects of class \code{colorConverter},
%  created by \code{\link{colorConverter}} or \code{\link{make.rgb}}.
%  Built-in color spaces may be referenced by strings: \code{"XYZ"},
%  \code{"sRGB"}, \code{"Apple RGB"}, \code{"CIE RGB"}, \code{"Lab"},
%  \code{"Luv"}.  The converters for these colour spaces are in the object
%  \code{colorspaces}.
%
%  The \code{"sRGB"} color space is that used by standard PC monitors.
%  \code{"Apple RGB"} is used by Apple monitors. \code{"Lab"} and
%  \code{"Luv"} are approximately perceptually uniform
%  spaces standardized by the Commission Internationale
%  d'Eclairage. \code{XYZ} is a 1931 CIE standard capable of representing
%  all visible colors (and then some), but not in a perceptually uniform
%  way.
%
%  The \code{Lab} and \code{Luv} spaces describe colors of objects, and
%  so require the specification of a reference \sQuote{white light}
%  color.  Illuminant \code{D65} is a standard indirect daylight,
%  Illuminant \code{D50} is close to direct sunlight, and Illuminant
%  \code{A} is the light from a standard incandescent bulb. Other
%  standard CIE illuminants supported are \code{B}, \code{C}, \code{E} and
%  \code{D55}.  RGB colour spaces are defined relative to a particular
%  reference white, and can be only approximately translated to other
%  reference whites.  The Bradford chromatic adaptation algorithm is used
%  for this.
%
%  The RGB color spaces are specific to a particular class of display.
%  An RGB space cannot represent all colors, and the \code{clip} option
%  controls what is done to out-of-range colors.
%  
%  For the named color spaces \code{color} must be a matrix of values in
%  the \code{from} color space: in particular opaque colors.
%}
%\value{
%  A 3-column matrix whose rows specify the colors.
%}
%
%\references{
%  For all the conversion equations \url{http://www.brucelindbloom.com/}.
%
%  For the white points
%  \url{http://www.efg2.com/Lab/Graphics/Colors/Chromaticity.htm}.
%}
%
%\seealso{
%  \code{\link{col2rgb}} and \code{\link{colors}} for ways to specify
%  colors in graphics.
%
%  \code{\link{make.rgb}} for specifying other colour spaces.
%}
%\examples{
%## The displayable colors from four planes of Lab space
%ab <- expand.grid(a = (-10:15)*10,
%                  b = (-15:10)*10)
%require(graphics); require(stats) # for na.omit
%par(mfrow = c(2, 2), mar = .1+c(3, 3, 3, .5), mgp = c(2,  .8,  0))
%
%Lab <- cbind(L = 20, ab)
%srgb <- convertColor(Lab, from = "Lab", to = "sRGB", clip = NA)
%clipped <- attr(na.omit(srgb), "na.action")
%srgb[clipped, ] <- 0
%cols <- rgb(srgb[, 1], srgb[, 2], srgb[, 3])
%image((-10:15)*10, (-15:10)*10, matrix(1:(26*26), ncol = 26), col = cols,
%  xlab = "a", ylab = "b", main = "Lab: L=20")
%
%Lab <- cbind(L = 40, ab)
%srgb <- convertColor(Lab, from = "Lab", to = "sRGB", clip = NA)
%clipped <- attr(na.omit(srgb), "na.action")
%srgb[clipped, ] <- 0
%cols <- rgb(srgb[, 1], srgb[, 2], srgb[, 3])
%image((-10:15)*10, (-15:10)*10, matrix(1:(26*26), ncol = 26), col = cols,
%  xlab = "a", ylab = "b", main = "Lab: L=40")
%
%Lab <- cbind(L = 60, ab)
%srgb <- convertColor(Lab, from = "Lab", to = "sRGB", clip = NA)
%clipped <- attr(na.omit(srgb), "na.action")
%srgb[clipped, ] <- 0
%cols <- rgb(srgb[, 1], srgb[, 2], srgb[, 3])
%image((-10:15)*10, (-15:10)*10, matrix(1:(26*26), ncol = 26), col = cols,
%  xlab = "a", ylab = "b", main = "Lab: L=60")
%
%Lab <- cbind(L = 80, ab)
%srgb <- convertColor(Lab, from = "Lab", to = "sRGB", clip = NA)
%clipped <- attr(na.omit(srgb), "na.action")
%srgb[clipped, ] <- 0
%cols <- rgb(srgb[, 1], srgb[, 2], srgb[, 3])
%image((-10:15)*10, (-15:10)*10, matrix(1:(26*26), ncol = 26), col = cols,
%  xlab = "a", ylab = "b", main = "Lab: L=80")
%
%cols <- t(col2rgb(palette())); rownames(cols) <- palette(); cols
%zapsmall(lab <- convertColor(cols, from = "sRGB", to = "Lab", scale.in = 255))
%stopifnot(all.equal(cols, # converting back.. getting the original:
%   round(convertColor(lab, from = "Lab", to = "sRGB", scale.out = 255)),
%                    check.attributes = FALSE))
%}
%\keyword{color}
%
%\encoding{UTF-8}
%