% File src/library/grDevices/man/dev.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{dev}
\title{複数のグラフィックスデバイスを制御する関数}
\alias{dev.cur}
\alias{dev.list}
\alias{dev.next}
\alias{dev.prev}
\alias{dev.off}
\alias{dev.set}
\alias{dev.new}
\alias{graphics.off}
%%\title{Control Multiple Devices}
\description{
  これらの関数は複数のグラフィックスデバイスの制御を提供する．
}
\usage{
dev.cur()
dev.list()
dev.next(which = dev.cur())
dev.prev(which = dev.cur())
dev.off(which = dev.cur())
dev.set(which = dev.next())
dev.new(\dots, noRStudioGD = FALSE)
graphics.off()
}

\arguments{
  \item{which}{デバイス番号を指定する整数．}
  \item{\dots}{選択されたデバイスに渡される引数．}
  \item{noRStudioGD}{
    RStudio グラフィックスをたとえそれが既定とされていても使用しない：
    これは \code{width} や \code{height} といった引数を受け入れない．}
}
\details{
  ただ一つのデバイスだけが\sQuote{アクティブ}なデバイスである：これは
  全てのグラフィックス操作が行われるデバイスである．
  常に開かれている \code{"null device"} があるがこれは
  実際は代替物である：それを使うあらゆる試みは
  \code{\link{getOption}("device")}) で指定される新しいデバイスを開く．

  デバイスには名前(例えば \code{"X11"} や
  \code{"postscript"}) そして範囲 1 から 63 の番号が伴う：
  \code{"null device"} は常にデバイス 1 である．
  一旦一つのデバイスが開かれていると null デバイスは
  可能なアクティブデバイスとは考えらない．
  開かれているデバイスのリストがあり，
  これは null デバイスを含まない巡回的なリストと考えられる．
  \code{dev.next} と \code{dev.prev} は如何なるデバイスも開かれていなければ
  適当な方向での次のデバイスを選ぶ．

  \code{dev.off} は指定された(既定では現在の)デバイスを閉じる．
  もし現在のデバイスが閉じられ任意の他のデバイスが開かれると，次の
  開かれたデバイスが現在のデバイスとされる．
  デバイス 1 を閉じるのはエラーになる．
  \code{graphics.off()} は全ての開かれたグラフィックスデバイスを閉じる．
  セッションの正常な終了は内部的に
  \code{graphics.off()} と同値なものを実行する．

  \code{dev.set} は指定されたデバイスをアクティブなデバイスにする．
  もしその番号のデバイスが存在しなければ，
  それは \code{dev.next} と同値である．
  もし \code{which = 1} ならばそれは新しいデバイスを開きそれを選択する．

  \code{dev.new} は新しいデバイスを開く．
  通常 \R は必要なときは新しいデバイスを自動的に開くが，
  これは更なるデバイスをプラットホーム依存の仕方で
  開くことを可能にする．
  (そのデバイスが使われるかは \code{\link{getOption}("device")} を見よ．)
  \code{\link{pdf}} と \code{\link{postscript}} のようなファイルベースの
  デバイスと，
  \file{Rplots.pdf}, \file{Rplots1.pdf}, \dots, \file{Rplots999.pdf}
  のようなファイル名が順番に試みられる時は注意がいる．
  名前付きの引数で
  デバイスの引数リストにマッチした時だけデバイスに渡される．，
  その場合も，例えば
  \code{width} の解釈には注意がいり，
  標準のビットマップデバイスに対してはどちらも提供されていなければ
  \code{units = "in", res = 72} が強制されるが，
  \code{width} と \code{height} の双方が提供されていればその限りではない．
}
\value{
  \code{dev.cur} はアクティブなデバイスの番号と名前を与える長さ1の名前付き
  整数ベクトルを返す．もしどれもアクティブでなければ
  null デバイスの 1 を返す．

  \code{dev.list} は全ての開かれているデバイスの番号を返す．
  例外は null デバイスの 1．
  これはデバイス名を与える \code{\link{names}} 属性を持つ数値ベクトルである，
  又は開かれたデバイスが無ければ \code{NULL}．

  \code{dev.next} と \code{dev.prev} は
  デバイスリスト中の次/前のデバイスの番号と名前を返す．
  これは開かれたデバイスが一つもない時そしてその時だけ
  null デバイスである．

  \code{dev.off} は新しいアクティブなデバイスの番号と名前を返す
  (指定されたデバイスが閉じられた後に)．

  \code{dev.set} は新しいアクティブなデバイスの番号と名前を返す．

  \code{dev.new} は開かれている開かれているデバイスの返り値を返す，
  普通不可視の \code{NULL}．
}
\seealso{
  \code{\link{postscript}} 等の \code{\link{Devices}}．

  現在のデバイス上のプロット領域を設定するには \code{\link{layout}} と
  そのリンク．
}
\examples{
\dontrun{## Unix 固有の例
x11()
plot(1:10)
x11()
plot(rnorm(10))
dev.set(dev.prev())
abline(0, 1) # 1:10 の点通って
dev.set(dev.next())
abline(h = 0, col = "gray") # 残差プロットには
dev.set(dev.prev())
dev.off(); dev.off() #- 二つの X デバイスを閉じる
}
}
\keyword{device}
\keyword{iplot}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/dev.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{dev}
%\alias{dev.cur}
%\alias{dev.list}
%\alias{dev.next}
%\alias{dev.prev}
%\alias{dev.off}
%\alias{dev.set}
%\alias{dev.new}
%\alias{graphics.off}
%\title{Control Multiple Devices}
%\description{
%  These functions provide control over multiple graphics devices.
%}
%\usage{
%dev.cur()
%dev.list()
%dev.next(which = dev.cur())
%dev.prev(which = dev.cur())
%dev.off(which = dev.cur())
%dev.set(which = dev.next())
%dev.new(\dots, noRStudioGD = FALSE)
%graphics.off()
%}
%
%\arguments{
%  \item{which}{An integer specifying a device number.}
%  \item{\dots}{arguments to be passed to the device selected.}
%  \item{noRStudioGD}{Do not use the RStudio graphics device even if
%    specified as the default device: it does not accept arguments such
%    as \code{width} and \code{height}.}
%}
%\details{
%  Only one device is the \sQuote{active} device: this is the device in
%  which all graphics operations occur.  There is a \code{"null device"}
%  which is always open but is really a placeholder: any attempt to use
%  it will open a new device specified by
%  \code{\link{getOption}("device")}).
%
%  Devices are associated with a name (e.g., \code{"X11"} or
%  \code{"postscript"}) and a number in the range 1 to 63; the
%  \code{"null device"} is always device 1.  Once a device has been
%  opened the null device is not considered as a possible active device.
%  There is a list of open devices, and this is considered as a circular
%  list not including the null device.  \code{dev.next} and
%  \code{dev.prev} select the next open device in the appropriate
%  direction, unless no device is open.
%
%  \code{dev.off} shuts down the specified (by default the current)
%  device.  If the current device is shut down and any other devices are
%  open, the next open device is made current.  It is an error to
%  attempt to shut down device 1.  \code{graphics.off()} shuts down all
%  open graphics devices.  Normal termination of a session runs the
%  internal equivalent of \code{graphics.off()}.
%
%  \code{dev.set} makes the specified device the active device.  If there
%  is no device with that number, it is equivalent to \code{dev.next}.
%  If \code{which = 1} it opens a new device and selects that.
%
%  \code{dev.new} opens a new device.  Normally \R will open a new device
%  automatically when needed, but this enables you to open further
%  devices in a platform-independent way.  (For which device is used see
%  \code{\link{getOption}("device")}.)  Note that care is needed with
%  file-based devices such as \code{\link{pdf}} and
%  \code{\link{postscript}} and in that case file names such as
%  \file{Rplots.pdf}, \file{Rplots1.pdf}, \dots, \file{Rplots999.pdf} are
%  tried in turn.  Only named arguments are passed to the device, and
%  then only if they match the argument list of the device.  Even so,
%  care is needed with the interpretation of e.g.\sspace{}\code{width}, and for
%  the standard bitmap devices \code{units = "in", res = 72} is forced if
%  neither is supplied but both \code{width} and \code{height} are.
%}
%\value{
%  \code{dev.cur} returns a length-one named integer vector giving the
%  number and name of the active device, or 1, the null device, if none
%  is active.
%
%  \code{dev.list} returns the numbers of all open devices, except device
%  1, the null device.  This is a numeric vector with a
%  \code{\link{names}} attribute giving the device names, or \code{NULL} is
%  there is no open device.
%
%  \code{dev.next} and \code{dev.prev} return the number and name of the
%  next / previous device in the list of devices.  This will be the null
%  device if and only if there are no open devices.
%
%  \code{dev.off} returns the number and name of the new active device
%  (after the specified device has been shut down).
%
%  \code{dev.set} returns the number and name of the new active device.
%
%  \code{dev.new} returns the return value of the device opened, usually
%  invisible \code{NULL}.
%}
%\seealso{
%  \code{\link{Devices}}, such as \code{\link{postscript}}, etc.
%
%  \code{\link{layout}} and its links for setting up plotting regions
%  on the current device.
%}
%\examples{
%\dontrun{## Unix-specific example
%x11()
%plot(1:10)
%x11()
%plot(rnorm(10))
%dev.set(dev.prev())
%abline(0, 1) # through the 1:10 points
%dev.set(dev.next())
%abline(h = 0, col = "gray") # for the residual plot
%dev.set(dev.prev())
%dev.off(); dev.off() #- close the two X devices
%}
%}
%\keyword{device}
%\keyword{iplot}
%
%\encoding{UTF-8}
%