% File src/library/grDevices/man/getGraphicsEvent.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{getGraphicsEvent}
\title{getGraphicsEvent}
\alias{getGraphicsEvent}
\alias{setGraphicsEventHandlers}
\alias{getGraphicsEventEnv}
\alias{setGraphicsEventEnv}
%%\title{Wait for a mouse or keyboard event from a graphics window}
\description{
この関数はグラフィックスウィンドからのマウス又はキーボードイベントの
形での入力を待つ．
}
\usage{
getGraphicsEvent(prompt = "Waiting for input",
                 onMouseDown = NULL, onMouseMove = NULL,
                 onMouseUp = NULL, onKeybd = NULL,
                 consolePrompt = prompt)
setGraphicsEventHandlers(which = dev.cur(), ...)
getGraphicsEventEnv(which = dev.cur())
setGraphicsEventEnv(which = dev.cur(), env)

}
\arguments{
  \item{prompt}{グラフィックスウィンド中でユーザに表示されるプロンプト．}
  \item{onMouseDown}{マウスのクリックに対応する関数．}
  \item{onMouseMove}{マウスの動きに対応する関数．}
  \item{onMouseUp}{マウスボタンの解放に対応する関数．}
  \item{onKeybd}{キーの押下に対応する関数．}
  \item{consolePrompt}{コンソール中でユーザに表示されるプロンプト．}
  \item{which}{どのウィンドに呼び出しが適用されるか?}
  \item{...}{イベントの環境中に置かれるハンドラーを含む項目．}
  \item{env}{イベントの環境として使われる環境．}
}
\details{
これらの関数はあるグラフィックスデバイスからのユーザの入力を許す
(現在基本 \R 中の \code{windows()} と \code{X11(type = "Xlib")}
スクリーンデバイスに見)．マウスやキーボードを含むイベントに
対応するイベントハンドラーをインストールすることが出来る．

これらの関数は次のように関係している．
\code{getGraphicsEvent} への最初の五つの引数のどれかが
与えられると，それはこれらを
現在のデバイス中の任意の存在するハンドラーを置き換えるために
\code{setGraphicsEventHandlers} への呼び出し中で使われる．
これは 2.12.0 以前の \R との互換性のためである．
イベントハンドラーを設定する現在の方法は
それらを一つ又は複数のグラフィックスデバイス上で
\code{setGraphicsEventHandlers} 又は \code{setGraphicsEventEnv} を
使い，それからイベントを回収するため
引数無しで \code{getGraphicsEvent()} を使うことである．
\code{getGraphicsEventEnv()} は後で使うためにイベントの環境を
保存するために使うことが出来る．

\code{getGraphicsEvent} 中の引数の名前は特別である．
イベントを処理する際，グラフィックスシステムは
イベントの環境で
\code{onMouseDown}, \code{onMouseMove}, \code{onMouseUp}
そして \code{onKeybd} という名前の関数を探しそれらをイベントハンドラーとして
使う．
それはグラフィックスデバイスのラベルとして \code{prompt} を使う．
他の二つの特別な名前はグラフィックスデバイスを特定する \code{which} と
直近のイベントハンドラーの結果が
\code{getGraphicsEvent()} で返される前に保存される \code{result} である．

マウスイベントハンドラーはヘッダー
\code{function(buttons, x, y)} を持つ関数でなければならない．
座標 \code{x} と \code{y} はデバイス独立な座標
(つまりウィンドの下左隅が \code{(0,0)} で
上右が \code{(1,1)})中でマウスイベントハンドラーに
渡される．\code{buttons} 引数はイベント時に押されたボタンを
リストするベクトルであり，
左は 0，中央は 1 そして右は 2 である．

キーボードイベントハンドラーはヘッダー
\code{function(key)} を持つ関数でなければならない．
シフトやその他の修飾キーは処理されているので，
\code{shift-a} は \code{"A"} として渡される．
次の特殊キーもハンドラーに渡されるかもしれない：
\itemize{
     \item コントロールキー，\code{"Ctrl-A"} 等として渡される．
     \item 方向キー，次の一つとして渡される\cr
     \code{"Left", "Up", "Right", "Down", "PgUp", "PgDn", "End", "Home"}
     \item 編集キー，\code{"Ins", "Del"} の一つとして渡される．
     \item 関数キー，\code{"F1", "F2", ...} の一つとして渡される．
}

イベントハンドラーは標準の R 関数であり，イベントの環境から呼び出され実行される．

対話的なセッション中ではイベントは以下が起きるまで処理される
\itemize{
     \item イベントハンドラ―の一つが
      \code{getGraphicsEvent} の値として返される
      \code{NULL} でない値を返す．
      \item ユーザがコンソールから関数を中断する．
}
}
\value{
対話的に実行されている時，
\code{getGraphicsEvent} はイベントハンドラーのどれかから返される
\code{NULL} でない値を返す．対話的でないセッションでは，
\code{getGraphicsEvent} は即座に \code{NULL} を返す．
それは又もしユーザがグラフィックスハンドラーを持つ直近のウィンドを
閉じれば \code{NULL} を返す．

\code{getGraphicsEventEnv} はグラフィックスデバイスに対する現在のイベント
環境を返すか，又は何も設定されていなければ \code{NULL} を返す．

\code{setGraphicsEventEnv} そして \code{setGraphicsEventHandlers} は
グラフィックスデバイスに対する以前のイベント環境を返す．
}
\author{Duncan Murdoch}
\examples{
# これは現在 Windows と
# X11(type = "Xlib") スクリーンデバイスだけで動く...
\dontrun{
savepar <- par(ask = FALSE)
dragplot <- function(..., xlim = NULL, ylim = NULL, xaxs = "r", yaxs = "r") {
    plot(..., xlim = xlim, ylim = ylim, xaxs = xaxs, yaxs = yaxs)
    startx <- NULL
    starty <- NULL
    prevx <- NULL
    prevy <- NULL
    usr <- NULL

    devset <- function()
        if (dev.cur() != eventEnv$which) dev.set(eventEnv$which)

    dragmousedown <- function(buttons, x, y) {
        startx <<- x
        starty <<- y
        prevx <<- 0
        prevy <<- 0
        devset()
        usr <<- par("usr")
        eventEnv$onMouseMove <- dragmousemove
        NULL
    }

    dragmousemove <- function(buttons, x, y) {
        devset()
        deltax <- diff(grconvertX(c(startx, x), "ndc", "user"))
        deltay <- diff(grconvertY(c(starty, y), "ndc", "user"))
	if (abs(deltax-prevx) + abs(deltay-prevy) > 0) {
	    plot(..., xlim = usr[1:2]-deltax, xaxs = "i",
		      ylim = usr[3:4]-deltay, yaxs = "i")
	    prevx <<- deltax
	    prevy <<- deltay
	}
        NULL
    }

    mouseup <- function(buttons, x, y) {
    	eventEnv$onMouseMove <- NULL
    }	

    keydown <- function(key) {
        if (key == "q") return(invisible(1))
        eventEnv$onMouseMove <- NULL
        NULL
    }

    setGraphicsEventHandlers(prompt = "Click and drag, hit q to quit",
                     onMouseDown = dragmousedown,
                     onMouseUp = mouseup,
                     onKeybd = keydown)
    eventEnv <- getGraphicsEventEnv()
}

dragplot(rnorm(1000), rnorm(1000))
getGraphicsEvent()
par(savepar)
}
}
\keyword{iplot}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/getGraphicsEvent.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{getGraphicsEvent}
%\alias{getGraphicsEvent}
%\alias{setGraphicsEventHandlers}
%\alias{getGraphicsEventEnv}
%\alias{setGraphicsEventEnv}
%\title{Wait for a mouse or keyboard event from a graphics window}
%\description{
%This function waits for input from a graphics window in the
%form of a mouse or keyboard event.
%}
%\usage{
%getGraphicsEvent(prompt = "Waiting for input",
%                 onMouseDown = NULL, onMouseMove = NULL,
%                 onMouseUp = NULL, onKeybd = NULL,
%                 consolePrompt = prompt)
%setGraphicsEventHandlers(which = dev.cur(), ...)
%getGraphicsEventEnv(which = dev.cur())
%setGraphicsEventEnv(which = dev.cur(), env)
%
%}
%\arguments{
%  \item{prompt}{prompt to be displayed to the user in the graphics window}
%  \item{onMouseDown}{a function to respond to mouse clicks}
%  \item{onMouseMove}{a function to respond to mouse movement}
%  \item{onMouseUp}{a function to respond to mouse button releases}
%  \item{onKeybd}{a function to respond to key presses}
%  \item{consolePrompt}{prompt to be displayed to the user in the console}
%  \item{which}{which graphics device does the call apply to?}
%  \item{...}{items including handlers to be placed in the event environment}
%  \item{env}{an environment to be used as the event environment}
%}
%\details{
%These functions allow user input from some graphics devices (currently
%only the \code{windows()} and \code{X11(type = "Xlib")} screen displays
%in base \R{}). Event handlers may be installed to respond to events
%involving the mouse or keyboard.
%
%The functions are related as follows.  If any of the first five
%arguments to \code{getGraphicsEvent} are given, then it uses those
%in a call to \code{setGraphicsEventHandlers} to replace any existing
%handlers in the current device.  This is for compatibility with pre-2.12.0 \R{}
%versions.  The current normal way to set up event handlers is to
%set them using \code{setGraphicsEventHandlers} or \code{setGraphicsEventEnv} on
%one or more graphics devices, and then use \code{getGraphicsEvent()} with
%no arguments to retrieve event data.
%\code{getGraphicsEventEnv()} may be used to save the event environment
%for use later.
%
%The names of the arguments in \code{getGraphicsEvent} are special.  When
%handling events, the graphics system will look through the event
%environment for functions named \code{onMouseDown}, \code{onMouseMove}, \code{onMouseUp}
%and \code{onKeybd} and use them as event handlers.  It will use
%\code{prompt} for a label on the graphics device.  Two other special names are
%\code{which}, which will identify the graphics device, and
%\code{result}, where the result of the last event
%handler will be stored before being returned by \code{getGraphicsEvent()}.
%
%The mouse event handlers should be functions with header
%\code{function(buttons, x, y)}.  The coordinates \code{x}
%and \code{y} will be passed to mouse event handlers in device independent
%coordinates (i.e., the lower left corner of the window is \code{(0,0)},
%the upper right is \code{(1,1)}).  The \code{buttons} argument
%will be a vector listing the buttons
%that are pressed at the time of the event, with 0 for left, 1 for middle, and 2
%for right.
%
%The keyboard event handler should be a function with header
%\code{function(key)}.  A single element character vector will be passed
%to this handler, corresponding to the key press.  Shift and other modifier
%keys will have been processed, so \code{shift-a} will be passed as
%\code{"A"}.  The following special keys may also be passed to the handler:
%\itemize{
%     \item Control keys, passed as \code{"Ctrl-A"}, etc.
%     \item Navigation keys, passed as one of\cr
%     \code{"Left", "Up", "Right", "Down", "PgUp", "PgDn", "End", "Home"}
%     \item Edit keys, passed as one of \code{"Ins", "Del"}
%     \item Function keys, passed as one of \code{"F1", "F2", ...}
%}
%
%The event handlers are standard R functions, and will be executed as though called
%from the event environment.
%
%In an interactive session, events will be processed until
%\itemize{
%     \item one of the event handlers returns
%a non-\code{NULL} value which will be returned as the value of
%\code{getGraphicsEvent}, or
%      \item the user interrupts the function from the
%console.
%}
%}
%\value{
%When run interactively,
%\code{getGraphicsEvent} returns a non-\code{NULL} value returned from one of the event handlers.
%In a non-interactive session, \code{getGraphicsEvent} will return \code{NULL} immediately.  It
%will also return \code{NULL} if the user closes the last window that has graphics handlers.
%
%\code{getGraphicsEventEnv} returns the current event environment for the graphics device,
%or \code{NULL} if none has been set.
%
%\code{setGraphicsEventEnv} and \code{setGraphicsEventHandlers} return the previous
%event environment for the graphics device.
%}
%\author{Duncan Murdoch}
%\examples{
%# This currently only works on the Windows
%# and X11(type = "Xlib") screen devices...
%\dontrun{
%savepar <- par(ask = FALSE)
%dragplot <- function(..., xlim = NULL, ylim = NULL, xaxs = "r", yaxs = "r") {
%    plot(..., xlim = xlim, ylim = ylim, xaxs = xaxs, yaxs = yaxs)
%    startx <- NULL
%    starty <- NULL
%    prevx <- NULL
%    prevy <- NULL
%    usr <- NULL
%
%    devset <- function()
%        if (dev.cur() != eventEnv$which) dev.set(eventEnv$which)
%
%    dragmousedown <- function(buttons, x, y) {
%        startx <<- x
%        starty <<- y
%        prevx <<- 0
%        prevy <<- 0
%        devset()
%        usr <<- par("usr")
%        eventEnv$onMouseMove <- dragmousemove
%        NULL
%    }
%
%    dragmousemove <- function(buttons, x, y) {
%        devset()
%        deltax <- diff(grconvertX(c(startx, x), "ndc", "user"))
%        deltay <- diff(grconvertY(c(starty, y), "ndc", "user"))
%	if (abs(deltax-prevx) + abs(deltay-prevy) > 0) {
%	    plot(..., xlim = usr[1:2]-deltax, xaxs = "i",
%		      ylim = usr[3:4]-deltay, yaxs = "i")
%	    prevx <<- deltax
%	    prevy <<- deltay
%	}
%        NULL
%    }
%
%    mouseup <- function(buttons, x, y) {
%    	eventEnv$onMouseMove <- NULL
%    }	
%
%    keydown <- function(key) {
%        if (key == "q") return(invisible(1))
%        eventEnv$onMouseMove <- NULL
%        NULL
%    }
%
%    setGraphicsEventHandlers(prompt = "Click and drag, hit q to quit",
%                     onMouseDown = dragmousedown,
%                     onMouseUp = mouseup,
%                     onKeybd = keydown)
%    eventEnv <- getGraphicsEventEnv()
%}
%
%dragplot(rnorm(1000), rnorm(1000))
%getGraphicsEvent()
%par(savepar)
%}
%}
%\keyword{iplot}
%
%\encoding{UTF-8}
%