% File src/library/grDevices/man/make.rgb.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2012 R Core Team
% Distributed under GPL 2 or later

\name{make.rgb}
\title{色空間を作る}
\alias{make.rgb}
\alias{colorConverter}
%%\title{Create colour spaces }
\description{
  この関数は \code{\link{convertColor}} 中で使うための
  色空間を指定する．
}
\usage{
make.rgb(red, green, blue, name = NULL, white = "D65",
         gamma = 2.2)

colorConverter(toXYZ, fromXYZ, name, white = NULL)
}
\arguments{
  \item{red,green,blue}{
    RGB 原色の色度 (xy 又は xyY)．}
  \item{name}{色空間の名前．}
  \item{white}{参照白を指定する文字列
    (\sQuote{詳細}節を見よ)．}
  \item{gamma}{表示ガンマ(非線形性)．正数または文字列
    \code{"sRGB"}．}
  \item{fromXYZ}{
    XYZ 三原色座標からこの空間へ変換する関数．}
  \item{toXYZ}{
    この空間から XYZ 三原色座標へ変換する関数．}
}
\details{
  RGB 色空間は赤，緑，そして青の色度で定義される．
  これらは xyZ 座標中の長さ 2 又は 3 のベクトルとして与えられる
  (Y 成分は使われず省略できる)．
  色度は参照白に関して定義され，
  これは CIE 標準発光色： "A", "B", "C",
  "D50", "D55", "D60", "E" (普通 "D65")の一つでなければならない．

  表示ガンマは最も普通に 2.2 であるが，Apple RGB では 1.8 が使われる．
  sRGB 標準はガンマ 2.2 に近いもっと複雑な関数を指定する；
  \code{gamma = "sRGB"} はこの関数を使う．

  RGB 以外の色空間は直接
  XYZ 三原色座標への/からの変換を与えることで指定できる．
  関数は二つの引数を取るべきである．
  挿し穂は一つの色に対する座標を与えるエクトルである．
  二番目の引数は参照白である．
  もし特定の参照白が色空間の定義に含められると
  (RGB 空間に対するように)この二番目の引数は無視されるべきで
  \code{...} で良い．
}
\value{
  クラス \code{colorConverter} のオブジェクト．
}
\references{
  変換アルゴリズムは \url{http://www.brucelindbloom.com} から．
}
\seealso{
  \code{\link{convertColor}
  }
}
\examples{
(pal <- make.rgb(red =   c(0.6400, 0.3300),
                 green = c(0.2900, 0.6000),
                 blue =  c(0.1500, 0.0600),
                 name = "PAL/SECAM RGB"))

## #rrggbb 書式での sRGB に対する書式変換
hexcolor <- colorConverter(toXYZ = function(hex, ...) {
                            rgb <- t(col2rgb(hex))/255
                            colorspaces$sRGB$toXYZ(rgb, ...) },
                           fromXYZ = function(xyz, ...) {
                              rgb <- colorspaces$sRGB$fromXYZ(xyz, ..)
                              rgb <- round(rgb, 5)
                              if (min(rgb) < 0 || max(rgb) > 1)
                                   as.character(NA)
                              else rgb(rgb[1], rgb[2], rgb[3])},
                           white = "D65", name = "#rrggbb")

(cols <- t(col2rgb(palette())))
zapsmall(luv <- convertColor(cols, from = "sRGB", to = "Luv", scale.in = 255))
(hex <- convertColor(luv, from = "Luv",  to = hexcolor, scale.out = NULL))

##それを使う前に16進数を行列にしなければならない
(cc <- round(convertColor(as.matrix(hex), from = hexcolor, to = "sRGB",
                          scale.in = NULL, scale.out = 255)))
stopifnot(cc == cols)
}
\keyword{color}


\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/make.rgb.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2012 R Core Team
%% Distributed under GPL 2 or later
%
%\name{make.rgb}
%\alias{make.rgb}
%\alias{colorConverter}
%\title{Create colour spaces }
%\description{
%  These functions specify colour spaces for use in
%  \code{\link{convertColor}}.
%}
%\usage{
%make.rgb(red, green, blue, name = NULL, white = "D65",
%         gamma = 2.2)
%
%colorConverter(toXYZ, fromXYZ, name, white = NULL)
%}
%\arguments{
%  \item{red,green,blue}{Chromaticity (xy or xyY) of RGB primaries}
%  \item{name}{Name for the colour space}
%  \item{white}{Character string specifying the reference white (see
%    \sQuote{Details}.)}
%  \item{gamma}{Display gamma (nonlinearity). A positive number or the
%    string \code{"sRGB"} }
%  \item{fromXYZ}{Function to convert from XYZ tristimulus coordinates
%    to this space}
%  \item{toXYZ}{Function to convert from this space to XYZ tristimulus
%    coordinates.}
%}
%\details{
%  An RGB colour space is defined by the chromaticities of the  red, green and
%  blue primaries.  These are given as vectors of length 2 or 3 in xyY
%  coordinates (the Y component is not used and may be omitted).
%  The chromaticities are defined relative to a reference white, which
%  must be one of the CIE standard illuminants: "A", "B", "C",
%  "D50", "D55", "D60", "E" (usually "D65").
%
%  The display gamma is most commonly 2.2, though 1.8 is used for Apple RGB.
%  The sRGB standard specifies a more complicated function that is close
%  to a gamma of 2.2; \code{gamma = "sRGB"} uses this function.
%
%  Colour spaces other than RGB can be specified directly by giving
%  conversions to and from XYZ tristimulus coordinates.
%  The functions  should take two arguments. The first is a vector giving the
%  coordinates for one colour. The second argument is the reference
%  white. If a specific reference white is included in the definition of
%  the colour space (as for the RGB spaces) this second argument should
%  be ignored and may be \code{...}.
%}
%\value{
%  An object of class \code{colorConverter}
%}
%\references{
%  Conversion algorithms from \url{http://www.brucelindbloom.com}.
%}
%\seealso{
%  \code{\link{convertColor}
%  }
%}
%\examples{
%(pal <- make.rgb(red =   c(0.6400, 0.3300),
%                 green = c(0.2900, 0.6000),
%                 blue =  c(0.1500, 0.0600),
%                 name = "PAL/SECAM RGB"))
%
%## converter for sRGB in #rrggbb format
%hexcolor <- colorConverter(toXYZ = function(hex, ...) {
%                            rgb <- t(col2rgb(hex))/255
%                            colorspaces$sRGB$toXYZ(rgb, ...) },
%                           fromXYZ = function(xyz, ...) {
%                              rgb <- colorspaces$sRGB$fromXYZ(xyz, ..)
%                              rgb <- round(rgb, 5)
%                              if (min(rgb) < 0 || max(rgb) > 1)
%                                   as.character(NA)
%                              else rgb(rgb[1], rgb[2], rgb[3])},
%                           white = "D65", name = "#rrggbb")
%
%(cols <- t(col2rgb(palette())))
%zapsmall(luv <- convertColor(cols, from = "sRGB", to = "Luv", scale.in = 255))
%(hex <- convertColor(luv, from = "Luv",  to = hexcolor, scale.out = NULL))
%
%## must make hex a matrix before using it
%(cc <- round(convertColor(as.matrix(hex), from = hexcolor, to = "sRGB",
%                          scale.in = NULL, scale.out = 255)))
%stopifnot(cc == cols)
%}
%\keyword{color}
%
%
%\encoding{UTF-8}
%