% File src/library/grDevices/man/pictex.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2010 R Core Team
% Distributed under GPL 2 or later

\name{pictex}
\alias{pictex}
\title{PicTeX ドライバー}
%%\title{A PicTeX Graphics Driver}
\usage{
pictex(file = "Rplots.tex", width = 5, height = 4, debug = FALSE,
       bg = "white", fg = "black")
}
\arguments{
  \item{file}{出力が置かれるファイル．}
  \item{width}{インチ単位のプロット幅．}
  \item{height}{インチ単位のプロット高さ．}
  \item{debug}{デバッグ情報をプリントすべきか．}
  \item{bg}{プロットの背景色．無視される．}
  \item{fg}{プロットの前景色．無視される．}
}
\description{
  この関数は
  TeX と LaTeX ドキュメント中に含めるのに適した簡単なグラフィクスを作る．
  これは \R のごく初期のもので歴史的興味しか無い．
}
\details{
  このドライバは \R に含まれる他のグラフィックスドライバよりも
  かなり基本的である．
  これは如何なるフォントメトリック情報も持たないので，
  \code{\link{plotmath}} の使用はサポートされていない．

  線幅は線のテクスチャを設定する場合を除き無視される．
  \code{pch = "."} は幅 1pt の正方形に対応する．

  このドライバは色をサポートしない(PicTeX パッケージも)し，
  全ての色設定は無視される．

  テキストはファイルにそのままで記録されるので，
  TeX の特殊文字(アンパサンドやアンダスコアのような)を含む注釈は
  それらが TeX に登場するように引用化される必要がある．

  複数のプロットは出力ファイルに別個の環境として置かれる．
}
\references{
  Knuth, D. E. (1984)
  \emph{The TeXbook.}
  Reading, MA: Addison-Wesley.

  Lamport, L. (1994)
  \emph{LATEX: A Document Preparation System.}
  Reading, MA: Addison-Wesley.

  Goossens, M., Mittelbach, F. and Samarin, A. (1994)
  \emph{The LATEX Companion.}
  Reading, MA: Addison-Wesley.
}
\author{
  このドライバーは 1996--7 年ごろに
   Department of Internal Medicine, University of Genoa, Italy の
   Valerio Aimale により提供された．
}
\section{慣例}{
  この節は
  \dQuote{R Internals Manual} 中で設定されているグラフィックスデバイスに
  対する慣例の実装を解説する．

  \itemize{
    \item デバイスの規定サイズは 5 インチ対 4 インチである．
    \item \code{pointsize} 引数はない：既定サイズは
      10 ポイントと解釈される．
    \item 唯一のフォントファミリは \code{cmss10}．
    \item 線幅は線のテクスチャの間隔を設定することだけに使われる．
    \item 任意の半径の円が許される．
    \item 色はサポートされていない．
  }
}
\seealso{
  \code{\link{postscript}}, \code{\link{pdf}}, \code{\link{Devices}}.

  より現代的な
  TeX に基づくグラフィックスは同名の CRAN パッケージ中の
  \code{tikzDevice}
  (\url{http://pgf.sourceforge.net/}，しかしながら
  \command{pdftex} \emph{経由}で
  PDF の図を含めるのが (La)TeX ドキュメントでは最も普通である)．
}
\examples{
require(graphics)

pictex()
plot(1:11, (-5:5)^2, type = "b", main = "Simple Example Plot")
dev.off()
##--------------------
\dontrun{
\%\% LaTeX の例
\\documentclass{article}
\\usepackage{pictex}
\\usepackage{graphics} \% \\rotatebox 用
\\begin{document}
\%...
\\begin{figure}[h]
  \\centerline{\\input{Rplots.tex}}
  \\caption{}
\\end{figure}
\%...
\\end{document}
}
##--------------------
unlink("Rplots.tex")
}
\keyword{device}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/pictex.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2010 R Core Team
%% Distributed under GPL 2 or later
%
%\name{pictex}
%\alias{pictex}
%\title{A PicTeX Graphics Driver}
%\usage{
%pictex(file = "Rplots.tex", width = 5, height = 4, debug = FALSE,
%       bg = "white", fg = "black")
%}
%\arguments{
%  \item{file}{the file where output will appear.}
%  \item{width}{The width of the plot in inches.}
%  \item{height}{the height of the plot in inches.}
%  \item{debug}{should debugging information be printed.}
%  \item{bg}{the background color for the plot.  Ignored.}
%  \item{fg}{the foreground color for the plot.  Ignored.}
%}
%\description{
%  This function produces simple graphics suitable for inclusion in TeX
%  and LaTeX documents.  It dates from the very early days of \R and is
%  for historical interest only.
%}
%\details{
%  This driver is much more basic than the other graphics drivers
%  included in \R.  It does not have any font metric information, so the
%  use of \code{\link{plotmath}} is not supported.
%
%  Line widths are ignored except when setting the spacing of line textures.
%  \code{pch = "."} corresponds to a square of side 1pt.
%
%  This device does not support colour (nor does the PicTeX package),
%  and all colour settings are ignored.
%
%  Note that text is recorded in the file as-is, so annotations involving
%  TeX special characters (such as ampersand and underscore) need to be
%  quoted as they would be when entering TeX.
%
%  Multiple plots will be placed as separate environments in the output file.
%}
%\references{
%  Knuth, D. E. (1984)
%  \emph{The TeXbook.}
%  Reading, MA: Addison-Wesley.
%
%  Lamport, L. (1994)
%  \emph{LATEX: A Document Preparation System.}
%  Reading, MA: Addison-Wesley.
%
%  Goossens, M., Mittelbach, F. and Samarin, A. (1994)
%  \emph{The LATEX Companion.}
%  Reading, MA: Addison-Wesley.
%}
%\author{
%  This driver was provided around 1996--7 by Valerio Aimale
%  of the Department of Internal Medicine, University of Genoa, Italy.
%}
%\section{Conventions}{
%  This section describes the implementation of the conventions for
%  graphics devices set out in the \dQuote{R Internals Manual}.
%
%  \itemize{
%    \item The default device size is 5 inches by 4 inches.
%    \item There is no \code{pointsize} argument: the default size is
%    interpreted as 10 point.
%    \item The only font family is \code{cmss10}.
%    \item Line widths are only used when setting the spacing on line textures.
%    \item Circle of any radius are allowed.
%    \item Colour is not supported.
%  }
%}
%\seealso{
%  \code{\link{postscript}}, \code{\link{pdf}}, \code{\link{Devices}}.
%
%  The \code{tikzDevice} in the CRAN package of that name for more modern
%  TeX-based graphics (\url{http://pgf.sourceforge.net/}, although
%  including PDF figures \emph{via} \command{pdftex} is most common
%  in (La)TeX documents).
%}
%\examples{
%require(graphics)
%
%pictex()
%plot(1:11, (-5:5)^2, type = "b", main = "Simple Example Plot")
%dev.off()
%##--------------------
%\dontrun{
%\%\% LaTeX Example
%\\documentclass{article}
%\\usepackage{pictex}
%\\usepackage{graphics} \% for \\rotatebox
%\\begin{document}
%\%...
%\\begin{figure}[h]
%  \\centerline{\\input{Rplots.tex}}
%  \\caption{}
%\\end{figure}
%\%...
%\\end{document}
%}
%##--------------------
%unlink("Rplots.tex")
%}
%\keyword{device}
%
%\encoding{UTF-8}
%