% File src/library/grDevices/man/pretty.Date.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2010-2016 R Core Team
% Distributed under GPL 2 or later

\name{pretty.Date}
%%\title{Pretty Breakpoints for Date-Time Classes}
\title{日付を見栄え良くプリント}
\alias{pretty.Date}%- keep alias{}es - such that ?pretty.Date  works
\alias{pretty.POSIXt}
\usage{
\method{pretty}{Date}(x, n = 5, min.n = n \%/\% 2, sep = " ", \dots)
\method{pretty}{POSIXt}(x, n = 5, min.n = n \%/\% 2, sep = " ", \dots)
}
\arguments{
  \item{x}{クラス \code{"Date"} 又は \code{"POSIXt"} (つまり，
    \code{"POSIXct"} 又は \code{"POSIXlt"})のオブジェクト. }
  \item{n}{区間の\emph{希望の}数．}
  \item{min.n}{区間の\emph{最少}数を与える非負整数．}
  \item{sep}{文字列で，ある書式に対する分離記号
    (例えば月と年の間)に使われる. }
  \item{\dots}{総称性との互換性のための追加引数で無視される．}
} 
\description{
  \code{x} 中の値の範囲をカバーする
  約 \code{n+1} 個の等間隔の \sQuote{良い}値を計算する，
  \code{min.n = 0} で
  \code{x} にユニークな値が唯一であれば長さは 1 かもしれない．
}
\value{
  位置(適当なクラスの)のベクトルで，
  \code{"labels"} は対応する整形済みの文字列ラベルを持つ．
}
\seealso{
  既定メソッドについては \code{\link{pretty}}．
}
\examples{
\donttest{% time-dependent
pretty(Sys.Date())
pretty(Sys.time(), n = 10)
}
pretty(as.Date("2000-03-01")) # R 1.0.0 は閏年に登場

## 様々なスケールでの時間範囲：% also in ../../../../tests/reg-tests-1c.R
require(stats)
steps <- setNames(,
    c("10 secs", "1 min", "5 mins", "30 mins", "6 hours", "12 hours",
      "1 DSTday", "2 weeks", "1 month", "6 months", "1 year",
      "10 years", "50 years", "1000 years"))
x <- as.POSIXct("2002-02-02 02:02")
lapply(steps,
       function(s) {
           at <- pretty(seq(x, by = s, length = 2), n = 5)
           attr(at, "labels")
       })
}
\keyword{dplot}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/pretty.Date.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2010-2016 R Core Team
%% Distributed under GPL 2 or later
%
%\name{pretty.Date}
%\title{Pretty Breakpoints for Date-Time Classes}
%\alias{pretty.Date}%- keep alias{}es - such that ?pretty.Date  works
%\alias{pretty.POSIXt}
%\usage{
%\method{pretty}{Date}(x, n = 5, min.n = n \%/\% 2, sep = " ", \dots)
%\method{pretty}{POSIXt}(x, n = 5, min.n = n \%/\% 2, sep = " ", \dots)
%}
%\arguments{
%  \item{x}{an object of class \code{"Date"} or \code{"POSIXt"} (i.e.,
%    \code{"POSIXct"} or \code{"POSIXlt"}). }
%  \item{n}{integer giving the \emph{desired} number of intervals.}
%  \item{min.n}{nonnegative integer giving the \emph{minimal} number of
%    intervals.}
%  \item{sep}{character string, serving as a separator for certain
%    formats (e.g., between month and year). }
%  \item{\dots}{further arguments for compatibility with the generic,
%    ignored.}
%}
%\description{
%  Compute a sequence of about \code{n+1} equally spaced \sQuote{nice}
%  values which cover the range of the values in \code{x}, possibly of
%  length one, when \code{min.n = 0} and there is only one unique
%  \code{x}.
%}
%\value{
%  A vector (of the suitable class) of locations, with attribute
%  \code{"labels"} giving corresponding formatted character labels.
%}
%\seealso{
%  \code{\link{pretty}} for the default method.
%}
%\examples{
%\donttest{% time-dependent
%pretty(Sys.Date())
%pretty(Sys.time(), n = 10)
%}
%pretty(as.Date("2000-03-01")) # R 1.0.0 came in a leap year
%
%## time ranges in diverse scales:% also in ../../../../tests/reg-tests-1c.R
%require(stats)
%steps <- setNames(,
%    c("10 secs", "1 min", "5 mins", "30 mins", "6 hours", "12 hours",
%      "1 DSTday", "2 weeks", "1 month", "6 months", "1 year",
%      "10 years", "50 years", "1000 years"))
%x <- as.POSIXct("2002-02-02 02:02")
%lapply(steps,
%       function(s) {
%           at <- pretty(seq(x, by = s, length = 2), n = 5)
%           attr(at, "labels")
%       })
%}
%\keyword{dplot}
%
%\encoding{UTF-8}
%