% File src/library/grDevices/man/ps.options.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2008 R Core Team
% Distributed under GPL 2 or later

\name{ps.options}
\title{ポストスクリプトの引数に対する既定値の設定}
\alias{ps.options}
\alias{setEPS}
\alias{setPS}
%%\title{Auxiliary Function to Set/View Defaults for Arguments of postscript}
\description{
  補助関数 \code{ps.options} は
  \code{\link{postscript}} への引数の幾つかに対して既定値を
  設定したり眺めたりする(もし引数なしに呼び出されると)のに使うことが出来る．

  \code{ps.options} は
  \code{postscript} の呼び出し前に呼ばれる必要があり，
  それが設定する既定値は
  \code{postscript} に引数を提供することで上書きできる．
  }
\usage{
ps.options(\dots, reset = FALSE, override.check = FALSE)

setEPS(\dots)
setPS(\dots)
}
\arguments{
  \item{\dots}{引数 \code{onefile}, \code{family}, \code{title},
    \code{fonts},
    \code{encoding}, \code{bg}, \code{fg}, \code{width}, \code{height},
    \code{horizontal}, \code{pointsize},  \code{paper},
    \code{pagecentre}, \code{print.it}, \code{command},
    \code{colormodel} そして \code{fillOddEven} を提供できる．
    \code{onefile},
    \code{horizontal} と \code{paper} は
    \code{setEPS} と \code{setPS} に対しては
    \emph{無視される}．}
  \item{reset}{論理値：既定値はそれらの
    \sQuote{工場出荷}値にリセットすべきか?}
  \item{override.check}{
    \code{\link{check.options}} に渡される論理値引数．
    例を見よ．}
}
\details{
  もし \code{reset = TRUE} と \code{...} の双方が提供されると，
  既定値は先ず
  \sQuote{工場出荷}値にリセットされそれから新しい値が適用される．

  後方互換性のため引数
  \code{append} は受け入れられるが警告と共に無視される．

  \code{setEPS} と \code{setPS} はそれぞれ
  ドキュメント中に含める図
  (\code{width} 又は \code{height} が提供されない限り既定サイズは 7 インチ四方)
  とポストスクリプトプリンターへのスプールに対して適当な既定値
  を設定するラッパである
}
\value{
  全ての直前の既定値の名前付きリスト．
  もし \code{\dots} 又は \code{reset = TRUE} が提供されると，
  結果は可視性フラグがオフにされる．
}
\seealso{
  \code{\link{postscript}}, \code{\link{pdf.options}}
}
\examples{
ps.options(bg = "pink")
utils::str(ps.options())

### ---- 引数のエラーチェック： ----
ps.options(width = 0:12, onefile = 0, bg = pi)
# 'width' に対するチェックを上書き，しかし 'bg' はしない：
ps.options(width = 0:12, bg = pi, override.check = c(TRUE,FALSE))
utils::str(ps.options())
ps.options(reset = TRUE) # 工場出荷値に戻る
}
\keyword{device}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/ps.options.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2008 R Core Team
%% Distributed under GPL 2 or later
%
%\name{ps.options}
%\alias{ps.options}
%\alias{setEPS}
%\alias{setPS}
%\title{Auxiliary Function to Set/View Defaults for Arguments of postscript}
%\description{
%  The auxiliary function \code{ps.options} can be used to set or view
%  (if called without arguments) the default values for some of the
%  arguments to \code{\link{postscript}}.
%
%  \code{ps.options} needs to be called before calling \code{postscript},
%  and the default values it sets can be overridden by supplying
%  arguments to \code{postscript}.
%  }
%\usage{
%ps.options(\dots, reset = FALSE, override.check = FALSE)
%
%setEPS(\dots)
%setPS(\dots)
%}
%\arguments{
%  \item{\dots}{arguments \code{onefile}, \code{family}, \code{title},
%    \code{fonts},
%    \code{encoding}, \code{bg}, \code{fg}, \code{width}, \code{height},
%    \code{horizontal}, \code{pointsize},  \code{paper},
%    \code{pagecentre}, \code{print.it}, \code{command},
%    \code{colormodel} and \code{fillOddEven} can be supplied.  \code{onefile},
%    \code{horizontal} and \code{paper} are \emph{ignored}
%    for \code{setEPS} and \code{setPS}.}
%  \item{reset}{logical: should the defaults be reset to their
%    \sQuote{factory-fresh} values?}
%  \item{override.check}{logical argument passed to
%    \code{\link{check.options}}.  See the Examples.}
%}
%\details{
%  If both \code{reset = TRUE} and \code{...} are supplied the defaults
%  are first reset to the \sQuote{factory-fresh} values and then the new
%  values are applied.
%
%  For backwards compatibility argument \code{append} is accepted but
%  ignored with a warning.
%
%  \code{setEPS} and \code{setPS} are wrappers to set defaults
%  appropriate for figures for inclusion in documents (the default size
%  is 7 inches square unless \code{width} or \code{height} is supplied)
%  and for spooling to a PostScript printer respectively.  For historical
%  reasons the latter is the ultimate default.
%}
%\value{
%  A named list of all the previous defaults.  If \code{\dots} or
%  \code{reset = TRUE} is supplied the result has the visibility flag
%  turned off.
%}
%\seealso{
%  \code{\link{postscript}}, \code{\link{pdf.options}}
%}
%\examples{
%ps.options(bg = "pink")
%utils::str(ps.options())
%
%### ---- error checking of arguments: ----
%ps.options(width = 0:12, onefile = 0, bg = pi)
%# override the check for 'width', but not 'bg':
%ps.options(width = 0:12, bg = pi, override.check = c(TRUE,FALSE))
%utils::str(ps.options())
%ps.options(reset = TRUE) # back to factory-fresh
%}
%\keyword{device}
%
%\encoding{UTF-8}
%