% File src/library/grDevices/man/rgb.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{rgb}
%%\title{RGB Color Specification}
\usage{
rgb(red, green, blue, alpha, names = NULL, maxColorValue = 1)
}
\title{赤緑青による色指定}
\alias{rgb}
\description{
  この関数は与えられた強度(0 と \code{max} の間)の赤緑青の三原色
  に対応する色を作る．色指定は標準の
  sRGB 色空間 (IEC 標準 61966)を参照する．

  アルファ透明度も指定できる(不透明度であり，
  \code{0} は完全な透明で \code{max} は不透明を意味する)．
  もし \code{alpha} が指定されないと不透明な色が生成される．

  \code{names} 引数は色名を提供するのに使うことが出来る．

  これらの関数が返す値はグラフィックス関数の
  \code{col=} 指定や
  \code{\link{par}} 中で使うことが出来る．
}
\arguments{
  \item{red, blue, green, alpha}{
    \eqn{[0, M]} 中の値の数値ベクトル，
    ここで \eqn{M} は \code{maxColorValue}．
    もしこれが \code{255} なら
    \code{red}, \code{blue}, \code{green} そして \code{alpha}
    の値は
    \code{0:255} 中の整数に変換され結果は最も効率的に計算される．}
  \item{names}{文字列ベクトル．結果のベクトルに対する名前．}
  \item{maxColorValue}{色の値範囲の最大値を与える数，上を見よ．}
}
\details{
  色は引数 \code{red} として行列やデータフレームを渡し
  \code{blue} と \code{green} が欠損するように指定できる．
  この場合 \code{red} の最初の三つの列が
  \code{red}, \code{green} そして \code{blue} 値に取られる．

  半透明な色(\code{0 < alpha < 1})はある種のデバイスでだけサポートされる：
  \code{\link{pdf}},
  \code{windows}, \code{quartz} そして \code{X11(type = "cairo")} デバイスと
  関連するビットマップデバイス(\code{jpeg}, \code{png}, \code{bmp},
  \code{tiff} そして \code{bitmap})．
  それらはパッケージ \CRANpkg{Cairo}, \CRANpkg{cairoDevice} そして
  \CRANpkg{JavaGD} のような幾つかのサードパーティー製のデバイス中でサポートされる．

  これらのある種のデバイスだけが半透明色をサポートする．

  他の殆どのグラフィックスデバイスは反透明色を完全に透明として
  プリントし，普通最初に遭遇した時警告が出る．
  
  \code{NA} 値は
  \code{red}, \code{blue}, 
  \code{green} 又は \code{alpha} のどれにも許されない．
}
\value{
  7 又は 9 文字の要素の文字列ベクトルで，
  \code{"#"} に16進数の赤緑青そしてオプションでアルファ値が続く
  (範囲 \code{0 ... 255} に再スケールされる)．
  オプションのアルファ値は
  \code{0} (完全に透明)から \code{255} (不透明)に渡る．

  \R は \sQuote{予め倍数化されたアルファ値}を使わない．
}
\seealso{
  \R の色を RGB ベクトルに変換するには \code{\link{col2rgb}}；
  \code{\link{rainbow}}, \code{\link{hsv}}, \code{\link{hcl}},
  \code{\link{gray}}.
}
\examples{
rgb(0, 1, 0)

rgb((0:15)/15, green = 0, blue = 0, names = paste("red", 0:15, sep = "."))

rgb(0, 0:12, 0, max = 255) # 整数入力

ramp <- colorRamp(c("red", "white"))
rgb( ramp(seq(0, 1, length = 5)), max = 255)
}
\keyword{color}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/rgb.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{rgb}
%\title{RGB Color Specification}
%\usage{
%rgb(red, green, blue, alpha, names = NULL, maxColorValue = 1)
%}
%\alias{rgb}
%\description{
%  This function creates colors corresponding to the given
%  intensities (between 0 and \code{max}) of the red, green and blue
%  primaries.  The colour specification refers to the
%  standard sRGB colorspace (IEC standard 61966).
%
%  An alpha transparency value can also be specified (as an opacity, so
%  \code{0} means fully transparent and \code{max} means opaque).  If
%  \code{alpha} is not specified, an opaque colour is generated.
%
%  The \code{names} argument may be used to provide names for the
%  colors.
%
%  The values returned by these functions can be used with a
%  \code{col=} specification in graphics functions or in \code{\link{par}}.
%}
%\arguments{
%  \item{red, blue, green, alpha}{numeric vectors with values in \eqn{[0, M]}
%    where \eqn{M} is \code{maxColorValue}.  When this is \code{255}, the
%    \code{red}, \code{blue}, \code{green}, and \code{alpha}
%    values are coerced to integers in \code{0:255} and the result is
%    computed most efficiently.}
%  \item{names}{character vector. The names for the resulting vector.}
%  \item{maxColorValue}{number giving the maximum of the color values
%    range, see above.}
%}
%\details{
%  The colors may be specified by passing a matrix or data frame as argument
%  \code{red}, and leaving \code{blue} and \code{green} missing.
%  In this case the first three columns of \code{red} are taken to be
%  the \code{red}, \code{green} and \code{blue} values.
%
%  Semi-transparent colors (\code{0 < alpha < 1}) are supported only on
%  some devices: at the time of writing on the \code{\link{pdf}},
%  \code{windows}, \code{quartz} and \code{X11(type = "cairo")} devices and
%  associated bitmap devices (\code{jpeg}, \code{png}, \code{bmp},
%  \code{tiff} and \code{bitmap}). They are supported by several
%  third-party devices such as those in packages \CRANpkg{Cairo},
%  \CRANpkg{cairoDevice} and \CRANpkg{JavaGD}.  Only some of these
%  devices support semi-transparent backgrounds.
%
%  Most other graphics devices plot semi-transparent colors as fully
%  transparent, usually with a warning when first encountered.
%  
%  \code{NA} values are not allowed for any of \code{red}, \code{blue}, 
%  \code{green} or \code{alpha}.
%}
%\value{
%  A character vector with elements of 7 or 9 characters, \code{"#"}
%  followed by the red, blue, green and optionally alpha values in
%  hexadecimal (after rescaling to \code{0 ... 255}).  The optional alpha
%  values range from \code{0} (fully transparent) to \code{255} (opaque).
%
%  \R does \strong{not} use \sQuote{premultiplied alpha}.
%}
%\seealso{
%  \code{\link{col2rgb}} for translating \R colors to RGB vectors;
%  \code{\link{rainbow}}, \code{\link{hsv}}, \code{\link{hcl}},
%  \code{\link{gray}}.
%}
%\examples{
%rgb(0, 1, 0)
%
%rgb((0:15)/15, green = 0, blue = 0, names = paste("red", 0:15, sep = "."))
%
%rgb(0, 0:12, 0, max = 255) # integer input
%
%ramp <- colorRamp(c("red", "white"))
%rgb( ramp(seq(0, 1, length = 5)), max = 255)
%}
%\keyword{color}
%
%\encoding{UTF-8}
%