% File src/library/grDevices/man/windows/windows.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{windows}
\title{Windows グラフィックスデバイス}
\alias{windows}
\alias{win.graph}
\alias{win.metafile}
\alias{win.print}
\alias{x11}
\alias{X11}
\alias{print.SavedPlots}
\alias{[.SavedPlots}

%%\title{Windows Graphics Devices}
\encoding{UTF-8}

\description{
  グラフィックスデバイスが開かれる．
  \code{windows}, \code{win.graph},
  \code{x11} そして \code{X11} に対してはこれは
  現在の Windows ディスプレイ上のウィンドであある：
  複数名は他のシステムとの互換性のためである．
  \code{win.metafile} はファイルにプリントし，そして
  \code{win.print} は Windows のプリントシステムにプリントする．
}

\usage{
windows(width, height, pointsize, record, rescale, xpinch, ypinch,
        bg, canvas, gamma, xpos, ypos, buffered, title,
        restoreConsole, clickToConfirm, fillOddEven,
        family, antialias)

win.graph(width, height, pointsize)
x11(width, height, pointsize, bg, gamma, xpos, ypos, title)
X11(width, height, pointsize, bg, gamma, xpos, ypos, title)

win.metafile(filename = "", width = 7, height = 7, pointsize = 12,
             family, restoreConsole = TRUE)

win.print(width = 7, height = 7, pointsize = 12, printer = "",
          family, antialias, restoreConsole = TRUE)
}

\arguments{
  \item{width, height}{インチ単位のプロットウィンドのキャンバス
    の(名目上の)幅と高さ．既定は \code{7}．}
  \item{pointsize}{プロットされるテキストの既定ポイントサイズで，
    ビッグポイント(1/72 インチ)として解釈される．
    値は最も近い整数に丸められる：
    ゼロより小さいか等しい値は既定の \code{12} にリセットされる．}
  \item{record}{論理値：プロットの記録に対するフラグの初期状態を設定する．
    既定は \code{FALSE}．}
  \item{rescale}{文字列，
    \code{c("R", "fit", "fixed")} のどれか．
    デバイスのリサイズに対するアクションを制御する．
    既定は \code{"R"}．\sQuote{リサイズオプション}節を見よ．}
  \item{xpinch, ypinch}{倍精度実数．水平と垂直のインチ単位のピクセル．
    既定は \code{NA_real_} で値を Windows から取ることを意味する．}
  \item{bg}{色．初期背景色．既定は \code{"transparent"}．}
  \item{canvas}{色．背景色が透明の時に見えるキャンバスの色．
    単色であるべきか(そして任意のアルファ値は無視される)．既定は \code{"white"}．}
  \item{gamma}{ガンマ補正のファッジ因子．
    R の色は sRGB である；もしモニターが
    sRGB と調和しなければ，追加のガンマ補正を
    RGB チャンネルに適用するこのパラメータを弄ることで状況を改善出来るかもしれない．
    既定では 1 (追加のガンマ補正なし)．}
  \item{xpos, ypos}{整数．ピクセル単位の上左隅の位置．
    負の値はモニターの反対側から取られる．
    欠損値(既定)は既定値を
    \file{\link{Rconsole}} ファイルから取ることを意味し，
    それは次に  \code{xpos = -25, ypos = 0} を既定値にする：
    これはウィンドの右隅を
    モニターから 25 ピクセルに置く．}
  \item{buffered}{論理値．スクリーン出力を二重にバッファすべきか?
    既定値は \code{TRUE}．}
  \item{title}{文字列で最大 100 バイト．
    既定の \code{""} では適当なタイトルが内部的に作られる．
    整数に対する C スタイルの書式にはデバイス番号が代入される．}
  \item{filename}{出力ファイルの名前：
    これは改良された
    Windows メタファイルであり，普通拡張子
    \file{.emf} 又は \file{.wmf} を持つ．最大 511 文字が許される．
    もし整数書式が文字列に含まれるとページ番号が挿入される
    (より詳細は \code{\link{postscript}} を見よ)．そして
    チルド展開が行われる(\code{\link{path.expand}} を見よ)．
    (結果は 600 文字以下でなければならない．)
    既定の \code{""} はクリップボードを意味する．}
  \item{printer}{Windows が知っているプリンターの名前．
    既定ではユーザがプリンターを選べるようにダイアログボックスを開く．}
  \item{restoreConsole}{論理値：下の\sQuote{詳細}節を見よ．
    スクリーンデバイスに対する既定値は \code{FALSE}．}
  \item{clickToConfirm}{論理値：もし真なら新しいフレームの確認は
    コンソールへの質問に答える代わりにデバイスのクリックで行う．
    既定では \code{TRUE}．}
  \item{fillOddEven}{多角形の塗りつぶしモードを制御する論理値：
    詳細は \code{\link{polygon}} を見よ．既定は \code{TRUE}．}
  \item{family}{既定のフォントファミリを指定する長さ 1 の文字列ベクトル．
    \sQuote{フォント}節を見よ．}
  \item{antialias}{長さ 1 の文字列ベクトルで，
    フォントのアンチエイリアシングの制御を要求する．
    これは部分的に \code{"default"}, \code{"none"}, \code{"cleartype"} 又は
    \code{"gray"} にマッチする．\sQuote{フォント}節を見よ．}
}

\details{
  これら全てのデバイスは同じデバイスの変種として実装されている．
  
  \code{windows} の全ての引数は
  \code{\link{windows.options}} で設定される既定値を持つ：
  引数節で与えられる既定値は既定値に対する既定値である．
  これらの既定値は又
  \code{win.graph}, \code{x11} そして \code{X11} に対する
  \code{gamma}, \code{xpinch}, \code{ypinch},
  \code{buffered}, \code{restoreConsole} そして \code{antialias}
  の内部値に適用される．

  ウィンドのサイズはディスプレイについて与えられる情報から計算される：
  これはシステムが正確にコンフィギュアされたことに依存する．
  既定ではスクリーンデバイスは
  Windows にインチあたりのピクセル数を問い合わせる．
  これは
  \code{xpinch} と \code{ypinch} を指定
  (しばしば間違って)することで上書きでき，最も簡便には
  \code{\link{windows.options}} \emph{経由}で行える．
  例えば，13.3 インチで 1280x800 のスクリーン
  (典型的なラップトップディスプレイ)は
  物理的には約 114 dpi であるが
  96 dpi と報告される．
  
  異なった色は注意深く区別される必要がある．
  デバイスの範囲外の領域は
  Windows のアプリケーションの背景色で色が付けられる．
  これは新しいページが呼び出されるとプロットの背景色で重ね塗りされるが，
  背景色は透明でも良い(既定がそうであるように)．
  キャンバス色と背景色の設定間の違いは，
  プロットが保存される時背景色はコピーされるがキャンバス色はされないことである．
  引数 \code{bg} は基礎グラフィックス中で
  \code{\link{par}("bg")}，
  グリッドグラフィックス中では \code{\link{gpar}("fill")} の初期値を設定する．

  記録されたプロットの履歴はクラス \code{"SavedPlots"} である．
  これらは \code{print} メソッドと部分抽出メソッドを持つ．
  個々のプロットはクラス \code{"recordedplot"} なので，
  それらはプリントすることで再演出来る：
  \code{\link{recordPlot}} を見よ．
  アクティブなプロット履歴は作業空間の
  変数 \code{.SavedPlots} に保管される．

  スクリーンデバイスが二重バッファ化(既定)されると，
  スクリーンは最後のプロット呼び出しのあと
  100ms で更新され，連続プロットの間は 500ms で更新される．
  これらの時間はデバイスを開く前に
  \code{options("windowsTimeout")} を二つの整数のベクトルに
  設定することで変更できる．

  \code{par(lwd =)} で制御される線幅は
  1/96 インチの倍数である．
  1 より小さな倍数が許され，1 ピクセルまで小さく出来る．

  \code{win.metafile} に対してはファイル毎に唯一つのプロットが許され，
  Windows はファイルの再利用を許さないように見える．
  従って複数プロットを許す\emph{唯一}の方法は例のような
  パラメータ化された \code{filename} を使うことである．
  もし \code{filename} が省かれる(又は
  \code{""} と指定する)と，デバイスが閉じられている時は出力は
  クリップボードにコピーされる．

  引数 \code{restoreConsole} は幾つかの Windows グラフィクスデバイスの
  現在の実装の問題に対する仮措置であり，将来のリリースで除かれる
  可能性が高い．
  もし \code{FALSE} に設定されると新しいデバイスが開かれるとコンソールは
  フォーカスを受け入れない．

  スクリーンデバイス上で線，塗りつぶしそしてテキストの
  半透明色のサポートがある．
  これらは PDF, PNG, BMP, JPEG そして TIFF
  への保存(\sQuote{File} メニューから)に対しては動作するが，
  メタファイルやポストスクリプトへの保存には無視される．
  基礎にある Windows API 中の制限は半透明なオブジェクトは
  厳密にデバイス領域中に含まれなければならないことを意味する
  (線幅と結び目に対しては許される)．
}

\section{リサイズオプション}{
  もしスクリーンデバイスのサイズが変更されると，
  既定行動 (\code{"R"}) はあたかも新しいサイズが元々指定されていたかのように
  プロットを再描画する．
  \code{"fit"} の使用は新しいデバイス領域にフィットするように
  既存のプロットのスケールを変える．
  \code{"fixed"} の使用はプロットのサイズを未変更にし，もしプロットの
  一部が見えなくなるとスクロールバーを加える．

  グラフィックスウィンドはスクリーン幅もしくは高さの
  85\% 以上の大きさでは作られないが，より大きなサイズに再スケール化することは
  出来る．最初の二つの \code{rescale} オプションに対しては幅と高さ
  は必要なら比例して再スケール化され，
  そしてもし \code{rescale = "fit"} ならば
  プロットはそれに応じて再スケール化される．
  もし \code{rescale = "fixed"} ならば最初に表示された部分が
  これらの制約の範囲内で幅と高さに対して個別に選択される．
  MDI モードでは上限は MDI クライエント領域の
  85\% である．

  ウィンドが再スケール化(\code{"fit"} をつかった場合)された後で
  \code{\link{strwidth}} 又は \code{\link{strheight}} を使うと
  オリジナルの単位での次元を与えるが，
  それらは再スケール化されたフォント(整数サイズである)
  のメトリックから導かれるため近似的に過ぎない．

  表示された領域は\sQuote{用紙}サイズより大きいかもしれず，
  \sQuote{用紙}の外側の範囲は Windows のアプリケーションの背景色で
  色が付く．
  \code{"din"} の様なグラフィックスパラメータは
  再スケールが有効ならばスケール化されたプロットを参照する．
}

\section{フォント}{
  Windows デバイス中で描かれるテキストに対して使われるフォントは
  二つの方法で制御される．
  ファイル \code{R_HOME\\etc\\\link{Rdevga}} は
  \code{par(font =)} (又は \pkg{grid} の同値物)に対するマッピングを
  指定するのに使える．もしくは，フォントファミリは
  空でない \code{family} 引数(又は，例えばグラフィックスパッケージ中の
  \sspace{}\code{par(family =)})で指定することが出来，そして
  これは Windows のフォントデータベースを使って
  フォント 1:4 に対して使うことが出来る
  (\code{\link{windowsFonts}} を見よ)．

  フォントの見かけはアンチエイリアシングの設定に依存し，
  \code{antialias} 引数と機械の設定の双方で行われる．
  従うことが出来ないかもしれない Windows GDI に対するヒントがあるが，
  しかし \code{antialias = "none"} はアンチエイリアシングを使わないことを
  保証するであろう．
  スクリーンデバイスに対しては既定値は機械の設定に依存する：
  もしそれが有効にされていれば \code{"cleartype"} である．
  小さなフォント(約 9 ピクセル以下，典型的なディスプレイでは
  7 ポイント近く)に対してだけ使われるグレイスケールのアンチエイリアシング
  に注意しよう．

  システムにリモートデスクトップからアクセス中は，
  リモートデスクトップの設定\emph{そして}ユーザのローカルなアカウントの
  設定の双方がアンチエイリアシングが使われるかどうかに関連する．

  ある種のフォントは
  ClearType アンチエイリアシングと共にだけ使われることを
  意図している，例えば \code{Meiryo} 日本語フォント．
}
% http://blogs.msdn.com/b/rds/archive/2006/09/08/747023.aspx

\section{慣例}{
  この節は
  \dQuote{R Internals Manual} 中で述べられたグラフィックスデバイスに
  対する慣例の実装を解説する．

  \itemize{
    \item 既定のデバイスサイズは 7 インチ四方であるが，
    これはしばしば
    Windows により不正確に実装される：\sQuote{詳細}節を見よ．
    \item フォントサイズはビッグポイント．
    \item 既定のフォントファミリは Arial．
    \item 線幅は 1/96 インチの倍数で，最小値は １ ピクセル．
    \item 円の最少半径は 1 ピクセル．
    \item \code{cex = 1} の時の \code{pch = "."} は側長が
    1 ピクセルと 0.01 インチの大きい方の矩形．
    \item 色はグラフィックスカードのプロファイルされない
    色マッピングにより解釈される
    -- これは sRGB に一致すると\emph{仮定}される．
  }
}

\value{
  プロットデバイスが開かれる：
  \R インタプリタには何も返されない．
}

\seealso{
  \code{\link{windowsFonts}},
  \code{\link{savePlot}}, \code{\link{bringToTop}},
  \code{\link{Devices}}, \code{\link{postscript}}
}
\examples{\dontrun{## 一連のプロットがメタファイルの系列に書き込まれる
win.metafile("Rplot\%02d.wmf", pointsize = 10)
}}
\keyword{device}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/windows/windows.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{windows}
%\alias{windows}
%\alias{win.graph}
%\alias{win.metafile}
%\alias{win.print}
%\alias{x11}
%\alias{X11}
%\alias{print.SavedPlots}
%\alias{[.SavedPlots}
%
%\title{Windows Graphics Devices}
%
%\description{
%  A graphics device is opened.  For \code{windows}, \code{win.graph},
%  \code{x11} and \code{X11} this is a window on the current
%  Windows display: the multiple names are for compatibility with other
%  systems.  \code{win.metafile} prints to a file and \code{win.print} to
%  the Windows print system.
%}
%
%\usage{
%windows(width, height, pointsize, record, rescale, xpinch, ypinch,
%        bg, canvas, gamma, xpos, ypos, buffered, title,
%        restoreConsole, clickToConfirm, fillOddEven,
%        family, antialias)
%
%win.graph(width, height, pointsize)
%x11(width, height, pointsize, bg, gamma, xpos, ypos, title)
%X11(width, height, pointsize, bg, gamma, xpos, ypos, title)
%
%win.metafile(filename = "", width = 7, height = 7, pointsize = 12,
%             family, restoreConsole = TRUE)
%
%win.print(width = 7, height = 7, pointsize = 12, printer = "",
%          family, antialias, restoreConsole = TRUE)
%}
%
%\arguments{
%  \item{width, height}{the (nominal) width and height of the canvas of
%    the plotting window in inches.  Default \code{7}.}
%  \item{pointsize}{the default pointsize of plotted text, interpreted as
%    big points (1/72 inch).  Values are rounded to the nearest integer:
%    values less than or equal to zero are reset to \code{12}, the
%    default.}
%  \item{record}{logical: sets the initial state of the flag for
%    recording plots.  Default \code{FALSE}.}
%  \item{rescale}{character, one of \code{c("R", "fit", "fixed")}.
%    Controls the action for resizing of the device.  Default
%    \code{"R"}.  See the \sQuote{Resizing options} section.}
%  \item{xpinch, ypinch}{double.  Pixels per inch, horizontally and
%    vertically.  Default \code{NA_real_}, which means to take the
%    value from Windows.}
%  \item{bg}{color.  The initial background color.  Default
%    \code{"transparent"}.}
%  \item{canvas}{color.  The color of the canvas which is visible
%    when the background color is transparent.  Should be a solid color
%    (and any alpha value will be ignored).  Default \code{"white"}.}
%  \item{gamma}{gamma correction fudge factor.
%    Colours in R are sRGB;  if your monitor does not conform to
%    sRGB, you might be able to improve things by tweaking this
%    parameter to apply additional gamma correction to the RGB channels.
%    By default 1 (no additional gamma correction).}
%  \item{xpos, ypos}{integer.  Position of the top left of the window, in
%    pixels.  Negative values are taken from the opposite edge of the
%    monitor.  Missing values (the default) mean take the default from the
%    \file{\link{Rconsole}} file, which in turn defaults to
%    \code{xpos = -25, ypos = 0}: this puts the right edge of the window 25
%    pixels from the right edge of the monitor.}
%  \item{buffered}{logical.  Should the screen output be double-buffered?
%    Default \code{TRUE}.}
%  \item{title}{character string, up to 100 bytes.  With the default
%    \code{""}, a suitable title is created internally.  A C-style format
%    for an integer will be substituted by the device number.}
%  \item{filename}{the name of the output file: it will be an enhanced
%    Windows metafile, usually given extension \file{.emf} or
%    \file{.wmf}.  Up to 511 characters are allowed. The page number is
%    substituted if an integer format is included in the character
%    string (see \code{\link{postscript}} for further details) and
%    tilde-expansion (see \code{\link{path.expand}}) is performed. (The
%    result must be less than 600 characters long.)  The default,
%    \code{""}, means the clipboard.}
%  \item{printer}{The name of a printer as known to Windows. The default
%    causes a dialog box to come up for the user to choose a printer.}
%  \item{restoreConsole}{logical:  see the \sQuote{Details} below.  Defaults to
%    \code{FALSE} for screen devices.}
%  \item{clickToConfirm}{logical: if true confirmation of a new frame
%    will be by clicking on the device rather than answering a problem in
%    the console.  Default \code{TRUE}.}
%  \item{fillOddEven}{logical controlling the polygon fill mode:  see
%    \code{\link{polygon}} for details.  Default \code{TRUE}.}
%  \item{family}{A length-one character vector specifying the default
%    font family.  See section \sQuote{Fonts}.}
%  \item{antialias}{A length-one character vector, requesting control
%    over font antialiasing.  This is partially matched to
%    \code{"default"}, \code{"none"}, \code{"cleartype"} or
%    \code{"gray"}.  See the \sQuote{Fonts} section.}
%}
%
%\details{
%  All these devices are implemented as variants of the same device.
%
%  All arguments of \code{windows} have defaults set by
%  \code{\link{windows.options}}: the defaults given in the arguments section
%  are the defaults for the defaults.  These defaults also apply to the
%  internal values of \code{gamma}, \code{xpinch}, \code{ypinch},
%  \code{buffered}, \code{restoreConsole} and \code{antialias} for
%  \code{win.graph}, \code{x11} and \code{X11}.
%
%  The size of a window is computed from information provided about the
%  display: it depends on the system being configured accurately.
%  By default a screen device asks Windows for the number of pixels per
%  inch.  This can be overridden (it is often wrong) by specifying
%  \code{xpinch} and \code{ypinch}, most conveniently \emph{via}
%  \code{\link{windows.options}}.  For example, a 13.3 inch 1280x800
%  screen (a typical laptop display) was reported as 96 dpi even though
%  it is physically about 114 dpi.
%
%  The different colours need to be distinguished carefully.  Areas
%  outside the device region are coloured in the Windows application background
%  colour.  The device region is coloured in the canvas colour.  This is
%  over-painted by the background colour of a plot when a new page is
%  called for, but that background colour can be transparent (and is by
%  default).  One difference between setting the canvas colour and the
%  background colour is that when a plot is saved the background
%  colour is copied but the canvas colour is not.  The argument \code{bg}
%  sets the initial value of \code{\link{par}("bg")} in base graphics and
%  \code{\link{gpar}("fill")} in grid graphics
%
%  Recorded plot histories are of class \code{"SavedPlots"}.  They have a
%  \code{print} method, and a subset method.  As the individual plots are
%  of class \code{"recordedplot"} they can be replayed by printing them:
%  see \code{\link{recordPlot}}.  The active plot history is stored in
%  variable \code{.SavedPlots} in the workspace.
%
%  When a screen device is double-buffered (the default) the
%  screen is updated 100ms after last plotting call or every 500ms during
%  continuous plotting.  These times can be altered by setting
%  \code{options("windowsTimeout")} to a vector of two integers before
%  opening the device.
%
%  Line widths as controlled by \code{par(lwd =)} are in multiples of
%  1/96inch.  Multiples less than 1 are allowed, down to one pixel width.
%
%  For \code{win.metafile} only one plot is allowed per file, and Windows
%  seems to disallow reusing the file.  So the \emph{only} way to allow
%  multiple plots is to use a parametrized \code{filename} as in the
%  example.  If the \code{filename} is omitted (or specified as
%  \code{""}), the output is copied to the clipboard when the device is
%  closed.
%
%  The \code{restoreConsole} argument is a temporary fix for a problem
%  in the current implementation of several Windows graphics devices,
%  and is likely to be removed in an upcoming release.  If set to
%  \code{FALSE}, the console will not receive the focus after the new
%  device is opened.
%
%  There is support for semi-transparent colours of lines, fills and text
%  on the screen devices.  These work for saving (from the \sQuote{File}
%  menu) to PDF, PNG, BMP, JPEG and TIFF, but will be ignored if saving
%  to Metafile and PostScript.  Limitations in the underlying Windows API
%  mean that a semi-transparent object must be contained strictly within
%  the device region (allowing for line widths and joins).
%}
%
%\section{Resizing options}{
%  If a screen device is re-sized, the default behaviour (\code{"R"}) is
%  to redraw the plot(s) as if the new size had been specified
%  originally.  Using \code{"fit"} will rescale the existing plot(s) to
%  fit the new device region, preserving the aspect ratio.  Using
%  \code{"fixed"} will leave the plot size unchanged, adding scrollbars
%  if part of the plot is obscured.
%
%  A graphics window will never be created at more than 85\% of
%  the screen width or height, but can be resized to a larger size.
%  For the first two \code{rescale} options the width and height are
%  rescaled proportionally if necessary, and if \code{rescale = "fit"}
%  the plot(s) are rescaled accordingly.  If \code{rescale = "fixed"}
%  the initially displayed portion is selected within these constraints,
%  separately for width and height.  In MDI mode,
%  the limit is 85\% of the MDI client region.
%
%  Using \code{\link{strwidth}} or \code{\link{strheight}} after a window
%  has been rescaled (when using \code{"fit"}) gives dimensions in the
%  original units, but only approximately as they are derived from the
%  metrics of the rescaled fonts (which are in integer sizes)
%
%  The displayed region may be bigger than the \sQuote{paper} size, and
%  area(s) outside the \sQuote{paper} are coloured in the Windows
%  application background colour.  Graphics parameters such as
%  \code{"din"} refer to the scaled plot if rescaling is in effect.
%}
%
%\section{Fonts}{
%  The fonts used for text drawn in a Windows device may be controlled in
%  two ways.  The file \code{R_HOME\\etc\\\link{Rdevga}} can be used to
%  specify mappings for \code{par(font =)} (or the \pkg{grid} equivalent).
%  Alternatively, a font family can be specified by a non-empty
%  \code{family} argument (or by e.g.\sspace{}\code{par(family =)} in the graphics
%  package) and this will be used for fonts 1:4 via the Windows font
%  database (see \code{\link{windowsFonts}}).
%
%  How the fonts look depends on the antialiasing settings, both through
%  the \code{antialias} argument and the machine settings.  These are
%  hints to Windows GDI that may not be able to be followed, but
%  \code{antialias = "none"} should ensure that no antialiasing is used.
%  For a screen device the default depends on the machine settings: it
%  will be \code{"cleartype"} if that has been enabled.  Note that the
%  greyscale antialiasing that is used only for small fonts (below about
%  9 pixels, around 7 points on a typical display).
%
%  When accessing a system through Remote Desktop, both the Remote
%  Desktop settings \emph{and} the user's local account settings are
%  relevant to whether antialiasing is used.
%
%  Some fonts are intended only to be used with ClearType antialiasing,
%  for example the \code{Meiryo} Japanese font.
%}
%% http://blogs.msdn.com/b/rds/archive/2006/09/08/747023.aspx
%
%\section{Conventions}{
%  This section describes the implementation of the conventions for
%  graphics devices set out in the \dQuote{R Internals Manual}.
%
%  \itemize{
%    \item The default device size is 7 inches square, although this is
%    often incorrectly implemented by Windows: see \sQuote{Details}.
%    \item Font sizes are in big points.
%    \item The default font family is Arial.
%    \item Line widths are as a multiple of 1/96 inch, with a minimum of
%    one pixel.
%    \item The minimum radius of a circle is 1 pixel.
%    \item \code{pch = "."} with \code{cex = 1} corresponds to a rectangle of sides
%    the larger of one pixel and 0.01 inch.
%    \item Colours are interpreted via the unprofiled colour mapping of
%    the graphics card -- this is \emph{assumed} to conform to sRGB.
%  }
%}
%
%\value{
%  A plot device is opened: nothing is returned to the \R interpreter.
%}
%
%\seealso{
%  \code{\link{windowsFonts}},
%  \code{\link{savePlot}}, \code{\link{bringToTop}},
%  \code{\link{Devices}}, \code{\link{postscript}}
%}
%\examples{\dontrun{## A series of plots written to a sequence of metafiles
%win.metafile("Rplot\%02d.wmf", pointsize = 10)
%}}
%\keyword{device}
%
