% File src/library/grDevices/man/windows/windowsFonts.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{windowsFonts}
\title{Windows のフォント}
\alias{windowsFont}
\alias{windowsFonts}
\concept{fonts}
%%\title{Windows Fonts}
\encoding{UTF-8}
\description{
  これらの関数はデバイス独立な
  R のグラフィックスフォントファミリ名の windows のフォント記述への
  翻訳を処理する．
}
\usage{
windowsFont(family)

windowsFonts(...)
}
\arguments{
  \item{family}{フォントファミリ名を含む文字列ベクトル
    (\code{"TT"} は TrueType フォントを指定する最初の二文字)．
  }
  \item{\dots}{表示するマッピング名の文字列か，
    又は定義する新しい(名前付きの)マッピング．}
}
\details{
  既定のフォントで windows デバイスが作られる
  (\code{windows} に対するドキュメントを見よ)が，
  デバイスに描き込む際のフォントファミリを指定することも可能である
  (例えば，\code{\link{par}} 中の
  \code{"family"} に対するドキュメントや
  \pkg{grid} パッケージ中の \code{\link{gpar}} の
  \code{"fontfamily"} に対するドキュメントを見よ．

  デバイスに送られるフォントファミリは単なる
  文字列名で，これは
  windows フォントに固有のものにマップされる必要がある．
  マッピングのリストが保持されておりユーザにより変更できる．

  \code{windowsFonts} 関数は既存のマッピングの閲覧と
  新しいマッピングの定義に使うことが出来る．
  \code{windowsFont} 関数は新しいマッピングを作るのに使うことが出来る．

  既定のマッピングが三つのデバイス独立なフォントファミリ名に対して
  低供されている：
  sans-serif フォントに対する \code{"sans"}，serif フォントに対する \code{"serif"}，
  そして monospace フォントに対する \code{"mono"} である．

  これらのマッピングは現在のフォントのフェイスが
  1 (plain), 2 (bold), 3 (italic) 又は 4 (bolditalic) の時だけ使われる．
}
\seealso{
  \code{\link{windows}}
}
\examples{
windowsFonts()
windowsFonts("mono")

\dontrun{## 日本語のための設定：フォントがインストールされている必要がある
windows()  # 正しいデバイスタイプであることを確認
Sys.setlocale("LC_ALL", "ja")
windowsFonts(JP1 = windowsFont("MS Mincho"),
             JP2 = windowsFont("MS Gothic"),
             JP3 = windowsFont("Arial Unicode MS"))
plot(1:10)
text(5, 2, "\u{4E10}\u{4E00}\u{4E01}", family = "JP1")
text(7, 2, "\u{4E10}\u{4E00}\u{4E01}", family = "JP1", font = 2)
text(5, 1.5, "\u{4E10}\u{4E00}\u{4E01}", family = "JP2")
text(9, 2, "\u{5100}", family = "JP3")
}}
\keyword{device}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/windows/windowsFonts.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{windowsFonts}
%\alias{windowsFont}
%\alias{windowsFonts}
%\concept{fonts}
%\title{Windows Fonts}
%\description{
%  These functions handle the translation of a device-independent R graphics
%  font family name to a windows font description.
%}
%\usage{
%windowsFont(family)
%
%windowsFonts(...)
%}
%\arguments{
%  \item{family}{a character vector containing the font family name
%    (\code{"TT"} as the first two characters indicates a TrueType font).
%  }
%  \item{\dots}{either character strings naming mappings to display,
%    or new (named) mappings to define.}
%}
%\details{
%  A windows device is created with a default font (see
%  the documentation for \code{windows}), but it is also possible
%  to specify a font family when drawing to the device (for example, see
%  the documentation for \code{"family"} in \code{\link{par}} and for
%  \code{"fontfamily"} in \code{\link{gpar}} in the \pkg{grid} package).
%
%  The font family sent to the device is a simple string name, which must be
%  mapped to something more specific to windows fonts.  A list of
%  mappings is maintained and can be modified by the user.
%
%  The \code{windowsFonts} function can be used to list existing
%  mappings and to define new mappings.  The \code{windowsFont}
%  function can be used to create a new mapping.
%
%  Default mappings are provided for three device-independent font family
%  names: \code{"sans"} for a sans-serif font, \code{"serif"} for a serif
%  font and \code{"mono"} for a monospaced font.
%
%  These mappings will only be used if the current font face is
%  1 (plain), 2 (bold), 3 (italic), or 4 (bolditalic).
%}
%\seealso{
%  \code{\link{windows}}
%}
%\examples{
%windowsFonts()
%windowsFonts("mono")
%
%\dontrun{## set up for Japanese: needs the fonts installed
%windows()  # make sure we have the right device type
%Sys.setlocale("LC_ALL", "ja")
%windowsFonts(JP1 = windowsFont("MS Mincho"),
%             JP2 = windowsFont("MS Gothic"),
%             JP3 = windowsFont("Arial Unicode MS"))
%plot(1:10)
%text(5, 2, "\u{4E10}\u{4E00}\u{4E01}", family = "JP1")
%text(7, 2, "\u{4E10}\u{4E00}\u{4E01}", family = "JP1", font = 2)
%text(5, 1.5, "\u{4E10}\u{4E00}\u{4E01}", family = "JP2")
%text(9, 2, "\u{5100}", family = "JP3")
%}}
%\keyword{device}
%
