% File src/library/grDevices/man/xyTable.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{xyTable}
\title{点の重複度}
\alias{xyTable}
%%\title{Multiplicities of (x,y) Points, e.g., for a Sunflower Plot}
\concept{2D binning}
\description{
  点 (x,y) を与えて，それらの重複度を決定する -- 等号は
  ある(大雑把な)雑音を除いている．これは2次元の特殊な仕分け
  であることを注意．
}
\usage{
xyTable(x, y = NULL, digits)
}
\arguments{
  \item{x, y}{同じ長さの数値ベクトル；
    又は (x, y) 引数の
    \code{\link{xy.coords}(x, y)} で許されるような組み合わせ．}
  \item{digits}{座標の一致性を決定するのに使われる有効精度を指定する整数．
    これらはそれらを
    \code{\link{signif}(*, digits)} で丸めた後に比較される．}
}
\value{
  同じ長さの三つの成分を持つリスト，
  \item{x}{x 座標，丸められソートされている．}
  \item{y}{y 座標，丸められ(そして \code{x} に合わせてソートされている)．}
  \item{number}{重複度(正整数)；つまり
    \code{number[i]} は \code{(x[i], y[i])} の重複度．}
}
\seealso{
  \code{\link{sunflowerplot}} は
  \code{xyTable()} を典型的に使う; \code{\link{signif}}．
}
\examples{
xyTable(iris[, 3:4], digits = 6)

## 無相間の正規変数を離散化：
\dontshow{set.seed(1)}
require(stats)
xy <- data.frame(x = round(sort(rnorm(100))), y = rnorm(100))
xyTable(xy, digits = 1)
}
\keyword{dplot}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/xyTable.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{xyTable}
%\alias{xyTable}
%\title{Multiplicities of (x,y) Points, e.g., for a Sunflower Plot}
%\concept{2D binning}
%\description{
%  Given (x,y) points, determine their multiplicity -- checking for
%  equality only up to some (crude kind of) noise.  Note that this is
%  special kind of 2D binning.
%}
%\usage{
%xyTable(x, y = NULL, digits)
%}
%\arguments{
%  \item{x, y}{numeric vectors of the same length; alternatively other
%    (x, y) argument combinations as allowed by
%    \code{\link{xy.coords}(x, y)}.}
%  \item{digits}{integer specifying the significant digits to be used for
%    determining equality of coordinates.  These are compared after
%    rounding them via \code{\link{signif}(*, digits)}.}
%}
%\value{
%  A list with three components of same length,
%  \item{x}{x coordinates, rounded and sorted.}
%  \item{y}{y coordinates, rounded (and sorted within \code{x}).}
%  \item{number}{multiplicities (positive integers); i.e.,
%    \code{number[i]} is the multiplicity of \code{(x[i], y[i])}.}
%}
%\seealso{\code{\link{sunflowerplot}} which typically uses
%  \code{xyTable()}; \code{\link{signif}}.
%}
%\examples{
%xyTable(iris[, 3:4], digits = 6)
%
%## Discretized uncorrelated Gaussian:
%\dontshow{set.seed(1)}
%require(stats)
%xy <- data.frame(x = round(sort(rnorm(100))), y = rnorm(100))
%xyTable(xy, digits = 1)
%}
%\keyword{dplot}
%
%\encoding{UTF-8}
%