% File src/library/graphics/man/curve.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{curve}
\title{Draw Function Plots}
\alias{curve}
\alias{plot.function}

\description{
  関数に対応する曲線を区間 \code{[from, to]} 上で描く．
  \code{curve} はまた変数 \code{xname} の表現式をプロットできる．
  \code{xname} の既定値は \samp{x} である．
}

\usage{
curve(expr, from = NULL, to = NULL, n = 101, add = FALSE,
      type = "l", xname = "x", xlab = xname, ylab = NULL,
      log = NULL, xlim = NULL, \dots)

\method{plot}{function}(x, y = 0, to = 1, from = y, xlim = NULL, ylab = NULL, \dots)
}

\arguments{
  \item{expr}{\code{x} の関数として書かれ \code{x} と同じ長さの
    オブジェクトに評価される関数の名前，又は呼び出し，又は表現式．}
  \item{x}{\sQuote{ベクトル化した}数値 \R 関数．}
  \item{y}{\code{plot} との互換性のための \code{from} の別名．}
  \item{from, to}{関数がプロットされる範囲．}
  \item{n}{整数；そこで評価を行う x 値の数．}
  \item{add}{論理値；もし \code{TRUE} なら既存のプロットに付け加えるｄ；
    もし \code{NA} ならば，以前の x 軸に対する対数スケールと限界を
    既定とする新しいプロットを開始する．
    もしグラフィックスデバイスが開かれていなければ \code{FALSE}
    とされる(もし異なった値が与えられると警告が出る)．}
  \item{xlim}{\code{NULL} か長さ 2 の数値ベクトル；
    もし \code{NULL} で無ければこれは \code{c(from, to)} に対する
    既定値を与え，\code{add = TRUE} で無い限りプロットの x 限界を選択する
    -- \code{\link{plot.window}} を見よ．}
  \item{type}{プロットタイプ：\code{\link{plot.default}} を見よ．}
  \item{xname}{x 軸に対して使われる名前を与える文字列．}
  \item{xlab, ylab, log, \dots}{ラベルとグラフィックスパラメータ
    を引数として与えることが出来る．\code{log} に対する既定値の
    解釈は\sQuote{詳細}を見よ．

    \code{plot} に対する \code{"function"} メソッドに対しては
    \code{\dots} は \code{expr} を除く \code{curve} の任意の
    他の引数を含むことが出来る．
  }
}

\details{
  関数，表現式 \code{expr} (\code{curve} に対する)又は関数
  \code{x} (\code{plot} 用)は範囲 \code{[from, to]} の上に
  等間隔に置かれた \code{n} 個の点に評価される．
  こうして決定された点がそれからプロットされる．

  もし \code{from} か \code{to} が \code{NULL} なら，これの既定値は
  もしそれが \code{NULL} で無いならば \code{xlim} の対応する要素になる．

  \code{from}/\code{to} も \code{xlim} も x の両方の限界を
  指定しない場合は何が起きるのかは複雑な話になる．
  \code{plot(<function>)} に対してと \code{curve(add = FALSE)}
  に対しては既定値は \eqn{(0, 1)} である．
  \code{curve(add = NA)} と \code{curve(add = TRUE)} に対しては
  既定値は先のプロットに対して使われた x 限界から取られる．
  (これは 2.14.0 以前のバージョンの \R と異なる．)

  \code{log} の値はプロット軸の指定(\code{add = TRUE} でない限り)と
  \sQuote{等間隔}がどのように解釈されるかの双方に使われる：
  もし x 成分が対数スケールを指示すれば，表現式もしくは
  関数がプロットされる点は対数スケールで等間隔に置かれる．

  \code{add = TRUE} の時は \code{log} の既定値は現在のプロットから
  取られるが，もし \code{add = NA} なら x 成分は(もしあれば)既存の
  プロットから取られ，y 成分の既定値は線形である．
  \code{add = FALSE} に対しては既定値は \code{""} である．

  これはかっては間に合わせの工夫であったが，今では有用な目的を
  果たすように思える．しかし滑らかでない関数に対しては悪い結果を
  与える可能性がある．

  計算に時間を喰う表現式
  \code{expr} に対してはよりスマートな
  ツールを使うべきである．

  \code{curve} が \code{expr} を処理する仕方は混乱を招く．
  それは最初 \code{expr} が名前(シンボルとしても知られている)
  かどうかを調べr，その場合にはそれは関数名として使われ，
  \code{expr} は名前が \code{xname} で与えられる一つの引数を持つ
  \code{expr} への呼び出しで置き換えられる．
  さもなければそれは \code{expr} が呼び出しか表現式か，そして
  \code{xname} で与えられる変数への参照を
  (\code{\link{all.vars}} を使い)を含むかどうかをチェックする：
  その他全てはエラーである．それから \code{expr} が
  長さ \code{n} の \code{xname} で与えられる名前のベクトルを
  提供する環境で評価され，評価結果は長さ \code{n} でなければならない．
  これは
  \code{curve(x, ...)} が名前 \code{x} の関数をプロットする
  要求とされることを意味する
  (そしてこれは \code{plot} に対する \code{function} メソッド
  に於けるように使われる)．

  \code{plot} メソッドは \code{plot.function} のように
  直接呼び出すことが出来る．
}

\value{
  描かれるべき点の \code{x} と \code{y} 成分を持つリストが
  不可視で返される．
}

\section{警告}{
  歴史的な理由から \code{add} が \code{plot} の \code{"function"} メソッド
  の引数として許されるが，その挙動は驚くべきものになるかもしれない．
  \code{add} は \code{curve} の時にだけ使うことが勧められる．}

\seealso{
  スプライン補間に対しては \code{\link{splinefun}}，\code{\link{lines}}．
}
\examples{
plot(qnorm) # 既定の範囲 c(0, 1) がここでは適当，
            # しかし端点が -/+Inf なので取り除く．
plot(qlogis, main = "The Inverse Logit : qlogis()")
abline(h = 0, v = 0:2/2, lty = 3, col = "gray")

curve(sin, -2*pi, 2*pi, xname = "t")
curve(tan, xname = "t", add = NA,
      main = "curve(tan)  --> same x-scale as previous plot")

op <- par(mfrow = c(2, 2))
curve(x^3 - 3*x, -2, 2)
curve(x^2 - 2, add = TRUE, col = "violet")

## 簡単と高度なバージョン，よく似ている：
plot(cos, -pi,  3*pi)
curve(cos, xlim = c(-pi, 3*pi), n = 1001, col = "blue", add = TRUE)

chippy <- function(x) sin(cos(x)*exp(-x/2))
curve(chippy, -8, 7, n = 2001)
plot (chippy, -8, -5)

for(ll in c("", "x", "y", "xy"))
   curve(log(1+x), 1, 100, log = ll, sub = paste0("log = '", ll, "'"))
par(op)
}
\keyword{hplot}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/curve.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{curve}
%\title{Draw Function Plots}
%\alias{curve}
%\alias{plot.function}
%
%\description{
%  Draws a curve corresponding to a function over the interval
%  \code{[from, to]}. \code{curve} can plot also an expression in the variable
%  \code{xname}, default \samp{x}.
%}
%
%\usage{
%curve(expr, from = NULL, to = NULL, n = 101, add = FALSE,
%      type = "l", xname = "x", xlab = xname, ylab = NULL,
%      log = NULL, xlim = NULL, \dots)
%
%\method{plot}{function}(x, y = 0, to = 1, from = y, xlim = NULL, ylab = NULL, \dots)
%}
%
%\arguments{
%  \item{expr}{The name of a function, or a \link{call} or an
%    \link{expression} written as a function of \code{x} which will
%    evaluate to an object of the same length as \code{x}.}
%  \item{x}{a \sQuote{vectorizing} numeric \R function.}
%  \item{y}{alias for \code{from} for compatibility with \code{plot}}
%  \item{from, to}{the range over which the function will be plotted.}
%  \item{n}{integer; the number of x values at which to evaluate.}
%  \item{add}{logical; if \code{TRUE} add to an already existing plot; if
%    \code{NA} start a new plot taking the defaults for the limits and
%    log-scaling of the x-axis from the previous plot.  Taken as
%    \code{FALSE} (with a warning if a different value is supplied) if no
%    graphics device is open.}
%  \item{xlim}{\code{NULL} or a numeric vector of length 2;
%    if non-\code{NULL} it provides the defaults for \code{c(from, to)}
%    and, unless \code{add = TRUE}, selects the x-limits of the plot -- see
%    \code{\link{plot.window}}.}
%  \item{type}{plot type: see \code{\link{plot.default}}.}
%  \item{xname}{character string giving the name to be used for the x axis.}
%  \item{xlab, ylab, log, \dots}{labels and \link{graphical parameters}
%    can also be specified as arguments.  See \sQuote{Details} for the
%    interpretation of the default for \code{log}.
%
%    For the \code{"function"} method of \code{plot}, \code{\dots} can
%    include any of the other arguments of \code{curve}, except
%    \code{expr}.
%  }
%}
%
%\details{
%  The function or expression \code{expr} (for \code{curve}) or function
%  \code{x} (for \code{plot}) is evaluated at \code{n} points equally
%  spaced over the range \code{[from, to]}.  The points determined in
%  this way are then plotted.
%
%  If either \code{from} or \code{to} is \code{NULL}, it defaults to the
%  corresponding element of \code{xlim} if that is not \code{NULL}.
%
%  What happens when neither \code{from}/\code{to} nor \code{xlim}
%  specifies both x-limits is a complex story.  For
%  \code{plot(<function>)} and for \code{curve(add = FALSE)} the defaults
%  are \eqn{(0, 1)}.  For \code{curve(add = NA)} and \code{curve(add =
%  TRUE)} the defaults are taken from the x-limits used for the previous
%  plot.  (This differs from versions of \R prior to 2.14.0.)
%
%  The value of \code{log} is used both to specify the plot axes (unless
%  \code{add = TRUE}) and how \sQuote{equally spaced} is interpreted: if
%  the x component indicates log-scaling, the points at which the
%  expression or function is plotted are equally spaced on log scale.
%
%  The default value of \code{log} is taken from the current plot when
%  \code{add = TRUE}, whereas if \code{add = NA} the x component is taken
%  from the existing plot (if any) and the y component defaults to
%  linear.  For \code{add = FALSE} the default is \code{""}
%
%  This used to be a quick hack which now seems to serve a useful purpose,
%  but can give bad results for functions which are not smooth.
%
%  For expensive-to-compute \code{expr}essions, you should use smarter tools.
%
%  The way \code{curve} handles \code{expr} has caused confusion.  It
%  first looks to see if \code{expr} is a \link{name} (also known as a
%  symbol), in which case it is taken to be the name of a function, and
%  \code{expr} is replaced by a call to \code{expr} with a single
%  argument with name given by \code{xname}.  Otherwise it checks that
%  \code{expr} is either a \link{call} or an \link{expression}, and that
%  it contains a reference to the variable given by \code{xname} (using
%  \code{\link{all.vars}}): anything else is an error.  Then \code{expr}
%  is evaluated in an environment which supplies a vector of name given
%  by \code{xname} of length \code{n}, and should evaluate to an object
%  of length \code{n}.  Note that this means that \code{curve(x, ...)} is
%  taken as a request to plot a function named \code{x} (and it is used
%  as such in the \code{function} method for \code{plot}).
%
%  The \code{plot} method can be called directly as \code{plot.function}.
%}
%
%\value{
%  A list with components \code{x} and \code{y} of the points that were
%  drawn is returned invisibly.
%}
%
%\section{Warning}{
%  For historical reasons, \code{add} is allowed as an argument to the
%  \code{"function"} method of \code{plot}, but its behaviour may surprise
%  you.  It is recommended to use \code{add} only with \code{curve}.
%}
%
%\seealso{
%  \code{\link{splinefun}} for spline interpolation, \code{\link{lines}}.
%}
%\examples{
%plot(qnorm) # default range c(0, 1) is appropriate here,
%            # but end values are -/+Inf and so are omitted.
%plot(qlogis, main = "The Inverse Logit : qlogis()")
%abline(h = 0, v = 0:2/2, lty = 3, col = "gray")
%
%curve(sin, -2*pi, 2*pi, xname = "t")
%curve(tan, xname = "t", add = NA,
%      main = "curve(tan)  --> same x-scale as previous plot")
%
%op <- par(mfrow = c(2, 2))
%curve(x^3 - 3*x, -2, 2)
%curve(x^2 - 2, add = TRUE, col = "violet")
%
%## simple and advanced versions, quite similar:
%plot(cos, -pi,  3*pi)
%curve(cos, xlim = c(-pi, 3*pi), n = 1001, col = "blue", add = TRUE)
%
%chippy <- function(x) sin(cos(x)*exp(-x/2))
%curve(chippy, -8, 7, n = 2001)
%plot (chippy, -8, -5)
%
%for(ll in c("", "x", "y", "xy"))
%   curve(log(1+x), 1, 100, log = ll, sub = paste0("log = '", ll, "'"))
%par(op)
%}
%\keyword{hplot}
%
\encoding{UTF8}
