% File src/library/graphics/man/persp.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{persp}
\alias{persp}
\alias{persp.default}
\title{Perspective Plots}
\description{
  この関数は
  x--y 平面上に曲面の鳥瞰図を描く．
  \code{persp} は総称的関数である．
}
\usage{
persp(x, \dots)

\method{persp}{default}(x = seq(0, 1, length.out = nrow(z)),
      y = seq(0, 1, length.out = ncol(z)),
      z, xlim = range(x), ylim = range(y),
      zlim = range(z, na.rm = TRUE),
      xlab = NULL, ylab = NULL, zlab = NULL,
      main = NULL, sub = NULL,
      theta = 0, phi = 15, r = sqrt(3), d = 1,
      scale = TRUE, expand = 1,
      col = "white", border = NULL, ltheta = -135, lphi = 0,
      shade = NA, box = TRUE, axes = TRUE, nticks = 5,
      ticktype = "simple", \dots)
}
\arguments{
  \item{x, y}{
    \code{z} 中の値が測られるグリッド線の位置．
    これらは増加順でなければならない．既定では 0 から 1 までの
    等間隔の値が使われる．are
    もし \code{x} がリストなら，その成分 \code{x$x} と \code{x$y}
    はそれぞれ \code{x} と \code{y} として使われる．}
  \item{z}{プロットされる値を含む行列(\code{NA} が許される)．
    便宜のために \code{x} を
    \code{z} の代わりに使えることを注意する．}
  \item{xlim, ylim, zlim}{x, y そして z の限界．これらは
    曲面の値の範囲をカバーするように選ばれるべきである：
    \sQuote{詳細}を見よ．}
  \item{xlab, ylab, zlab}{軸のタイトル．
    注意．これらは文字列でなければならい；表現式は許されない．
    数値は文字列に変換される．}
    \item{main, sub}{\code{\link{title}} に対するような主と副タイトル．}
    \item{theta, phi}{眺望方向を定義する角度 \code{theta} は方位角を
    そして \code{phi} の変更は余緯度を変更する．}
  \item{r}{プロットボックスの中心からの視点距離．}
  \item{d}{鳥瞰変換の強度を変更するために使われる使える値．
    1 より大きな \code{d} の値は鳥瞰効果を弱め，
    1 より小さな値はそれを強調する．}
  \item{scale}{
    眺望前に曲面を定義する点の x, y そして z
    座標は区間 [0,1] に変換される．
    もし \code{scale} が \code{TRUE} ならば x, y そして z
    座標は個別に変換される．もし \code{scale} が \code{FALSE} なら
    座標はアスペクト比が保存されるようにスケール化される．
    DEM 情報の様に対象を表現するために役に立つ．}
  \item{expand}{\code{z} 座標に適用される拡大率．
    しばしば \code{z} 方向に縮小するために \code{0 < expand < 1} で使われる．}
  \item{col}{曲面の面の色．透明な色は無視される．
    これは \eqn{(nx-1)(ny-1)} 個の面にまでリサイクルされる．}
  \item{border}{曲面の面の首位に描かれる線の色．
    既定値の \code{NULL} は \code{par("fg")} に対応する．
    値 \code{NA} は境界を描くことをやめる：これは
    曲面が陰影化されている時は時折役に立つ．}
  \item{ltheta, lphi}{
    \code{ltheta} と \code{lphi} に対して有限値が指定されると，
    曲面はそれがあたかも 方位角 \code{theta} と
    余緯度 \code{phi} で指示される方向から照明されたかのように
    陰影が付けられる．}
  \item{shade}{ある曲面の面の陰影は
    \code{((1+d)/2)^shade} として計算される，ここで
    \code{d} は面と垂直な単位ベクトルと
    光源方向の単位ベクトルのドット積である．
    1 に近い \code{shade} の値は点光源モデルに似た陰影を生み出し，
    ゼロに近い値は陰影を付けない．
    範囲 0.5 から 0.75 の値は日光で照らされたのに近い効果を
    生み出す．}
  \item{box}{曲面に対するバウンディングボックスを表示すべきか．
    既定値は \code{TRUE}．}
  \item{axes}{ボックスにチックとラベルを加えるべきか．
    既定値は \code{TRUE} である．もし \code{box} が \code{FALSE} ならば
    チックもラベルは描かれない．}
  \item{ticktype}{文字列：\code{"simple"} は増加の方向を指示するため
    単に軸に平行な矢印を描く；
    \code{"detailed"} は2次元プロットのように普通のチックを描く．}
  \item{nticks}{軸上に描かれるチックマークの(近似的)数．
    もし \code{ticktype} が \code{"simple"} ならば如何なる効果も持たない．}
  \item{\dots}{追加のグラフィカルパラメータ(\code{\link{par}} を見よ)．}
}
\value{
  \code{persp()} は\emph{鳥瞰変換行列}，\code{VT} とする，を返す．
  これは等質的な4次元座標 \eqn{(x,y,z,t)} を用いた
  3次元座標 \eqn{(x,y,z)} の2次元平面への射影に適している
  \eqn{4 \times 4}{4 x 4} 行列である．
  これは関数 \code{\link{trans3d}()} を用いた
  \code{\link{lines}()} 又は \code{\link{points}()} により，
  3次元プロットへの追加のグラフィカル要素の重ね合わせに使うことが出来る．
}
\details{
  プロットは先ず座標 (x,y,z) を提供された限界又はデータの範囲から
  計算された限界を用いて区間 [0,1] に変換する．
  曲面はそれから
  \code{theta} と \code{phi} で定義された方向から原点を見ることで
  眺められる．
  もし \code{theta} と \code{phi} が共にセロならば
  眺める方向は負の y 軸をまっすぐ下に向く．
  \code{theta} の変更は方位角を
  そして \code{phi} の変更は余緯度を変更する．

  プロットが終了した後に呼び出される \code{"persp"} と
  呼ばれるフックがある(\code{\link{setHook}} を見よ)．
  これはプロットページを注釈するテストコード中で使われる．
  フック関数は引数無しで呼び出される．

  \code{persp} は \code{z} m行列を
  \code{f(x[i], y[j])} 値のテーブルと解釈するので，
  x 軸は行数に y 軸は列数に対応し，列 1 が底に対応することを注意する．
  従って標準の回転角では行列の上左隅がユーザに最も近い左側に
  表示される．

  \code{ticktype = "detailed"} に対する軸ラベルと注釈のサイズとフォントは
  グラフィックスパラメータ
  \code{"cex.lab"}/\code{"font.lab"} と
  \code{"cex.axis"}/\code{"font.axis"} でそれぞれ制御される．

  バウンディングボックスは面の辺が
  鳥瞰者に対面(従って箱の背後から)するように実線で描かれ，
  他の辺は曲面の上に鎖線で描かれる．
  これ(そして軸のプロット)は軸の限界が曲面がボックス内部にあることを
  仮定しており，もしそうでなければ関数は警告を出す．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{contour}} そして \code{\link{image}}; \code{\link{trans3d}}.

  回転可能な 3D プロットをパッケージ \CRANpkg{rgl} で作れる：
  静的な鳥瞰図を生成する他の方法がパッケージ
  \CRANpkg{lattice} と \CRANpkg{scatterplot3d} にある．
}
\examples{
require(grDevices) # trans3d のため
## demo(persp) にもっと例が!!
##                   -----------

# (1) 必須の数学的曲面
#     回転 sinc 関数．

x <- seq(-10, 10, length= 30)
y <- x
f <- function(x, y) { r <- sqrt(x^2+y^2); 10 * sin(r)/r }
z <- outer(x, y, f)
z[is.na(z)] <- 1
op <- par(bg = "white")
persp(x, y, z, theta = 30, phi = 30, expand = 0.5, col = "lightblue")
persp(x, y, z, theta = 30, phi = 30, expand = 0.5, col = "lightblue",
      ltheta = 120, shade = 0.75, ticktype = "detailed",
      xlab = "X", ylab = "Y", zlab = "Sinc( r )"
) -> res
round(res, 3)

# (2) 既存の鳥瞰図に加える - trans3d() を使用：

xE <- c(-10,10); xy <- expand.grid(xE, xE)
points(trans3d(xy[,1], xy[,2], 6, pmat = res), col = 2, pch = 16)
lines (trans3d(x, y = 10, z = 6 + sin(x), pmat = res), col = 3)

phi <- seq(0, 2*pi, len = 201)
r1 <- 7.725 # 二番目の最大値の半径
xr <- r1 * cos(phi)
yr <- r1 * sin(phi)
lines(trans3d(xr,yr, f(xr,yr), res), col = "pink", lwd = 2)
## (no hidden lines)

# (3) 簡単な DEM モデルの視覚化

z <- 2 * volcano        # 起伏を強調
x <- 10 * (1:nrow(z))   # 10 メートル間隔 (S から N)
y <- 10 * (1:ncol(z))   # 10 メートル間隔 (E から W)
## グリッド線を描かない :  border = NA
par(bg = "slategray")
persp(x, y, z, theta = 135, phi = 30, col = "green3", scale = FALSE,
      ltheta = -120, shade = 0.75, border = NA, box = FALSE)

# (4) z 値に対応する曲面の色付け

par(bg = "white")
x <- seq(-1.95, 1.95, length = 30)
y <- seq(-1.95, 1.95, length = 35)
z <- outer(x, y, function(a, b) a*b^2)
nrz <- nrow(z)
ncz <- ncol(z)
# 指定色の範囲内で色を保管する関数
jet.colors <- colorRampPalette( c("blue", "green") )
# このパレットから必要な数の色を生成
nbcol <- 100
color <- jet.colors(nbcol)
# 面の中心での z 値を計算
zfacet <- z[-1, -1] + z[-1, -ncz] + z[-nrz, -1] + z[-nrz, -ncz]
# 面の z 値を色添字に記録
facetcol <- cut(zfacet, nbcol)
persp(x, y, z, col = color[facetcol], phi = 30, theta = -30)

par(op)
}
\keyword{hplot}
\keyword{aplot}

\encoding{UTF8}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/persp.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{persp}
%\alias{persp}
%\alias{persp.default}
%\title{Perspective Plots}
%\description{
%  This function draws perspective plots of a surface over the
%  x--y plane.  \code{persp} is a generic function.
%}
%\usage{
%persp(x, \dots)
%
%\method{persp}{default}(x = seq(0, 1, length.out = nrow(z)),
%      y = seq(0, 1, length.out = ncol(z)),
%      z, xlim = range(x), ylim = range(y),
%      zlim = range(z, na.rm = TRUE),
%      xlab = NULL, ylab = NULL, zlab = NULL,
%      main = NULL, sub = NULL,
%      theta = 0, phi = 15, r = sqrt(3), d = 1,
%      scale = TRUE, expand = 1,
%      col = "white", border = NULL, ltheta = -135, lphi = 0,
%      shade = NA, box = TRUE, axes = TRUE, nticks = 5,
%      ticktype = "simple", \dots)
%}
%\arguments{
%  \item{x, y}{locations of grid lines at which the values in \code{z} are
%    measured.  These must be in ascending order.  By default, equally
%    spaced values from 0 to 1 are used.  If \code{x} is a \code{list},
%    its components \code{x$x} and \code{x$y} are used for \code{x}
%    and \code{y}, respectively.}
%  \item{z}{a matrix containing the values to be plotted (\code{NA}s are
%    allowed).  Note that \code{x} can be used instead of \code{z} for
%    convenience.}
%  \item{xlim, ylim, zlim}{x-, y-  and z-limits.  These should be chosen
%    to cover the range of values of the surface: see \sQuote{Details}.}
%  \item{xlab, ylab, zlab}{titles for the axes.  N.B. These must be
%    character strings; expressions are not accepted.  Numbers will be
%    coerced to character strings.}
%  \item{main, sub}{main and sub title, as for \code{\link{title}}.}
%  \item{theta, phi}{angles defining the viewing direction.
%    \code{theta} gives the azimuthal direction and \code{phi}
%    the colatitude.}
%  \item{r}{the distance of the eyepoint from the centre of the plotting box.}
%  \item{d}{a value which can be used to vary the strength of
%    the perspective transformation.  Values of \code{d} greater
%    than 1 will lessen the perspective effect and values less
%    and 1 will exaggerate it.}
%  \item{scale}{before viewing the x, y and z coordinates of the
%    points defining the surface are transformed to the interval
%    [0,1].  If \code{scale} is \code{TRUE} the x, y and z coordinates
%    are transformed separately.  If \code{scale} is \code{FALSE}
%    the coordinates are scaled so that aspect ratios are retained.
%    This is useful for rendering things like DEM information.}
%  \item{expand}{a expansion factor applied to the \code{z}
%    coordinates. Often used with \code{0 < expand < 1} to shrink the
%    plotting box in the \code{z} direction.}
%  \item{col}{the color(s) of the surface facets.  Transparent colours are
%    ignored.  This is recycled to the \eqn{(nx-1)(ny-1)} facets.}
%  \item{border}{the color of the line drawn around the surface facets.
%    The default, \code{NULL}, corresponds to \code{par("fg")}.
%    A value of \code{NA} will disable the drawing of borders: this is
%    sometimes useful when the surface is shaded.}
%  \item{ltheta, lphi}{if finite values are specified for \code{ltheta}
%    and \code{lphi}, the surface is shaded as though it was being
%    illuminated from the direction specified by azimuth \code{ltheta}
%    and colatitude \code{lphi}.}
%  \item{shade}{the shade at a surface facet is computed as
%    \code{((1+d)/2)^shade}, where \code{d} is the dot product of
%    a unit vector normal to the facet and a unit vector in the
%    direction of a light source.  Values of \code{shade} close
%    to one yield shading similar to a point light source model
%    and values close to zero produce no shading.  Values in the
%    range 0.5 to 0.75 provide an approximation to daylight
%    illumination.}
%  \item{box}{should the bounding box for the surface be displayed.
%    The default is \code{TRUE}.}
%  \item{axes}{should ticks and labels be added to the box.  The
%    default is \code{TRUE}.  If \code{box} is \code{FALSE} then no
%    ticks or labels are drawn.}
%  \item{ticktype}{character: \code{"simple"} draws just an arrow
%    parallel to the axis to indicate direction of increase;
%    \code{"detailed"} draws normal ticks as per 2D plots.}
%  \item{nticks}{the (approximate) number of tick marks to draw on the
%    axes.  Has no effect if \code{ticktype} is \code{"simple"}.}
%  \item{\dots}{additional \link{graphical parameters} (see \code{\link{par}}).}
%}
%\value{
%  \code{persp()} returns the \emph{viewing transformation matrix}, say
%  \code{VT}, a \eqn{4 \times 4}{4 x 4} matrix suitable for projecting 3D
%  coordinates \eqn{(x,y,z)} into the 2D plane using homogeneous 4D
%  coordinates \eqn{(x,y,z,t)}.  It can be used to superimpose
%  additional graphical elements on the 3D plot, by
%  \code{\link{lines}()} or \code{\link{points}()}, using the
%  function \code{\link{trans3d}()}.
%}
%\details{
%  The plots are produced by first transforming the (x,y,z)
%  coordinates to the interval [0,1] using the limits supplied or
%  computed from the range of the data.  The surface is then viewed
%  by looking at the origin from a direction defined by \code{theta}
%  and \code{phi}.  If \code{theta} and \code{phi} are both zero
%  the viewing direction is directly down the negative y axis.
%  Changing \code{theta} will vary the azimuth and changing \code{phi}
%  the colatitude.
%
%  There is a hook called \code{"persp"} (see \code{\link{setHook}})
%  called after the plot is completed, which is used in the
%  testing code to annotate the plot page.  The hook function(s) are
%  called with no argument.
%
%  Notice that \code{persp} interprets the \code{z} matrix as a table of
%  \code{f(x[i], y[j])} values, so that the x axis corresponds to row
%  number and the y axis to column number, with column 1 at the bottom,
%  so that with the standard rotation angles, the top left corner of the
%  matrix is displayed at the left hand side, closest to the user.
%
%  The sizes and fonts of the axis labels and the annotations for
%  \code{ticktype = "detailed"} are controlled by graphics parameters
%  \code{"cex.lab"}/\code{"font.lab"} and
%  \code{"cex.axis"}/\code{"font.axis"} respectively.
%
%  The bounding box is drawn with edges of faces facing away from the
%  viewer (and hence at the back of the box) with solid lines and other
%  edges dashed and on top of the surface.  This (and the plotting of the
%  axes) assumes that the axis limits are chosen so that the surface
%  is within the box, and the function will warn if this is not the case.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{contour}} and \code{\link{image}}; \code{\link{trans3d}}.
%
%  Rotatable 3D plots can be produced by package \CRANpkg{rgl}: other
%  ways to produce static perspective plots are available in packages
%  \CRANpkg{lattice} and \CRANpkg{scatterplot3d}.
%}
%\examples{
%require(grDevices) # for trans3d
%## More examples in  demo(persp) !!
%##                   -----------
%
%# (1) The Obligatory Mathematical surface.
%#     Rotated sinc function.
%
%x <- seq(-10, 10, length= 30)
%y <- x
%f <- function(x, y) { r <- sqrt(x^2+y^2); 10 * sin(r)/r }
%z <- outer(x, y, f)
%z[is.na(z)] <- 1
%op <- par(bg = "white")
%persp(x, y, z, theta = 30, phi = 30, expand = 0.5, col = "lightblue")
%persp(x, y, z, theta = 30, phi = 30, expand = 0.5, col = "lightblue",
%      ltheta = 120, shade = 0.75, ticktype = "detailed",
%      xlab = "X", ylab = "Y", zlab = "Sinc( r )"
%) -> res
%round(res, 3)
%
%# (2) Add to existing persp plot - using trans3d() :
%
%xE <- c(-10,10); xy <- expand.grid(xE, xE)
%points(trans3d(xy[,1], xy[,2], 6, pmat = res), col = 2, pch = 16)
%lines (trans3d(x, y = 10, z = 6 + sin(x), pmat = res), col = 3)
%
%phi <- seq(0, 2*pi, len = 201)
%r1 <- 7.725 # radius of 2nd maximum
%xr <- r1 * cos(phi)
%yr <- r1 * sin(phi)
%lines(trans3d(xr,yr, f(xr,yr), res), col = "pink", lwd = 2)
%## (no hidden lines)
%
%# (3) Visualizing a simple DEM model
%
%z <- 2 * volcano        # Exaggerate the relief
%x <- 10 * (1:nrow(z))   # 10 meter spacing (S to N)
%y <- 10 * (1:ncol(z))   # 10 meter spacing (E to W)
%## Don't draw the grid lines :  border = NA
%par(bg = "slategray")
%persp(x, y, z, theta = 135, phi = 30, col = "green3", scale = FALSE,
%      ltheta = -120, shade = 0.75, border = NA, box = FALSE)
%
%# (4) Surface colours corresponding to z-values
%
%par(bg = "white")
%x <- seq(-1.95, 1.95, length = 30)
%y <- seq(-1.95, 1.95, length = 35)
%z <- outer(x, y, function(a, b) a*b^2)
%nrz <- nrow(z)
%ncz <- ncol(z)
%# Create a function interpolating colors in the range of specified colors
%jet.colors <- colorRampPalette( c("blue", "green") )
%# Generate the desired number of colors from this palette
%nbcol <- 100
%color <- jet.colors(nbcol)
%# Compute the z-value at the facet centres
%zfacet <- z[-1, -1] + z[-1, -ncz] + z[-nrz, -1] + z[-nrz, -ncz]
%# Recode facet z-values into color indices
%facetcol <- cut(zfacet, nbcol)
%persp(x, y, z, col = color[facetcol], phi = 30, theta = -30)
%
%par(op)
%}
%\keyword{hplot}
%\keyword{aplot}
%
%\encoding{UTF8}
%