% File src/library/parallel/man/unix/mcfork.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2009-2014 R Core Team
% Distributed under GPL 2 or later

\name{mcfork}
\alias{mcfork}
\alias{mcexit}
\title{Fork a Copy of the Current R Process}
\description{
  これらは低水準の関数であり，
  Windows では利用できず，名前空間から移出されない．

  \code{mcfork} は新しい子プロセスを
  現在の \R プロセスのコピーとして作る．

  \code{mcexit} は現在の子プロセスを閉じ，
  必要に応じてマスタープロセスに通知する．
}
\usage{
mcfork(estranged = FALSE)

mcexit(exit.code = 0L, send = NULL)
}
\arguments{
  \item{estranged}{論理値，もし \code{TRUE} ならば新しいプロセスは
    親プロセスと一切結びつきを持たず，子プロセスのリストに示されず
    退出時にも抹消されない．}
  \item{exit.code}{プロセスの退出コード．
    慣習から \code{0L} は正常な退出を，\code{1L} はエラーを意味する．}
  \item{send}{もし \code{NULL} でなければ退出前にこのデータを送る
    (\code{\link{sendMaster}} の使用と同値)．}
}
\details{
  \code{mcfork} 関数は
  \code{fork} システムコールへのインタフェイスを提供する．
  更にそれはマスターと子プロセス間にパイプを設定し，
  それにより子プロセスからマスターにデータを送ったり
  (\code{\link{sendMaster}} を見よ)，子プロセスの \file{stdin} を
  マスタープロセスが所持する別のパイプに再マップ
  (\code{\link{sendChildStdin}} を見よ)することが出来るようになる．.

  もし \code{fork} システムコールに不慣れなら，
  この関数を直接使ってはならない．
  なぜならそれは
  関係する \R プロセス間に非常に複雑な相互作用を
  もたらすからである．
  
  要約すれば \code{fork} は現在のプロセスのコピー(子プロセス)
  を生み出し，それはマスター(親)プロセスと並列に動作可能になる．
  フォークの時点で双方のプロセスは作業空間，大局的オプション，
  ロード済みパッケージ等正確に同じ状態を共有する．

  フォークは現代のオペレーティング・システムでは相対的に安上がりで，
  使用メモリーの実際のコピーは作られず，代わりに
  双方のプロセスは同じメモリーを共有し，変更された部分だけがコピーされる．
  並列な作業環境を設定する必要がないため，これは \code{mcfork} を
  並列プロセスに対する理想的なツールにする．
  データとコードは最初から自動的に共有される．

  \code{mcexit} は子プロセス中で実行されるべきである．
  これは \code{send} をマスタープロセスに送り
  (\code{NULL} で無い限り)，そして子プロセスをシャットダウンする．
  子プロセスは
  未移出の関数 \code{parallel:::rmChild} により実行されるように，それにシグナル
  \code{SIGUSR1} を送ることでもシャットダウン出来る．
}

\value{
  \code{mcfork} は
  クラス \code{"childProcess"} のオブジェクトをマスタープロセスに返し，
  子プロセスにクラス \code{"masterProcess"} のオブジェクトを返す：
  二つのクラスはクラス \code{"process"} を継承する．
  もし \code{estranged} が
  \code{TRUE} に設定されると子プロセスはクラス
  \code{"estrangedProcess"} になりマスタープロセスと交信できないし
  子プロセスのりストにも示されない．
  これらはリストであり，\code{pid} (\emph{他の}プロセスの id)
  と，プロセス間パイプの現在のプロセス中の最後に対する
  二つのファイル記述子数 \code{fd} を成分に持つ．

  \code{mcexit} は決して返らない．
}

\section{GUI/埋め込み環境}{
  \code{mcfork} とそれに依存する高水準関数
  (例えば \code{mcparallel}, \code{mclapply} そして \code{pvec})
  を GUI や埋め込み環境で使うことは
  \emph{全く勧められない}．なぜなら
  それは複数のプロセスが同じ
  GUI を共有することになり混乱しやすい(そして恐らくクラッシュする)
  からである．
  子プロセスは決してスクリーンを使うグラフィックスデバイスを
  使うべきではない．
  OS X の \command{R.app} ではこれを使用可能にするある種の処置が
  取られてきているが，サードパーティのフロントエンドのユーザは
  それらのドキュメントを吟味すべきである．

  これは又フォーク前に作られた他のコネクション(例えば X サーバー)と
  例えばグラフィックスデバイスで開かれたファイルにも当てはまる．

  \command{Tcl}はイベントループを実行するため，これらの目的にとっては
  \pkg{tcltk} は GUI と考えられることを注意する．
  そうしたイベントループは子プロセス中では禁じられているが，
  Tk グラフィカルコネクションに関しては依然問題があり得る．
}

\author{
  Simon Urbanek と R Core．

  Derived from the
  パッケージ \CRANpkg{multicore} 由来．
}
\section{警告}{
  これはエキスパート使用専用の非常に低レベルの API である．
}
\seealso{
  \code{\link{mcparallel}}, \code{\link{sendMaster}}
}
% The results here involve a random PID.
\examples{\donttest{
## これは例として実行すると動作するが，貼り付けすると動作しない．
p <- parallel:::mcfork()
if (inherits(p, "masterProcess")) {
    cat("I'm a child! ", Sys.getpid(), "\n")
    parallel:::mcexit(,"I was a child")
}
cat("I'm the master\n")
unserialize(parallel:::readChildren(1.5))
}}
\keyword{interface}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/parallel/man/unix/mcfork.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2009-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{mcfork}
%\alias{mcfork}
%\alias{mcexit}
%\title{Fork a Copy of the Current R Process}
%\description{
%  These are low-level functions, not available on Windows, and not
%  exported from the namespace.
%
%  \code{mcfork} creates a new child process as a copy of the current \R process.
%
%  \code{mcexit} closes the current child process, informing the master
%  process as necessary.
%}
%\usage{
%mcfork(estranged = FALSE)
%
%mcexit(exit.code = 0L, send = NULL)
%}
%\arguments{
%  \item{estranged}{logical, if \code{TRUE} then the new process has
%    no ties to the parent process, will not show in the list of
%    children and will not be killed on exit.}
%  \item{exit.code}{process exit code.  By convention \code{0L} signifies
%    a clean exit, \code{1L} an error.}
%  \item{send}{if not \code{NULL} send this data before exiting
%    (equivalent to using \code{\link{sendMaster}}).}
%}
%\details{
%  The \code{mcfork} function provides an interface to the \code{fork}
%  system call.  In addition it sets up a pipe between the master and
%  child process that can be used to send data from the child process
%  to the master (see \code{\link{sendMaster}}) and child's \file{stdin} is
%  re-mapped to another pipe held by the master process (see
%  \code{\link{sendChildStdin}}).
%
%  If you are not familiar with the \code{fork} system call, do not use
%  this function directly as it leads to very complex inter-process
%  interactions amongst the \R processes involved.
%
%  In a nutshell \code{fork} spawns a copy (child) of the current
%  process, that can work in parallel to the master (parent)
%  process.  At the point of forking both processes share exactly the
%  same state including the workspace, global options, loaded packages
%  etc.  Forking is relatively cheap in modern operating systems and no
%  real copy of the used memory is created, instead both processes
%  share the same memory and only modified parts are copied. This makes
%  \code{mcfork} an ideal tool for parallel processing since there is no
%  need to setup the parallel working environment, data and code is
%  shared automatically from the start.
%
%  \code{mcexit} is to be run in the child process.  It sends \code{send}
%  to the master (unless \code{NULL}) and then shuts down the child
%  process.  The child can also be shut down by sending it the signal
%  \code{SIGUSR1}, as is done by the unexported function
%  \code{parallel:::rmChild}.
%}
%
%\value{
%  \code{mcfork} returns an object of the class \code{"childProcess"} to
%  the master and of class \code{"masterProcess"} to the child: both the
%  classes inherit from class \code{"process"}.  If \code{estranged} is
%  set to \code{TRUE} then the child process will be of the class
%  \code{"estrangedProcess"} and cannot communicate with the master
%  process nor will it show up on the list of children. These are lists
%  with components \code{pid} (the process id of the \emph{other}
%  process) and a vector \code{fd} of the two file descriptor numbers
%  for ends in the current process of the inter-process pipes.
%
%  \code{mcexit} never returns.
%}
%
%\section{GUI/embedded environments}{
%  It is \emph{strongly discouraged} to use \code{mcfork} and the
%  higher-level functions which rely on it (e.g., \code{mcparallel},
%  \code{mclapply} and \code{pvec}) in GUI or embedded environments,
%  because it leads to several processes sharing the same GUI which will
%  likely cause chaos (and possibly crashes).  Child processes should
%  never use on-screen graphics devices.  Some precautions have been
%  taken to make this usable in \command{R.app} on OS X, but users of
%  third-party front-ends should consult their documentation.
%
%  This can also apply to other connections (e.g., to an X server) created
%  before forking, and to files opened by e.g.\sspace{}graphics devices.
%
%  Note that \pkg{tcltk} counts as a GUI for these purposes since
%  \command{Tcl} runs an event loop.  That event loop is inhibited in a
%  child process but there could still be problems with Tk graphical
%  connections.
%}
%
%\author{
%  Simon Urbanek and R Core.
%
%  Derived from the \CRANpkg{multicore} package.
%}
%\section{Warning}{
%  This is a very low-level API for expert use only.
%}
%\seealso{
%  \code{\link{mcparallel}}, \code{\link{sendMaster}}
%}
%% The results here involve a random PID.
%\examples{\donttest{
%## This will work when run as an example, but not when pasted in.
%p <- parallel:::mcfork()
%if (inherits(p, "masterProcess")) {
%    cat("I'm a child! ", Sys.getpid(), "\n")
%    parallel:::mcexit(,"I was a child")
%}
%cat("I'm the master\n")
%unserialize(parallel:::readChildren(1.5))
%}}
%\keyword{interface}
%
%\encoding{UTF-8}
%\encoding{UTF8}


