% File src/library/parallel/man/mclapply.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2009-2014 R Core Team
% Distributed under GPL 2 or later

\name{mclapply}
\alias{mclapply}
\alias{mcmapply}
\alias{mcMap}

\title{Parallel Versions of \code{lapply} and \code{mapply} using Forking}
\description{
  \code{mclapply} は
  \code{\link{lapply}} の並列バージョンであり，
  \code{X} と同じ長さのリストを返す．その各要素は
  \code{FUN} を対応する
  code{X} の要素に適用した結果である．

  これはフォークを使っており，従って \code{mc.cores = 1} で無い限り
  Windows では使えない．
  
  \code{mcmapply} は
  \code{\link{mapply}} の並列バージョンであり，そして
  \code{mcMap} は \code{\link{Map}} に対応する．
}
\usage{
mclapply(X, FUN, ...,
         mc.preschedule = TRUE, mc.set.seed = TRUE,
         mc.silent = FALSE, mc.cores = getOption("mc.cores", 2L),
         mc.cleanup = TRUE, mc.allow.recursive = TRUE)

mcmapply(FUN, ...,
         MoreArgs = NULL, SIMPLIFY = TRUE, USE.NAMES = TRUE,
         mc.preschedule = TRUE, mc.set.seed = TRUE,
         mc.silent = FALSE, mc.cores = getOption("mc.cores", 2L),
         mc.cleanup = TRUE)

mcMap(f, ...)
}
\arguments{
  \item{X}{ベクトル(原子的又はリスト)又は表現式ベクトル．他のオブジェクト
    (クラス付きオブジェクトを含む)は
    \code{\link{as.list}} で変換される．}
  \item{FUN}{(\code{mclapply}) \code{X} の各要素，
    又は (\code{mcmapply}) 並列に \code{\dots} へ
    適用される関数．}
  \item{f}{
    \code{\dots} に並列に適用される関数．}
  \item{...}{\code{mclapply} に対しては
    \code{FUN} へのオプションの引数．
    \code{mcmapply} と \code{mcMap} に対してはベクトル又はリスト入力：
    \code{\link{mapply}} を見よ．}
  \item{MoreArgs, SIMPLIFY, USE.NAMES}{\code{\link{mapply}} を見よ．}
  \item{mc.preschedule}{もし \code{TRUE} に設定すると計算は
    最初(最大)コア数だけの多さのジョブに分割されそれからジョブが開始する．
    各ジョブは可能性として一つ以上の値をカバーしている．
    もし \code{FALSE} に設定されると
    \code{X} の各値に対して一つのジョブがフォークされる．
    短い計算や
    \code{X} 中に大量の値がある場合は前者が好ましい．
    後者は完了時間に大きな変動があり
    \code{mc.cores} に比較してそれほど大量の \code{X} の値が無いような
    ジョブに適している．}
  \item{mc.set.seed}{\code{\link{mcparallel}} を見よ．}
  \item{mc.silent}{もし \code{TRUE} に設定すると全ての
    フォークされた並列プロセスに対して
    \file{stdout} 上の全ての出力は抑制される
    (\file{stderr} は影響されない)．}
  \item{mc.cores}{使用するコア数，つまり最大幾つの子プロセスを同時に
    実行するか．
    オプションはもし設定されていれば
    環境変数 \env{MC_CORES} から初期化される．
    少なくとも一つのコアがなければならず，並列化のためには
    少なくとも二つのコアがいる．}
  \item{mc.cleanup}{もし \code{TRUE} に設定すると
    この関数でフォークされた全ての子プロセスはこの関数が
    復帰する前に(\code{SIGTERM} を送ることにより)消滅する．
    普通の状況では \code{mclapply} は子プロセスが結果を配送するのを
    待つので，このオプションは普通
    \code{mclapply} が中断された時だけ効果を持つ．
    もし \code{FALSE} に設定されると子プロセスは収集されるが
    強制的に停止されることはない．
    特別なケースとしてこの引数は
    \code{SIGTERM} の代わりに子プロセスを消滅するのに使われる
    幾つかのシグナルに設定することが出来る．}
    \item{mc.allow.recursive}{真でない限り，子プロセス内での \code{mclapply}
    の使用は子プロセスを使い再びフォークしない．}
}

\details{
  \code{mclapply} は provided \code{mc.cores > 1} であれば
  \code{\link{lapply}} の並列化バージョンである：
  \code{mc.cores == 1} に対してはそれは単に
  \code{lapply} を呼び出す．

  既定 (\code{mc.preschedule = TRUE}) では入力 \code{X} はコア数と同じだけ
  の部分に分割され
  (現在値はコアに順番に割り当てられる，つまり
  最初の値がコア 1，二番目がコア 2,
  \ldots，(core + 1)番目がコア 1 等)，そしてそれから一つの
  プロセスが各コアに対してフォークされ，結果が回収される．

  事前のスケジューリング無しでは，個別のジョブが
  \code{X} の各値に対してフォークされる．
  \code{mc.cores} 以上のジョブが同時に実行されないことを保証するために，
  その数だけフォークされると次のフォークの前にマスタープロセスは子プロセスが
  完了するまで待つ．

  実行の並列化特性のために乱数は
  \code{lapply} を使用した時にそうなるようには
  (乱数系列の中で)シーケンシャルではない．
  それらは各フォークされたプロセスに対してはシーケンシャルであるが，
  全体としての全てのジョブに対してはそうではない．
  結果を \code{mc.preschedule = TRUE} で再現可能にする方法については
  \code{\link{mcparallel}} やパッケージのビニエットを見よ．

  ノート：ファイル記述子
  (とプロセス)の数は普通オペレーティングシステムにより制限されているので，
  100 位以上(\code{ulimit -n} 等とするか OS のドキュメントを見よ)
  のコアを使おうとすると，
  開かれたファイル記述子の許可限界を増やしておかない限り，
  問題が起きるかもしれない
  (フォークはエラー \code{"unable to create a pipe"} で失敗する)．
}

\value{
  \code{mclapply} に対しては \code{X} と同じ長さで
  \code{X} で名前が付けられたリスト．

  \code{mcmapply} に対してはベクトルか配列：
  \code{\link{mapply}} を見よ．

  \code{mcMap} に対してはリスト．

  フォークで作られたプロセスはその作業を
  \code{try(..., silent = TRUE)} の内部で実行するので，
  もしエラーが起きるとそれらは
  返り値中のクラス \code{"try-error"} のオブジェクトとして
  保存され警告がでる．ジョブは典型的に
  \code{X} の一つ以上の値を含むので
  \code{"try-error"} オブジェクトは失敗に含まれる全ての値について
  返される．それら全てが失敗しなかったとしてでもある．
}

\section{警告}{
  これらの関数を GUI や埋め込み環境で使うことは
  \emph{全く勧められない}．なぜならそれは複数のプロセスが同じ
  GUI を共有することになり混乱しやすい(そして恐らくクラッシュする)
  からである．
  子プロセスは決してスクリーンを使うグラフィックスデバイスを
  使うべきではない．

  OS X の \command{R.app} ではこれを使用可能にするある種の処置が
  取られてきているが，サードパーティのフロントエンドのユーザは
  それらのドキュメントを吟味すべきである．

  \command{Tcl}はイベントループを実行するため，これらの目的にとっては
  \pkg{tcltk} は GUI と考えられることを注意する．
  そうしたイベントループは子プロセス中では禁じられているが，
  Tk グラフィカルコネクションに関しては依然問題があり得る．
}

\author{
  Simon Urbanek と R Core．

  パッケージ \CRANpkg{multicore} に由来する．
}
\seealso{
  \code{\link{mcparallel}}, \code{\link{pvec}},
  \code{\link{parLapply}}, \code{\link{clusterMap}}.

  \code{\link{sapply}} のような結果には \code{\link{simplify2array}}．
}
\examples{\donttest{
simplify2array(mclapply(rep(4, 5), rnorm))
# 全ての値に同じ乱数を使う
set.seed(1)
simplify2array(mclapply(rep(4, 5), rnorm, mc.preschedule = FALSE,
                mc.set.seed = FALSE))

## これを clusterCallContrast の例と比較せよ
library(boot)
cd4.rg <- function(data, mle) MASS::mvrnorm(nrow(data), mle$m, mle$v)
cd4.mle <- list(m = colMeans(cd4), v = var(cd4))
mc <- getOption("mc.cores", 2)
run1 <- function(...) boot(cd4, corr, R = 500, sim = "parametric",
                           ran.gen = cd4.rg, mle = cd4.mle)
## これを再現可能にするには：
set.seed(123, "L'Ecuyer")
res <- mclapply(seq_len(mc), run1)
cd4.boot <- do.call(c, res)
boot.ci(cd4.boot,  type = c("norm", "basic", "perc"),
        conf = 0.9, h = atanh, hinv = tanh)
}}
\keyword{interface}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/parallel/man/mclapply.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2009-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{mclapply}
%\alias{mclapply}
%\alias{mcmapply}
%\alias{mcMap}
%
%\title{Parallel Versions of \code{lapply} and \code{mapply} using Forking}
%\description{
%  \code{mclapply} is a parallelized version of \code{\link{lapply}},
%  it returns a list of the same length as \code{X}, each element of
%  which is the result of applying \code{FUN} to the corresponding
%  element of \code{X}.
%
%  It relies on forking and hence is not available on Windows unless
%  \code{mc.cores = 1}.
%
%  \code{mcmapply} is a parallelized version of \code{\link{mapply}}, and
%  \code{mcMap} corresponds to \code{\link{Map}}.
%}
%\usage{
%mclapply(X, FUN, ...,
%         mc.preschedule = TRUE, mc.set.seed = TRUE,
%         mc.silent = FALSE, mc.cores = getOption("mc.cores", 2L),
%         mc.cleanup = TRUE, mc.allow.recursive = TRUE)
%
%mcmapply(FUN, ...,
%         MoreArgs = NULL, SIMPLIFY = TRUE, USE.NAMES = TRUE,
%         mc.preschedule = TRUE, mc.set.seed = TRUE,
%         mc.silent = FALSE, mc.cores = getOption("mc.cores", 2L),
%         mc.cleanup = TRUE)
%
%mcMap(f, ...)
%}
%\arguments{
%  \item{X}{a vector (atomic or list) or an expressions vector.  Other
%    objects (including classed objects) will be coerced by
%    \code{\link{as.list}}.}
%  \item{FUN}{the function to be applied to (\code{mclapply}) each
%    element of \code{X} or (\code{mcmapply}) in parallel to \code{\dots}.}
%  \item{f}{the function to be applied in parallel to \code{\dots}.}
%  \item{...}{For \code{mclapply}, optional arguments to \code{FUN}.
%    For \code{mcmapply} and \code{mcMap}, vector or list inputs: see
%    \code{\link{mapply}}.}
%  \item{MoreArgs, SIMPLIFY, USE.NAMES}{see \code{\link{mapply}}.}
%  \item{mc.preschedule}{if set to \code{TRUE} then the computation is
%    first divided to (at most) as many jobs are there are cores and then
%    the jobs are started, each job possibly covering more than one
%    value.  If set to \code{FALSE} then one job is forked for each value
%    of \code{X}.  The former is better for short computations or large
%    number of values in \code{X}, the latter is better for jobs that
%    have high variance of completion time and not too many values of
%    \code{X} compared to \code{mc.cores}.}
%  \item{mc.set.seed}{See \code{\link{mcparallel}}.}
%  \item{mc.silent}{if set to \code{TRUE} then all output on
%    \file{stdout} will be suppressed for all parallel processes forked
%    (\file{stderr} is not affected).}
%  \item{mc.cores}{The number of cores to use, i.e.\sspace{}at most how many
%    child processes will be run simultaneously.   The option is
%    initialized from environment variable \env{MC_CORES} if set.  Must
%    be at least one, and parallelization requires at least two cores.}
%  \item{mc.cleanup}{if set to \code{TRUE} then all children that have
%    been forked by this function will be killed (by sending
%    \code{SIGTERM}) before this function returns.  Under normal
%    circumstances \code{mclapply} waits for the children to deliver
%    results, so this option usually has only effect when \code{mclapply}
%    is interrupted. If set to \code{FALSE} then child processes are
%    collected, but not forcefully terminated.  As a special case this
%    argument can be set to the number of the signal that should be used
%    to kill the children instead of \code{SIGTERM}.}
%  \item{mc.allow.recursive}{Unless true, calling \code{mclapply} in a
%    child process will use the child and not fork again.}
%}
%
%\details{
%  \code{mclapply} is a parallelized version of \code{\link{lapply}},
%  provided \code{mc.cores > 1}: for \code{mc.cores == 1} it simply calls
%  \code{lapply}.
%
%  By default (\code{mc.preschedule = TRUE}) the input \code{X} is split
%  into as many parts as there are cores (currently the values are spread
%  across the cores sequentially, i.e.\sspace{}first value to core 1, second to
%  core 2, \ldots (core + 1)-th value to core 1 etc.) and then one process
%  is forked to each core and the results are collected.
%
%  Without prescheduling, a separate job is forked for each value of
%  \code{X}.  To ensure that no more than \code{mc.cores} jobs are
%  running at once, once that number has been forked the master process
%  waits for a child to complete before the next fork.
%
%  Due to the parallel nature of the execution random numbers are not
%  sequential (in the random number sequence) as they would be when using
%  \code{lapply}.  They are sequential for each forked process, but not
%  all jobs as a whole.  See \code{\link{mcparallel}} or the package's
%  vignette for ways to make the results reproducible with
%  \code{mc.preschedule = TRUE}.
%
%  Note: the number of file descriptors (and processes) is usually
%  limited by the operating system, so you may have trouble using more
%  than 100 cores or so (see \code{ulimit -n} or similar in your OS
%  documentation) unless you raise the limit of permissible open file
%  descriptors (fork will fail with error \code{"unable to create a
%  pipe"}).
%}
%
%\value{
%  For \code{mclapply}, a list of the same length as \code{X} and named
%  by \code{X}.
%
%  For \code{mcmapply}, a list, vector or array: see
%  \code{\link{mapply}}.
%
%  For \code{mcMap}, a list.
%
%  Each forked process runs its job inside \code{try(..., silent = TRUE)}
%  so if errors occur they will be stored as class \code{"try-error"}
%  objects in the return value and a warning will be given.  Note that
%  the job will typically involve more than one value of \code{X} and
%  hence a \code{"try-error"} object will be returned for all the values
%  involved in the failure, even if not all of them failed.
%}
%
%\section{Warning}{
%  It is \emph{strongly discouraged} to use these functions in GUI or
%  embedded environments, because it leads to several processes sharing
%  the same GUI which will likely cause chaos (and possibly
%  crashes).  Child processes should never use on-screen graphics
%  devices.
%
%  Some precautions have been taken to make this usable in
%  \command{R.app} on OS X, but users of third-party front-ends
%  should consult their documentation.
%
%  Note that \pkg{tcltk} counts as a GUI for these purposes since
%  \command{Tcl} runs an event loop.  That event loop
%  is inhibited in a child process but there could still be problems with
%  Tk graphical connections.
%}
%
%\author{
%  Simon Urbanek and R Core.
%
%  Derived from the \CRANpkg{multicore} package.
%}
%\seealso{
%  \code{\link{mcparallel}}, \code{\link{pvec}},
%  \code{\link{parLapply}}, \code{\link{clusterMap}}.
%
%  \code{\link{simplify2array}} for results like \code{\link{sapply}}.
%}
%\examples{\donttest{
%simplify2array(mclapply(rep(4, 5), rnorm))
%# use the same random numbers for all values
%set.seed(1)
%simplify2array(mclapply(rep(4, 5), rnorm, mc.preschedule = FALSE,
%                mc.set.seed = FALSE))
%
%## Contrast this with the examples for clusterCall
%library(boot)
%cd4.rg <- function(data, mle) MASS::mvrnorm(nrow(data), mle$m, mle$v)
%cd4.mle <- list(m = colMeans(cd4), v = var(cd4))
%mc <- getOption("mc.cores", 2)
%run1 <- function(...) boot(cd4, corr, R = 500, sim = "parametric",
%                           ran.gen = cd4.rg, mle = cd4.mle)
%## To make this reproducible:
%set.seed(123, "L'Ecuyer")
%res <- mclapply(seq_len(mc), run1)
%cd4.boot <- do.call(c, res)
%boot.ci(cd4.boot,  type = c("norm", "basic", "perc"),
%        conf = 0.9, h = atanh, hinv = tanh)
%}}
%\keyword{interface}
%
%\encoding{UTF-8}
%\encoding{UTF8}


