% File src/library/stats/man/dummy.coef.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{dummy.coef}
\title{Extract Coefficients in Original Coding}
\usage{
dummy.coef(object, \dots)

\method{dummy.coef}{lm}(object, use.na = FALSE, \dots)

\method{dummy.coef}{aovlist}(object, use.na = FALSE, \dots)
}
\alias{dummy.coef}%@%\alias{ダミー係数}
\alias{dummy.coef.lm}
\alias{dummy.coef.aovlist}
\arguments{
  \item{object}{線形モデル当てはめ．}
  \item{use.na}{特異モデル中の係数に対する論理フラグ．
    もし \code{use.na} が真なら，未決定の係数は失われる；
    もし偽ならそれらは一つの可能な値を得る．}
  \item{\dots}{他のメソッドへ・から渡される引数．}
}
\description{
  これは係数をコードされた変数ではなく係数のオリジナルレベルで
  取り出す．
}
\details{
  当てはめ線形モデルは因子項の対比に対する係数を持つ．
  この項は普通水準の数より一つ少ない．
  この関数は係数をオリジナルのコーディングで係数を再表現する；
  係数は縮約されたベースで当てはめられるので，
  任意の含意される対比
  (例えば \code{contr.helmert} や \code{contr.sum} に
  対するゼロ和)は尊重される．
  欠損係数は定義からゼロであるので，\code{contr.treatment} 対比に
  対して \code{dummy.coef} を使うことは意味が無い．

  使われるメソッドはある種の制限があり，
  \code{poly(x, 2)} のような項に対しては不完全な結果を与える．
  しかしながらこれはその種の目的である
  \code{aov} モデルに対しては十分である．
}
\value{
  各項に対して係数の値を与えるリスト．
  多層の \code{aov} モデルに対しては，各層毎のそうしたリスト．
}

\section{警告}{
  この関数は出力を人間が吟味することを意図している：
  計算のために使ってはならない．
  コードされた変数を全ての計算で使うこと．

  結果は特異な変数に対しては S と異なり，S は不正確なことがある．
}

\seealso{\code{\link{aov}}, \code{\link{model.tables}}}

\examples{
options(contrasts = c("contr.helmert", "contr.poly"))
## Venables and Ripley (2002) p.165 より
npk.aov <- aov(yield ~ block + N*P*K, npk)
dummy.coef(npk.aov)

npk.aovE <- aov(yield ~  N*P*K + Error(block), npk)
dummy.coef(npk.aovE)
}
\keyword{models}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/dummy.coef.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{dummy.coef}
%\title{Extract Coefficients in Original Coding}
%\usage{
%dummy.coef(object, \dots)
%
%\method{dummy.coef}{lm}(object, use.na = FALSE, \dots)
%
%\method{dummy.coef}{aovlist}(object, use.na = FALSE, \dots)
%}
%\alias{dummy.coef}
%\alias{dummy.coef.lm}
%\alias{dummy.coef.aovlist}
%\arguments{
%  \item{object}{a linear model fit.}
%  \item{use.na}{logical flag for coefficients in a singular model. If
%    \code{use.na} is true, undetermined coefficients will be missing; if
%    false they will get one possible value.}
%  \item{\dots}{arguments passed to or from other methods.}
%}
%\description{
%  This extracts coefficients in terms of the original levels of the
%  coefficients rather than the coded variables.
%}
%\details{
%  A fitted linear model has coefficients for the contrasts of the factor
%  terms, usually one less in number than the number of levels.  This
%  function re-expresses the coefficients in the original coding; as the
%  coefficients will have been fitted in the reduced basis, any implied
%  constraints (e.g., zero sum for \code{contr.helmert} or \code{contr.sum})
%  will be respected.  There will be little point in using
%  \code{dummy.coef} for \code{contr.treatment} contrasts, as the missing
%  coefficients are by definition zero.
%
%  The method used has some limitations, and will give incomplete results
%  for terms such as \code{poly(x, 2)}.  However, it is adequate for
%  its main purpose, \code{aov} models.
%}
%\value{
%  A list giving for each term the values of the coefficients. For a
%  multistratum \code{aov} model, such a list for each stratum.
%}
%
%\section{Warning}{
%  This function is intended for human inspection of the
%  output: it should not be used for calculations.  Use coded variables
%  for all calculations.
%
%  The results differ from S for singular values, where S can be incorrect.
%}
%
%\seealso{\code{\link{aov}}, \code{\link{model.tables}}}
%
%\examples{
%options(contrasts = c("contr.helmert", "contr.poly"))
%## From Venables and Ripley (2002) p.165.
%npk.aov <- aov(yield ~ block + N*P*K, npk)
%dummy.coef(npk.aov)
%
%npk.aovE <- aov(yield ~  N*P*K + Error(block), npk)
%dummy.coef(npk.aovE)
%}
%\keyword{models}
%
%\encoding{UTF-8}
%
