% File src/library/stats/man/family.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{family}
\alias{family}%@%\alias{モデルに対するファミリオブジェクト}
\alias{binomial}
\alias{gaussian}
\alias{Gamma}
\alias{inverse.gaussian}
\alias{poisson}
\alias{quasi}
\alias{quasibinomial}
\alias{quasipoisson}
%\alias{print.family}

\title{Family Objects for Models}
\usage{
family(object, \dots)

binomial(link = "logit")
gaussian(link = "identity")
Gamma(link = "inverse")
inverse.gaussian(link = "1/mu^2")
poisson(link = "log")
quasi(link = "identity", variance = "constant")
quasibinomial(link = "logit")
quasipoisson(link = "log")
}
\arguments{
  \item{link}{モデルのリンク関数の指定．
    これは名前/表現式，文字通りの文字列，
    それが次に与えられる標準名のどれかで指定されていない限り
    長さ1の文字列ベクトルか(\code{\link{make.link}} が作りだしたような)
    クラス \code{"\link[=make.link]{link-glm}"}
    のオブジェクトで良い．

    \code{gaussian} ファミリはリンク(名前として)
    \code{identity}, \code{log} そして \code{inverse}
    を受け入れる；
    \code{binomial} ファミリは(それぞれロジスティク，
    正規，そしてコーシー CDF に対応する)リンク \code{logit},
    \code{probit}, \code{cauchit},  \code{log} そして
    \code{cloglog} (complementary log-log) を受け入れる；
    \code{Gamma} ファミリはリンク \code{inverse}, \code{identity}
    そして \code{log} を受け入れる；
    \code{poisson} ファミリはリンク \code{log}, \code{identity},
    そして \code{sqrt} を，\code{inverse.gaussian} ファミリはリンク
    \code{1/mu^2}, \code{inverse}, \code{identity}
    そして \code{log} を受け入れる．

    \code{quasi} ファミリはリンク
    \code{logit}, \code{probit},
    \code{cloglog},  \code{identity}, \code{inverse},
    \code{log}, \code{1/mu^2} そして \code{sqrt} を受け入れ，
    関数 \code{\link{power}} は巾乗リンク関数を生成するのに使える．
  }
  \item{variance}{
    \code{quasi} 以外の全てのファミリに対して分散関数は
    ファミリにより決定される．
    \code{quasi} ファミリは文字通りの文字列による指定
    (又は名前/表現式として引用化されていない)
    \code{"constant"}, \code{"mu(1-mu)"}, \code{"mu"},
    \code{"mu^2"} そして \code{"mu^3"}，
    これらの値の一つを取る長さ 1 の文字列ベクトル，又は
    成分
    \code{varfun}, \code{validmu}, \code{dev.resids}, \code{initialize}
    そして \code{name} を含むリストを受け入れる．
  }
  \item{object}{\code{family} が
    モデリング関数(例えば \code{glm})により作られたオブジェクトの
    内部に保管された \code{family} オブジェクトにアクセスする
    関数．}
  \item{\dots}{メソッドに渡される追加引数．}
}
\description{
  ファミリオブジェクトは
  \code{\link{glm}} のような関数が使うモデルの詳細を指定する
  便利な手段を提供する．
  そうしたモデル当てはめがどのように行われるかの詳細は
  \code{\link{glm}} に対するドキュメントを見よ．
}
\details{
  \code{family} は総称的関数で
  クラス \code{"glm"} と \code{"lm"} に対するメソッドを持つ
  (後者は \code{gaussian()} で稼働する)．

  
  \code{binomial} と \code{quasibinomial} ファミリに対しては
  応答は三つの方法で指定できる：
  \enumerate{
    \item 因子として：\sQuote{成功}は最初の水準を持たない
    (従って普通二番目の水準を持つ)と解釈される．
    \item \code{0} と \code{1} の間の値を持つ数値ベクトルとして：
    成功ケースの割合と解釈される
    (ケースの総数は \code{weights} で与えられる)．
    \item 二列の整数行列として：
    最初の列は成功数そして二番目の列は失敗数を与える．
  }
    
  \code{quasibinomial} と \code{quasipoisson} ファミリは
  \code{binomial} と \code{poisson} ファミリから
  逸脱度パラメータが 1 に固定されていないという点だけで
  異なる．従ってそれらは過剰逸脱状態をモデル化出来る．
  二項ケースに対しては
  McCullagh and Nelder (1989, pp.\sspace{}124--8) を見よ．
  彼らは
  (ある制限の下では)準二項モデルのような分散が平均に比例するような
  モデルがあることを示しているが，
  \code{glm} はそのモデルでは最尤推定量を計算しないことを注意する．
  S の挙動は"準"変種に近い．
}
\note{
  後方互換性のため \code{link} と \code{variance} 引数は
  かなり厄介なセマンティックスを持つ．
  それらを提供する推奨される方法は
  引用化文字列とすることであるが，
  (名前か表現式として)それらを引用化無しで与えることも出来る．
  加えて，それらはオプションの一つの名前を与える長さ 1 の
  文字列ベクトルとして，又はリスト
  (\code{link} に対して，クラス \code{"link-glm"})として
  与えることも出来る．
  この制限は名前で与えられるリンクに対してだけ適用される：
  文字列として与えられた時
  \code{\link{make.link}} が知る全てのリンクが受け入れられる．

  これは曖昧である可能性がある：
  \code{link = logit} は引用化されないリンク名，又は
  オブジェクト \code{logit} の値を意味することが出来る．
  もし可能ならばそれは認められるリンクの名前として，
  それからオブジェクトとして解釈される.  
  (オブジェクトの値であることを
  \code{logit[1]} によって常に強制することが出来る．)
}
\value{
  クラス \code{"family"} のオブジェクト(簡潔なプリントメソッドを持つ)．
  これは以下の成分を持つリストである
  \item{family}{文字列：ファミリ名．}
  \item{link}{文字列：リンク名．}
  \item{linkfun}{関数：リンク．}
  \item{linkinv}{関数：リンク関数の逆関数．}
  \item{variance}{関数：平均の関数としての分散．}
  \item{dev.resids}{
    \code{(y, mu, wt)} の関数としての逸脱度残差を与える関数．}
  \item{aic}{もし適切であれば AIC 値を与える関数
    (しかし準ファミリに対しては \code{NA})．
    逸脱度パラメータに関する仮定は \code{\link{logLik}} を見よ．}
  \item{mu.eta}{関数：導関数 \code{function(eta)}
    \eqn{d\mu/d\eta}．}
  \item{initialize}{表現式．
    これはファミリに対して必要な如何なるデータオブジェクト
    のみならず \code{n}
    (二項ファミリの AIC に対し必要) と \code{mustart}
    (\code{\link{glm}} を見よ) を設定する必要がある．}
  \item{validmu}{論理値関数．もし
    平均ベクトル \code{mu} が
    \code{variance} の領域中にあれば
    \code{TRUE} を返す．}
  \item{valideta}{論理値関数．もし
    線形予測子 \code{eta} が
    \code{linkinv} の領域中にあれば \code{TRUE} を返す．}
  \item{simulate}{(オプションの)関数 \code{simulate(object, nsim)}
    で \code{\link{simulate}} の \code{"lm"} メソッドにより
    呼び出される. これは普通
    列数 \code{nsim} で各当てはめ値に対して一行を持つ
    行列を返すが，
    長さ \code{nsim} のりストを返すことも出来る．
    明らかにこれは
    \sQuote{準}ファミリに対しては欠損する．}
}
\references{
  McCullagh P. and Nelder, J. A. (1989)
  \emph{Generalized Linear Models.}
  London: Chapman and Hall.

  Dobson, A. J. (1983)
  \emph{An Introduction to Statistical Modelling.}
  London: Chapman and Hall.

  Cox, D. R. and  Snell, E. J. (1981).
  \emph{Applied Statistics; Principles and Examples.}
  London: Chapman and Hall.

  Hastie, T. J. and Pregibon, D. (1992)
  \emph{Generalized linear models.}
  Chapter 6 of \emph{Statistical Models in S}
  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
}
\author{
  デザインは
  Hastie & Pregibon (1992) (\code{quasibinomial} と
  \code{quasipoisson} を除く)で説明されている同名の S 関数に
  啓発されている．
}
\seealso{
  \code{\link{glm}}, \code{\link{power}}, \code{\link{make.link}}.
  二項ファミリに対しては \emph{coefficients}, \code{\link{choose}}；
  二項ファミリと負の二項ファミリに対しては
  \emph{distributions},
  \code{\link{Binomial}} そして \code{\link{NegBinomial}}．
}
\examples{
require(utils) # str のため

nf <- gaussian()  # 正規ファミリ
nf
str(nf)

gf <- Gamma()
gf
str(gf)
gf$linkinv
gf$variance(-3:4) #- == (.)^2


## 準ポアッソンファミリ，example(glm) と比較せよ
counts <- c(18,17,15,20,10,20,25,13,12)
outcome <- gl(3,1,9)
treatment <- gl(3,3)
d.AD <- data.frame(treatment, outcome, counts)
glm.qD93 <- glm(counts ~ outcome + treatment, family = quasipoisson())
\donttest{
glm.qD93
anova(glm.qD93, test = "F")
summary(glm.qD93)
## ポアッソンファミリに対する結果は次を使う
anova(glm.qD93, dispersion = 1, test = "Chisq")
summary(glm.qD93, dispersion = 1)
}

## ユーザ固有のリンクの例，p^days に対するロジットモデル
## See Shaffer, T.  2004. Auk 121(2): 526-540.
logexp <- function(days = 1)
{
    linkfun <- function(mu) qlogis(mu^(1/days))
    linkinv <- function(eta) plogis(eta)^days
    mu.eta <- function(eta) days * plogis(eta)^(days-1) * binomial()$mu_eta
    valideta <- function(eta) TRUE
    link <- paste0("logexp(", days, ")")
    structure(list(linkfun = linkfun, linkinv = linkinv,
                   mu.eta = mu.eta, valideta = valideta, name = link),
              class = "link-glm")
}
binomial(logexp(3))
## 実際にはこれは 'days' のベクトルと共に使われるであろう，
## そのケースはナルの逸脱度を正しく得るために
## 対応する公式中でオフセット 0 を使う

## 高等リンクの二項ファミリ：しばしば良い考えではない
\dontrun{binomial(link = make.link("identity"))}

## 準ファミリのテスト
x <- rnorm(100)
y <- rpois(100, exp(1+x))
glm(y ~ x, family = quasi(variance = "mu", link = "log"))
# これは次と同じ
glm(y ~ x, family = poisson)
glm(y ~ x, family = quasi(variance = "mu^2", link = "log"))
\dontrun{glm(y ~ x, family = quasi(variance = "mu^3", link = "log")) # fails}
y <- rbinom(100, 1, plogis(x))
# 次の当てはめのためには初期値の設定が必要
glm(y ~ x, family = quasi(variance = "mu(1-mu)", link = "logit"), start = c(0,1))
}
\keyword{models}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/family.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{family}
%\alias{family}
%\alias{binomial}
%\alias{gaussian}
%\alias{Gamma}
%\alias{inverse.gaussian}
%\alias{poisson}
%\alias{quasi}
%\alias{quasibinomial}
%\alias{quasipoisson}
%%\alias{print.family}
%
%\title{Family Objects for Models}
%\usage{
%family(object, \dots)
%
%binomial(link = "logit")
%gaussian(link = "identity")
%Gamma(link = "inverse")
%inverse.gaussian(link = "1/mu^2")
%poisson(link = "log")
%quasi(link = "identity", variance = "constant")
%quasibinomial(link = "logit")
%quasipoisson(link = "log")
%}
%\arguments{
%  \item{link}{a specification for the model link function.  This can be
%    a name/expression, a literal character string, a length-one character
%    vector or an object of class
%    \code{"\link[=make.link]{link-glm}"} (such as generated by
%    \code{\link{make.link}}) provided it is not specified
%    \emph{via} one of the standard names given next.
%
%    The \code{gaussian} family accepts the links (as names)
%    \code{identity}, \code{log} and \code{inverse};
%    the \code{binomial} family the links \code{logit},
%    \code{probit}, \code{cauchit}, (corresponding to logistic,
%    normal and Cauchy CDFs respectively) \code{log} and
%    \code{cloglog} (complementary log-log);
%    the \code{Gamma} family the links \code{inverse}, \code{identity}
%     and \code{log};
%    the \code{poisson} family the links \code{log}, \code{identity},
%    and \code{sqrt} and the \code{inverse.gaussian} family the links
%    \code{1/mu^2}, \code{inverse}, \code{identity}
%    and \code{log}.
%
%    The \code{quasi} family accepts the links \code{logit}, \code{probit},
%    \code{cloglog},  \code{identity}, \code{inverse},
%    \code{log}, \code{1/mu^2} and \code{sqrt}, and
%    the function \code{\link{power}} can be used to create a
%    power link function.
%  }
%  \item{variance}{for all families other than \code{quasi}, the variance
%    function is determined by the family.  The \code{quasi} family will
%    accept the literal character string (or unquoted as a name/expression)
%    specifications \code{"constant"}, \code{"mu(1-mu)"}, \code{"mu"},
%    \code{"mu^2"} and \code{"mu^3"}, a length-one character vector
%    taking one of those values, or a list containing components
%    \code{varfun}, \code{validmu}, \code{dev.resids}, \code{initialize}
%    and \code{name}.
%  }
%  \item{object}{the function \code{family} accesses the \code{family}
%    objects which are stored within objects created by modelling
%    functions (e.g., \code{glm}).}
%  \item{\dots}{further arguments passed to methods.}
%}
%\description{
%  Family objects provide a convenient way to specify the details of the
%  models used by functions such as \code{\link{glm}}.  See the
%  documentation for \code{\link{glm}} for the details on how such model
%  fitting takes place.
%}
%\details{
%  \code{family} is a generic function with methods for classes
%  \code{"glm"} and \code{"lm"} (the latter returning \code{gaussian()}).
%
%  
%  For the \code{binomial} and \code{quasibinomial} families the response
%  can be specified in one of three ways:
%  \enumerate{
%    \item As a factor: \sQuote{success} is interpreted as the factor not
%    having the first level (and hence usually of having the second level).
%    \item As a numerical vector with values  between \code{0} and
%    \code{1}, interpreted as the proportion of successful cases (with the
%    total number of cases given by the \code{weights}).
%    \item As a two-column integer matrix: the first column gives the
%    number of successes and the second the number of failures.
%  }
%    
%  The \code{quasibinomial} and \code{quasipoisson} families differ from
%  the \code{binomial} and \code{poisson} families only in that the
%  dispersion parameter is not fixed at one, so they can model
%  over-dispersion.  For the binomial case see McCullagh and Nelder
%  (1989, pp.\sspace{}124--8).  Although they show that there is (under some
%  restrictions) a model with
%  variance proportional to mean as in the quasi-binomial model, note
%  that \code{glm} does not compute maximum-likelihood estimates in that
%  model.  The behaviour of S is closer to the quasi- variants.
%}
%\note{
%  The \code{link} and \code{variance} arguments have rather awkward
%  semantics for back-compatibility.  The recommended way is to supply
%  them is as quoted character strings, but they can also be supplied
%  unquoted (as names or expressions).  In addition, they can also be
%  supplied as a length-one character vector giving the name of one of
%  the options, or as a list (for \code{link}, of class
%  \code{"link-glm"}).  The restrictions apply only to links given as
%  names: when given as a character string all the links known to
%  \code{\link{make.link}} are accepted.
%
%  This is potentially ambiguous: supplying \code{link = logit} could mean
%  the unquoted name of a link or the value of object \code{logit}.  It
%  is interpreted if possible as the name of an allowed link, then
%  as an object.  (You can force the interpretation to always be the value of
%  an object via \code{logit[1]}.)
%}
%\value{
%  An object of class \code{"family"} (which has a concise print method).
%  This is a list with elements
%  \item{family}{character: the family name.}
%  \item{link}{character: the link name.}
%  \item{linkfun}{function: the link.}
%  \item{linkinv}{function: the inverse of the link function.}
%  \item{variance}{function: the variance as a function of the mean.}
%  \item{dev.resids}{function giving the deviance residuals as a function
%    of \code{(y, mu, wt)}.}
%  \item{aic}{function giving the AIC value if appropriate (but \code{NA}
%    for the quasi- families).  See \code{\link{logLik}} for the assumptions
%      made about the dispersion parameter.}
%  \item{mu.eta}{function: derivative \code{function(eta)}
%    \eqn{d\mu/d\eta}.}
%  \item{initialize}{expression.  This needs to set up whatever data
%    objects are needed for the family as well as \code{n} (needed for
%    AIC in the binomial family) and \code{mustart} (see \code{\link{glm}}.}
%  \item{validmu}{logical function.  Returns \code{TRUE} if a mean
%    vector \code{mu} is within the domain of \code{variance}.}
%  \item{valideta}{logical function.   Returns \code{TRUE} if a linear
%    predictor \code{eta} is within the domain of \code{linkinv}.}
%  \item{simulate}{(optional) function \code{simulate(object, nsim)} to be
%    called by the \code{"lm"} method of \code{\link{simulate}}.  It will
%    normally return a matrix with \code{nsim} columns and one row for
%    each fitted value, but it can also return a list of length
%    \code{nsim}. Clearly this will be missing for \sQuote{quasi-} families.}
%}
%\references{
%  McCullagh P. and Nelder, J. A. (1989)
%  \emph{Generalized Linear Models.}
%  London: Chapman and Hall.
%
%  Dobson, A. J. (1983)
%  \emph{An Introduction to Statistical Modelling.}
%  London: Chapman and Hall.
%
%  Cox, D. R. and  Snell, E. J. (1981).
%  \emph{Applied Statistics; Principles and Examples.}
%  London: Chapman and Hall.
%
%  Hastie, T. J. and Pregibon, D. (1992)
%  \emph{Generalized linear models.}
%  Chapter 6 of \emph{Statistical Models in S}
%  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
%}
%\author{
%  The design was inspired by S functions of the same names described
%  in Hastie & Pregibon (1992) (except \code{quasibinomial} and
%  \code{quasipoisson}).
%}
%\seealso{
%  \code{\link{glm}}, \code{\link{power}}, \code{\link{make.link}}.
%
%  For binomial \emph{coefficients}, \code{\link{choose}};
%  the binomial and negative binomial \emph{distributions},
%  \code{\link{Binomial}}, and \code{\link{NegBinomial}}.
%}
%\examples{
%require(utils) # for str
%
%nf <- gaussian()  # Normal family
%nf
%str(nf)
%
%gf <- Gamma()
%gf
%str(gf)
%gf$linkinv
%gf$variance(-3:4) #- == (.)^2
%
%
%## quasipoisson. compare with example(glm)
%counts <- c(18,17,15,20,10,20,25,13,12)
%outcome <- gl(3,1,9)
%treatment <- gl(3,3)
%d.AD <- data.frame(treatment, outcome, counts)
%glm.qD93 <- glm(counts ~ outcome + treatment, family = quasipoisson())
%\donttest{
%glm.qD93
%anova(glm.qD93, test = "F")
%summary(glm.qD93)
%## for Poisson results use
%anova(glm.qD93, dispersion = 1, test = "Chisq")
%summary(glm.qD93, dispersion = 1)
%}
%
%## Example of user-specified link, a logit model for p^days
%## See Shaffer, T.  2004. Auk 121(2): 526-540.
%logexp <- function(days = 1)
%{
%    linkfun <- function(mu) qlogis(mu^(1/days))
%    linkinv <- function(eta) plogis(eta)^days
%    mu.eta <- function(eta) days * plogis(eta)^(days-1) * binomial()$mu_eta
%    valideta <- function(eta) TRUE
%    link <- paste0("logexp(", days, ")")
%    structure(list(linkfun = linkfun, linkinv = linkinv,
%                   mu.eta = mu.eta, valideta = valideta, name = link),
%              class = "link-glm")
%}
%binomial(logexp(3))
%## in practice this would be used with a vector of 'days', in
%## which case use an offset of 0 in the corresponding formula
%## to get the null deviance right.
%
%## Binomial with identity link: often not a good idea.
%\dontrun{binomial(link = make.link("identity"))}
%
%## tests of quasi
%x <- rnorm(100)
%y <- rpois(100, exp(1+x))
%glm(y ~ x, family = quasi(variance = "mu", link = "log"))
%# which is the same as
%glm(y ~ x, family = poisson)
%glm(y ~ x, family = quasi(variance = "mu^2", link = "log"))
%\dontrun{glm(y ~ x, family = quasi(variance = "mu^3", link = "log")) # fails}
%y <- rbinom(100, 1, plogis(x))
%# needs to set a starting value for the next fit
%glm(y ~ x, family = quasi(variance = "mu(1-mu)", link = "logit"), start = c(0,1))
%}
%\keyword{models}
%
%\encoding{UTF-8}
%
