% File src/library/stats/man/friedman.test.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{friedman.test}
\alias{friedman.test}%@%\alias{Friedman のランク和検定}
\alias{friedman.test.default}
\alias{friedman.test.formula}
\title{Friedman Rank Sum Test}
\description{
  繰り返しのないブロックデータを用いた Friedman のランク和検定を実行する．
}
\usage{
friedman.test(y, \dots)

\method{friedman.test}{default}(y, groups, blocks, \dots)

\method{friedman.test}{formula}(formula, data, subset, na.action, \dots)
}
\arguments{
  \item{y}{データ値の数値ベクトル化データ行列．}
  \item{groups}{
    もしこれが行列ならば \code{y} の要素に対応するグループを与える
    ベクトル；もし \code{y} が行列ならば無視される．
    もし因子オブジェクトでなければ，因子に変換される．}
  \item{blocks}{
    もしこれがベクトルならば \code{y} の対応する要素に対する
    ブロックを与えるベクトル；
    もし \code{y} が行列ならば無視される．
    因子でなければ因子に変換される．}
  \item{formula}{
    形式 \code{a ~ b | c} の公式で，ここで
    \code{a}, \code{b} そして \code{c} はそれぞれデータと対応する
    グループ及びブロックを与える．}
  \item{data}{
    \code{formula} 中の変数を含むオプションの行列か
    データフレーム(又は類似物：
    \code{\link{model.frame}} を見よ)
    既定では変数は \code{environment(formula)} から取られる．}
  \item{subset}{使われる観測値の部分集合を指定するオプションの
    ベクトル．}
  \item{na.action}{
    データが \code{NA} を含む時の処理を指示する関数．
    既定では\cr
    \code{getOption("na.action")}．}
  \item{\dots}{メソッドに・から渡される追加の引数．}
}
\details{
  \code{friedman.test} は正規性の仮定が成り立たない繰り返しのない
  完全なブロックデザイン(つまり，
  \code{groups} と \code{blocks} の水準の各組み合わせに対して
  正確に一つの \code{y} がある)の解析に対して使うことが出来る，

  帰無仮説は \code{blocks} の効果を除いて
  \code{y} の位置パラメータが
  各 \code{groups} で同じというものである．

  もし \code{y} が行列ならば，\code{groups} と \code{blocks} は
  それぞれ列と行の添字から得られる．
  \code{groups} 又は \code{blocks} 中の \code{NA} は許されない；
  もし \code{y} が \code{NA} を含めば対応するブロックは除かれる．
}
\value{
  クラス \code{"htest"} のリストで次の成分を持つ：
  \item{statistic}{Friedman のカイ二乗統計量の値．}
  \item{parameter}{検定統計量の近似カイ二乗分布はの自由度．}
  \item{p.value}{検定の p 値．}
  \item{method}{文字列\sspace{} \code{"Friedman rank sum test"}．}
  \item{data.name}{データの名前を与える文字列．}
}
\references{
  Myles Hollander and Douglas A. Wolfe (1973),
  \emph{Nonparametric Statistical Methods.}
  New York: John Wiley & Sons.
  Pages 139--146.
}
\seealso{
  \code{\link{quade.test}}.
}
\examples{
## Hollander & Wolfe (1973), p. 140ff.
## 一塁を廻る三つの方法("丸く", "鋭角" そして "広角")の比較．
## 18人の選手の各々と三つの方法で，本塁から35フィート離れた
## 一塁ベース線上の点から二塁まで15フィートの点までの二回の
## 試走の平均時間を計った
RoundingTimes <-
matrix(c(5.40, 5.50, 5.55,
         5.85, 5.70, 5.75,
         5.20, 5.60, 5.50,
         5.55, 5.50, 5.40,
         5.90, 5.85, 5.70,
         5.45, 5.55, 5.60,
         5.40, 5.40, 5.35,
         5.45, 5.50, 5.35,
         5.25, 5.15, 5.00,
         5.85, 5.80, 5.70,
         5.25, 5.20, 5.10,
         5.65, 5.55, 5.45,
         5.60, 5.35, 5.45,
         5.05, 5.00, 4.95,
         5.50, 5.50, 5.40,
         5.45, 5.55, 5.50,
         5.55, 5.55, 5.35,
         5.45, 5.50, 5.55,
         5.50, 5.45, 5.25,
         5.65, 5.60, 5.40,
         5.70, 5.65, 5.55,
         6.30, 6.30, 6.25),
       nrow = 22,
       byrow = TRUE,
       dimnames = list(1 : 22,
                       c("Round Out", "Narrow Angle", "Wide Angle")))
friedman.test(RoundingTimes)
## => 方法は速度に関して同等という帰無仮説に反する強い証拠

wb <- aggregate(warpbreaks$breaks,
                by = list(w = warpbreaks$wool,
                          t = warpbreaks$tension),
                FUN = mean)
wb
friedman.test(wb$x, wb$w, wb$t)
friedman.test(x ~ w | t, data = wb)
}
\keyword{htest}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/friedman.test.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{friedman.test}
%\alias{friedman.test}
%\alias{friedman.test.default}
%\alias{friedman.test.formula}
%\title{Friedman Rank Sum Test}
%\description{
%  Performs a Friedman rank sum test with unreplicated blocked data.
%}
%\usage{
%friedman.test(y, \dots)
%
%\method{friedman.test}{default}(y, groups, blocks, \dots)
%
%\method{friedman.test}{formula}(formula, data, subset, na.action, \dots)
%}
%\arguments{
%  \item{y}{either a numeric vector of data values, or a data matrix.}
%  \item{groups}{a vector giving the group for the corresponding
%    elements of \code{y} if this is a vector;  ignored if \code{y}
%    is a matrix.  If not a factor object, it is coerced to one.}
%  \item{blocks}{a vector giving the block for the corresponding
%    elements of \code{y} if this is a vector;  ignored if \code{y}
%    is a matrix.  If not a factor object, it is coerced to one.}
%  \item{formula}{a formula of the form \code{a ~ b | c}, where \code{a},
%    \code{b} and \code{c} give the data values and corresponding groups
%    and blocks, respectively.}
%  \item{data}{an optional matrix or data frame (or similar: see
%    \code{\link{model.frame}}) containing the variables in the
%    formula \code{formula}.  By default the variables are taken from
%    \code{environment(formula)}.}
%  \item{subset}{an optional vector specifying a subset of observations
%    to be used.}
%  \item{na.action}{a function which indicates what should happen when
%    the data contain \code{NA}s.  Defaults to
%    \code{getOption("na.action")}.}
%  \item{\dots}{further arguments to be passed to or from methods.}
%}
%\details{
%  \code{friedman.test} can be used for analyzing unreplicated complete
%  block designs (i.e., there is exactly one observation in \code{y}
%  for each combination of levels of \code{groups} and \code{blocks})
%  where the normality assumption may be violated.
%
%  The null hypothesis is that apart from an effect of \code{blocks},
%  the location parameter of \code{y} is the same in each of the
%  \code{groups}.
%
%  If \code{y} is a matrix, \code{groups} and \code{blocks} are
%  obtained from the column and row indices, respectively.  \code{NA}'s
%  are not allowed in \code{groups} or \code{blocks};  if \code{y}
%  contains \code{NA}'s, corresponding blocks are removed.
%}
%\value{
%  A list with class \code{"htest"} containing the following components:
%  \item{statistic}{the value of Friedman's chi-squared statistic.}
%  \item{parameter}{the degrees of freedom of the approximate
%    chi-squared distribution of the test statistic.}
%  \item{p.value}{the p-value of the test.}
%  \item{method}{the character string \code{"Friedman rank sum test"}.}
%  \item{data.name}{a character string giving the names of the data.}
%}
%\references{
%  Myles Hollander and Douglas A. Wolfe (1973),
%  \emph{Nonparametric Statistical Methods.}
%  New York: John Wiley & Sons.
%  Pages 139--146.
%}
%\seealso{
%  \code{\link{quade.test}}.
%}
%\examples{
%## Hollander & Wolfe (1973), p. 140ff.
%## Comparison of three methods ("round out", "narrow angle", and
%##  "wide angle") for rounding first base.  For each of 18 players
%##  and the three method, the average time of two runs from a point on
%##  the first base line 35ft from home plate to a point 15ft short of
%##  second base is recorded.
%RoundingTimes <-
%matrix(c(5.40, 5.50, 5.55,
%         5.85, 5.70, 5.75,
%         5.20, 5.60, 5.50,
%         5.55, 5.50, 5.40,
%         5.90, 5.85, 5.70,
%         5.45, 5.55, 5.60,
%         5.40, 5.40, 5.35,
%         5.45, 5.50, 5.35,
%         5.25, 5.15, 5.00,
%         5.85, 5.80, 5.70,
%         5.25, 5.20, 5.10,
%         5.65, 5.55, 5.45,
%         5.60, 5.35, 5.45,
%         5.05, 5.00, 4.95,
%         5.50, 5.50, 5.40,
%         5.45, 5.55, 5.50,
%         5.55, 5.55, 5.35,
%         5.45, 5.50, 5.55,
%         5.50, 5.45, 5.25,
%         5.65, 5.60, 5.40,
%         5.70, 5.65, 5.55,
%         6.30, 6.30, 6.25),
%       nrow = 22,
%       byrow = TRUE,
%       dimnames = list(1 : 22,
%                       c("Round Out", "Narrow Angle", "Wide Angle")))
%friedman.test(RoundingTimes)
%## => strong evidence against the null that the methods are equivalent
%##    with respect to speed
%
%wb <- aggregate(warpbreaks$breaks,
%                by = list(w = warpbreaks$wool,
%                          t = warpbreaks$tension),
%                FUN = mean)
%wb
%friedman.test(wb$x, wb$w, wb$t)
%friedman.test(x ~ w | t, data = wb)
%}
%\keyword{htest}
%
%\encoding{UTF-8}
%
