% File src/library/stats/man/ftable.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{ftable}
\title{Flat Contingency Tables}
\alias{ftable}%@%\alias{フラットな分割表}
\alias{ftable.default}
\description{\sQuote{フラット}な分割表を作る．}
\usage{
ftable(x, \dots)

\method{ftable}{default}(\dots, exclude = c(NA, NaN), row.vars = NULL,
       col.vars = NULL)
}
\arguments{
  \item{x, \dots}{因子として解釈可能な \R オブジェクト
    (文字列を含む)，又はその成分がそのように解釈できる
    リスト(かデータフレーム)，または
    クラス \code{"table"} か \code{"ftable"} の分割表．}
  \item{exclude}{因子でないオブジェクトを解釈する時 \code{factor} の
    除外引数中で使われる値．}
  \item{row.vars}{変数の数を与える整数か，
    フラットな分割表の行に使われる変数の名前を与える
    文字列ベクトル．}
  \item{col.vars}{変数の数を与える整数か，
    フラットな分割表の列に使われる変数の名前を与える
    文字列ベクトル．}
}
\value{
  \code{ftable} はクラス
  \code{"ftable"} のオブジェクトを返す．これは行列で，
  変数の水準の各組み合わせのカウントと
  属性 \code{"row.vars"} と \code{"col.vars"} として保管された
  (行と列)変数の名前と水準に関する情報を持つ．
}
\details{
  \code{ftable} は\sQuote{フラット}な分割表を作る．
  通常の分割表と同じく，これは含まれる変数(因子)の水準の各組み合わせの
  カウントを含む．この情報はその行と列が
  行と列変数の水準のユニークな組み合わせに対応する行列に
  (それぞれ \code{row.vars} と \code{col.vars} で指定されたように)
  再編成される．
  
  組み合わせは変数を逆順にループすることで作られる
  (従って一番左の変数が最もゆっくり変化する)．
  分割表をこのフラットな行列で表示
  (クラス \code{"ftable"} のオブジェクトに対する \code{print.ftable}
  メソッドをを使って)することはしばしばそれを高次元の配列で
  表示するよりも好ましい．

  \code{ftable} は総称的関数である．その既定のメソッド
  \code{ftable.default} は最初
  \code{row.vars} と \code{col.vars} を除く全ての変数から配列
  形式の分割表を作る．もし最初の引数が
  クラス \code{"table"} であればそれは分割表を表し，
  そのままで使われる；もしそれがクラス \code{"ftable"} のフラットな表ならば，
  それが含む情報は \code{as.ftable} を使い通常の配列表現に変換される．
  さもなければ引数は因子(文字列を含む)か，その成分が
  そのように解釈されるリスト(データフレーム)で，
  \code{\link{table}} を使いクロス集計される．
  それから，引数 \code{row.vars} と \code{col.vars} が
  分割表をフラットな形式に潰すのに使われる．
  もしこれら二つのどちらも与えられないと，
  最後の変数が列として使われる．
  もし双方が与えられそれらの合併が含まれる全ての変数の
  真正な部分集合であれば，他の変数は加えつくされる．

  引数が因子として解釈された \R 表現式ならば，
  追加の引数は変数名の表示方法を制御するために
  \code{table} に渡される；
  最後の例を見よ．

  関数 \code{\link{ftable.formula}} は
  フラットな分割表に対する公式メソッドを提供する．

  \code{\link{as.table}}, \code{\link{as.matrix}}
  そして \code{\link{as.data.frame}} に対するメソッドがある．
}
\seealso{
  公式インタフェイスに対しては \code{\link{ftable.formula}}
  (これは \code{data = .} 引数を許す)；
  フラットな分割表の読み書きと変換に対する情報は \code{\link{read.ftable}}；
  通常のクロス集計ついては \code{\link{table}}；
  公式を用いたクロス集計については \code{\link{xtabs}}．
}
\examples{
## 分割表から開始．
ftable(Titanic, row.vars = 1:3)
ftable(Titanic, row.vars = 1:2, col.vars = "Survived")
ftable(Titanic, row.vars = 2:1, col.vars = "Survived")
\dontshow{%% must work
. <- integer()
(f04 <- ftable(Titanic, col.vars= .))
(f10 <- ftable(Titanic, col.vars= 1, row.vars= .))
(f01 <- ftable(Titanic, col.vars= ., row.vars= 1))
(f00 <- ftable(Titanic, col.vars= ., row.vars= .))
stopifnot(
  dim(f04) == c(32,1),
  dim(f10) == c(1,4),
  dim(f01) == c(4,1),
  dim(f00) == c(1,1))
}
## データフレームから開始．
x <- ftable(mtcars[c("cyl", "vs", "am", "gear")])
x
ftable(x, row.vars = c(2, 4))

## 表現式から開始，ラベルの変更には table() の "dnn" を使う
ftable(mtcars$cyl, mtcars$vs, mtcars$am, mtcars$gear, row.vars = c(2, 4),
       dnn = c("Cylinders", "V/S", "Transmission", "Gears"))
}
\keyword{category}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/ftable.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{ftable}
%\title{Flat Contingency Tables}
%\alias{ftable}
%\alias{ftable.default}
%\description{Create \sQuote{flat} contingency tables.}
%\usage{
%ftable(x, \dots)
%
%\method{ftable}{default}(\dots, exclude = c(NA, NaN), row.vars = NULL,
%       col.vars = NULL)
%}
%\arguments{
%  \item{x, \dots}{\R objects which can be interpreted as factors (including
%    character strings), or a list (or data frame) whose components can
%    be so interpreted, or a contingency table object of class
%    \code{"table"} or \code{"ftable"}.}
%  \item{exclude}{values to use in the exclude argument of \code{factor}
%    when interpreting non-factor objects.}
%  \item{row.vars}{a vector of integers giving the numbers of the
%    variables, or a character vector giving the names of the variables
%    to be used for the rows of the flat contingency table.}
%  \item{col.vars}{a vector of integers giving the numbers of the
%    variables, or a character vector giving the names of the variables
%    to be used for the columns of the flat contingency table.}
%}
%\value{
%  \code{ftable} returns an object of class \code{"ftable"}, which is a
%  matrix with counts of each combination of the levels of variables with
%  information on the names and levels of the (row and columns) variables
%  stored as attributes \code{"row.vars"} and \code{"col.vars"}.
%}
%\details{
%  \code{ftable} creates \sQuote{flat} contingency tables.  Similar to the
%  usual contingency tables, these contain the counts of each combination
%  of the levels of the variables (factors) involved.  This information
%  is then re-arranged as a matrix whose rows and columns correspond to
%  unique combinations of the levels of the row and column variables (as
%  specified by \code{row.vars} and \code{col.vars}, respectively).  The
%  combinations are created by looping over the variables in reverse
%  order (so that the levels of the left-most variable vary the
%  slowest).  Displaying a contingency table in this flat matrix form
%  (via \code{print.ftable}, the print method for objects of class
%  \code{"ftable"}) is often preferable to showing it as a
%  higher-dimensional array.
%
%  \code{ftable} is a generic function.  Its default method,
%  \code{ftable.default}, first creates a contingency table in array
%  form from all arguments except \code{row.vars} and \code{col.vars}.
%  If the first argument is of class \code{"table"}, it represents a
%  contingency table and is used as is; if it is a flat table of class
%  \code{"ftable"}, the information it contains is converted to the usual
%  array representation using \code{as.ftable}.  Otherwise, the arguments
%  should be \R objects which can be interpreted as factors (including
%  character strings), or a list (or data frame) whose components can be
%  so interpreted, which are cross-tabulated using \code{\link{table}}.
%  Then, the arguments \code{row.vars} and \code{col.vars} are used to
%  collapse the contingency table into flat form.  If neither of these
%  two is given, the last variable is used for the columns.  If both are
%  given and their union is a proper subset of all variables involved,
%  the other variables are summed out.
%
%  When the arguments are \R expressions interpreted as factors,
%  additional arguments will be passed to \code{table} to control how
%  the variable names are displayed; see the last example below.
%
%  Function \code{\link{ftable.formula}} provides a formula method for
%  creating flat contingency tables.
%
%  There are methods for \code{\link{as.table}}, \code{\link{as.matrix}}
%  and \code{\link{as.data.frame}}.
%}
%\seealso{
%  \code{\link{ftable.formula}} for the formula interface (which allows a
%  \code{data = .} argument);
%  \code{\link{read.ftable}} for information on reading, writing and
%  coercing flat contingency tables;
%  \code{\link{table}} for ordinary cross-tabulation;
%  \code{\link{xtabs}} for formula-based cross-tabulation.
%}
%\examples{
%## Start with a contingency table.
%ftable(Titanic, row.vars = 1:3)
%ftable(Titanic, row.vars = 1:2, col.vars = "Survived")
%ftable(Titanic, row.vars = 2:1, col.vars = "Survived")
%\dontshow{%% must work
%. <- integer()
%(f04 <- ftable(Titanic, col.vars= .))
%(f10 <- ftable(Titanic, col.vars= 1, row.vars= .))
%(f01 <- ftable(Titanic, col.vars= ., row.vars= 1))
%(f00 <- ftable(Titanic, col.vars= ., row.vars= .))
%stopifnot(
%  dim(f04) == c(32,1),
%  dim(f10) == c(1,4),
%  dim(f01) == c(4,1),
%  dim(f00) == c(1,1))
%}
%## Start with a data frame.
%x <- ftable(mtcars[c("cyl", "vs", "am", "gear")])
%x
%ftable(x, row.vars = c(2, 4))
%
%## Start with expressions, use table()'s "dnn" to change labels
%ftable(mtcars$cyl, mtcars$vs, mtcars$am, mtcars$gear, row.vars = c(2, 4),
%       dnn = c("Cylinders", "V/S", "Transmission", "Gears"))
%}
%\keyword{category}
%
%\encoding{UTF-8}
%
