% File src/library/stats/man/identify.hclust.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{identify.hclust}
\alias{identify.hclust}%@%\alias{デンドログラム中のクラスターを特定する}
\title{Identify Clusters in a Dendrogram}
\description{
  \code{identify.hclust} は
  (最初の)マウスボタンが押された時のグラフィックスポインターの位置を
  読み取る．
  それからポインターの垂直位置でツリーをカットし，
  ポインターの水平位置を含むクラスターをハイライトする．
  オプションでクラスター中に含まれるデータ点の添字に関数を適用できる．
}
\usage{
\method{identify}{hclust}(x, FUN = NULL, N = 20, MAXCLUSTER = 20, DEV.FUN = NULL,
          \dots)
}
\arguments{
  \item{x}{\code{hclust} で作られるタイプのオブジェクト．}
  \item{FUN}{
    クラスター中のデータ点の添字番号に適用される適用される
    (オプションの)関数(下の\sQuote{詳細}を見よ)．}
  \item{N}{特定されるべきクラスターの最大数．}
  \item{MAXCLUSTER}{カットで作り出すことが出来るクラスターの最大数
    (ポインターの実効的な垂直範囲の限界)．}
  \item{DEV.FUN}{(オプションの)整数値スカラー．
    もし指定されると，
    対応するグラフィックスデバイスが
    \code{FUN} が適用される前にアクティブにされる．}
  \item{\dots}{\code{FUN} への追加引数．}
}
\details{
  既定ではクラスターはマウスを使って特定でき，
  そして対応するデータ点の添字の不可視のリストが返される．

  もし \code{FUN} が \code{NULL} でなければ，データ点の添字ベクトル
  がこの関数の最初の引数として渡される，下の例を見よ．
  \code{FUN} に対するアクティブなグラフィックスデバイスは
  \code{DEV.FUN} を使って指定できる．

  特定のプロセスは最初以外のマウスボタンを押すことで終了する，
  \code{\link{identify}} も見よ．
}
\value{
  データ点の添字ベクトルか \code{FUN} の返り値のりスト．
}
\seealso{
  \code{\link{hclust}},
  \code{\link{rect.hclust}}
}
\examples{\dontrun{
require(graphics)

hca <- hclust(dist(USArrests))
plot(hca)
(x <- identify(hca)) ##  二番目のマウスボタンで終了!!

hci <- hclust(dist(iris[,1:4]))
plot(hci)
identify(hci, function(k) print(table(iris[k,5])))

# 新しいデバイスを開く(一つはデンドログラムで，一つはバー用)：
dev.new() # << それは狭く(そして小さく)する
          # そして最初のものの横に
nD <- dev.cur()            # バープロット用になる
dev.set(dev.prev())  # デンドログラム用の古いもの
plot(hci)
## デンドログラム中の副ツリーを選び種類の分布を"見る"
identify(hci, function(k) barplot(table(iris[k,5]), col = 2:4), DEV.FUN = nD)
}}
\keyword{cluster}
\keyword{iplot}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/identify.hclust.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{identify.hclust}
%\alias{identify.hclust}
%\title{Identify Clusters in a Dendrogram}
%\description{
%  \code{identify.hclust} reads the position of the graphics pointer when the
%  (first) mouse button is pressed.  It then cuts the tree at the
%  vertical position of the pointer and highlights the cluster containing
%  the horizontal position of the pointer.  Optionally a function is
%  applied to the index of data points contained in the cluster.
%}
%\usage{
%\method{identify}{hclust}(x, FUN = NULL, N = 20, MAXCLUSTER = 20, DEV.FUN = NULL,
%          \dots)
%}
%\arguments{
%  \item{x}{an object of the type produced by \code{hclust}.}
%  \item{FUN}{(optional) function to be applied to the index numbers of
%    the data points in a cluster (see \sQuote{Details} below).}
%  \item{N}{the maximum number of clusters to be identified.}
%  \item{MAXCLUSTER}{the maximum number of clusters that can be produced
%    by a cut (limits the effective vertical range of the pointer). }
%  \item{DEV.FUN}{(optional) integer scalar. If specified, the
%    corresponding graphics device is made active before \code{FUN} is
%    applied.}
%  \item{\dots}{further arguments to \code{FUN}.}
%}
%\details{
%  By default clusters can be identified using the mouse and an
%  \code{\link{invisible}} list of indices of the respective data points
%  is returned.
%
%  If \code{FUN} is not \code{NULL}, then the index vector of data points
%  is passed to this function as first argument, see the examples
%  below.  The active graphics device for \code{FUN} can be specified using
%  \code{DEV.FUN}.
%
%  The identification process is terminated by pressing any mouse
%  button other than the first, see also \code{\link{identify}}.
%}
%\value{
%  Either a list of data point index vectors or a list of return values
%  of \code{FUN}.
%}
%\seealso{
%  \code{\link{hclust}},
%  \code{\link{rect.hclust}}
%}
%\examples{\dontrun{
%require(graphics)
%
%hca <- hclust(dist(USArrests))
%plot(hca)
%(x <- identify(hca)) ##  Terminate with 2nd mouse button !!
%
%hci <- hclust(dist(iris[,1:4]))
%plot(hci)
%identify(hci, function(k) print(table(iris[k,5])))
%
%# open a new device (one for dendrogram, one for bars):
%dev.new() # << make that narrow (& small)
%          # and *beside* 1st one
%nD <- dev.cur()            # to be for the barplot
%dev.set(dev.prev())  # old one for dendrogram
%plot(hci)
%## select subtrees in dendrogram and "see" the species distribution:
%identify(hci, function(k) barplot(table(iris[k,5]), col = 2:4), DEV.FUN = nD)
%}}
%\keyword{cluster}
%\keyword{iplot}
%
%\encoding{UTF-8}
%
