% File src/library/stats/man/kmeans.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{kmeans}
\alias{kmeans}%@%\alias{k-maenas クラスタリング}
\alias{print.kmeans}
\alias{fitted.kmeans}
\title{
K-Means Clustering
}
\description{
  データ行列に対して k-means クラスタリングを実行する．
}
\usage{
kmeans(x, centers, iter.max = 10, nstart = 1,
       algorithm = c("Hartigan-Wong", "Lloyd", "Forgy",
                     "MacQueen"), trace=FALSE)
\method{fitted}{kmeans}(object, method = c("centers", "classes"), ...)
}
\arguments{
  \item{x}{データの数値行列，又は
    そうした行列に変換できるオブジェクト
    (数値ベクトル又は全てが数値列のデータフレームの様な)．}
  \item{centers}{クラスター数，例えば \eqn{k}，か
    (異なった)クラスター中心のセット．
    もし数値ならば，
    (異なった) \code{x} 中のランダムなセットが初期中心に選ばれる．}
  \item{iter.max}{許される最大繰り返し数．}
  \item{nstart}{もし \code{centers} が数値ならば，何組のランダムセットを
    選ぶか?}
  \item{algorithm}{文字列：短縮化出来る．
    \code{"Lloyd"} と \code{"Forgy"} は一つのアルゴリズムに対する
    別の名前であることを注意する．}
  \item{object}{
    クラス \code{"kmeans"} の \R オブジェクトで，典型的には
    \code{ob <- kmeans(..)} の結果 result \code{ob}．}
  \item{method}{文字列：短縮化可能．
    \code{"centers"} は \code{fitted} にクラスター中心
    (各入力点毎に一つ)を返すようにし，
    \code{"classes"} は \code{fitted} にクラス付値のベクトルを返すようにする．}
  \item{trace}{論理値か整数で，現在は既定メソッド
    (\code{"Hartigan-Wong"})でだけ使われる：もし正(か真)ならば，
    アルゴリズムの進行過程の情報を与える．
    値が大きいほどより多くのトレース情報が与えられるかもしれない．}
  \item{\dots}{使われない．}
}
\details{
  \code{x} で与えられるデータは \eqn{k}-means 法でクラスタリングされる，
  これは点を
  \eqn{k} 個のグループに分割し，点から与えられたクラスター中心への
  距離の二乗和を最小化することを目指している．
  最小値ではクラスター中心はそれらのボロノイ集合
  (クラスター中心へ一番近いデータ点の集まり)の平均に位置する．

  Hartigan and Wong (1979) のアルゴリズムが既定で使われる．
  何人かの著者は
  \eqn{k}-means 法を一般的な手法ではなく特定のアルゴリズムのこととしている：
  最も普通に使われるアルゴリズムは MacQueen (1967) によるが，
  時おり Lloyd (1957) と Forgy (1965) の方法も使われる．
  Hartigan--Wong のアルゴリズムは一般にこれらのどれよりも良い仕事をするが，
  幾つもの(\code{nstart}\eqn{> 1})ランダムな初期値がしばしば勧められる．
  点の幾つかが極端に近い時には，稀に
  アルゴリズムは\dQuote{Quick-Transfer}ステージで収束しないかもしれず，
  警告を出す(そして \code{ifault = 4} を返す)．
  そうした場合データを少し丸めることが勧められる．

  プログラムのテストを容易にする，
  特に中心と \code{withinss} を返す，
  ため \eqn{k=1} が許される，

  Lloyd--Forgy 法を除き，もし数値が指定されると \eqn{k} 個のクラスターが常に
  返される．
  もし中心の初期行列が提供されると，
  どの点も一つもしくはそれ以上の中心に一番近いことが無いことも
  起こり得，Hartigan--Wong 法では現在これはエラーになる．
}
\value{
  \code{kmeans} はクラス
  \code{"kmeans"} のオブジェクトを返す，これは
  \code{print} と \code{fitted} メソッドを持つ．
  これは少なくとも次の成分を持つリストである：
  \item{cluster}{
    各点が集められるクラスターを指示する(\code{1:k} からの)整数
    のベクトル．
  }
  \item{centers}{クラスター中心の行列．}
  \item{totss}{二乗総和．}
  \item{withinss}{クラスター内部の二乗和のベクトル，
    クラスごとに一つの要素．}
  \item{tot.withinss}{クラスター内二乗和の総和，
    つまり \sspace{}\code{sum(withinss)}．}
  \item{betweenss}{クラスター間二乗和，
    つまり \sspace{}\code{totss-tot.withinss}．}
  \item{size}{各クラスター内の点の数．}
  \item{iter}{(外部)繰り返しの数．}
  \item{ifault}{整数：ありそうなアルゴリズムの問題を指示する
    -- エキスパート用．}
}
\references{
  Forgy, E. W. (1965) Cluster analysis of multivariate data:
  efficiency vs interpretability of classifications.
  \emph{Biometrics} \bold{21}, 768--769.

  Hartigan, J. A. and Wong, M. A. (1979).
  A K-means clustering algorithm.
  \emph{Applied Statistics} \bold{28}, 100--108.

  Lloyd, S. P. (1957, 1982)  Least squares quantization in PCM.
  Technical Note, Bell Laboratories.  Published in 1982 in
  \emph{IEEE Transactions on Information Theory} \bold{28}, 128--137.

  MacQueen, J. (1967)  Some methods for classification and analysis of
  multivariate observations. In \emph{Proceedings of the Fifth Berkeley
    Symposium on  Mathematical Statistics and  Probability},
  eds L. M. Le Cam & J. Neyman,
  \bold{1}, pp.\sspace{}281--297. Berkeley, CA: University of California Press.
}
\examples{
require(graphics)

# 二次元の例
x <- rbind(matrix(rnorm(100, sd = 0.3), ncol = 2),
           matrix(rnorm(100, mean = 1, sd = 0.3), ncol = 2))
colnames(x) <- c("x", "y")
(cl <- kmeans(x, 2))
plot(x, col = cl$cluster)
points(cl$centers, col = 1:2, pch = 8, cex = 2)

# 二乗和
ss <- function(x) sum(scale(x, scale = FALSE)^2)

## 各観測地に"当てはめられた"クラスター中心
fitted.x <- fitted(cl);  head(fitted.x)
resid.x <- x - fitted(cl)

## 等式： ----------------------------------
cbind(cl[c("betweenss", "tot.withinss", "totss")], # 同じ二つの列
         c(ss(fitted.x), ss(resid.x),    ss(x)))
stopifnot(all.equal(cl$ totss,        ss(x)),
	  all.equal(cl$ tot.withinss, ss(resid.x)),
	  ## これら三つは同じ：
	  all.equal(cl$ betweenss,    ss(fitted.x)),
	  all.equal(cl$ betweenss, cl$totss - cl$tot.withinss),
	  ## 従って同様に
	  all.equal(ss(x), ss(fitted.x) + ss(resid.x))
	  )

kmeans(x,1)$withinss # 自明な一つのクラスター，(その W.SS == ss(x))

## 多すぎるクラスターがあればランダムに開始することが役に立つ
## (そしていずれにせよしばしば推奨される!)：
(cl <- kmeans(x, 5, nstart = 25))
plot(x, col = cl$cluster)
points(cl$centers, col = 1:5, pch = 8)
}
\keyword{multivariate}
\keyword{cluster}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/kmeans.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{kmeans}
%\alias{kmeans}
%\alias{print.kmeans}
%\alias{fitted.kmeans}
%\title{
%K-Means Clustering
%}
%\description{
%  Perform k-means clustering on a data matrix.
%}
%\usage{
%kmeans(x, centers, iter.max = 10, nstart = 1,
%       algorithm = c("Hartigan-Wong", "Lloyd", "Forgy",
%                     "MacQueen"), trace=FALSE)
%\method{fitted}{kmeans}(object, method = c("centers", "classes"), ...)
%}
%\arguments{
%  \item{x}{numeric matrix of data, or an object that can be coerced to
%    such a matrix (such as a numeric vector or a data frame with all
%    numeric columns).}
%  \item{centers}{either the number of clusters, say \eqn{k}, or a set of
%    initial (distinct) cluster centres.  If a number, a random set of
%    (distinct) rows in \code{x} is chosen as the initial centres.}
%  \item{iter.max}{the maximum number of iterations allowed.}
%  \item{nstart}{if \code{centers} is a number, how many random sets
%    should be chosen?}
%  \item{algorithm}{character: may be abbreviated.  Note that
%    \code{"Lloyd"} and \code{"Forgy"} are alternative names for one
%    algorithm.}
%  \item{object}{an \R object of class \code{"kmeans"}, typically the
%    result \code{ob} of \code{ob <- kmeans(..)}.}
%  \item{method}{character: may be abbreviated. \code{"centers"} causes
%    \code{fitted} to return cluster centers (one for each input point) and
%    \code{"classes"} causes \code{fitted} to return a vector of class
%    assignments.}
%  \item{trace}{logical or integer number, currently only used in the
%    default method (\code{"Hartigan-Wong"}): if positive (or true),
%    tracing information on the progress of the algorithm is
%    produced.  Higher values may produce more tracing information.}
%  \item{\dots}{not used.}
%}
%\details{
%  The data given by \code{x} are clustered by the \eqn{k}-means method,
%  which aims to partition the points into \eqn{k} groups such that the
%  sum of squares from points to the assigned cluster centres is minimized.
%  At the minimum, all cluster centres are at the mean of their Voronoi
%  sets (the set of data points which are nearest to the cluster centre).
%
%  The algorithm of Hartigan and Wong (1979) is used by default.  Note
%  that some authors use \eqn{k}-means to refer to a specific algorithm
%  rather than the general method: most commonly the algorithm given by
%  MacQueen (1967) but sometimes that given by Lloyd (1957) and Forgy
%  (1965).  The Hartigan--Wong algorithm generally does a better job than
%  either of those, but trying several random starts (\code{nstart}\eqn{>
%  1}) is often recommended.  In rare cases, when some of the points
%  (rows of \code{x}) are extremely close, the algorithm may not converge
%  in the \dQuote{Quick-Transfer} stage, signalling a warning (and
%  returning \code{ifault = 4}).  Slight
%  rounding of the data may be advisable in that case.
%
%  For ease of programmatic exploration, \eqn{k=1} is allowed, notably
%  returning the center and \code{withinss}.
%
%  Except for the Lloyd--Forgy method, \eqn{k} clusters will always be
%  returned if a number is specified.
%  If an initial matrix of centres is supplied, it is possible that
%  no point will be closest to one or more centres, which is currently
%  an error for the Hartigan--Wong method.
%}
%\value{
%  \code{kmeans} returns an object of class \code{"kmeans"} which has a
%  \code{print} and a \code{fitted} method.  It is a list with at least
%  the following components:
%  \item{cluster}{
%    A vector of integers (from \code{1:k}) indicating the cluster to
%    which each point is allocated.
%  }
%  \item{centers}{A matrix of cluster centres.}
%  \item{totss}{The total sum of squares.}
%  \item{withinss}{Vector of within-cluster sum of squares,
%    one component per cluster.}
%  \item{tot.withinss}{Total within-cluster sum of squares,
%    i.e.\sspace{}\code{sum(withinss)}.}
%  \item{betweenss}{The between-cluster sum of squares,
%    i.e.\sspace{}\code{totss-tot.withinss}.}
%  \item{size}{The number of points in each cluster.}
%  \item{iter}{The number of (outer) iterations.}
%  \item{ifault}{integer: indicator of a possible algorithm problem
%    -- for experts.}
%}
%\references{
%  Forgy, E. W. (1965) Cluster analysis of multivariate data:
%  efficiency vs interpretability of classifications.
%  \emph{Biometrics} \bold{21}, 768--769.
%
%  Hartigan, J. A. and Wong, M. A. (1979).
%  A K-means clustering algorithm.
%  \emph{Applied Statistics} \bold{28}, 100--108.
%
%  Lloyd, S. P. (1957, 1982)  Least squares quantization in PCM.
%  Technical Note, Bell Laboratories.  Published in 1982 in
%  \emph{IEEE Transactions on Information Theory} \bold{28}, 128--137.
%
%  MacQueen, J. (1967)  Some methods for classification and analysis of
%  multivariate observations. In \emph{Proceedings of the Fifth Berkeley
%    Symposium on  Mathematical Statistics and  Probability},
%  eds L. M. Le Cam & J. Neyman,
%  \bold{1}, pp.\sspace{}281--297. Berkeley, CA: University of California Press.
%}
%\examples{
%require(graphics)
%
%# a 2-dimensional example
%x <- rbind(matrix(rnorm(100, sd = 0.3), ncol = 2),
%           matrix(rnorm(100, mean = 1, sd = 0.3), ncol = 2))
%colnames(x) <- c("x", "y")
%(cl <- kmeans(x, 2))
%plot(x, col = cl$cluster)
%points(cl$centers, col = 1:2, pch = 8, cex = 2)
%
%# sum of squares
%ss <- function(x) sum(scale(x, scale = FALSE)^2)
%
%## cluster centers "fitted" to each obs.:
%fitted.x <- fitted(cl);  head(fitted.x)
%resid.x <- x - fitted(cl)
%
%## Equalities : ----------------------------------
%cbind(cl[c("betweenss", "tot.withinss", "totss")], # the same two columns
%         c(ss(fitted.x), ss(resid.x),    ss(x)))
%stopifnot(all.equal(cl$ totss,        ss(x)),
%	  all.equal(cl$ tot.withinss, ss(resid.x)),
%	  ## these three are the same:
%	  all.equal(cl$ betweenss,    ss(fitted.x)),
%	  all.equal(cl$ betweenss, cl$totss - cl$tot.withinss),
%	  ## and hence also
%	  all.equal(ss(x), ss(fitted.x) + ss(resid.x))
%	  )
%
%kmeans(x,1)$withinss # trivial one-cluster, (its W.SS == ss(x))
%
%## random starts do help here with too many clusters
%## (and are often recommended anyway!):
%(cl <- kmeans(x, 5, nstart = 25))
%plot(x, col = cl$cluster)
%points(cl$centers, col = 1:5, pch = 8)
%}
%\keyword{multivariate}
%\keyword{cluster}
%
%\encoding{UTF-8}
%
