% File src/library/stats/man/loadings.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{loadings}
\alias{loadings}%@%\alias{因子分析(または主成分分析)中の負荷の抽出とプリント}
\alias{print.loadings}
\alias{print.factanal}
\title{Print Loadings in Factor Analysis}
\description{
  因子分析(または主成分分析)中の負荷の抽出とプリント．
}
\usage{
loadings(x, ...)

\method{print}{loadings}(x, digits = 3, cutoff = 0.1, sort = FALSE, \dots)

\method{print}{factanal}(x, digits = 3, \dots)
}
\arguments{
  \item{x}{
    クラス \code{"\link{factanal}"} または \code{"\link{princomp}"}の
    オブジェクト，又はそうしたオブジェクトの \code{loadings} 成分．}
  \item{digits}{一意性と負荷のプリントに使われる有効桁数．}
  \item{cutoff}{(絶対値で)これより小さな負荷は抑制される．}
  \item{sort}{論理値．もし真なら変数は各因子におけるそれらの重要性に
    従いソートされる．
    負荷が 0.5 (絶対値で)より大きな各変数は最大の負荷をもつ因子にあてがわれ，
    変数はそれらがあてがわれた因子の順序でプリントされ，
    それからその他のものがプリントされる．}
  \item{\dots}{他のメソッドに対する追加引数，
    \code{loadings} に対しては無視される．}
}

\details{
  \sQuote{負荷}は\emph{因子分析}からの用語であるが，
  因子分析と主成分分析(PCA)は社会科学文献では合体されるので，
  SPSS では PCA に対して使われ，
  S-PLUS では SPSS ユーザーを助けるため \code{\link{princomp}} で使われる．

  より大きな負荷のnパターンに注目させるため，小さな負荷は伝統的にプリントされない
  (空白で置き換えられる)．

  クラス \code{"\link{factanal}"} に対する \code{print} メソッドは
  負荷のプリントのために \code{"loadings"} メソッドを呼び出し，
  そのため \code{cutoff} と \code{sort} のような引数をそれに渡す．
  
  負荷ベクトルの符号は因子分析と PCA の双方で任意である．
}

\note{
  S3 と S4 総称的である \code{loadings} と呼ばれる他の関数が幾つかの
  貢献パッケージにある：
  \code{\dots} 引数はこれを既定メソッドにするのを容易にする．
}

\seealso{
  \code{\link{factanal}}, \code{\link{princomp}}
}

\keyword{multivariate}
\keyword{print}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/loadings.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{loadings}
%\alias{loadings}
%\alias{print.loadings}
%\alias{print.factanal}
%\title{Print Loadings in Factor Analysis}
%\description{
%  Extract or print loadings in factor analysis (or principal
%  components analysis).
%}
%\usage{
%loadings(x, ...)
%
%\method{print}{loadings}(x, digits = 3, cutoff = 0.1, sort = FALSE, \dots)
%
%\method{print}{factanal}(x, digits = 3, \dots)
%}
%\arguments{
%  \item{x}{an object of class \code{"\link{factanal}"} or
%    \code{"\link{princomp}"} or the \code{loadings} component of such an
%    object.}
%  \item{digits}{number of decimal places to use in printing uniquenesses
%    and loadings.}
%  \item{cutoff}{loadings smaller than this (in absolute value) are suppressed.}
%  \item{sort}{logical. If true, the variables are sorted by their
%    importance on each factor.  Each variable with any loading larger
%    than 0.5 (in modulus) is assigned to the factor with the largest
%    loading, and the variables are printed in the order of the factor
%    they are assigned to, then those unassigned.}
%  \item{\dots}{further arguments for other methods,
%    ignored for \code{loadings}.}
%}
%
%\details{
%  \sQuote{Loadings} is a term from \emph{factor analysis}, but because
%  factor analysis and principal component analysis (PCA) are often
%  conflated in the social science literature, it was used for PCA by
%  SPSS and hence by \code{\link{princomp}} in S-PLUS to help SPSS users.
%
%  Small loadings are conventionally not printed (replaced by spaces), to
%  draw the eye to the pattern of the larger loadings.
%
%  The \code{print} method for class \code{"\link{factanal}"} calls the
%  \code{"loadings"} method to print the loadings, and so passes down
%  arguments such as \code{cutoff} and \code{sort}.
%  
%  The signs of the loadings vectors are arbitrary for both factor
%  analysis and PCA.
%}
%
%\note{
%  There are other functions called \code{loadings} in contributed
%  packages which are S3 or S4 generic: the \code{\dots} argument is to
%  make it easier for this one to become a default method.
%}
%
%\seealso{
%  \code{\link{factanal}}, \code{\link{princomp}}
%}
%
%\keyword{multivariate}
%\keyword{print}
%
%\encoding{UTF-8}
%
