% File src/library/stats/man/lowess.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{lowess}
\title{Scatter Plot Smoothing}
\description{
  この関数は
  局所的に重み付けられた多項式回帰
  (参考文献を見よ)である
  \emph{LOWESS} 平滑化のための計算を実行する．
}
\usage{
lowess(x, y = NULL, f = 2/3, iter = 3, delta = 0.01 * diff(range(x)))
}
\alias{lowess}%@%\alias{散布図平滑化}
\arguments{
  \item{x, y}{散布図中の点の座標を与えるベクトル．
    別法として単一のプロット構造を指定できる
    -- \code{\link{xy.coords}} を見よ．}
  \item{f}{平滑化幅．
    これは各値に於いて平滑化に影響を与えるプロット中の点の割合を与える．
    大きな値ほどより滑らかになる．}
  \item{iter}{
    実行される\sQuote{頑健化}のための繰り返し数．
    小さな \code{iter} は \code{lowess} の実行を速くする．}
  \item{delta}{\sQuote{詳細}節を見よ．既定は
    \code{x} の範囲の100分の1．}
}
\details{
  \code{lowess} は複雑なアルゴリズムで定義される．
  そのオリジナルの Ratfor コード
  (W. S. Cleveland による)は \R のソースファイル
  \file{src/appl/lowess.doc} にある．
  普通局所的な一次多項式当てはめが使われるが，
  ある場合には
  (file を見よ)局所的定数当てはめも使うことが出来る．
  \sQuote{局所性}は \code{floor(f*n)} 番目の最近接近傍への距離
  で定義され，3乗の3乗重みが
  近傍内に入る \code{x} に対して使われる．

  最初の当てはめは重み付き最少二乗法で行われる．
  もし \code{iter > 0} なら更に重み付き当てはめが
  \code{x} 値の近接度からの重みと
  前の繰り返しでの残差から導かれたケース重みの
  積を使ってなされる．具体的に言うと，
  ケースの重みは Tukey の biweight で，カットオフは残差の
  MAD の6倍である．
  (現在の \R の実装はオリジナルと
  MAD が実効的にゼロになると繰り返しを停止する点で異なる，その場合
  アルゴリズムが極点に不安定になるからである．)

  \code{delta} は計算の速度向上に使われる：
  各データ点での局所多項式当てはめを計算する代わりに，
  直前で計算された点から \code{delta} 以内の点に対しては
  計算をせず，スキップした点の当てはめ値には線形補間が
  用いられる．
}
\value{
  \code{lowess} は
  平滑化の結果の座標を与える成分 \code{x} と \code{y} を含むリストを返す．
  平滑化の結果は
  \code{lines} を用いオリジナルの点のプロットに加えることが出来る：
  例を見よ．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.

  Cleveland, W. S. (1979)
  Robust locally weighted regression and smoothing scatterplots.
  \emph{J. American Statistical Association} \bold{74}, 829--836.

  Cleveland, W. S. (1981)
  LOWESS: A program for smoothing scatterplots by robust locally weighted
  regression. \emph{The American Statistician} \bold{35}, 54.
}
\seealso{\code{\link{loess}} は公式ベースの
  \code{lowess} の新しいバージョン(異なった既定値を持つ!)．
}
\examples{
require(graphics)

plot(cars, main = "lowess(cars)")
lines(lowess(cars), col = 2)
lines(lowess(cars, f = .2), col = 3)
legend(5, 120, c(paste("f = ", c("2/3", ".2"))), lty = 1, col = 2:3)
}
\keyword{smooth}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/lowess.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{lowess}
%\title{Scatter Plot Smoothing}
%\description{
%  This function performs the computations for the
%  \emph{LOWESS} smoother which uses locally-weighted polynomial
%  regression (see the references).
%}
%\usage{
%lowess(x, y = NULL, f = 2/3, iter = 3, delta = 0.01 * diff(range(x)))
%}
%\alias{lowess}
%\arguments{
%  \item{x, y}{vectors giving the coordinates of the points in the scatter plot.
%    Alternatively a single plotting structure can be specified -- see
%    \code{\link{xy.coords}}.}
%  \item{f}{the smoother span. This gives the proportion of points in
%    the plot which influence the smooth at each value.
%    Larger values give more smoothness.}
%  \item{iter}{the number of \sQuote{robustifying} iterations which should be
%    performed.
%    Using smaller values of \code{iter} will make \code{lowess} run faster.}
%  \item{delta}{See \sQuote{Details}.  Defaults to 1/100th of the range
%    of \code{x}.}
%}
%\details{
%  \code{lowess} is defined by a complex algorithm, the Ratfor original
%  of which (by W. S. Cleveland) can be found in the \R sources as file
%  \file{src/appl/lowess.doc}.  Normally a local linear polynomial fit is
%  used, but under some circumstances (see the file) a local constant fit
%  can be used.  \sQuote{Local} is defined by the distance to the
%  \code{floor(f*n)}th nearest neighbour, and tricubic weighting is used
%  for \code{x} which fall within the neighbourhood.
%
%  The initial fit is done using weighted least squares.  If
%  \code{iter > 0}, further weighted fits are done using the product of
%  the weights from the proximity of the \code{x} values and case weights
%  derived from the residuals at the previous iteration.  Specifically,
%  the case weight is Tukey's biweight, with cutoff 6 times the MAD of the
%  residuals.  (The current \R implementation differs from the original
%  in stopping iteration if the MAD is effectively zero since the
%  algorithm is highly unstable in that case.)
%
%  \code{delta} is used to speed up computation: instead of computing the
%  local polynomial fit at each data point it is not computed for points
%  within \code{delta} of the last computed point, and linear
%  interpolation is used to fill in the fitted values for the skipped
%  points.
%}
%\value{
%  \code{lowess} returns a list containing components
%  \code{x} and \code{y} which give the coordinates of the smooth.
%  The smooth can be added to a plot of the original
%  points with the function \code{lines}: see the examples.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%
%  Cleveland, W. S. (1979)
%  Robust locally weighted regression and smoothing scatterplots.
%  \emph{J. American Statistical Association} \bold{74}, 829--836.
%
%  Cleveland, W. S. (1981)
%  LOWESS: A program for smoothing scatterplots by robust locally weighted
%  regression. \emph{The American Statistician} \bold{35}, 54.
%}
%\seealso{\code{\link{loess}}, a newer
%  formula based version of \code{lowess} (with different defaults!).
%}
%\examples{
%require(graphics)
%
%plot(cars, main = "lowess(cars)")
%lines(lowess(cars), col = 2)
%lines(lowess(cars, f = .2), col = 3)
%legend(5, 120, c(paste("f = ", c("2/3", ".2"))), lty = 1, col = 2:3)
%}
%\keyword{smooth}
%
%\encoding{UTF-8}
%
