% File src/library/stats/man/makepredictcall.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{makepredictcall}
\alias{makepredictcall}
\alias{makepredictcall.default}
\alias{SafePrediction}%@%\alias{安全な予測のためのユーティリティー関数}
\title{Utility Function for Safe Prediction}
\description{
  (一変量の) \code{poly} または \code{ns} のような項を持つモデルから
  予測する際 \code{\link{model.frame.default}} が正しい行列を
  作るのを助けるユーティリティー．
}
\usage{
makepredictcall(var, call)
}
\arguments{
  \item{var}{変数．}
  \item{call}{呼び出しとしての公式中の項．}
}
\details{
  これは総称的関数で
  \code{poly}, \code{bs} そして \code{ns} に対するメソッドを持つ：
  既定のメソッドは \code{scale} を処理する．
  もし \code{model.frame.default} がモデルフレームを作る際そうした
  項に出会うと，
  与えられた項の \code{predvars} 属性を新しいデータに対して
  動作するそれを持つ項で置き換える．
  例えば \code{makepredictcall.ns} はノットと切片に対する引数を
  付け加える．

  これを利用するには，モデル当てはめ関数が
  \code{terms} 属性をもつモデルフレームを返すようにするか，
  モデルフレームの
  \code{terms} 属性の \code{predvars} 属性を
  自分の \code{terms} オブジェクトにコピーする．

  これを拡張するには項がクラスを持つ変数を作り
  そのクラスに対する適当なメソッドを書くことを
  忘れない．
}
\value{
  項の \code{predvars} 属性に対する
  \code{call} の代替物．
}
\seealso{
  \code{\link{model.frame}}, \code{\link{poly}}, \code{\link{scale}};
  パッケージ \pkg{splines} 中の \code{\link{bs}} と \code{\link{ns}}．

  多項式当てはめからの例は \code{\link{cars}}．
}
\examples{
require(graphics)

## 多項式を使う：これは R < 1.5.0 では動作しない
fm <- lm(weight ~ poly(height, 2), data = women)
plot(women, xlab = "Height (in)", ylab = "Weight (lb)")
ht <- seq(57, 73, len = 200)
lines(ht, predict(fm, data.frame(height = ht)))

## example(cars) も見よ

## スプラインの例は bs と ns を見よ．
}
\keyword{models}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/makepredictcall.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{makepredictcall}
%\alias{makepredictcall}
%\alias{makepredictcall.default}
%\alias{SafePrediction}
%\title{Utility Function for Safe Prediction}
%\description{
%  A utility to help \code{\link{model.frame.default}} create the right
%  matrices when predicting from models with terms like (univariate)
%  \code{poly} or \code{ns}.
%}
%\usage{
%makepredictcall(var, call)
%}
%\arguments{
%  \item{var}{A variable.}
%  \item{call}{The term in the formula, as a call.}
%}
%\details{
%  This is a generic function with methods for \code{poly}, \code{bs} and
%  \code{ns}: the default method handles \code{scale}.  If
%  \code{model.frame.default} encounters such a term when
%  creating a model frame, it modifies the \code{predvars} attribute of
%  the terms supplied by replacing the term with one which will work for
%  predicting new data.  For example \code{makepredictcall.ns} adds
%  arguments for the knots and intercept.
%
%  To make use of this, have your model-fitting function return the
%  \code{terms} attribute of the model frame, or copy the \code{predvars}
%  attribute of the \code{terms} attribute of the model frame to your
%  \code{terms} object.
%
%  To extend this, make sure the term creates variables with a class,
%  and write a suitable method for that class.
%}
%\value{
%  A replacement for \code{call} for the \code{predvars} attribute of
%  the terms.
%}
%\seealso{
%  \code{\link{model.frame}}, \code{\link{poly}}, \code{\link{scale}};
%  \code{\link{bs}} and \code{\link{ns}} in package \pkg{splines}.
%
%  \code{\link{cars}} for an example of prediction from a polynomial fit.
%}
%\examples{
%require(graphics)
%
%## using poly: this did not work in R < 1.5.0
%fm <- lm(weight ~ poly(height, 2), data = women)
%plot(women, xlab = "Height (in)", ylab = "Weight (lb)")
%ht <- seq(57, 73, len = 200)
%lines(ht, predict(fm, data.frame(height = ht)))
%
%## see also example(cars)
%
%## see bs and ns for spline examples.
%}
%\keyword{models}
%
%\encoding{UTF-8}
%
