% File src/library/stats/man/plot.spec.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{plot.spec}
\alias{plot.spec}%@%\alias{スペクトル密度をプロット}
\alias{plot.spec.coherency}
\alias{plot.spec.phase}
\title{Plotting Spectral Densities}
\description{
  Plotting method for objects of class
  クラス \code{"spec"} のオブジェクトに対するプロットメソッド．
  多変量時系列に対しては，これは系列の周辺スペクトルか
  クロススペクトルのコヒーレンシーとフェイズの対プロットをプロットする．
}
\usage{
\method{plot}{spec}(x, add = FALSE, ci = 0.95, log = c("yes", "dB", "no"),
     xlab = "frequency", ylab = NULL, type = "l",
     ci.col = "blue", ci.lty = 3,
     main = NULL, sub = NULL,
     plot.type = c("marginal", "coherency", "phase"),
     \dots)

plot.spec.phase(x, ci = 0.95,
                xlab = "frequency", ylab = "phase",
                ylim = c(-pi, pi), type = "l",
                main = NULL, ci.col = "blue", ci.lty = 3, \dots)

plot.spec.coherency(x, ci = 0.95,
                    xlab = "frequency",
                    ylab = "squared coherency",
                    ylim = c(0, 1), type = "l",
                    main = NULL, ci.col = "blue", ci.lty = 3, \dots)
}
\arguments{
  \item{x}{
    クラス \code{"spec"} のオブジェクト．}
  \item{add}{論理値．もし \code{TRUE} なら既に存在するプロットに付け加える．\cr
    \code{plot.type = "marginal"} の時だけ有効である．}
  \item{ci}{信頼区間に対する被覆確率．
    信頼バー/限界は \code{ci} が狭義に正でない限り除かれる．}
  \item{log}{もし \code{"dB"} ならば log10 (デシベル)スケールでプロットされる
    (S-PLUS のように)，さもなければ伝統的な対数スケールや線形スケール
    でプロットされる．論理値も受け入れられる．
    \code{options(ts.S.compat = TRUE)} が設定されていない限り
    既定値は \code{"yes"} で，その時は \code{"dB"}．
    \code{plot.type = "marginal"} の時だけ適正である．}
  \item{xlab}{プロットの x ラベル．}
  \item{ylab}{プロットの y ラベル．もし欠損していれば適当なラベルが作られる．}
  \item{type}{描かれるプロットのタイプ，既定値は線．}
  \item{ci.col}{コヒーレンシーとフェイズに対する
    信頼バー又は信頼区間の色．}
  \item{ci.lty}{コヒーレンシーとフェイズに対する
    信頼バー又は信頼区間の線種．}
  \item{main}{プロットの全体的なタイトル．もし欠損していれば，
    適当なタイトルが作られる．}
  \item{sub}{プロットに対する副タイトル．
    \code{plot.type = "marginal"} の時だけ使われる．
    もし欠損していれば，平滑化の記述が使われる．}
  \item{plot.type}{多変量時系列に対して，
    必要なプロットのタイプ．最初の文字だけで十分．}
  \item{ylim, \dots}{グラフィカルパラメータ．}
}
\seealso{
  \code{\link{spectrum}}
}
\keyword{hplot} 
\keyword{ts}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/plot.spec.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{plot.spec}
%\alias{plot.spec}
%\alias{plot.spec.coherency}
%\alias{plot.spec.phase}
%\title{Plotting Spectral Densities}
%\description{
%  Plotting method for objects of class \code{"spec"}.  For multivariate
%  time series it plots the marginal spectra of the series or pairs plots
%  of the coherency and phase of the cross-spectra.
%}
%\usage{
%\method{plot}{spec}(x, add = FALSE, ci = 0.95, log = c("yes", "dB", "no"),
%     xlab = "frequency", ylab = NULL, type = "l",
%     ci.col = "blue", ci.lty = 3,
%     main = NULL, sub = NULL,
%     plot.type = c("marginal", "coherency", "phase"),
%     \dots)
%
%plot.spec.phase(x, ci = 0.95,
%                xlab = "frequency", ylab = "phase",
%                ylim = c(-pi, pi), type = "l",
%                main = NULL, ci.col = "blue", ci.lty = 3, \dots)
%
%plot.spec.coherency(x, ci = 0.95,
%                    xlab = "frequency",
%                    ylab = "squared coherency",
%                    ylim = c(0, 1), type = "l",
%                    main = NULL, ci.col = "blue", ci.lty = 3, \dots)
%}
%\arguments{
%  \item{x}{an object of class \code{"spec"}.}
%  \item{add}{logical.  If \code{TRUE}, add to already existing plot.
%    Only valid for \code{plot.type = "marginal"}.
%  }
%  \item{ci}{coverage probability for confidence interval.  Plotting of
%    the confidence bar/limits is omitted unless \code{ci} is strictly
%    positive.}
%  \item{log}{If \code{"dB"}, plot on log10 (decibel) scale (as S-PLUS),
%    otherwise use conventional log scale or linear scale.  Logical
%    values are also accepted.  The default is \code{"yes"} unless
%    \code{options(ts.S.compat = TRUE)} has been set, when it is
%    \code{"dB"}.  Only valid for \code{plot.type = "marginal"}.
%  }
%  \item{xlab}{the x label of the plot.}
%  \item{ylab}{the y label of the plot.  If missing a suitable label will
%    be constructed.}
%  \item{type}{the type of plot to be drawn, defaults to lines.}
%  \item{ci.col}{colour for plotting confidence bar or confidence
%    intervals for coherency and phase.}
%  \item{ci.lty}{line type for confidence intervals for coherency and
%    phase.}
%  \item{main}{overall title for the plot. If missing, a suitable title
%    is constructed.}
%  \item{sub}{a sub title for the plot.  Only used for \code{plot.type =
%      "marginal"}.  If missing, a description of the smoothing is used.}
%  \item{plot.type}{For multivariate time series, the type of plot
%    required.  Only the first character is needed.}
%  \item{ylim, \dots}{Graphical parameters.}
%}
%\seealso{
%  \code{\link{spectrum}}
%}
%\keyword{hplot}
%\keyword{ts}
%
%\encoding{UTF-8}
%
