% File src/library/stats/man/prcomp.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2012 R Core Team
% Distributed under GPL 2 or later

\name{prcomp}
\alias{prcomp}%@%\alias{主成分分析}
\alias{prcomp.formula}
\alias{prcomp.default}
\alias{plot.prcomp}
\alias{predict.prcomp}
\alias{print.prcomp}
\alias{summary.prcomp}
\alias{print.summary.prcomp}
\concept{PCA}
\title{Principal Components Analysis}
\description{
  与えられたデータ行列に対して主成分分析を実行し
  結果をクラス \code{prcomp} のオブジェクトとして返す．}
\usage{
prcomp(x, \dots)

\method{prcomp}{formula}(formula, data = NULL, subset, na.action, \dots)

\method{prcomp}{default}(x, retx = TRUE, center = TRUE, scale. = FALSE,
       tol = NULL, \dots)

\method{predict}{prcomp}(object, newdata, \dots)
}
\arguments{
  \item{formula}{応答変数を持たない公式で，
    数値変数だけを参照する．}
  \item{data}{
    オプションのデータフレーム(又は類似物：
    \code{\link{model.frame}} を見よ)で
    公式 \code{formula} 中の変数を含む．既定では変数は
    \code{environment(formula)} から取られる．}
  \item{subset}{
    データ行列 \code{x} の行(観測値)を選ぶのに使われるオプションのベクトル．}
  \item{na.action}{
    データが \code{NA} を含む時何が起きるべきかを指示する関数．
    既定は \code{\link{options}} の \code{na.action} 設置で，
    もしそれが未設定なら
    \code{\link{na.fail}}．
    \sQuote{工場出荷時}既定値は \code{\link{na.omit}}．}
  \item{\dots}{
    他のメソッドに・から渡される引数．
    もし \code{x} が公式なら
    \code{scale.} か \code{tol} を指定するかもしれない．}
  \item{x}{
    主成分分析に対するデータを提供する数値もしくは複素数値行列
    (又はデータフレーム)．}
  \item{retx}{
    回転された変数を返すべきかどうかを指示する論理値．}
  \item{center}{
    変数がゼロを中心とするようにシフトされるべきかどうかを指示する論理値．
    別法として
    \code{x} の列数に長さが等しいベクトルを提供できる．
    値は \code{scale} に渡される．}
  \item{scale.}{
    解析前に変数を単位分散を持つようにスケール化すべきかどうかを
    指示する論理値．
    既定は S との互換性から \code{FALSE} であるが，
    一般にはスケーリングが勧められる．
    別法として \code{x} の列数に長さが等しいベクトルを提供できる．
    値は \code{scale} に渡される．}
  \item{tol}{
    それ以下の成分を除外する大きさを指示する値．
    (成分はもしそれらの標準分散が
    最初の成分の標準偏差の \code{tol} 倍以下であれば除外される．)
    既定の \code{NULL} ではどの成分も除外されない．
    \code{tol} への他の設定は \code{tol = 0} か
    \code{tol = sqrt(.Machine$double.eps)} で，これは
    本質的に定数である成分を除外する．}
  \item{object}{
    \code{"prcomp"} を継承するクラスのオブジェクト．}
  \item{newdata}{
    それを使い予測を行う変数を探すオプションのデータフレームか行列．
    もし省略されるとスコアが使われる．
    もしオリジナルの当てはめが公式かデータフレームか
    列名を持つ行列を使えば，
    \code{newdata} は同じ名前の列を含まねばならない．
    さもなければ同じ数の列を含まねばならず，同じ順序で使われる．
  }
}
\value{
  \code{prcomp} は次の成分を含むクラス \code{"prcomp"} のリスト：
  \item{sdev}{主成分の標準偏差
    (つまり，共分散/相関行列の固有値の平方根であるが，
    計算はデータ行列の特異値を用いてなされる)．}
  \item{rotation}{変数負荷(つまりその列が固有ベクトルを含む
    行列)．関数 \code{princomp} はこれを \code{loadings} の要素中に返す．}
  \item{x}{
    もし \code{retx} が真なら回転されたデータ
    (中心化され(要求されればスケール化され \code{rotation} 行列を
    掛けた)が返される．
    たデータ
    \code{rotation} matrix) is returned.
    従って \code{cov(x)} は対角行列
    \code{diag(sdev^2)} である．公式メソッドに対しては，
    \code{\link{napredict}()} が
    \code{na.action} で除外された値の処理を行うために適用される．}
  \item{center, scale}{使われた中心化とスケール化，又は \code{FALSE}．}
}
\details{
  計算はデータ行列
  (中心化され可能性としてスケール化された)の特異値分解で行われ，
  共分散行列に関する \code{eigen} を使ってではない．
  これは数値的精度に対しては一般に好ましい手法である．
  これらのオブジェクトに対する \code{print} メソッドは
  結果を見栄えの良い書式でプリントし，
  そして \code{plot} メソッドはスクリーンのプロットを作り出す．

  \code{\link{princomp}} ととは異なり，分散は通例の除数
  \eqn{N - 1} で計算される．

  (\code{center = TRUE} に対して)
  もしゼロや定数の変数があれば
  \code{scale = TRUE} は使われないことを注意する．
}
\note{
  回転行列の列の符号は任意であり，
  PCA に対する異なったプログラム間で異なるかもしれず，
  異なった \R のビルド間でも同様である．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.

  Mardia, K. V., J. T. Kent, and J. M. Bibby (1979)
  \emph{Multivariate Analysis}, London: Academic Press.

  Venables, W. N. and B. D. Ripley (2002)
  \emph{Modern Applied Statistics with S}, Springer-Verlag.
}
\seealso{
  \code{\link{biplot.prcomp}}, \code{\link{screeplot}},
  \code{\link{princomp}}, \code{\link{cor}}, \code{\link{cov}},
  \code{\link{svd}}, \code{\link{eigen}}.
}
\examples{\donttest{## 符号はランダム
require(graphics)

## USArrests データ中の変数の分散はマグニチュードのオーダーで
## 変化するので，スケーリングが適当である
prcomp(USArrests)  # 不適切
prcomp(USArrests, scale = TRUE)
prcomp(~ Murder + Assault + Rape, data = USArrests, scale = TRUE)
plot(prcomp(USArrests))
summary(prcomp(USArrests, scale = TRUE))
biplot(prcomp(USArrests, scale = TRUE))
}}
\keyword{multivariate}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/prcomp.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2012 R Core Team
%% Distributed under GPL 2 or later
%
%\name{prcomp}
%\alias{prcomp}
%\alias{prcomp.formula}
%\alias{prcomp.default}
%\alias{plot.prcomp}
%\alias{predict.prcomp}
%\alias{print.prcomp}
%\alias{summary.prcomp}
%\alias{print.summary.prcomp}
%\concept{PCA}
%\title{Principal Components Analysis}
%\description{
%  Performs a principal components analysis on the given data matrix
%  and returns the results as an object of class \code{prcomp}.}
%\usage{
%prcomp(x, \dots)
%
%\method{prcomp}{formula}(formula, data = NULL, subset, na.action, \dots)
%
%\method{prcomp}{default}(x, retx = TRUE, center = TRUE, scale. = FALSE,
%       tol = NULL, \dots)
%
%\method{predict}{prcomp}(object, newdata, \dots)
%}
%\arguments{
%  \item{formula}{a formula with no response variable, referring only to
%    numeric variables.}
%  \item{data}{an optional data frame (or similar: see
%    \code{\link{model.frame}}) containing the variables in the
%    formula \code{formula}.  By default the variables are taken from
%    \code{environment(formula)}.}
%  \item{subset}{an optional vector used to select rows (observations) of the
%    data matrix \code{x}.}
%  \item{na.action}{a function which indicates what should happen
%    when the data contain \code{NA}s.  The default is set by
%    the \code{na.action} setting of \code{\link{options}}, and is
%    \code{\link{na.fail}} if that is unset. The \sQuote{factory-fresh}
%    default is \code{\link{na.omit}}.}
%  \item{\dots}{arguments passed to or from other methods. If \code{x} is
%    a formula one might specify \code{scale.} or \code{tol}.}
%  \item{x}{a numeric or complex matrix (or data frame) which provides
%    the data for the principal components analysis.}
%  \item{retx}{a logical value indicating whether the rotated variables
%    should be returned.}
%  \item{center}{a logical value indicating whether the variables
%    should be shifted to be zero centered. Alternately, a vector of
%    length equal the number of columns of \code{x} can be supplied.
%    The value is passed to \code{scale}.}
%  \item{scale.}{a logical value indicating whether the variables should
%    be scaled to have unit variance before the analysis takes
%    place. The default is \code{FALSE} for consistency with S, but
%    in general scaling is advisable.  Alternatively, a vector of length
%    equal the number of columns of \code{x} can be supplied.  The
%    value is passed to \code{\link{scale}}.}
%  \item{tol}{a value indicating the magnitude below which components
%    should be omitted. (Components are omitted if their
%    standard deviations are less than or equal to \code{tol} times the
%    standard deviation of the first component.)
%    With the default null setting, no components
%    are omitted.  Other settings for tol could be \code{tol = 0} or
%    \code{tol = sqrt(.Machine$double.eps)}, which would omit
%    essentially constant components.}
%  \item{object}{Object of class inheriting from \code{"prcomp"}}
%  \item{newdata}{An optional data frame or matrix in which to look for
%    variables with which to predict.  If omitted, the scores are used.
%    If the original fit used a formula or a data frame or a matrix with
%    column names, \code{newdata} must contain columns with the same
%    names. Otherwise it must contain the same number of columns, to be
%    used in the same order.
%  }
%}
%\value{
%  \code{prcomp} returns a list with class \code{"prcomp"}
%  containing the following components:
%  \item{sdev}{the standard deviations of the principal components
%    (i.e., the square roots of the eigenvalues of the
%    covariance/correlation matrix, though the calculation
%    is actually done with the singular values of the data matrix).}
%  \item{rotation}{the matrix of variable loadings (i.e., a matrix
%    whose columns contain the eigenvectors).  The function
%    \code{princomp} returns this in the element \code{loadings}.}
%  \item{x}{if \code{retx} is true the value of the rotated data (the
%    centred (and scaled if requested) data multiplied by the
%    \code{rotation} matrix) is returned.  Hence, \code{cov(x)} is the
%    diagonal matrix \code{diag(sdev^2)}.  For the formula method,
%    \code{\link{napredict}()} is applied to handle the treatment of values
%    omitted by the \code{na.action}.}
%  \item{center, scale}{the centering and scaling used, or \code{FALSE}.}
%}
%\details{
%  The calculation is done by a singular value decomposition of the
%  (centered and possibly scaled) data matrix, not by using
%  \code{eigen} on the covariance matrix.  This
%  is generally the preferred method for numerical accuracy.  The
%  \code{print} method for these objects prints the results in a nice
%  format and the \code{plot} method produces a scree plot.
%
%  Unlike \code{\link{princomp}}, variances are computed with the usual
%  divisor \eqn{N - 1}.
%
%  Note that \code{scale = TRUE} cannot be used if there are zero or
%  constant (for \code{center = TRUE}) variables.
%}
%\note{
%  The signs of the columns of the rotation matrix are arbitrary, and
%  so may differ between different programs for PCA, and even between
%  different builds of \R.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%
%  Mardia, K. V., J. T. Kent, and J. M. Bibby (1979)
%  \emph{Multivariate Analysis}, London: Academic Press.
%
%  Venables, W. N. and B. D. Ripley (2002)
%  \emph{Modern Applied Statistics with S}, Springer-Verlag.
%}
%\seealso{
%  \code{\link{biplot.prcomp}}, \code{\link{screeplot}},
%  \code{\link{princomp}}, \code{\link{cor}}, \code{\link{cov}},
%  \code{\link{svd}}, \code{\link{eigen}}.
%}
%\examples{\donttest{## signs are random
%require(graphics)
%
%## the variances of the variables in the
%## USArrests data vary by orders of magnitude, so scaling is appropriate
%prcomp(USArrests)  # inappropriate
%prcomp(USArrests, scale = TRUE)
%prcomp(~ Murder + Assault + Rape, data = USArrests, scale = TRUE)
%plot(prcomp(USArrests))
%summary(prcomp(USArrests, scale = TRUE))
%biplot(prcomp(USArrests, scale = TRUE))
%}}
%\keyword{multivariate}
%
%\encoding{UTF-8}
%
