% File src/library/stats/man/princomp.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{princomp}
\alias{princomp}%@%\alias{主成分分析}
\alias{princomp.formula}
\alias{princomp.default}
\alias{plot.princomp}
\alias{print.princomp}
\alias{predict.princomp}
\title{Principal Components Analysis}
\concept{PCA}
\usage{
princomp(x, \dots)

\method{princomp}{formula}(formula, data = NULL, subset, na.action, \dots)

\method{princomp}{default}(x, cor = FALSE, scores = TRUE, covmat = NULL,
         subset = rep_len(TRUE, nrow(as.matrix(x))), \dots)

\method{predict}{princomp}(object, newdata, \dots)
}
\arguments{
  \item{formula}{応答変数のない公式で，数値変数だけを参照する．}
  \item{data}{
    オプションのデータフレーム(又は類似物：
    \code{\link{model.frame}} を見よ)で
    公式 \code{formula} 中の変数を含む．既定では変数は
    \code{environment(formula)} から取られる．}
  \item{subset}{
    データ行列 \code{x} の行(観測値)を選ぶのに使われるオプションのベクトル．}
  \item{na.action}{
    データが \code{NA} を含む時何が起きるべきかを指示する関数．
    既定は \code{\link{options}} の \code{na.action} 設置で，
    もしそれが未設定なら
    \code{\link{na.fail}}．
    \sQuote{工場出荷時}既定値は \code{\link{na.omit}}．}
  \item{x}{
    主成分分析に対するデータを提供する数値もしくは複素数値行列
    (又はデータフレーム)．}
  \item{cor}{
    計算が相関行列又は共分散行列を用いてされるべきかどうかを
    指示する論理値．
    (相関行列は定数変数が無い時だけ使うことが出来る)．}
  \item{scores}{各主成分に対するスコアを計算すべきかどうかを指示する論理値．}
  \item{covmat}{
    \code{\link{cov.wt}} (そしてパッケージ \CRANpkg{MASS} からの
    \code{\link[MASS:cov.rob]{cov.mve}} や
    \code{\link[MASS:cov.rob]{cov.mcd}})が返すような共分散か
    共分散リスト．
    もし提供されるとこれは
    \code{x} の共分散行列ではなくこれが使われる．}
  \item{\dots}{
    他のメソッドに・から渡される引数．
    もし \code{x} が公式なら
    \code{cor} か \code{scores} を指定するかもしれない．}
  \item{object}{
    \code{"princomp"} を継承するクラスのオブジェクト．}
  \item{newdata}{
    それを使い予測を行う変数を探すオプションのデータフレームか行列．
    もし省略されるとスコアが使われる．
    もしオリジナルの当てはめが公式かデータフレームか
    列名を持つ行列を使えば，
    \code{newdata} は同じ名前の列を含まねばならない．
    さもなければ同じ数の列を含まねばならず，同じ順序で使われる．
  }
}
\description{
  \code{princomp} は与えられた数値データ行列に対して主成分分析を
  実行し，結果をクラス \code{princomp} のオブジェクトとして返す．
}
\value{
  \code{princomp} は次の成分を含むクラス
  \code{"princomp"} のりストを返す：
  \item{sdev}{主成分の標準偏差．}
  \item{loadings}{
    負荷の行列(つまりその列が固有ベクトルを含む)．これはクラス
    \code{"loadings"} である：
    その \code{print} メソッドについては
    \code{\link{loadings}} を見よ．}
  \item{center}{差し引かれた平均．}
  \item{scale}{各変数に適用されたスケーリング．}
  \item{n.obs}{観測値数．}
  \item{scores}{もし \code{scores = TRUE} ならば，主成分に関して
    提供されたデータのスコア．
    これらは \code{x} が提供され，
    そしててもし共分散リスト \code{covmat} がまた提供された時だけ
    NULL で無い．
    公式メソッドに対しては \code{\link{napredict}()} が
    \code{na.action} で除かれた値の処理のために適用される．}
  \item{call}{マッチした呼び出し．}
  \item{na.action}{もし関連すれば．}
}
\details{
  \code{princomp} はメソッド
  \code{"formula"} と \code{"default"} を持つ総称的関数である．

  計算は \code{\link{cor}} で決まる共分散又は相関行列に
  \code{\link{eigen}} を使うことで行われる．
  これは S-PLUS の結果との互換性からである．
  好ましい計算は \code{prcomp} でそうされるように，
  \code{x} について \code{\link{svd}} を使うことである．

  既定の計算は共分散に対して除数
  \code{N} を使うことを注意しよう．

  これらのオブジェクトに対する \code{\link{print}} メソッドは
  結果を見栄えの良い形式でプリントし，そして
  \code{\link{plot}} メソッドは
  スクリーンプロット (\code{\link{screeplot}}) を作る．
  また \code{\link{biplot}} メソッドがある．

  もし \code{x} が公式なら標準の NA 処理がスコア(もし必要なら)に
  適用される：\code{\link{napredict}} を見よ．

  \code{princomp} は変数の特性抽出であるいわゆる R モードの PCA だけを扱う．
  もしデータ行列が提供されると
  (可能性として公式を使い)，少なくとも変数と同じだけのユニットが
  あることが必要とされる．
  Q モードの PCA に対しては \code{\link{prcomp}} を使う．
}
\note{
  負荷とスコア列の符号は任意であり，
  従って異なった PCA プログラム間で異なるかもしれないし，異なった \R のビルド
  間ですら異なるかもしれない．
}
\references{, K. V., J. T. Kent and J. M. Bibby (1979).
  \emph{Multivariate Analysis}, London: Academic Press.

  Venables, W. N. and B. D. Ripley (2002).
  \emph{Modern Applied Statistics with S}, Springer-Verlag.
}
\seealso{
  \code{\link{summary.princomp}}, \code{\link{screeplot}},
  \code{\link{biplot.princomp}},
  \code{\link{prcomp}}, \code{\link{cor}}, \code{\link{cov}},
  \code{\link{eigen}}.
}
\examples{
require(graphics)

## USArrests データ中の変数の分散はマグニチュードのオーダーで
## 変化するので，スケーリングが適当である
(pc.cr <- princomp(USArrests))  # 不適切
princomp(USArrests, cor = TRUE) # =^= prcomp(USArrests, scale=TRUE)
## 類似だが異なる：
## 標準偏差が sqrt(49/50) の因子で異なる

summary(pc.cr <- princomp(USArrests, cor = TRUE))
loadings(pc.cr)  # 空の項目は小さいがゼロではない
## 列の符号は任意
plot(pc.cr) # screeplot を示す．
biplot(pc.cr)

## 公式インタフェイス
princomp(~ ., data = USArrests, cor = TRUE)

## NA の処理
USArrests[1, 2] <- NA
pc.cr <- princomp(~ Murder + Assault + UrbanPop,
                  data = USArrests, na.action = na.exclude, cor = TRUE)
\donttest{pc.cr$scores[1:5, ]}

## (簡単な)頑健 PCA：
## 古典的：
(pc.cl  <- princomp(stackloss))
\donttest{## Robust:
(pc.rob <- princomp(stackloss, covmat = MASS::cov.rob(stackloss)))
}}
\keyword{multivariate}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/princomp.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{princomp}
%\alias{princomp}
%\alias{princomp.formula}
%\alias{princomp.default}
%\alias{plot.princomp}
%\alias{print.princomp}
%\alias{predict.princomp}
%\title{Principal Components Analysis}
%\concept{PCA}
%\usage{
%princomp(x, \dots)
%
%\method{princomp}{formula}(formula, data = NULL, subset, na.action, \dots)
%
%\method{princomp}{default}(x, cor = FALSE, scores = TRUE, covmat = NULL,
%         subset = rep_len(TRUE, nrow(as.matrix(x))), \dots)
%
%\method{predict}{princomp}(object, newdata, \dots)
%}
%\arguments{
%  \item{formula}{a formula with no response variable, referring only to
%    numeric variables.}
%  \item{data}{an optional data frame (or similar: see
%    \code{\link{model.frame}}) containing the variables in the
%    formula \code{formula}.  By default the variables are taken from
%    \code{environment(formula)}.}
%  \item{subset}{an optional vector used to select rows (observations) of the
%    data matrix \code{x}.}
%  \item{na.action}{a function which indicates what should happen
%    when the data contain \code{NA}s.  The default is set by
%    the \code{na.action} setting of \code{\link{options}}, and is
%    \code{\link{na.fail}} if that is unset. The \sQuote{factory-fresh}
%    default is \code{\link{na.omit}}.}
%  \item{x}{a numeric matrix or data frame which provides the data for the
%    principal components analysis.}
%  \item{cor}{a logical value indicating whether the calculation should
%    use the correlation matrix or the covariance matrix.  (The
%    correlation matrix can only be used if there are no constant variables.)}
%  \item{scores}{a logical value indicating whether the score on each
%    principal component should be calculated.}
%  \item{covmat}{a covariance matrix, or a covariance list as returned by
%    \code{\link{cov.wt}} (and \code{\link[MASS:cov.rob]{cov.mve}} or
%    \code{\link[MASS:cov.rob]{cov.mcd}} from package \CRANpkg{MASS}).
%    If supplied, this is used rather than the covariance matrix of
%    \code{x}.}
%  \item{\dots}{arguments passed to or from other methods. If \code{x} is
%    a formula one might specify \code{cor} or \code{scores}.}
%  \item{object}{Object of class inheriting from \code{"princomp"}}
%  \item{newdata}{An optional data frame or matrix in which to look for
%    variables with which to predict.  If omitted, the scores are used.
%    If the original fit used a formula or a data frame or a matrix with
%    column names, \code{newdata} must contain columns with the same
%    names. Otherwise it must contain the same number of columns, to be
%    used in the same order.
%  }
%}
%\description{
%  \code{princomp} performs a principal components analysis on the given
%  numeric data matrix and returns the results as an object of class
%  \code{princomp}.
%}
%\value{
%  \code{princomp} returns a list with class \code{"princomp"}
%  containing the following components:
%  \item{sdev}{the standard deviations of the principal components.}
%  \item{loadings}{the matrix of variable loadings (i.e., a matrix
%    whose columns contain the eigenvectors).  This is of class
%    \code{"loadings"}: see \code{\link{loadings}} for its \code{print}
%    method.}
%  \item{center}{the means that were subtracted.}
%  \item{scale}{the scalings applied to each variable.}
%  \item{n.obs}{the number of observations.}
%  \item{scores}{if \code{scores = TRUE}, the scores of the supplied
%    data on the principal components.  These are non-null only if
%    \code{x} was supplied, and if \code{covmat} was also supplied if it
%    was a covariance list.  For the formula method,
%    \code{\link{napredict}()} is applied to handle the treatment of
%    values omitted by the \code{na.action}.}
%  \item{call}{the matched call.}
%  \item{na.action}{If relevant.}
%}
%\details{
%  \code{princomp} is a generic function with \code{"formula"} and
%  \code{"default"} methods.
%
%  The calculation is done using \code{\link{eigen}} on the correlation or
%  covariance matrix, as determined by \code{\link{cor}}.  This is done for
%  compatibility with the S-PLUS result.  A preferred method of
%  calculation is to use \code{\link{svd}} on \code{x}, as is done in
%  \code{prcomp}.
%
%  Note that the default calculation uses divisor \code{N} for the
%  covariance matrix.
%
%  The \code{\link{print}} method for these objects prints the
%  results in a nice format and the \code{\link{plot}} method produces
%  a scree plot (\code{\link{screeplot}}).  There is also a
%  \code{\link{biplot}} method.
%
%  If \code{x} is a formula then the standard NA-handling is applied to
%  the scores (if requested): see \code{\link{napredict}}.
%
%  \code{princomp} only handles so-called R-mode PCA, that is feature
%  extraction of variables.  If a data matrix is supplied (possibly via a
%  formula) it is required that there are at least as many units as
%  variables.  For Q-mode PCA use \code{\link{prcomp}}.
%}
%\note{
%  The signs of the columns of the loadings and scores are arbitrary, and
%  so may differ between different programs for PCA, and even between
%  different builds of \R.
%}
%\references{
%  Mardia, K. V., J. T. Kent and J. M. Bibby (1979).
%  \emph{Multivariate Analysis}, London: Academic Press.
%
%  Venables, W. N. and B. D. Ripley (2002).
%  \emph{Modern Applied Statistics with S}, Springer-Verlag.
%}
%\seealso{
%  \code{\link{summary.princomp}}, \code{\link{screeplot}},
%  \code{\link{biplot.princomp}},
%  \code{\link{prcomp}}, \code{\link{cor}}, \code{\link{cov}},
%  \code{\link{eigen}}.
%}
%\examples{
%require(graphics)
%
%## The variances of the variables in the
%## USArrests data vary by orders of magnitude, so scaling is appropriate
%(pc.cr <- princomp(USArrests))  # inappropriate
%princomp(USArrests, cor = TRUE) # =^= prcomp(USArrests, scale=TRUE)
%## Similar, but different:
%## The standard deviations differ by a factor of sqrt(49/50)
%
%summary(pc.cr <- princomp(USArrests, cor = TRUE))
%loadings(pc.cr)  # note that blank entries are small but not zero
%## The signs of the columns are arbitrary
%plot(pc.cr) # shows a screeplot.
%biplot(pc.cr)
%
%## Formula interface
%princomp(~ ., data = USArrests, cor = TRUE)
%
%## NA-handling
%USArrests[1, 2] <- NA
%pc.cr <- princomp(~ Murder + Assault + UrbanPop,
%                  data = USArrests, na.action = na.exclude, cor = TRUE)
%\donttest{pc.cr$scores[1:5, ]}
%
%## (Simple) Robust PCA:
%## Classical:
%(pc.cl  <- princomp(stackloss))
%\donttest{## Robust:
%(pc.rob <- princomp(stackloss, covmat = MASS::cov.rob(stackloss)))
%}}
%\keyword{multivariate}
%
%\encoding{UTF-8}
%
