% File src/library/stats/man/profile.nls.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2008 R Core Team
% Distributed under GPL 2 or later

\name{profile.nls}
\alias{profile.nls}
\title{Method for Profiling nls Objects}
\description{
  クラス \code{"nls"} の当てはめモデルに対するプロファイル対数尤度関数を
  調べる．
}
\usage{
\method{profile}{nls}(fitted, which = 1:npar, maxpts = 100, alphamax = 0.01,
        delta.t = cutoff/5, \dots)
}
\arguments{
  \item{fitted}{オリジナルの当てはめモデルオブジェクト．}
  \item{which}{プロファイルされるべきオリジナルのモデルパラメータ．
    これは数値や文字列で良い．
    既定では全ての非線型Ｐラメータがプロファイルされる．}
  \item{maxpts}{各パラメータのプロファイルに対して
    使われる点の最大数．}
  \item{alphamax}{プロファイル t 統計量に対して許される
    最も高い信頼水準．}
  \item{delta.t}{
    プロファイル t 統計量のスケールに関する示唆される変更．
    既定値は約10 パラメータ値でプロファイルを認めるように
    選ばれる．}
  \item{\dots}{他の引数へ・から渡される追加引数．}
}
\value{
  プロファイルされた各パラメータに対して成分を持つリスト．
  成分は次の二つの変数を持つデータフレーム
  \item{par.vals}{各当てはめモデルに対するパラメータ値の行列．}
  \item{tau}{プロファイル t 統計量．}
}
\details{
  プロファイル t 統計量は二乗和の変化の平方根を
  残差標準偏差で割ったもので適当な符号を持つ．
}
\references{
  Bates, D. M. and Watts, D. G. (1988), \emph{Nonlinear Regression Analysis
    and Its Applications}, Wiley (chapter 6).
}
\author{
  オリジナルのバージョンは
  Douglas M. Bates と Saikat DebRoy
}
\seealso{
  \code{\link{nls}}, \code{\link{profile}}, \code{\link{plot.profile.nls}}
}
\examples{
\testonly{od <- options(digits = 4)}
# 当てはめオブジェクトを得る
fm1 <- nls(demand ~ SSasympOrig(Time, A, lrc), data = BOD)
# 当てはめモデルに対するプロファイルを得る：既定レベルは極端過ぎる
pr1 <- profile(fm1, alpha = 0.05)
# 二つのパラメータに対するプロファイル値
pr1$A
pr1$lrc
# example(plot.profile.nls) も見よ
\testonly{options(od)}
}
\keyword{nonlinear}
\keyword{regression}
\keyword{models}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/profile.nls.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2008 R Core Team
%% Distributed under GPL 2 or later
%
%\name{profile.nls}
%\alias{profile.nls}
%\title{Method for Profiling nls Objects}
%\description{
%  Investigates the profile log-likelihood function for a fitted model of
%  class \code{"nls"}.
%}
%\usage{
%\method{profile}{nls}(fitted, which = 1:npar, maxpts = 100, alphamax = 0.01,
%        delta.t = cutoff/5, \dots)
%}
%\arguments{
%  \item{fitted}{the original fitted model object.}
%  \item{which}{the original model parameters which should be profiled.
%    This can be a numeric or character vector.
%    By default, all non-linear parameters are profiled.}
%  \item{maxpts}{maximum number of points to be used for profiling each
%    parameter.}
%  \item{alphamax}{highest significance level allowed
%    for the profile t-statistics.}
%  \item{delta.t}{suggested change on the scale of the profile
%    t-statistics.  Default value chosen to allow profiling at about
%    10 parameter values.}
%  \item{\dots}{further arguments passed to or from other methods.}
%}
%\value{
%  A list with an element for each parameter being profiled. The elements
%  are data-frames with two variables
%  \item{par.vals}{a matrix of parameter values for each fitted model.}
%  \item{tau}{the profile t-statistics.}
%}
%\details{
%  The profile t-statistics is defined as the square root of change in
%  sum-of-squares divided by residual standard error with an
%  appropriate sign.
%}
%\references{
%  Bates, D. M. and Watts, D. G. (1988), \emph{Nonlinear Regression Analysis
%    and Its Applications}, Wiley (chapter 6).
%}
%\author{
%  Of the original version,
%  Douglas M. Bates and Saikat DebRoy
%}
%\seealso{
%  \code{\link{nls}}, \code{\link{profile}}, \code{\link{plot.profile.nls}}
%}
%\examples{
%\testonly{od <- options(digits = 4)}
%# obtain the fitted object
%fm1 <- nls(demand ~ SSasympOrig(Time, A, lrc), data = BOD)
%# get the profile for the fitted model: default level is too extreme
%pr1 <- profile(fm1, alpha = 0.05)
%# profiled values for the two parameters
%pr1$A
%pr1$lrc
%# see also example(plot.profile.nls)
%\testonly{options(od)}
%}
%\keyword{nonlinear}
%\keyword{regression}
%\keyword{models}
%
%\encoding{UTF-8}
%