% File src/library/stats/man/reorder.dendrogram.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{reorder.dendrogram}
\alias{reorder.dendrogram}%@%\alias{デンドログラムを並べ替える}
\title{Reorder a Dendrogram}
\description{
  総称的関数 \code{\link{reorder}} に対するメソッド．

  課せられた構造と一貫性のある多くの異なったデンドログラムの順序がある．
  この関数はデンドログラムと値のベクトルを取り，
  デンドログラムに課せられた制約を守りながら，
  提供されたベクトルの順序でデンドログラムを並べ替える．
}
\usage{
\method{reorder}{dendrogram}(x, wts, agglo.FUN = sum, \dots)
}
\arguments{
  \item{x}{並べ替えられる(デンドログラム)オブジェクト．}
  \item{wts}{並べ替えのための(任意の値の)重み．}
  \item{agglo.FUN}{重みの凝集化のための関数，下を見よ．}
  \item{\dots}{追加引数．}
}
\details{
  重み \code{wts} を用い，デンドログラムの葉が
  重みと可能な限り一貫性がある順序で並べ替えられる．
  各ノードで，枝は重みの増加順に並べられる．
  ここで重みは
  \eqn{f(w_j)} で定義され，\eqn{f} は \code{agglo.FUN} で \eqn{w_j} 
  は \eqn{j} 番目の副枝の重みである．
}
\value{
  各ノードがそれに対応する追加属性
  \code{value} を持つデンドログラム．
}
\author{R. Gentleman と M. Maechler}
\seealso{
  \code{\link{reorder}}.

  単にノードの順序を逆転する \code{\link{rev.dendrogram}}；
  \code{\link{heatmap}}, \code{\link{cophenetic}}.
}
\examples{
require(graphics)

set.seed(123)
x <- rnorm(10)
hc <- hclust(dist(x))
dd <- as.dendrogram(hc)
dd.reorder <- reorder(dd, 10:1)
plot(dd, main = "random dendrogram 'dd'")

op <- par(mfcol = 1:2)
plot(dd.reorder, main = "reorder(dd, 10:1)")
plot(reorder(dd, 10:1, agglo.FUN = mean), main = "reorder(dd, 10:1, mean)")
par(op)
}
\keyword{manip}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/reorder.dendrogram.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{reorder.dendrogram}
%\alias{reorder.dendrogram}
%\title{Reorder a Dendrogram}
%\description{
%  A method for the generic function \code{\link{reorder}}.
%
%  There are many different orderings of a dendrogram that are consistent
%  with the structure imposed.  This function takes a dendrogram and a
%  vector of values and reorders the dendrogram in the order of the
%  supplied vector, maintaining the constraints on the dendrogram.
%}
%\usage{
%\method{reorder}{dendrogram}(x, wts, agglo.FUN = sum, \dots)
%}
%\arguments{
%  \item{x}{the (dendrogram) object to be reordered}
%  \item{wts}{numeric weights (arbitrary values) for reordering.}
%  \item{agglo.FUN}{a function for weights agglomeration, see below.}
%  \item{\dots}{additional arguments}
%}
%\details{
%  Using the weights \code{wts}, the leaves of the dendrogram are
%  reordered so as to be in an order as consistent as possible with the
%  weights.  At each node, the branches are ordered in
%  increasing weights where the weight of a branch is defined as
%  \eqn{f(w_j)} where \eqn{f} is \code{agglo.FUN} and \eqn{w_j} is the
%  weight of the \eqn{j}-th sub branch).
%}
%\value{
%  A dendrogram where each node has a further attribute \code{value} with
%  its corresponding weight.
%}
%\author{R. Gentleman and M. Maechler}
%\seealso{
%  \code{\link{reorder}}.
%
%  \code{\link{rev.dendrogram}} which simply reverses the nodes'
%  order; \code{\link{heatmap}}, \code{\link{cophenetic}}.
%}
%\examples{
%require(graphics)
%
%set.seed(123)
%x <- rnorm(10)
%hc <- hclust(dist(x))
%dd <- as.dendrogram(hc)
%dd.reorder <- reorder(dd, 10:1)
%plot(dd, main = "random dendrogram 'dd'")
%
%op <- par(mfcol = 1:2)
%plot(dd.reorder, main = "reorder(dd, 10:1)")
%plot(reorder(dd, 10:1, agglo.FUN = mean), main = "reorder(dd, 10:1, mean)")
%par(op)
%}
%\keyword{manip}
%
%\encoding{UTF-8}
%
