% File src/library/stats/man/smooth.spline.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2016 R Core Team
% Distributed under GPL 2 or later

\name{smooth.spline}
\alias{smooth.spline}%@%\alias{キュービックスプラインによる平滑化}
\alias{.nknots.smspl}
%\alias{print.smooth.spline}% is not exported
\title{Fit a Smoothing Spline}
\description{
  与えられたデータにキュービックスプラインを当てはめる．
}
\usage{
smooth.spline(x, y = NULL, w = NULL, df, spar = NULL, cv = FALSE,
              all.knots = FALSE, nknots = .nknots.smspl,
              keep.data = TRUE, df.offset = 0, penalty = 1,
              control.spar = list(), tol = 1e-6 * IQR(x))
}
\arguments{
 \item{x}{予測変数の値を与えるベクトル，又は
   x と y を指定する二列の行列．}
 \item{y}{応答．もし \code{y} が欠損しているか \code{NULL} ならば
   応答は
   \code{x} 指定されると仮定され，\code{x} は添字ベクトルである．}
 \item{w}{
   \code{x} と同じ長さのオプションの重みのベクトル；
   既定では全て 1．}
 \item{df}{希望の同値自由度
   (平滑化行列のトレース)．
   \eqn{(1,n_x]}{(1,nx]} 中になければならない，
   \eqn{n_x}{nx} はユニークな x 値の数である，下を見よ．}
 \item{spar}{平滑化パラメータで，典型的には \eqn{(0,1]} 中(しかし必須ではない)．
   当てはめ(罰則付き対数尤度)基準中の二階導関数の二乗の積分の
   係数 \eqn{\lambda} は
   \code{spar} の単調関数である，下の詳細を見よ．}
 \item{cv}{通常(\code{TRUE})か \code{FALSE} の時は
   \sQuote{一般化}クロスバリデーション(GCV)；
   \code{df} が指定されていな時だけ平滑化パラメータの計算に使われる．
   それを速度向上のために \code{NA} に設定すると
   梃子値と任意のスコアの評価をスキップする．}
 \item{all.knots}{もし \code{TRUE} ならば，
   \code{x} 中の全ての異なる値がノットとして使われる．
   もし \code{FALSE} (既定)なら
   \code{x[]} の部分集合が使われる．
   特に \code{nknots} 添字が
   \code{1:n} 中に等間隔で置かれているときは \code{x[j]}，
   次の引数 \code{nknots} も見よ．}
 \item{nknots}{整数又は関数で，
   \code{all.knots = FALSE} の時に使われるノットの数を与える．
   もし関数ならば(既定であるように)ノットの数は \code{nknots(nx)} である．
   既定では
   \eqn{n_x > 49}{nx > 49} に対してはこれは
   ユニークな \code{x} 値の数である
   \eqn{n_x}{nx} より小さい，注意節を見よ．}
 \item{keep.data}{
   入力データを結果中に保存するかどうかを指定する論理値．
   もし \code{TRUE} (既定であるように)ならば当てはめ値と残差が結果から
   利用できる．}
 \item{df.offset}{GCV 基準で自由度を
   \code{df.offset} だけ増やすことを許す．}
 \item{penalty}{GCV 基準で自由度に対する罰則の係数．}
 \item{control.spar}{
   平滑化パラメータ \code{spar} を計算する時の
   根の解法を制御する名前付き成分を持つオプションのリスト，
   つまり欠損か \code{NULL}，下を見よ．

   これは部分的に\emph{実験的}であり一般的な spar 計算の
   改良を伴い変更されるかもしれないことを
   \bold{注意}する．

   \describe{
     \item{low:}{\code{spar} に対する下界；既定値は -1.5
       (\R の 1.4 以前のバージョンでは暗黙のうちに
       既定で 0 にされた)．}
     \item{high:}{\code{spar} に対する上界；既定値は +1.5．}
     \item{tol:}{使用される絶対精度(許容度)；既定では
     1e-4 (以前は 1e-3)．}
     \item{eps:}{使用される相対精度；
       既定では 2e-8 (以前は 0.00244)．}
     \item{trace:}{繰り返しをトレースするかどうかを指示する論理値．}
     \item{maxit:}{繰り返しの最大数を与える整数；
       既定値は 500．}
   }
   \code{spar} は区間
   \eqn{[low, high]} 中だけで探されることを注意する．
 }

 \item{tol}{
   \code{x} 値の同一性又は一意性に対する許容度．
   値はサイズ  \code{tol} のビンに仕分けされ，同じビンに入った値は
   同一と見做される．
   狭義に正(そして有限)でなければならない.}
}
\details{
  \code{x} も \code{y} も欠損値や無限値を含むことは出来ない．

  \code{x} ベクトルは少なくとも四つの異なった値を含まなければならない．
  ここで\sQuote{異なる}とは \code{tol} で制御される：
  同じと見做された値はそれらの値の最初のもので置き換えられ，
  対応する \code{y} と \code{w} は対応してプールされる．

  使われる \eqn{\lambda} の計算は
  (\eqn{s=spar}{\code{spar}} の関数として)
  \eqn{\lambda = r * 256^{3 s - 1}}{\lambda = r * 256^(3*spar - 1)}
  で，ここで
  \eqn{r = tr(X' W X) / tr(\Sigma)},
  \eqn{\Sigma} は次で与えられる行列
  \eqn{\Sigma_{ij} = \int B_i''(t) B_j''(t) dt}{\Sigma[i,j] = Integral B''[i](t) B''[j](t) dt}，
  \eqn{X} は \eqn{X_{ij} = B_j(x_i)}{X[i,j] = B[j](x[i])} で与えられる，
  \eqn{W} は重みの対角行列
  (そのトレースがオリジナルの観測値数 \eqn{n} になるようにスケール化)
  そして \eqn{B_k(.)}{B[k](.)} は \eqn{k} 番目の B-スプラインである．

  これらの定義では，\eqn{f_i = f(x_i)} で B-スプラインのベース表現は
  \eqn{f = X c} (つまり，\eqn{c} は
  スプライン係数のベクトル)で，ペナルティー付き対数尤度は
  \eqn{L = (y - f)' W (y - f) + \lambda c' \Sigma c} であり，従って
  \eqn{c} は(リッジ回帰)
  \eqn{(X' W X + \lambda \Sigma) c = X' W y} の解である．

  もし \code{spar} が欠損するか又は \code{NULL} なら \code{df} の値が
  平滑化の次数を決めるのに使われる．
  もし双方が欠損していれば，leave-one-out クロスバリデーション
  (\code{cv} で決められる通常又は\sQuote{一般化})
  が \eqn{\lambda} を決めるのに使われる．
  上の関係から
%%  lam      = r * 256^(3s - 1)
%%  log(lam) = log(r) + (3s - 1) * log(256)
%% (log(lam) - log(r)) / log(256)  = 3s - 1
%% s = [1 +  {log(lam) - log(r)} / {8 log(2)} ] / 3
%%   = 1/3 + {log(lam) - log(r)} / {24 log(2)}
%%   = 1/3 - log(r)/{24 log(2)} +  log(lam) / {24 log(2)}
%%   =               s0         + 0.0601 * log(lam)
  \code{spar} は \eqn{s = s0 + 0.0601 * \bold{\log}\lambda}{spar = s0 + 0.0601 * log(\lambda)}
  で，これは意図的に
  S-PLUS の \code{smooth.spline} の移植とは\emph{異なる}
  (そこで \code{spar} は \eqn{\lambda} に比例する)．
  \R の(\eqn{\log \lambda}{log \lambda})スケールでは，
  \code{spar} を線形に変えることがより意味を持つ．

  しかしながら現在 \code{spar} 値が
  約 -1 か -2 より小さいと結果は非常に信頼できなくなるかもしれないことを
  注意する．同じことが 2 かそれぐらいより大きな値でも起こるかもしれない．
  自分が何をしているか理解していない限り，
  \code{spar} や制御値 \code{low} と \code{high} をそうした
  安全な範囲外に設定することを考えないこと．

  \sQuote{一般化}クロスバリデーション法は
  \code{x} 中に重複点があっても正しく動作する．しかしながら，
  重複点がある場合
  leave-one-out クロスバリデーションが何を意味するのかは曖昧であり，
  内部コードは重複点のグループの除去を含む近似を使う．
}
\note{
  ユニークな \code{x} の値の数，\eqn{\code{nx} = n_x}{nx}，は
  \code{tol} 引数で決められ，同じことだが
  \preformatted{%
    nx <- length(x)  -  sum(duplicated( round((x - mean(x)) / tol) )).}

  既定の \code{all.knots = FALSE} と \code{nknots = .nknots.smspl} は
  \eqn{n_x > 49}{nx > 49} に対して \eqn{n_x}{nx} の代わりに
  \eqn{O({n_x}^{0.2})}{O(nx ^ 0.2)} 個のノットだけを使うことを
  必要とする．これは速度とメモリ必要量を減らすが，
  \R バージョン 1.5.1 以来では最早それほど劇的ではなく
  単に \eqn{O(n_k) + O(n)}{O(nk) + O(n)} である，ここで
  \eqn{n_k}{nk} はノット数である．

  ユニークな \code{x} 全ての値がノットとして使われるのではない
  場合は，結果は狭義には平滑化スプラインではないが，
  小さな(又は大きな)平滑化パラメータを使わない限り非常に近い．
}
\value{
  クラス \code{"smooth.spline"} のオブジェクトで次の成分を持つ
  \item{x}{
    増加順の\emph{異なる} \code{x} 値，
    上の\sQuote{詳細}節を見よ．}
  \item{y}{\code{x} に対応する当てはめ値．}
  \item{w}{
    ユニークな \code{x} で使われる重み．}
  \item{yin}{
    ユニークな \code{y} で使われる y 値．}
  \item{data}{
    \code{keep.data = TRUE} の時のみ：それ自体
    同じ長さの成分
    \code{x}, \code{y} そして \code{w} を持つリスト．
    これらはオリジナルの \eqn{(x_i,y_i,w_i), i = 1, \dots, n} 値で，
    \code{data$x} は繰り返し値を持つかもしれず，
    従って最早
    上の \code{x} 成分よりも長いかもしれない；詳細節を見よ．}
  \item{lev}{
    (\code{cv} が \code{NA} でない時)梃子値，
    平滑化行列の対角値．}
  \item{cv.crit}{クロスバリデーションのスコア．
    \code{cv} に依存して\sQuote{generalized}か真．}
  \item{pen.crit}{ペナルティ基準．}
  \item{crit}{
    基礎にある \code{.Fortran} ルーチン \file{sslvrg} 中で
    最小化される基準値．\code{df} が指定された時，
    基準は \eqn{3 + (tr(S_\lambda) - df)^2}{3 + (tr(S[lambda]) - df)^2} で，
    ここで \eqn{3 +} は数値(そして歴史)的な理由からここにある．}
  \item{df}{
    使用される同値自由度．(現在)この値は
    真の \code{df} が 1 と 2 の間にある時全く不正確になるかもしれない．}
  \item{spar}{計算された又は与えられた \code{spar} の値．}
  \item{lambda}{\code{spar} に対応する \eqn{\lambda} の値，上の詳細節を見よ．}
  \item{iparms}{
    名前付きの長さ3の整数値ベクトルで，ここで \code{..$ipars["iter"]}
    は使用される spar 計算繰り返しの数．}
  \item{fit}{
    \code{\link{predict.smooth.spline}} によって使用するためのりストで．
    次の成分を持つ
    \describe{
      \item{knot:}{ノット列(繰り返し境界ノットを含む)．}
      \item{nk:}{係数の数か\sQuote{適正}なノットの数プラス2．}
      \item{coef:}{使用されるスプラインベースに対する係数．}
      \item{min, range:}{\code{x} の対応する量を与える数．}
    }
  }
  \item{call}{マッチした呼び出し．}
}
\references{
  Chambers, J. M. and Hastie, T. J. (1992)
  \emph{Statistical Models in S}, Wadsworth & Brooks/Cole.

  Green, P. J. and Silverman, B. W. (1994)
  \emph{Nonparametric Regression and Generalized Linear Models:
    A Roughness Penalty Approach.} Chapman and Hall.

  Hastie, T. J. and Tibshirani, R. J. (1990)
  \emph{Generalized Additive Models.}  Chapman and Hall.
}
\author{
  \R への移植は B. D. Ripley と Martin Maechler による
  (\code{spar/lambda} 等)．
}
\source{
  この関数 は T. Hastie と R. Tibshirani による
  \code{GAMFIT} Fortran プログラム中のコードに基づいている
  (元々 \url{http://lib.stat.cmu.edu/general/} から取られたが，これは今は
  廃止されているがミラーがどこかで利用できるかもしれない)．
  これは Finbarr O'Sullivan のスプラインコードを利用している．
  そのデザインは Chambers & Hastie (1992) の
  \code{smooth.spline} 関数と並行している．
}
\seealso{
  スプラインとその導関数を評価するには \code{\link{predict.smooth.spline}}．
}
\examples{
require(graphics)

attach(cars)
plot(speed, dist, main = "data(cars)  &  smoothing splines")
cars.spl <- smooth.spline(speed, dist)
(cars.spl)
## この例は重複点を持つので，cv = TRUE を避ける
\dontshow{
  stopifnot(cars.spl $ w == table(speed)) # 重み = 重複度
  utils::str(cars.spl, digits = 5, vec.len = 6)
  cars.spl$fit
}
lines(cars.spl, col = "blue")
lines(smooth.spline(speed, dist, df = 10), lty = 2, col = "red")
legend(5,120,c(paste("default [C.V.] => df =",round(cars.spl$df,1)),
               "s( * , df = 10)"), col = c("blue","red"), lty = 1:2,
       bg = 'bisque')
detach()


## 残差(Tukey Anscombe)プロット：
plot(residuals(cars.spl) ~ fitted(cars.spl))
abline(h = 0, col = "gray")

## 一貫性のチェック：
stopifnot(all.equal(cars$dist,
                    fitted(cars.spl) + residuals(cars.spl)))

## .nknots.smspl() の挙動を視覚化
nKnots <- Vectorize(.nknots.smspl) ; c.. <- adjustcolor("gray20",.5)
curve(nKnots, 1, 250, n=250)
abline(0,1, lty=2, col=c..); text(90,90,"y = x", col=c.., adj=-.25)
abline(h=100,lty=2); abline(v=200, lty=2)

n <- c(1:799, seq(800, 3490, by=10), seq(3500, 10000, by = 50))
plot(n, nKnots(n), type="l", main = "Vectorize(.nknots.smspl) (n)")
abline(0,1, lty=2, col=c..); text(180,180,"y = x", col=c..)
n0 <- c(50, 200, 800, 3200); c0 <- adjustcolor("blue3", .5)
lines(n0, nKnots(n0), type="h", col=c0)
axis(1, at=n0, line=-2, col.ticks=c0, col=NA, col.axis=c0)
axis(4, at=.nknots.smspl(10000), line=-.5, col=c..,col.axis=c.., las=1)

##-- 人工的な例
y18 <- c(1:3, 5, 4, 7:3, 2*(2:5), rep(10, 4))
xx  <- seq(1, length(y18), len = 201)
(s2  <- smooth.spline(y18)) # GCV
(s02  <- smooth.spline(y18, spar = 0.2))
(s02. <- smooth.spline(y18, spar = 0.2, cv = NA))
plot(y18, main = deparse(s2$call), col.main = 2)
lines(s2, col = "gray"); lines(predict(s2, xx), col = 2)
lines(predict(s02, xx), col = 3); mtext(deparse(s02$call), col = 3)

\dontshow{
stopifnot(all.equal(predict(s02 , xx),
		    predict(s02., xx), tolerance = 1e-15))
}
\donttest{
## 次は 'spar' 検索の問題のある挙動を示す：
(s2  <- smooth.spline(y18, control =
                      list(trace = TRUE, tol = 1e-6, low = -1.5)))
(s2m <- smooth.spline(y18, cv = TRUE, control =
                      list(trace = TRUE, tol = 1e-6, low = -1.5)))
## 上の二つは非常に似通っている(Df = 8.5 +- 0.2)
}}
\keyword{smooth}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/smooth.spline.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2016 R Core Team
%% Distributed under GPL 2 or later
%
%\name{smooth.spline}
%\alias{smooth.spline}
%\alias{.nknots.smspl}
%%\alias{print.smooth.spline}% is not exported
%\title{Fit a Smoothing Spline}
%\description{
%  Fits a cubic smoothing spline to the supplied data.
%}
%\usage{
%smooth.spline(x, y = NULL, w = NULL, df, spar = NULL, cv = FALSE,
%              all.knots = FALSE, nknots = .nknots.smspl,
%              keep.data = TRUE, df.offset = 0, penalty = 1,
%              control.spar = list(), tol = 1e-6 * IQR(x))
%}
%\arguments{
% \item{x}{a vector giving the values of the predictor variable, or  a
%   list or a two-column matrix specifying x and y. }
% \item{y}{responses. If \code{y} is missing or \code{NULL}, the responses
%   are assumed to be specified by \code{x}, with \code{x} the index
%   vector.}
% \item{w}{optional vector of weights of the same length as \code{x};
%   defaults to all 1.}
% \item{df}{the desired equivalent number of degrees of freedom (trace of
%   the smoother matrix).  Must be in \eqn{(1,n_x]}{(1,nx]},
%   \eqn{n_x}{nx} the number of unique x values, see below.}
% \item{spar}{smoothing parameter, typically (but not necessarily) in
%   \eqn{(0,1]}.  The coefficient \eqn{\lambda} of the integral of the
%   squared second derivative in the fit (penalized log likelihood)
%   criterion is a monotone function of \code{spar}, see the details
%   below.}
% \item{cv}{ordinary (\code{TRUE}) or \sQuote{generalized} cross-validation
%   (GCV) when \code{FALSE}; is used for smoothing parameter computation
%   only when \code{df} is not specified; it is used however
%   to determine \code{cv.crit} in the result.  Setting it to \code{NA}
%   for speedup skips the evaluation of leverages and any score.}
% \item{all.knots}{if \code{TRUE}, all distinct points in \code{x} are used as
%   knots.  If \code{FALSE} (default), a subset of \code{x[]} is used,
%   specifically \code{x[j]} where the \code{nknots} indices are evenly
%   spaced in \code{1:n}, see also the next argument \code{nknots}.}
% \item{nknots}{integer or \code{\link{function}} giving the number of
%   knots to use when \code{all.knots = FALSE}.  If a function (as by
%   default), the number of knots is \code{nknots(nx)}.  By default for
%   \eqn{n_x > 49}{nx > 49} this is less than \eqn{n_x}{nx}, the number
%   of unique \code{x} values, see the Note.}
% \item{keep.data}{logical specifying if the input data should be kept
%   in the result.  If \code{TRUE} (as per default), fitted values and
%   residuals are available from the result.}
% \item{df.offset}{allows the degrees of freedom to be increased by
%   \code{df.offset} in the GCV criterion.}
% \item{penalty}{the coefficient of the penalty for degrees of freedom
%   in the GCV criterion.}
%
% \item{control.spar}{optional list with named components controlling the
%   root finding when the smoothing parameter \code{spar} is computed,
%   i.e., missing or \code{NULL}, see below.
%
%   \bold{Note} that this is partly \emph{experimental} and may change
%   with general spar computation improvements!
%
%   \describe{
%     \item{low:}{lower bound for \code{spar}; defaults to -1.5 (used to
%       implicitly default to 0 in \R versions earlier than 1.4).}
%     \item{high:}{upper bound for \code{spar}; defaults to +1.5.}
%     \item{tol:}{the absolute precision (\bold{tol}erance) used; defaults
%     to 1e-4 (formerly 1e-3).}
%     \item{eps:}{the relative precision used; defaults to 2e-8 (formerly
%       0.00244).}
%     \item{trace:}{logical indicating if iterations should be traced.}
%     \item{maxit:}{integer giving the maximal number of iterations;
%       defaults to 500.}
%   }
%   Note that \code{spar} is only searched for in the interval
%   \eqn{[low, high]}.
% }
%
% \item{tol}{a tolerance for same-ness or uniqueness of the \code{x}
%   values.  The values are binned into bins of size \code{tol} and
%   values which fall into the same bin are regarded as the same.  Must
%   be strictly positive (and finite).}
%}
%\details{
%  Neither \code{x} nor \code{y} are allowed to containing missing or
%  infinite values.
%
%  The \code{x} vector should contain at least four distinct values.
%  \sQuote{Distinct} here is controlled by \code{tol}: values which are
%  regarded as the same are replaced by the first of their values and the
%  corresponding \code{y} and \code{w} are pooled accordingly.
%
%  The computational \eqn{\lambda} used (as a function of
%  \eqn{s=spar}{\code{spar}}) is
%  \eqn{\lambda = r * 256^{3 s - 1}}{\lambda = r * 256^(3*spar - 1)}
%  where
%  \eqn{r = tr(X' W X) / tr(\Sigma)},
%  \eqn{\Sigma} is the matrix given by
%  \eqn{\Sigma_{ij} = \int B_i''(t) B_j''(t) dt}{\Sigma[i,j] = Integral B''[i](t) B''[j](t) dt},
%  \eqn{X} is given by \eqn{X_{ij} = B_j(x_i)}{X[i,j] = B[j](x[i])},
%  \eqn{W} is the diagonal matrix of weights (scaled such that
%  its trace is \eqn{n}, the original number of observations)
%  and \eqn{B_k(.)}{B[k](.)} is the \eqn{k}-th B-spline.
%
%  Note that with these definitions, \eqn{f_i = f(x_i)}, and the B-spline
%  basis representation \eqn{f = X c} (i.e., \eqn{c} is
%  the vector of spline coefficients), the penalized log likelihood is
%  \eqn{L = (y - f)' W (y - f) + \lambda c' \Sigma c}, and hence
%  \eqn{c} is the solution of the (ridge regression)
%  \eqn{(X' W X + \lambda \Sigma) c = X' W y}.
%
%  If \code{spar} is missing or \code{NULL}, the value of \code{df} is used to
%  determine the degree of smoothing.  If both are missing, leave-one-out
%  cross-validation (ordinary or \sQuote{generalized} as determined by
%  \code{cv}) is used to determine \eqn{\lambda}.
%  Note that from the above relation,
%%%  lam      = r * 256^(3s - 1)
%%%  log(lam) = log(r) + (3s - 1) * log(256)
%%% (log(lam) - log(r)) / log(256)  = 3s - 1
%%% s = [1 +  {log(lam) - log(r)} / {8 log(2)} ] / 3
%%%   = 1/3 + {log(lam) - log(r)} / {24 log(2)}
%%%   = 1/3 - log(r)/{24 log(2)} +  log(lam) / {24 log(2)}
%%%   =               s0         + 0.0601 * log(lam)
%  \code{spar} is \eqn{s = s0 + 0.0601 * \bold{\log}\lambda}{spar = s0 + 0.0601 * log(\lambda)},
%  which is intentionally \emph{different} from the S-PLUS implementation
%  of \code{smooth.spline} (where \code{spar} is proportional to
%  \eqn{\lambda}).  In \R's (\eqn{\log \lambda}{log \lambda}) scale, it makes more
%  sense to vary \code{spar} linearly.
%
%  Note however that currently the results may become very unreliable
%  for \code{spar} values smaller than about -1 or -2.  The same may
%  happen for values larger than 2 or so. Don't think of setting
%  \code{spar} or the controls \code{low} and \code{high} outside such a
%  safe range, unless you know what you are doing!
%
%  The \sQuote{generalized} cross-validation method will work correctly when
%  there are duplicated points in \code{x}.  However, it is ambiguous what
%  leave-one-out cross-validation means with duplicated points, and the
%  internal code uses an approximation that involves leaving out groups
%  of duplicated points.  \code{cv = TRUE} is best avoided in that case.
%}
%\note{
%  The number of unique \code{x} values, \eqn{\code{nx} = n_x}{nx}, are
%  determined by the \code{tol} argument, equivalently to \preformatted{%
%    nx <- length(x)  -  sum(duplicated( round((x - mean(x)) / tol) ))}
%
%  The default \code{all.knots = FALSE} and \code{nknots = .nknots.smspl},
%  entails using only \eqn{O({n_x}^{0.2})}{O(nx ^ 0.2)}
%  knots instead of \eqn{n_x}{nx} for \eqn{n_x > 49}{nx > 49}.  This cuts
%  speed and memory requirements, but not drastically anymore since \R
%  version 1.5.1 where it is only \eqn{O(n_k) + O(n)}{O(nk) + O(n)} where
%  \eqn{n_k}{nk} is the number of knots.
%
%  In this case where not all unique \code{x} values are
%  used as knots, the result is not a smoothing spline in the strict
%  sense, but very close unless a small smoothing parameter (or large
%  \code{df}) is used.
%}
%\value{
%  An object of class \code{"smooth.spline"} with components
%  \item{x}{the \emph{distinct} \code{x} values in increasing order, see
%  the \sQuote{Details} above.}
%  \item{y}{the fitted values corresponding to \code{x}.}
%  \item{w}{the weights used at the unique values of \code{x}.}
%  \item{yin}{the y values used at the unique \code{y} values.}
%  \item{data}{only if \code{keep.data = TRUE}: itself a
%    \code{\link{list}} with components \code{x}, \code{y} and \code{w}
%    of the same length.  These are the original \eqn{(x_i,y_i,w_i),
%      i = 1, \dots, n}, values where \code{data$x} may have repeated values and
%    hence be longer than the above \code{x} component; see details.
%    }
%  \item{lev}{(when \code{cv} was not \code{NA}) leverages, the diagonal
%  values of the smoother matrix.}
%  \item{cv.crit}{cross-validation score, \sQuote{generalized} or true, depending
%    on \code{cv}.}
%  \item{pen.crit}{penalized criterion}
%  \item{crit}{the criterion value minimized in the underlying
%    \code{.Fortran} routine \file{sslvrg}.  When \code{df} has been specified,
%    the criterion is \eqn{3 + (tr(S_\lambda) - df)^2}{3 + (tr(S[lambda]) - df)^2},
%    where the \eqn{3 +} is there for numerical (and historical) reasons.}
%  \item{df}{equivalent degrees of freedom used.  Note that (currently)
%    this value may become quite imprecise when the true \code{df} is
%    between and 1 and 2.
%  }
%  \item{spar}{the value of \code{spar} computed or given.}
%  \item{lambda}{the value of \eqn{\lambda} corresponding to \code{spar},
%    see the details above.}
%  \item{iparms}{named integer(3) vector where \code{..$ipars["iter"]}
%    gives number of spar computing iterations used.}
%  \item{fit}{list for use by \code{\link{predict.smooth.spline}}, with
%    components
%    \describe{
%      \item{knot:}{the knot sequence (including the repeated boundary
%        knots).}
%      \item{nk:}{number of coefficients or number of \sQuote{proper}
%        knots plus 2.}
%      \item{coef:}{coefficients for the spline basis used.}
%      \item{min, range:}{numbers giving the corresponding quantities of
%        \code{x}.}
%    }
%  }
%  \item{call}{the matched call.}
%}
%\references{
%  Chambers, J. M. and Hastie, T. J. (1992)
%  \emph{Statistical Models in S}, Wadsworth & Brooks/Cole.
%
%  Green, P. J. and Silverman, B. W. (1994)
%  \emph{Nonparametric Regression and Generalized Linear Models:
%    A Roughness Penalty Approach.} Chapman and Hall.
%
%  Hastie, T. J. and Tibshirani, R. J. (1990)
%  \emph{Generalized Additive Models.}  Chapman and Hall.
%}
%\author{
%  \R implementation by B. D. Ripley and Martin Maechler
%  (\code{spar/lambda}, etc).
%}
%\source{
%  This function is based on code in the \code{GAMFIT} Fortran program by
%  T. Hastie and R. Tibshirani (originally taken from
%  \url{http://lib.stat.cmu.edu/general/}, which is now defunct but
%  mirrors may still be available),
%  which makes use of spline code by Finbarr O'Sullivan.  Its design
%  parallels the \code{smooth.spline} function of Chambers & Hastie (1992).
%}
%\seealso{
%  \code{\link{predict.smooth.spline}} for evaluating the spline
%  and its derivatives.
%}
%\examples{
%require(graphics)
%
%attach(cars)
%plot(speed, dist, main = "data(cars)  &  smoothing splines")
%cars.spl <- smooth.spline(speed, dist)
%(cars.spl)
%## This example has duplicate points, so avoid cv = TRUE
%\dontshow{
%  stopifnot(cars.spl $ w == table(speed)) # weights = multiplicities
%  utils::str(cars.spl, digits = 5, vec.len = 6)
%  cars.spl$fit
%}
%lines(cars.spl, col = "blue")
%lines(smooth.spline(speed, dist, df = 10), lty = 2, col = "red")
%legend(5,120,c(paste("default [C.V.] => df =",round(cars.spl$df,1)),
%               "s( * , df = 10)"), col = c("blue","red"), lty = 1:2,
%       bg = 'bisque')
%detach()
%
%
%## Residual (Tukey Anscombe) plot:
%plot(residuals(cars.spl) ~ fitted(cars.spl))
%abline(h = 0, col = "gray")
%
%## consistency check:
%stopifnot(all.equal(cars$dist,
%                    fitted(cars.spl) + residuals(cars.spl)))
%
%## Visualize the behavior of  .nknots.smspl()
%nKnots <- Vectorize(.nknots.smspl) ; c.. <- adjustcolor("gray20",.5)
%curve(nKnots, 1, 250, n=250)
%abline(0,1, lty=2, col=c..); text(90,90,"y = x", col=c.., adj=-.25)
%abline(h=100,lty=2); abline(v=200, lty=2)
%
%n <- c(1:799, seq(800, 3490, by=10), seq(3500, 10000, by = 50))
%plot(n, nKnots(n), type="l", main = "Vectorize(.nknots.smspl) (n)")
%abline(0,1, lty=2, col=c..); text(180,180,"y = x", col=c..)
%n0 <- c(50, 200, 800, 3200); c0 <- adjustcolor("blue3", .5)
%lines(n0, nKnots(n0), type="h", col=c0)
%axis(1, at=n0, line=-2, col.ticks=c0, col=NA, col.axis=c0)
%axis(4, at=.nknots.smspl(10000), line=-.5, col=c..,col.axis=c.., las=1)
%
%##-- artificial example
%y18 <- c(1:3, 5, 4, 7:3, 2*(2:5), rep(10, 4))
%xx  <- seq(1, length(y18), len = 201)
%(s2  <- smooth.spline(y18)) # GCV
%(s02  <- smooth.spline(y18, spar = 0.2))
%(s02. <- smooth.spline(y18, spar = 0.2, cv = NA))
%plot(y18, main = deparse(s2$call), col.main = 2)
%lines(s2, col = "gray"); lines(predict(s2, xx), col = 2)
%lines(predict(s02, xx), col = 3); mtext(deparse(s02$call), col = 3)
%
%\dontshow{
%stopifnot(all.equal(predict(s02 , xx),
%		    predict(s02., xx), tolerance = 1e-15))
%}
%\donttest{
%## The following shows the problematic behavior of 'spar' searching:
%(s2  <- smooth.spline(y18, control =
%                      list(trace = TRUE, tol = 1e-6, low = -1.5)))
%(s2m <- smooth.spline(y18, cv = TRUE, control =
%                      list(trace = TRUE, tol = 1e-6, low = -1.5)))
%## both above do quite similarly (Df = 8.5 +- 0.2)
%}}
%\keyword{smooth}
%
%\encoding{UTF-8}
%
