% File src/library/stats/man/terms.object.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{terms.object}
\title{Description of Terms Objects}
\alias{terms.object}%@%\alias{項オブジェクトの説明}
\description{
  クラス \code{\link{terms}} のオブジェクトはモデルに関する情報を持つ．
  普通モデルは \code{\link{formula}} の言葉で指定されており，
  公式は項オブジェクトを決定するのに使われている．
}
\value{
  オブジェクト自体は単に
  \code{\link{terms.formula}} の呼び出しに提供された公式である．
  オブジェクトは幾つかの属性を持ち，それらはモデルフレームを
  構成するのに使われる．

  \item{factors}{
    どの変数がどの項の中に現れるかを示す項による変数の行列．
    項は変数が項の中になければ 0 で，
    もし項の中にあって対比でコードされるべきであれば 1，
    もし項の中にあって全ての水準に対して
    (下位のオーダーの項が欠損している場合のように)
    ダミー変数でコードされるべきなら 2 である．
    主効果中の変数は仮に切片項が無くても常に 1 になる
    (その場合最初のものはダミー変数でコードされるべきである)．
    もし切片項とオフセット以外の項がなければ，
    これは \code{numeric(0)} である．}
  \item{term.labels}{
    オフセットを除く，モデル中の各項に対するラベルを含む文字列
    ベクトル．
    これらはもしかすると項を並び替えた後であることを注意する．

    シンタックスに合わない名前はバックチックで囲まれる；
    これは公式を項ラベルから再攻勢するのを簡単にする．
  }
  \item{variables}{
    モデル中の変数の \code{list} への呼び出し．}
  \item{intercept}{切片項が当てはめられなければ 0，
    切片項を当てはめるのなら 1．}
  \item{order}{
    \code{term.labels} と同じ長さのベクトルで，各項に
    対する交互作用の順序を指示する．}
  \item{response}{
    応答の(変数中の)変数の添字．もし応答が無ければゼロ．}
  \item{offset}{
    もしモデルが \code{\link{offset}} 項を含めば，
    どの変数がオフセットかを指示する
    \code{offset} 属性がある．}
  \item{specials}{
    もし \code{specials} 引数が
    \code{\link{terms.formula}} に与えられると，
    \code{specials} 属性がある．
    これはベクトルの対リスト(各指定された特別関数に対して一つ)．
    これはこれらの特別関数を含む
    \code{variables} 属性として返されるリストの引数の数値添字を与える．}
  \item{dataClasses}{オプション．
    当てはめで使われた変数のクラス(\code{\link{.MFclass}} が与えるような)
    を与える名前付きの文字列．} 
  \item{predvars}{オプション．
    新しい共変値での予測値を計算するのを助ける表現式\sspace{}；\cr
    \code{\link{makepredictcall}} を見よ．}

  オブジェクトはクラス \code{c("terms", "formula")} を持つ．
}
\note{
  これらのオブジェクトは S 中にあるそれらと異なる．
  特に \code{formula} 属性はない：代わりにオブジェクト自体が公式である．
  (このように，項オブジェクトのモードが異なる．)

  \code{specials} 引数の例は
  \code{\link{aov}} と \code{\link[survival]{coxph}} 関数中で見られる，
  後者はパッケージ \CRANpkg{survival} にある．
}
\seealso{
  \code{\link{terms}}, \code{\link{formula}}.
}
\examples{
## specials の使用(パッケージ mgcv と gamas 中の gam() に対して使用)
(tf <- terms(y ~ x + x:z + s(x), specials = "s"))
## "factors" 属性は変数を行名として
## 項ラベルを列名として持つことを注意．共に文字列．
attr(tf, "specials")    # 添字 's' 変数
rownames(attr(tf, "factors"))[attr(tf, "specials")$s]

## 順序を次のようにして保つことが出来る
terms(y ~ x + x:z + s(x), specials = "s", keep.order = TRUE)
}
%%--- MM: I would really like instructive examples here...
\keyword{models}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/terms.object.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{terms.object}
%\title{Description of Terms Objects}
%\alias{terms.object}
%\description{
%  An object of class \code{\link{terms}} holds information about a
%  model.  Usually the model was specified in terms of a
%  \code{\link{formula}} and that formula was used to determine the terms
%  object.
%}
%\value{
%  The object itself is simply the formula supplied to the call of
%  \code{\link{terms.formula}}.  The object has a number of attributes
%  and they are used to construct the model frame:
%
%  \item{factors}{A matrix of variables by terms showing which variables
%    appear in which terms.  The entries are 0 if the variable does not
%    occur in the term, 1 if it does occur and should be coded by
%    contrasts, and 2 if it occurs and should be coded via dummy
%    variables for all levels (as when a lower-order term
%    is missing).  Note that variables in main effects always receive 1,
%    even if the intercept is missing (in which case the first one
%    should be coded with dummy variables).
%    If there are no terms other than an intercept and offsets,
%    this is \code{numeric(0)}.}
%  \item{term.labels}{A character vector containing the labels for each
%    of the terms in the model, except for offsets.  Note that these are
%    after possible re-ordering of terms.
%
%    Non-syntactic names will be quoted by backticks: this makes it
%    easier to re-construct the formula from the term labels.
%  }
%  \item{variables}{A call to \code{list} of the variables in the model.}
%  \item{intercept}{Either 0, indicating no intercept is to be fit, or 1
%    indicating that an intercept is to be fit.}
%  \item{order}{A vector of the same length as \code{term.labels}
%    indicating the order of interaction for each term.}
%  \item{response}{The index of the variable (in variables) of the
%    response (the left hand side of the formula).  Zero, if there is no
%    response.}
%  \item{offset}{If the model contains \code{\link{offset}} terms there
%    is an \code{offset} attribute indicating which variable(s) are offsets}
%  \item{specials}{If a \code{specials} argument was given to
%    \code{\link{terms.formula}} there is a \code{specials} attribute, a
%    pairlist of vectors (one for each specified special function) giving
%    numeric indices of the arguments of the list returned as the
%    \code{variables} attribute which contain these special functions.}
%  \item{dataClasses}{optional.  A named character vector giving the classes
%    (as given by \code{\link{.MFclass}}) of the variables used in a fit.}
%  \item{predvars}{optional.  An expression to help in computing 
%    predictions at new covariate values; see \code{\link{makepredictcall}}.}
%
%  The object has class \code{c("terms", "formula")}.
%}
%\note{
%  These objects are different from those found in S.  In particular
%  there is no \code{formula} attribute: instead the object is itself a
%  formula.  (Thus, the mode of a terms object is different.)
%
%  Examples of the \code{specials} argument can be seen in the
%  \code{\link{aov}} and \code{\link[survival]{coxph}} functions, the
%  latter from package \CRANpkg{survival}.
%}
%\seealso{
%  \code{\link{terms}}, \code{\link{formula}}.
%}
%\examples{
%## use of specials (as used for gam() in packages mgcv and gam)
%(tf <- terms(y ~ x + x:z + s(x), specials = "s"))
%## Note that the "factors" attribute has variables as row names
%## and term labels as column names, both as character vectors.
%attr(tf, "specials")    # index 's' variable(s)
%rownames(attr(tf, "factors"))[attr(tf, "specials")$s]
%
%## we can keep the order by
%terms(y ~ x + x:z + s(x), specials = "s", keep.order = TRUE)
%}
%%%--- MM: I would really like instructive examples here...
%\keyword{models}
%
%\encoding{UTF-8}
%
