% File src/library/stats/man/ts.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{ts}
\title{Time-Series Objects}
\alias{ts}%@%\alias{時系列オブジェクト}
\alias{as.ts}
\alias{as.ts.default}
\alias{is.ts}
\alias{Ops.ts}
\alias{cbind.ts}
\alias{is.mts}
\alias{[.ts}
\alias{t.ts}
\description{
  関数 \code{ts} は時系列オブジェクトを作るのに使われる．

  \code{as.ts} と \code{is.ts} オブジェクトを時系列オブジェクトに
  強制変換し，オブジェクトが時系列かどうか検査する．
}
\usage{
ts(data = NA, start = 1, end = numeric(), frequency = 1,
   deltat = 1, ts.eps = getOption("ts.eps"), class = , names = )
as.ts(x, \dots)
is.ts(x)
}
\arguments{
  \item{data}{観測された時系列のベクトルか行列．
    データフレームは \code{data.matrix} で数値行列に強制変換される．
    (\sQuote{詳細}節も見よ．)}
  \item{start}{最初の観測の時間．
    単一の数値か，自然な時間単位と
    単位時間中の標本数の二つの整数のベクトル．
    後者の使用法は例を見よ．}
  \item{end}{最後の観測時間，
    \code{start} と同じように指定される．}
  \item{frequency}{単位時間中の観測数．}
  \item{deltat}{引き続くサンプル期間の割合；
    例えば月データには 1/12．
    \code{frequency} か \code{deltat} のひとつだけが提供される．}
  \item{ts.eps}{時系列の比較許容度．
    周波数はそれらの絶対値が
    \code{ts.eps} 以下ならば等しいとされる．}
  \item{class}{
    結果に与えられるクラス，又は
    もし \code{NULL} か \code{"none"} ならば無い．
    既定値は単一の系列には \code{"ts"} で，
    複数の系列には \code{c("mts", "ts", "matrix")}．}
  \item{names}{
    複数系列中の系列名を与える文字列ベクトル：
    既定では \code{data} の列名か \code{Series 1},
    \code{Series 2}, \dots．}
  \item{x}{任意の \R オブジェクト．}
  \item{\dots}{メソッドに渡される引数(既定メソッドには使われない)．}
}
\details{
  関数 \code{ts} は時系列オブジェクトを作るのに使われる．
  これらは等間隔の時間でサンプルされた
  クラス \code{"ts"} (そして追加の属性)を持つベクトルか行列
  である．
  行列の場合，行列 \code{data} の各列は単一の(一変量)時系列を
  含むと仮定される．
  時系列は少なくとも一つの観測値を持たなければならず，
  数値である必要はないが非数値系列に対しては非常に限られた
  サポートしか無い．

  クラス \code{"ts"} は幾つかのメソッドを持つ．
  特に算術は時間軸を揃えることを試み，系列の部分集合を取り出す添字操作
  が使える
  (例えば \code{EuStockMarkets[, "DAX"]})．しかしながら，
  最初の(もしくは唯一の)次元の添字操作は行列の添字操作がそうするように
  行列かベクトルを返す．
  部分付値は値の置き換えに使えるが，
  系列の拡大には使えない
  (\code{\link{window}} を見よ)．
  \code{\link{t}} に対するメソッドは
  系列を行列として転置し
  (もしベクトルならば一列の行列)，従って
  結果はクラス \code{"ts"} を継承しない．

  引数 \code{frequency} の値は系列が
  各時間単位で時間の整数倍サンプルされている時に使われる．
  例えば，データが毎日サンプルされていれば
  \code{7} を \code{frequency} に対して使うことが出来，
  自然な時間周期は週である．
  又はデータが月毎にサンプルされていれば \code{12} であり自然な
  時間周期は一年になる．値 \code{4} と \code{12} は
  (例えば) \code{print} メソッドではそれぞれ季節毎と月毎を
  意味する．

  \code{as.ts} は総称的である．その既定メソッドは
  もしそれが開始と終了時間と周波数を持てば
  オブジェクトの \code{\link{tsp}} 属性を使う．

  \code{is.ts} はオブジェクトが時系列かどうかを検査する．
  これは総称的である：
  特定のオブジェクトのクラスを扱うメソッドを描くことが出来る，
  link{InternalMethods} を見よ．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{tsp}},
  \code{\link{frequency}},
  \code{\link{start}},
  \code{\link{end}},
  \code{\link{time}},
  \code{\link{window}};
  時系列のプリントメソッド \code{\link{print.ts}}；
  時系列のプロットメソッド \code{\link{plot.ts}}．
  
  \sQuote{時系列}の他の定義(例えば
  時間で順序付けられた観測値)については 
  \url{https://cran.r-project.org/web/views/TimeSeries.html}
  にある CRAN タスクビューを見よ．
}
\examples{
require(graphics)

ts(1:10, frequency = 4, start = c(1959, 2)) # 1959年の第二四半期
print( ts(1:10, frequency = 7, start = c(12, 2)), calendar = TRUE)
# print.ts(.)
## 1954年の7月を開始日にする：
gnp <- ts(cumsum(1 + round(rnorm(100), 2)),
          start = c(1954, 7), frequency = 12)
plot(gnp) # 時系列のプロットに 'plot.ts' を使う

## 多変量
z <- ts(matrix(rnorm(300), 100, 3), start = c(1961, 1), frequency = 12)
class(z)
head(z) # "行列"として
plot(z)
plot(z, plot.type = "single", lty = 1:3)

## フェイズのプロット：
plot(nhtemp, lag(nhtemp, 1), cex = .8, col = "blue",
     main = "Lag plot of New Haven temperatures")
}
\keyword{ts}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/ts.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{ts}
%\title{Time-Series Objects}
%\alias{ts}
%\alias{as.ts}
%\alias{as.ts.default}
%\alias{is.ts}
%\alias{Ops.ts}
%\alias{cbind.ts}
%\alias{is.mts}
%\alias{[.ts}
%\alias{t.ts}
%\description{
%  The function \code{ts} is used to create time-series objects.
%
%  \code{as.ts} and \code{is.ts} coerce an object to a time-series and
%  test whether an object is a time series.
%}
%\usage{
%ts(data = NA, start = 1, end = numeric(), frequency = 1,
%   deltat = 1, ts.eps = getOption("ts.eps"), class = , names = )
%as.ts(x, \dots)
%is.ts(x)
%}
%\arguments{
%  \item{data}{a vector or matrix of the observed time-series
%    values. A data frame will be coerced to a numeric matrix via
%    \code{data.matrix}.  (See also \sQuote{Details}.)}
%  \item{start}{the time of the first observation.  Either a single
%    number or a vector of two integers, which specify a natural time
%    unit and a (1-based) number of samples into the time unit.  See
%    the examples for the use of the second form.}
%  \item{end}{the time of the last observation, specified in the same way
%    as \code{start}.}
%  \item{frequency}{the number of observations per unit of time.}
%  \item{deltat}{the fraction of the sampling period between successive
%    observations; e.g., 1/12 for monthly data.  Only one of
%    \code{frequency} or \code{deltat} should be provided.}
%  \item{ts.eps}{time series comparison tolerance.  Frequencies are
%    considered equal if their absolute difference is less than
%    \code{ts.eps}.}
%  \item{class}{class to be given to the result, or none if \code{NULL}
%    or \code{"none"}.  The default is \code{"ts"} for a single series,
%    \code{c("mts", "ts", "matrix")} for multiple series.}
%  \item{names}{a character vector of names for the series in a multiple
%    series: defaults to the colnames of \code{data}, or \code{Series 1},
%    \code{Series 2}, \dots.}
%  \item{x}{an arbitrary \R object.}
%  \item{\dots}{arguments passed to methods (unused for the default method).}
%}
%\details{
%  The function \code{ts} is used to create time-series objects.  These
%  are vector or matrices with class of \code{"ts"} (and additional
%  attributes) which represent data which has been sampled at equispaced
%  points in time.  In the matrix case, each column of the matrix
%  \code{data} is assumed to contain a single (univariate) time series.
%  Time series must have at least one observation, and although they need
%  not be numeric there is very limited support for non-numeric series.
%
%  Class \code{"ts"} has a number of methods.  In particular arithmetic
%  will attempt to align time axes, and subsetting to extract subsets of
%  series can be used (e.g., \code{EuStockMarkets[, "DAX"]}).  However,
%  subsetting the first (or only) dimension will return a matrix or
%  vector, as will matrix subsetting.  Subassignment can be used to
%  replace values but not to extend a series (see \code{\link{window}}).
%  There is a method for \code{\link{t}} that transposes the series as a
%  matrix (a one-column matrix if a vector) and hence returns a result
%  that does not inherit from class \code{"ts"}.
%
%  The value of argument \code{frequency} is used when the series is
%  sampled an integral number of times in each unit time interval.  For
%  example, one could use a value of \code{7} for \code{frequency} when
%  the data are sampled daily, and the natural time period is a week, or
%  \code{12} when the data are sampled monthly and the natural time
%  period is a year.  Values of \code{4} and \code{12} are assumed in
%  (e.g.) \code{print} methods to imply a quarterly and monthly series
%  respectively.
%
%  \code{as.ts} is generic.  Its default method will use the
%  \code{\link{tsp}} attribute of the object if it has one to set the
%  start and end times and frequency.
%
%  \code{is.ts} tests if an object is a time series.  It is generic: you
%  can write methods to handle specific classes of objects,
%  see \link{InternalMethods}.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{tsp}},
%  \code{\link{frequency}},
%  \code{\link{start}},
%  \code{\link{end}},
%  \code{\link{time}},
%  \code{\link{window}};
%  \code{\link{print.ts}}, the print method for time series objects;
%  \code{\link{plot.ts}}, the plot method for time series objects.
%  
%  For other definitions of \sQuote{time series} (e.g.,
%  time-ordered observations) see the CRAN task view at
%  \url{https://cran.r-project.org/web/views/TimeSeries.html}.
%}
%\examples{
%require(graphics)
%
%ts(1:10, frequency = 4, start = c(1959, 2)) # 2nd Quarter of 1959
%print( ts(1:10, frequency = 7, start = c(12, 2)), calendar = TRUE)
%# print.ts(.)
%## Using July 1954 as start date:
%gnp <- ts(cumsum(1 + round(rnorm(100), 2)),
%          start = c(1954, 7), frequency = 12)
%plot(gnp) # using 'plot.ts' for time-series plot
%
%## Multivariate
%z <- ts(matrix(rnorm(300), 100, 3), start = c(1961, 1), frequency = 12)
%class(z)
%head(z) # as "matrix"
%plot(z)
%plot(z, plot.type = "single", lty = 1:3)
%
%## A phase plot:
%plot(nhtemp, lag(nhtemp, 1), cex = .8, col = "blue",
%     main = "Lag plot of New Haven temperatures")
%}
%\keyword{ts}
%
%\encoding{UTF-8}
%
