% File src/library/stats/man/zC.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{C}
\title{Sets Contrasts for a Factor}
\usage{
C(object, contr, how.many, \dots)
}
\alias{C}%@%\alias{因子に対比を設定}
\arguments{
  \item{object}{因子又は順序付き因子．}
  \item{contr}{どの対比を使うか．
   因子の各レベルに対して一つの行を持つ行列，
    又は \code{contr.poly} のような適当な関数，
    又は関数の名前を与える文字列で良い．}
  \item{how.many}{設定する対比の数で，
    既定では
    \code{nlevels(object)} より一つ少ない．}
  \item{\dots}{
    関数 \code{contr} に対する追加引数．}
}
\description{
  因子に \code{"contrasts"} 属性を設定する．
}
\details{
  S との互換性から \code{contr} は \code{treatment},
  \code{helmert}, \code{sum} 又は \code{poly} (引用符無し) 
  でよく，これらは \code{contr.treatment} 等の略である．
}
\value{
  \code{"contrasts"} 属性が設定された因子 \code{object}．
}
\seealso{
  \code{\link{contrasts}}, \code{\link{contr.sum}}, 等．
}
\references{
  Chambers, J. M. and Hastie, T. J. (1992)
  \emph{Statistical models.}
  Chapter 2 of \emph{Statistical Models in S}
  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
}
\examples{
## 対比を既定にリセット
options(contrasts = c("contr.treatment", "contr.poly"))
tens <- with(warpbreaks, C(tension, poly, 1))
\donttest{attributes(tens)}
## tension は順序付き因子でなければならないが，そうではないので次を使う
aov(breaks ~ wool + tens + tension, data = warpbreaks)

## ... の使用法．既定の対比はここでは contr.treatment
summary(lm(breaks ~ wool + C(tension, base = 2), data = warpbreaks))


# help(esoph) に続く
model3 <- glm(cbind(ncases, ncontrols) ~ agegp + C(tobgp, , 1) +
     C(alcgp, , 1), data = esoph, family = binomial())
summary(model3)
}
\keyword{models}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/zC.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{C}
%\title{Sets Contrasts for a Factor}
%\usage{
%C(object, contr, how.many, \dots)
%}
%\alias{C}
%\arguments{
%  \item{object}{a factor or ordered factor}
%  \item{contr}{which contrasts to use. Can be a matrix with one row for
%    each level of the factor or a suitable function like
%    \code{contr.poly} or a character string giving the name of the function}
%  \item{how.many}{the number of contrasts to set, by default one less
%    than \code{nlevels(object)}.}
%  \item{\dots}{additional arguments for the function \code{contr}.}
%}
%\description{
%  Sets the \code{"contrasts"} attribute for the factor.
%}
%\details{
%  For compatibility with S, \code{contr} can be \code{treatment},
%  \code{helmert}, \code{sum} or \code{poly} (without quotes) as shorthand
%  for \code{contr.treatment} and so on.
%}
%\value{
%  The factor \code{object} with the \code{"contrasts"} attribute set.
%}
%\seealso{
%  \code{\link{contrasts}}, \code{\link{contr.sum}}, etc.
%}
%\references{
%  Chambers, J. M. and Hastie, T. J. (1992)
%  \emph{Statistical models.}
%  Chapter 2 of \emph{Statistical Models in S}
%  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
%}
%\examples{
%## reset contrasts to defaults
%options(contrasts = c("contr.treatment", "contr.poly"))
%tens <- with(warpbreaks, C(tension, poly, 1))
%\donttest{attributes(tens)}
%## tension SHOULD be an ordered factor, but as it is not we can use
%aov(breaks ~ wool + tens + tension, data = warpbreaks)
%
%## show the use of ...  The default contrast is contr.treatment here
%summary(lm(breaks ~ wool + C(tension, base = 2), data = warpbreaks))
%
%
%# following on from help(esoph)
%model3 <- glm(cbind(ncases, ncontrols) ~ agegp + C(tobgp, , 1) +
%     C(alcgp, , 1), data = esoph, family = binomial())
%summary(model3)
%}
%\keyword{models}
%
%\encoding{UTF-8}
%
