% File src/library/tools/man/checkRdaFiles.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2012-2014 R Core Team
% Distributed under GPL 2 or later

\name{checkPoFiles}
%@%\alias{翻訳ファイルの一貫性チェック}
\alias{checkPoFile}
\alias{checkPoFiles}
\title{一貫性のない書式文字列に対する翻訳ファイルのチェック}
%\title{Check translation files for inconsistent format strings.}
\description{
  これらの関数は一貫性のチェックのために英文メッセージに埋め込まれた書式を
  翻訳文字列と比較する．
  \code{checkPoFile} は一つのファイルをチェックする一方，
  \code{checkPoFiles} は指定された言語に対する全てのファイルをチェックする．
}
\usage{
checkPoFile(f, strictPlural = FALSE)
checkPoFiles(language, dir = ".")
}
\arguments{
  \item{f}{単一のファイルパスを与える文字列．}
  \item{strictPlural}{単数と複数の書式を厳格に非アックするかどうか．}
  \item{language}{言語コードを与える文字列．}
  \item{dir}{ファイルをその中でチェックするディレクトリへのパス．}
}
\details{

  \R の国際化の一部は
  \file{.po} ファイル中のメッセージの翻訳に依存している．
  これらのファイル中には
  \R のソースから取られた\sQuote{英語}のメッセージ
  に別の言語への翻訳が続く．
  これらのメッセージの多くは C や \R の
  \code{\link{sprintf}} と関連関数の書式文字である．
  これらのケースでは翻訳は一貫性のある書式を与える必要があり，
  さもなければメッセージが表示される時エラーが起きる．

  一貫性の規則は幾つかの点で C と \R では異なる．
  C は \R がサポートしていない幾つかの変換をサポートしている，
  つまり \code{c}, \code{u}, \code{p}, \code{n}．
  C の \code{sprintf()} 関数では書式文字列が必要とするよりも
  多くの引数を持つことが許されているが，
  \R では数は正確に一致しなければならない．
  \R は引数のタイプがマッチすることを要求するが，
  C はそれが意味があろうとなかろうと表示を行う．

  これらの関数はテストに対して次のように妥協する．
  C で許される全ての書式は受け入れられ，
  引数のタイプと数の違いは全て報告される．
  結果として報告されるある種の違いはエラーではない．

  もし \code{strictPlural} 引数が \code{TRUE} ならば，
  引数リストはメッセージの単数形と複数形の間で正確に一致しなければならない；
  もし \code{FALSE} ならば，翻訳は二つの形式の一つかもうひとつにマッチ
  しさえすれば良い．
  \code{checkPoFiles} は \code{checkPoFile} を呼び出す時，
  \code{strictPlural} 引数は
  \file{R-} で始まる名前を持つファイルに対して \code{TRUE} に
  設定され，さもなければ \code{FALSE} に設定される．

  \file{.po} ファイル中で \sQuote{fuzzy} とマークされた項目は
  処理されない(それらはメッセージコンパイラにより無視されるから)．

  もし食い違いが見つかると，翻訳文字列が
  変形パーセント符号
  (例えば幅広パーセント符号 \code{"\uFF05"})に対してチェックされる．
  そうした符号は書式指定子として認識されず，エラーになる可能性がある．
}
\value{
  どちらの関数も
  S3 クラス \code{"check_po_files"} のオブジェクトを返す．
  このクラスに対しては食い違いに関する報告を表示する
  \code{print} メソッドがある．
}
\references{
  \file{.po} ファイルの書式については
  GNU の gettext のマニュアルを見よ：\cr
  \url{https://www.gnu.org/software/gettext/manual/gettext.html}.
}
\author{
  Duncan Murdoch
}
\seealso{
  \code{\link{update_pkg_po}()} which calls \code{checkPoFile()};
  \code{\link{xgettext}}, \code{\link{sprintf}}.
}
\examples{
\dontrun{
checkPoFiles("de", "/path/to/R/src/directory")
}
}
\keyword{ utilities }

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/tools/man/checkRdaFiles.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2012-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{checkPoFiles}
%\alias{checkPoFile}
%\alias{checkPoFiles}
%\title{
%  Check translation files for inconsistent format strings.
%}
%\description{
%  These functions compare formats embedded in English messages
%  with translated strings to check for consistency.  \code{checkPoFile}
%  checks one file, while \code{checkPoFiles} checks all files for a specified
%  language.
%}
%\usage{
%checkPoFile(f, strictPlural = FALSE)
%checkPoFiles(language, dir = ".")
%}
%\arguments{
%  \item{f}{a character string giving a single filepath.}
%  \item{strictPlural}{whether to compare formats of singular and plural
%    forms in a strict way.}
%  \item{language}{a character string giving a language code.}
%  \item{dir}{a path to a directory in which to check files.}
%}
%\details{
%
%  Part of \R's internationalization depends on translations of messages
%  in \file{.po} files.  In these files an \sQuote{English} message taken
%  from the \R sources is followed by a translation into another
%  language.  Many of these messages are format strings for C or \R
%  \code{\link{sprintf}} and related functions.  In these cases, the
%  translation must give a compatible format or an error will be
%  generated when the message is displayed.
%
%  The rules for compatibility differ between C and \R in several ways. C
%  supports several conversions not supported by \R, namely \code{c},
%  \code{u}, \code{p}, \code{n}.  It is allowed in C's \code{sprintf()}
%  function to have more arguments than are needed by the format string,
%  but in \R the counts must match exactly.  \R requires types of
%  arguments to match, whereas C will do the display whether it makes
%  sense or not.
%
%  These functions compromise on the testing as follows.  The additional
%  formats allowed in C are accepted, and all differences in argument
%  type or count are reported.  As a consequence some reported
%  differences are not errors.
%
%  If the \code{strictPlural} argument is \code{TRUE}, then argument
%  lists must agree exactly between singular and plural forms of messages; if
%  \code{FALSE}, then translations only need to match one or the other
%  of the two forms.  When \code{checkPoFiles} calls \code{checkPoFile},
%  the \code{strictPlural} argument is set to \code{TRUE} for files with
%  names starting \file{R-}, and to \code{FALSE} otherwise.
%
%  Items marked as \sQuote{fuzzy} in the \file{.po} file are not
%  processed (as they are ignored by the message compiler).
%
%  If a difference is found, the translated string is checked for variant
%  percent signs (e.g., the wide percent sign \code{"\uFF05"}).  Such signs
%  will not be recognized as format specifiers, and are likely to be
%  errors.
%}
%\value{
%  Both functions return an object of S3 class \code{"check_po_files"}.  A
%  \code{print} method is defined for this class to display a report on
%  the differences.
%}
%\references{
%  See the GNU gettext manual for the \file{.po} file format:\cr
%  \url{https://www.gnu.org/software/gettext/manual/gettext.html}.
%}
%\author{
%  Duncan Murdoch
%}
%\seealso{
%  \code{\link{update_pkg_po}()} which calls \code{checkPoFile()};
%  \code{\link{xgettext}}, \code{\link{sprintf}}.
%}
%\examples{
%\dontrun{
%checkPoFiles("de", "/path/to/R/src/directory")
%}
%}
%\keyword{ utilities }
%
%\encoding{UTF8}
%