% File src/library/tools/man/check_packages_in_dir.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2013-2014 R Core Team
% Distributed under GPL 2 or later

\name{check_packages_in_dir}
%@%\alias{ソースパッケージのチェック}
\alias{check_packages_in_dir}
\alias{summarize_check_packages_in_dir_depends}
\alias{summarize_check_packages_in_dir_results}
\alias{summarize_check_packages_in_dir_timings}
\alias{check_packages_in_dir_changes}
%\title{Check Source Packages and Their Reverse Dependencies}
\title{ソースパッケージとそれらの従属性をチェックする}
\description{
  与えられたディレクトリ中のソースパッケージをチェックする．
  オプションで逆向きの従属性も調べる．
}
\usage{
check_packages_in_dir(dir,
                      check_args = character(),
                      check_args_db = list(),
                      reverse = NULL,
                      check_env = character(),
                      xvfb = FALSE,
                      Ncpus = getOption("Ncpus", 1L),
                      clean = TRUE,
                      ...)

summarize_check_packages_in_dir_results(dir, all = TRUE,
                                        full = FALSE)
summarize_check_packages_in_dir_timings(dir, all = FALSE,
                                        full = FALSE)
summarize_check_packages_in_dir_depends(dir, all = FALSE,
                                        which = c("Depends",
                                                  "Imports",
                                                  "LinkingTo"))

check_packages_in_dir_changes(dir, old,
                              outputs = FALSE, sources = FALSE)
}
\arguments{
  \item{dir}{
    チェックされるソース \file{.tar.gz} ファイルのあるディレクトリへの
    パスを与える文字列．}
  \item{check_args}{
    \command{R CMD check} に渡される引数の文字列ベクトル，または
    それぞれパッケージのチェックと逆向きの従属性をチェックするために
    使われるそうした文字列ベクトルの長さ2のりスト．}
  \item{check_args_db}{
    \command{R CMD check} に渡される引数の文字列ベクトルの名前付きリストで，
    名前はそれぞれのパッケージ名に対応する．}
  \item{reverse}{
    \code{"repos"}, \code{"which"} または \code{"recursive"} に
    部分的にマッチする名前のリストで，逆向きの従属性の位置に対する
    レポジトリ
    (既定：\code{getOption("repos")})と，
    逆向き従属性のタイプ
    (既定：\code{"Depends", "Imports", "LinkingTo")}
    \code{\link{package_dependencies}} に対するように
    省略形 \code{"most"} と \code{"all"} を持つ)を与える，
    そして逆向きの従属性の逆向きの従属性のチェック等も行うかを
    指示する
    (既定：\code{FALSE})，または \code{NULL} (既定)で，
    その時は逆向きの従属性はチェックされない．} 
  \item{check_env}{
    チェックに対する環境変数を設定する
    name=value の形式の文字列の文字列ベクトル，または
    それぞれパッケージと逆向き従属性のチェックに対して使われる
    そうした文字列ベクトルの長さ2のりスト．}
  \item{xvfb}{
    チェックを仮想的フレームバッファ― X サーバーの内部で
    実行するかどうかを指示する論理値(Unix のみ)，または
    それを行うための Xvfb オプションの文字列ベクトル．}
  \item{Ncpus}{並列インストールとチェックとのために使われる並列プロセスの数．}
  \item{clean}{ダウンロードされた逆向き依存ソースを削除するかどうかを
    指示する論理値．}
  \item{...}{現在使われない．}
  \item{all}{チェックされた逆向き依存性も要約するかどうかを指示する論理値．}
  \item{full}{
    OK では無かったチェックに対する詳細も与えるか，
    またはチェック例のタイミングを要約する(もし利用可能なら)かどうかを指示する論理値．}
  \item{which}{\code{\link{package_dependencies}} を見よ．}
  \item{old}{前の \code{check_packages_in_dir} 実行のディレクトリへのパスを
    与える文字列．}
  \item{outputs}{
    実行されたチェックの出力中の変更を解析すべきかどうか，
    または(既定)チェックの状態だけかを指示する論理値．}
  \item{sources}{
    チェックされたソースファイル中の変更も調査すべきかどうかを指示する論理値
    (既定値：\code{FALSE})．}
}
\details{
  \code{check_packages_in_dir} は
  与えられたディレクトリ \code{dir} 中の
  ソースパッケージファイル \file{.tar.gz} を
  \code{reverse} で制御されるそれらの逆向き従属性に沿って
  便利にチェックすることを可能にする．

  \code{reverse} の \code{"which"} 成分はまたリストでもよく，
  その場合逆向きの従属性がリストの各成分
  そして対応する \code{reverse} の成分 \code{"recursive"}
  (これは必要に応じてリサイクルされる)に対して得られる．

  もし必要なら，同様にチェックされる逆向きに従属するソースファイル \file{.tar.gz}
  \code{dir} にダウンロードされる(そして
  もし \code{clean} が真なら最後に削除される)．
  次にチェックに対して必要な(追加の)全てのパッケージが
  \code{dir} の \file{Library} 副ディレクトリにインストールされる．
  それから全ての \file{.tar.gz} ファイルが
  与えられた引数と環境変数を使いチェックされ，ファイルに対する
  出力とメッセージが \code{dir} の副ディレクトリ
  \file{Outputs} 中のファイルに置かれる．
  逆向き依存性のチェック結果の \file{*.Rcheck} ディレクトリは
  それらの基礎名に接頭辞 \samp{rdepends_} を付けて改名される．

  結果とタイミングはそれぞれ
  \code{summarize_check_packages_in_dir_results} と\cr
  \code{summarize_check_packages_in_dir_timings} を使って
  簡便に要約することが出来る．

  もし \code{Ncpus} が1より大きければインストールとチェックは
  並列で行える：これは Unix では \code{\link[parallel]{mclapply}}，
  Windows では \code{\link[parallel]{parLapply}} を使う．

  \code{check_packages_in_dir} は
  クラス \code{"check_packages_in_dir"} を継承するオブジェクトを返し，
  これは \code{\link{print}} と \code{\link{summary}}メソッドを持つ．

  \code{check_packages_in_dir_changes} は
  ソース(の一部)を変更する影響を解析することを可能にする．
  \code{dir} と \code{old} を対応するチェック結果を持つ
  それぞれ新旧のディレクトリへのパスとすると，チェック結果の
  変更はもしあれば簡便に解析出来，
  オプション \code{outputs} と \code{sources} で制御できる．
}
\note{
  この機能は依然実験的である：インタフェイスは将来変更されるかもしれない．
}
\keyword{utilities}
\examples{
\dontrun{
## dir 中のパッケージを逆向きの従属性無しにチェック：
check_packages_in_dir(dir)
## dir 中のパッケージと逆向きの従属性を既定値を使いチェック
## (getOption("repos") 中の全てのディレクトリ，全ての"強い"
## 逆向き従属性，再帰的な逆向き従属性は無し)：
check_packages_in_dir(dir, reverse = list())
## dir 中のパッケージと CRAN からの逆向きの従属性を
## 全ての"強い"逆向き従属性と逆向きの推奨を使いチェック：
check_packages_in_dir(dir,
                      reverse = list(repos = getOption("repos")["CRAN"],
                                     which = "most"))                   
## dir 中のパッケージと CRAN からの逆向きの従属性を
## '--as-cran' を前者に対して使うが後者に対しては使わずチェック：
check_packages_in_dir(dir,
                      check_args = c("--as-cran", ""),
                      reverse = list(repos = getOption("repos")["CRAN"]))
}
}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/tools/man/check_packages_in_dir.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2013-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{check_packages_in_dir}
%\alias{check_packages_in_dir}
%\alias{summarize_check_packages_in_dir_depends}
%\alias{summarize_check_packages_in_dir_results}
%\alias{summarize_check_packages_in_dir_timings}
%\alias{check_packages_in_dir_changes}
%\title{Check Source Packages and Their Reverse Dependencies}
%\description{
%  Check source packages in a given directory, optionally with their
%  reverse dependencies.
%}
%\usage{
%check_packages_in_dir(dir,
%                      check_args = character(),
%                      check_args_db = list(),
%                      reverse = NULL,
%                      check_env = character(),
%                      xvfb = FALSE,
%                      Ncpus = getOption("Ncpus", 1L),
%                      clean = TRUE,
%                      ...)
%
%summarize_check_packages_in_dir_results(dir, all = TRUE,
%                                        full = FALSE)
%summarize_check_packages_in_dir_timings(dir, all = FALSE,
%                                        full = FALSE)
%summarize_check_packages_in_dir_depends(dir, all = FALSE,
%                                        which = c("Depends",
%                                                  "Imports",
%                                                  "LinkingTo"))
%
%check_packages_in_dir_changes(dir, old,
%                              outputs = FALSE, sources = FALSE)
%}
%\arguments{
%  \item{dir}{a character string giving the path to the directory with
%    the source \file{.tar.gz} files to be checked.}
%  \item{check_args}{a character vector with arguments to be passed to
%    \command{R CMD check}, or a list of length two of such character
%    vectors to be used for checking packages and reverse dependencies,
%    respectively.}
%  \item{check_args_db}{a named list of character vectors with arguments
%    to be passed to \command{R CMD check}, with names the respective
%    package names.}
%  \item{reverse}{a list with names partially matching \code{"repos"},
%    \code{"which"}, or \code{"recursive"}, giving the repositories to
%    use for locating reverse dependencies (default:
%    \code{getOption("repos")}), the types of reverse dependencies
%    (default: \code{c("Depends", "Imports", "LinkingTo")}, with
%    shorthands \code{"most"} and \code{"all"} as for
%    \code{\link{package_dependencies}}), and indicating whether to also
%    check reverse dependencies of reverse dependencies and so on
%    (default: \code{FALSE}), or \code{NULL} (default), in which case no
%    reverse dependencies are checked.} 
%  \item{check_env}{a character vector of name=value strings to set
%    environment variables for checking, or a list of length two of such
%    character vectors to be used for checking packages and reverse
%    dependencies, respectively.}
%  \item{xvfb}{a logical indicating whether to perform checking inside a
%    virtual framebuffer X server (Unix only), or a character vector of
%    Xvfb options for doing so.}
%  \item{Ncpus}{the number of parallel processes to use for parallel
%    installation and checking.}
%  \item{clean}{a logical indicating whether to remove the downloaded
%    reverse dependency sources.}
%  \item{...}{currently not used.}
%  \item{all}{a logical indicating whether to also summarize the reverse
%    dependencies checked.}
%  \item{full}{a logical indicating whether to also give details for
%    checks with non-ok results, or summarize check example timings (if
%    available).}
%  \item{which}{see \code{\link{package_dependencies}}.}
%  \item{old}{a character string giving the path to the directory of a
%    previous \code{check_packages_in_dir} run.}
%  \item{outputs}{a logical indicating whether to analyze changes in
%    the outputs of the checks performed, or only (default) the status of
%    the checks.}
%  \item{sources}{a logical indicating whether to also investigate the
%    changes in the source files checked (default: \code{FALSE}).}
%}
%\details{
%  \code{check_packages_in_dir} allows to conveniently check source
%  package \file{.tar.gz} files in the given directory \code{dir}, along
%  with their reverse dependencies as controlled by \code{reverse}.
%
%  The \code{"which"} component of \code{reverse} can also be a list, in
%  which case reverse dependencies are obtained for each element of the
%  list and the corresponding element of the \code{"recursive"} component
%  of \code{reverse} (which is recycled as needed).
%
%  If needed, the source \file{.tar.gz} files of the reverse dependencies
%  to be checked as well are downloaded into \code{dir} (and removed at
%  the end if \code{clean} is true).  Next, all packages (additionally)
%  needed for checking are installed to the \file{Library} subdirectory
%  of \code{dir}.  Then, all \file{.tar.gz} files are checked using the
%  given arguments and environment variables, with outputs and messages
%  to files in the \file{Outputs} subdirectory of \code{dir}.  The
%  \file{*.Rcheck} directories with the check results of the reverse
%  dependencies are renamed by prefixing their base names with
%  \samp{rdepends_}.
%
%  Results and timings can conveniently be summarized using
%  \code{summarize_check_packages_in_dir_results} and
%  \code{summarize_check_packages_in_dir_timings}, respectively.
%
%  Installation and checking is performed in parallel if \code{Ncpus} is
%  greater than one: this will use \code{\link[parallel]{mclapply}} on
%  Unix and \code{\link[parallel]{parLapply}} on Windows.
%
%  \code{check_packages_in_dir} returns an object inheriting from class
%  \code{"check_packages_in_dir"} which has \code{\link{print}} and
%  \code{\link{summary}} methods.
%
%  \code{check_packages_in_dir_changes} allows to analyze the effect of
%  changing (some of) the sources.  With \code{dir} and \code{old} the
%  paths to the directories with the new and old sources, respectively,
%  and the corresponding check results, possible changes in the check
%  results can conveniently be analyzed as controlled via options
%  \code{outputs} and \code{sources}.
%}
%\note{
%  This functionality is still experimental: interfaces may change in
%  future versions. 
%}
%\keyword{utilities}
%\examples{
%\dontrun{
%## Check packages in dir without reverse dependencies:
%check_packages_in_dir(dir)
%## Check packages in dir and their reverse dependencies using the
%## defaults (all repositories in getOption("repos"), all "strong"
%## reverse dependencies, no recursive reverse dependencies):
%check_packages_in_dir(dir, reverse = list())
%## Check packages in dir with their reverse dependencies from CRAN,
%## using all strong reverse dependencies and reverse suggests:
%check_packages_in_dir(dir,
%                      reverse = list(repos = getOption("repos")["CRAN"],
%                                     which = "most"))                   
%## Check packages in dir with their reverse dependencies from CRAN,
%## using '--as-cran' for the former but not the latter:
%check_packages_in_dir(dir,
%                      check_args = c("--as-cran", ""),
%                      reverse = list(repos = getOption("repos")["CRAN"]))
%}
%}
%
%\encoding{UTF8}
%