% File src/library/tools/man/codoc.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2009 R Core Team
% Distributed under GPL 2 or later

\name{codoc}
%@%\alias{コードとドキュメントの一貫性チェック}
\alias{codoc}
\alias{codocClasses}
\alias{codocData}
\alias{print.codoc}
\alias{print.codocClasses}
\alias{print.codocData}
\title{コードとドキュメントの一貫性のチェック}
%\title{Check Code/Documentation Consistency}
\usage{
codoc(package, dir, lib.loc = NULL,
      use.values = NULL, verbose = getOption("verbose"))
codocClasses(package, lib.loc = NULL)
codocData(package, lib.loc = NULL)
}
\description{
  パッケージ中の \R オブジェクトの実際とドキュメント化された
  \sQuote{構造}の間の非一貫性を見つける．
  \code{codoc} は名前と，オプションでまた対応する位置と
  関数引数の既定値を比較する．
  \code{codocClasses} と \code{codocData} はそれぞれ
  S4 クラスのスロット名とデータセットの変数名を比較する．
}
\arguments{
  \item{package}{インストールされたパッケージの名前の文字列．}
  \item{dir}{
    パッケージのルートソースディレクトリへのパスを指定する文字列．
    これは \R のドキュメントのソース(in Rd format)を持つ副ディレクトリ \file{man} と
    \R コードを持つ \file{R} を含まなければならない．
    \code{package} が与えられない時だけ使われる．}
  \item{lib.loc}{
    \R ライブラリのディレクトリ名の文字列ベクトルか
    \code{NULL}．既定値の \code{NULL} は現在知られている全てのライブラリに
    対応する．指定されたライブラリツリーは
    \code{package} を探すために使われる．}
  \item{use.values}{もし \code{FALSE} ならばコードとドキュメントを
    比較する際に関数の既定値を使わない．
    さもなければ，
    もし \code{TRUE} なら\emph{全ての}既定値を比較し，
    さもなければ用法中に文章化されているものだけを比較する．}
  \item{verbose}{論理値．もし \code{TRUE} なら，追加の診断がプリントされる．}
}
\note{
  \code{use.values} に対する既定値は \R バージョン 1.9.0 とそれ以降で
  \code{FALSE} から \code{NULL} へ変更されている．
}
\details{
  \code{codoc} の目的は関数オブジェクトのドキュメント化された用法と
  \R コードで定義されたそれらの形式的引数とが一致するかどうかを
  チェックすることである．特に総称的関数のメソッドは
  しばしばメソッドではなく総称的関数の名前を用いているので，
  これは常に簡単なわけではない．

  次のようなアルゴリズムが使われる．
  もしインストール済みのパッケージが使われると，もしかすると既にロードされている
  パッケージ(それが \pkg{base} パッケージでない限り)のバージョンを切り離した後に，
  それをロードする．さもなければ
  もしソースが使われるとパッケージの \R コードファイルが集められ
  新しい環境中で読み込まれる．
  それから Rd ファイルの用法セクションが抜き出されドキュメント化された
  形式引数を与えるために
  \sQuote{可能な限り}構文解析される．
  コード環境中のインタプリタ関数に対しては，
  引数 \code{use.values} の値に応じて形式的引数がコードとドキュメント間で
  比較される．もしあれば梗概セクションが使われる；それらの存在は
  もし \code{verbose} が真ならば報告される．

  もしパッケージが名前空間を持てば，移出オブジェクトと未移出オブジェクトの
  双方が登録された S3 メソッドと共にチェックされる．
  (ありそうもない食い違いの場合は
  順序はパッケージ中の移出オブジェクト，登録された
  S3 メソッド，そして名前空間中のオブジェクトであり，
  そして最初に見つかったものがチェックされる．)

  現在 R のドキュメント書式は
  基本的なクラスの\sQuote{構造}とデータセット
  (関数の梗概に対する用法セクションに似た)
  高水準のマークアップを持たない．
  \code{\link{prompt}} で作られた\sQuote{テンプレート}を適当に編集して
  得られたドキュメントオブジェクト中のデータフレームに対する変数名は
  ドキュメントオブジェクトが単一のデータフレーム
  (つまり唯一つの別名を持つ)ならば
  \code{codocData} により認識されそして使われる．
  
  \code{codocClasses} は同様に
  \code{\link{promptClass}} により作られるシェルを編集して得られる
  ドキュメントオブジェクト中のクラスに対するスロット名を処理する．

  適当な \var{pkgname} に対する \file{\var{pkgname}-defunct.Rd} という名前の
  ヘルプファイルはより大雑把にチェックされる，それらは
  ドキュメント化され無い引数を持つかもしれないからである．
}
\value{
  \code{codoc} はクラス
  \code{"codoc"} のオブジェクトを返す．現在これはリストであり，
  非一貫性が見つかったパッケージ中の各 Rd オブジェクトに対して，
  ミスマッチのリスト要素を含む
  (これは更に要素
  \code{code} と \code{docs} を持つリストで，
  関数コードとドキュメントの用法から得られた対応する引数を与える)．

  \code{codocClasses} と \code{codocData} はそれぞれクラス
  \code{"codocClasses"} と \code{"codocData"} を返し，
  クラス \code{"codoc"} に類似した構造を持つ．

  そうしたオブジェクトに含まれる情報を見栄え良く表示する
  \code{print} メソッドがある．
}
\seealso{
  \code{\link{undoc}}, \code{\link{QC}}
}
\keyword{documentation}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% File src/library/tools/man/codoc.Rd
%%% Part of the R package, https://www.R-project.org
%%% Copyright 1995-2009 R Core Team
%%% Distributed under GPL 2 or later
%%
%%\name{codoc}
%%\alias{codoc}
%%\alias{codocClasses}
%%\alias{codocData}
%%\alias{print.codoc}
%%\alias{print.codocClasses}
%%\alias{print.codocData}
%%\title{Check Code/Documentation Consistency}
%%\usage{
%%codoc(package, dir, lib.loc = NULL,
%%      use.values = NULL, verbose = getOption("verbose"))
%%codocClasses(package, lib.loc = NULL)
%%codocData(package, lib.loc = NULL)
%%}
%%\description{
%%  Find inconsistencies between actual and documented \sQuote{structure}
%%  of \R objects in a package.  \code{codoc} compares names and
%%  optionally also corresponding positions and default values of the
%%  arguments of functions.  \code{codocClasses} and \code{codocData}
%%  compare slot names of S4 classes and variable names of data sets,
%%  respectively.
%%}
%%\arguments{
%%  \item{package}{a character string naming an installed package.}
%%  \item{dir}{a character string specifying the path to a package's root
%%    source directory.  This must contain the subdirectories \file{man}
%%    with \R documentation sources (in Rd format) and \file{R} with \R
%%    code.  Only used if \code{package} is not given.}
%%  \item{lib.loc}{a character vector of directory names of \R libraries,
%%    or \code{NULL}.  The default value of \code{NULL} corresponds to all
%%    libraries currently known.  The specified library trees are used to
%%    search for \code{package}.}
%%  \item{use.values}{if \code{FALSE}, do not use function default values
%%    when comparing code and docs.  Otherwise, compare \emph{all} default
%%    values if \code{TRUE}, and only the ones documented in the usage
%%    otherwise (default).}
%%  \item{verbose}{a logical.  If \code{TRUE}, additional diagnostics are
%%    printed.}
%%}
%%\note{
%%  The default for \code{use.values} has been changed from
%%  \code{FALSE} to \code{NULL}, for \R versions 1.9.0 and later.
%%}
%%\details{
%%  The purpose of \code{codoc} is to check whether the documented usage
%%  of function objects agrees with their formal arguments as defined in
%%  the \R code.  This is not always straightforward, in particular as the
%%  usage information for methods to generic functions often employs the
%%  name of the generic rather than the method.
%%
%%  The following algorithm is used.  If an installed package is used, it
%%  is loaded (unless it is the \pkg{base} package), after possibly
%%  detaching an already loaded version of the package.  Otherwise, if the
%%  sources are used, the \R code files of the package are collected and
%%  sourced in a new environment.  Then, the usage sections of the Rd
%%  files are extracted and parsed \sQuote{as much as possible} to give
%%  the formals documented.  For interpreted functions in the code
%%  environment, the formals are compared between code and documentation
%%  according to the values of the argument \code{use.values}.  Synopsis
%%  sections are used if present; their occurrence is reported if
%%  \code{verbose} is true.
%%
%%  If a package has a namespace both exported and unexported objects are
%%  checked, as well as registered S3 methods.  (In the unlikely event of
%%  differences the order is exported objects in the package, registered
%%  S3 methods and finally objects in the namespace and only the first
%%  found is checked.)
%%
%%  Currently, the R documentation format has no high-level markup for the
%%  basic \sQuote{structure} of classes and data sets (similar to the usage
%%  sections for function synopses).  Variable names for data frames in
%%  documentation objects obtained by suitably editing \sQuote{templates}
%%  created by \code{\link{prompt}} are recognized by \code{codocData}
%%  and used provided that the documentation object is for a single data
%%  frame (i.e., only has one alias).  \code{codocClasses} analogously
%%  handles slot names for classes in documentation objects obtained by
%%  editing shells created by \code{\link{promptClass}}.
%%
%%  Help files named \file{\var{pkgname}-defunct.Rd} for the
%%  appropriate \var{pkgname} are checked more loosely, as they may
%%  have undocumented arguments.
%%}
%%\value{
%%  \code{codoc} returns an object of class \code{"codoc"}.  Currently,
%%  this is a list which, for each Rd object in the package where an
%%  inconsistency was found, contains an element with a list of the
%%  mismatches (which in turn are lists with elements \code{code} and
%%  \code{docs}, giving the corresponding arguments obtained from the
%%  function's code and documented usage).
%%
%%  \code{codocClasses} and \code{codocData} return objects of class
%%  \code{"codocClasses"} and \code{"codocData"}, respectively, with a
%%  structure similar to class \code{"codoc"}.
%%
%%  There are \code{print} methods for nicely displaying the information
%%  contained in such objects.
%%}
%%\seealso{
%%  \code{\link{undoc}}, \code{\link{QC}}
%%}
%%\keyword{documentation}
%%
%%\encoding{UTF8}
%
