% File src/library/tools/man/parse_Rd.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2008-2016 R Core Team
% Distributed under GPL 2 or later

\name{parse_Rd}
\alias{parse_Rd}
%@%\alias{Rd ファイルの構文解析}
\alias{print.Rd}
\alias{as.character.Rd}
%\title{ Parse an Rd file }
\title{Rd ファイルを構文解析する}
\description{
  この関数は他の関数による処理のために
  R のドキュメント(Rd)ファイルを読み取りそれを構文解析する．
}
\usage{
parse_Rd(file, srcfile = NULL, encoding = "unknown",
         verbose = FALSE, fragment = FALSE, warningCalls = TRUE,
	 macros = file.path(R.home("share"), "Rd", "macros", "system.Rd"),
         permissive = FALSE)
\method{print}{Rd}(x, deparse = FALSE, \dots)
\method{as.character}{Rd}(x, deparse = FALSE, \dots)
}
\arguments{
  \item{file}{ファイル名かテキストモードのコネクション．
    現在ファイル名が最も上手く動作する．}
  \item{srcfile}{\code{NULL} または \code{"srcfile"} オブジェクト．
    \sQuote{詳細}節を見よ．}
  \item{encoding}{入力文字に対して仮定されるエンコーディング．}
  \item{verbose}{
    詳細な構文解析情報がプリントされるべきかどうかを指示する論理値．}
  \item{fragment}{ファイルが完全な
    Rd ファイルを表すか断片かを指示する論理値．}
  \item{warningCalls}{論理値：構文解析の警告は呼び出しを含めるべきか?}
  \item{macros}{追加のマクロをそこからロードするファイル名か環境，
    もしくは論理値．\sQuote{詳細}節を見よ．}
  \item{permissive}{
    認識できないマクロは警告なしでテキストとして扱われるべきことを
    指示する論理値．}
  \item{x}{クラス Rd のオブジェクト．}
  \item{deparse}{もし \code{TRUE} なら，
    結果の文字が同じオブジェクトに構文解析されるように
    エスケープシーケンスを回復しようと試みる．}
  \item{\dots}{他のメソッドへ・から渡される追加引数．}
}
\details{
  この関数は
  \url{https://developer.r-project.org/parseRd.pdf} で与えられた仕様に
  従って \file{Rd} ファイルを構文解析する．

  各構文エラーに対して警告が生成され構文解析を続行しようと試みる．
  続行するためには一般にファイルのある部分を取り除く必要があるので，
  そうしたそうした警告は無視されるべきではない．
  
  マークされたエンコーディングが無いファイルは既定では
  ネイティブなエンコーディング中にあると仮定される．
  別の既定値は \code{encoding} 引数を使って設定できる．
  ファイル中の全てのテキストは構文解析されたオブジェクト中では
  UTF-8 エンコーディングに翻訳される．
  
  \R のバージョン 3.2.0 から，ユーザが定義したマクロを
  \samp{\newcommand} または \samp{\renewcommand} を使って別のファイル
  中に与えることができる．
  環境もまた与えることが出来る：
  それは \code{\link{loadRdMacros}}, \code{\link{loadPkgRdMacros}} または
  以前の \code{parse_Rd} の呼び出しで作ることが出来る．
  もし論理値が与えられると．
  既定の組み込みのマクロだけが使われる；
  \code{FALSE} は結果には
  \code{"macros"} 属性を返さないことを指示する．
  
  \code{permissive} 引数は完全には
  Rd 書式ではないテキストの構文解析を許す．
  典型的にはそれは \code{\link{bibentry}} 中におけるような，
  Rd 断片中で使われる LaTeX コードである．
  \code{permissive = TRUE} では，これは平文として渡される．
  \code{parse_Rd} はどれだけ多くの引数が
  LaTeX マクロに属するか知らないので，
  それはマクロの後の括弧の存在に基づいて推測する；
  これは絶対確かではない．
}
\value{
  \code{parse_Rd} はクラス \code{"Rd"} のオブジェクトを返す．
  このオブジェクトの内部書式は変更されるかもしれない．
  このクラスに対して定義された \code{as.character()} と \code{print()}
  メソッドはそれぞれ文字列ベクトルを返しそれらをプリントする．

  \code{macros = FALSE} で無い限り，オブジェクトは
  \code{"macros"} という名前の属性を持ち，これは
  \code{file} 中で定義された同じセッション中の
  更なる \code{parse_Rd} 呼び出しに対して使うことが出来る書式
  で書かれたマクロを含む環境である．
  もしファイルに保存され異なったセッションで再ロードされると
  動作するかどうかは保証されない．
}
\references{ \url{https://developer.r-project.org/parseRd.pdf} }
\author{ Duncan Murdoch }
\seealso{
  変換のために \code{parse_Rd()}の出力を利用する\code{\link{Rd2HTML}}．
  .
}
\keyword{utilities}
\keyword{documentation}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/tools/man/parse_Rd.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2008-2016 R Core Team
%% Distributed under GPL 2 or later
%
%\name{parse_Rd}
%\alias{parse_Rd}
%\alias{print.Rd}
%\alias{as.character.Rd}
%\title{ Parse an Rd file }
%\description{
%  This function reads an R documentation (Rd) file and parses it, for
%  processing by other functions.
%}
%\usage{
%parse_Rd(file, srcfile = NULL, encoding = "unknown",
%         verbose = FALSE, fragment = FALSE, warningCalls = TRUE,
%	 macros = file.path(R.home("share"), "Rd", "macros", "system.Rd"),
%         permissive = FALSE)
%\method{print}{Rd}(x, deparse = FALSE, \dots)
%\method{as.character}{Rd}(x, deparse = FALSE, \dots)
%}
%\arguments{
%  \item{file}{A filename or text-mode connection.  At present filenames
%    work best.}
%  \item{srcfile}{\code{NULL}, or a \code{"srcfile"} object.  See the
%    \sQuote{Details} section.}
%  \item{encoding}{Encoding to be assumed for input strings.}
%  \item{verbose}{Logical indicating whether detailed parsing
%    information should be printed.}
%  \item{fragment}{Logical indicating whether file represents a complete
%    Rd file, or a fragment.}
%  \item{warningCalls}{Logical: should parser warnings include the call?}
%  \item{macros}{Filename or environment from which to load additional
%    macros, or a logical value.  See the Details below.}
%  \item{permissive}{Logical indicating that unrecognized macros
%    should be treated as text with no warning.}
%  \item{x}{An object of class Rd.}
%  \item{deparse}{If \code{TRUE}, attempt to reinstate the escape characters
%    so that the resulting characters will parse to the same object.}
%  \item{\dots}{Further arguments to be passed to or from other methods.}
%}
%\details{
%  This function parses \file{Rd} files according to the specification given
%  in \url{https://developer.r-project.org/parseRd.pdf}.
%
%  It generates a warning for each parse error and attempts to continue
%  parsing.  In order to continue, it is generally necessary to drop some
%  parts of the file, so such warnings should not be ignored.  
%  
%  Files without a marked encoding are by default assumed to be in the
%  native encoding.  An alternate default can be set using the
%  \code{encoding} argument.  All text in files is translated to the
%  UTF-8 encoding in the parsed object.
%  
%  As from \R version 3.2.0, User-defined macros may be given in a
%  separate file using \samp{\newcommand} or \samp{\renewcommand}.
%  An environment may also be given:  it would be produced by
%  \code{\link{loadRdMacros}}, \code{\link{loadPkgRdMacros}}, or
%  by a previous call to \code{parse_Rd}.  If a logical value
%  is given, only the default built-in macros will be used; 
%  \code{FALSE} indicates that no \code{"macros"} attribute
%  will be returned with the result.
%  
%  The \code{permissive} argument allows text to be parsed that is
%  not completely in Rd format.  Typically it would be LaTeX code,
%  used in an Rd fragment, e.g.\sspace{}in a \code{\link{bibentry}}.  
%  With \code{permissive = TRUE}, this will be passed through as plain 
%  text.  Since \code{parse_Rd} doesn't know how many arguments
%  belong in LaTeX macros, it will guess based on the presence
%  of braces after the macro; this is not infallible.
%}
%\value{
%  \code{parse_Rd} returns an object of class \code{"Rd"}.  The
%  internal format of this object is subject to change.  The
%  \code{as.character()} and \code{print()} methods defined for the
%  class return character vectors and print them, respectively.
%
%  Unless \code{macros = FALSE}, the object will have an attribute 
%  named \code{"macros"}, which is an environment containing the 
%  macros defined in \code{file}, in a format that can be used for 
%  further \code{parse_Rd} calls  in the same session.  It is not 
%  guaranteed to work if saved to a file and reloaded in a different 
%  session.
%}
%\references{ \url{https://developer.r-project.org/parseRd.pdf} }
%\author{ Duncan Murdoch }
%\seealso{
%  \code{\link{Rd2HTML}} for the converters that use the output of
%  \code{parse_Rd()}.
%}
%\keyword{utilities}
%\keyword{documentation}
%
%\encoding{UTF8}
%