% File src/library/tools/man/writePACKAGES.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{write_PACKAGES}
%@%\alias{PACKAGES ファイルを作る}
\alias{write_PACKAGES}
\title{PACKAGES ファイルを作る}
%\title{Generate PACKAGES files}
\description{
  ソースや Mac/Windows バイナリパッケージの保存場所として
  \file{PACKAGES} と \file{PACKAGES.gz} ファイルを作る．
}
\usage{
write_PACKAGES(dir = ".", fields = NULL,
               type = c("source", "mac.binary", "win.binary"),
               verbose = FALSE, unpacked = FALSE, subdirs = FALSE,
               latestOnly = TRUE, addFiles = FALSE)
}
\arguments{
  \item{dir}{
    \file{PACKAGES} と \file{PACKAGES.gz} ファイルをそこから作り書き込み
    生成するレポジトリ
    (ソースまたはバイナリパッケージをを含むディレクトリ)の
    位置を記述する文字列ベクトル．
  }
  \item{fields}{
    既定以外に
    \file{PACKAGES} と \file{PACKAGES.gz} ファイル中で使われる欄を
    与える文字列ベクトル，または
    \code{NULL} (既定)．既定は
    \code{\link{available.packages}}:
    \code{"Package"}, \code{"Version"}, \code{"Priority"},
    \code{"Depends"}, \code{"Imports"}, \code{"LinkingTo"},
    \code{"Suggests"}, \code{"Enhances"}, \code{"OS_type"},
    \code{"License"} そして \code{"Archs"} が必要とする欄に対応し，
    そしてこれらは常に含められ，そしてもし \code{addFile = TRUE}
    ならば \code{"File"} 中にファイル名，もし副ディレクトリが
    使われるならば副ディレクトリへのパスが欄
    \code{"Path"} 中に加わる．
  }
  \item{type}{
    パッケージのタイプ：現在ソースアーカイブ \file{.tar.\{gz,bz2,xz\}}，と
    OS X または Windows バイナリパッケージ
    (それぞれ \file{.tgz} または \file{.zip})がサポートされる．
    既定では Windows では
    \code{"win.binary"}で，他では \code{"source"}．
  }
  \item{verbose}{論理値．パッケージを処理中に表示すべきか?}
  \item{unpacked}{論理値で，パッケージの中身がパックされない形式で利用できるか
    またはそうでないか(既定)を指示する．}
  \item{subdirs}{論理値(副ディレクトリを再帰的に含むべきかどうかを指示する)
    または含めるべき副ディレクトリの名前の文字列ベクトル．}
  \item{latestOnly}{論理値：もしパッケージ複数のバージョンが
    利用できるなら最新のバージョンだけを含めるべきか?}
  \item{addFiles}{論理値：ファイル名を
    \file{PACKAGES} ファイル中の欄 \samp{File} に含めるべきか.}
}
\details{
  \code{write_PACKAGES} は
  R パッケージに対する名前付きディレクトリをスキャンし，
  各パッケージの
  \file{DESCRIPTION} ファイルを取り出し，そして
  この情報を
  \file{PACKAGES} と \file{PACKAGES.gz} ファイルに書き込む．

  最新でないバージョンのパッケージを含めることは
  それらがより制約的でないバージョン要求を持つ時だけ
  役に立つので，例えば \code{latestOnly = FALSE} は
  \samp{foo_1.0} が \samp{R >= 2.15.0} に依存するが 
  \samp{R >= 2.11.0} に依存する \samp{foo_0.9} が利用できる時の
  ソースレポジトリに対して使うことが出来る．

  副ディレクトリを持つ，そして従って
  \code{subdirs != FALSE} に対するレポジトリに対するサポートは
  \file{PACKAGES} ファイル中の
  \code{"Path"} 欄の記録に依存する．

  \file{PACKAGES} ファイル中の
  \code{"File"} 欄経由のより一般的なファイル名(例えば他のタイプの圧縮)
  が \code{\link{download.packages}} で使用できる．もしファイル名が
  標準的な形式でなければ
  \code{addFiles = TRUE} を使う．

  \code{type = "win.binary"} は
  与えられたディレクトリ \code{dir} 中の Windows に対する(zip 圧縮された)
  バイナリパッケージ中に含まれる全ての \file{DESCRIPTION} ファイルを
  読むために \code{\link{unz}} コネクションを使い，
  そしてこの情報からファイル
  \file{PACKAGES} と \file{PACKAGES.gz} を構築する．
}
\value{
  結果の \file{PACKAGES} と \file{PACKAGES.gz} ファイル中で
  記述されたパッケージの数を不可視で返す．
  もし \code{0} ならパッケージは見つからず如何なる
  ファイルも書き込まれない．
}
\note{
  \file{DESCRIPTION} ファイルを取り出すための
  \file{.tar.gz} アーカイブの処理は非常に遅い．

  この関数は他の OS から Windows の稼働する機械が利用するための
  レポジトリを用意するために有用でありえるので，
  \code{type = "win.binary"} は全ての OS で動作すべきである．
}
\author{
  Uwe Ligges と R-core．
}
\seealso{
  \file{DESCRIPTION} ファイルの読み取りと
  \file{PACKAGES} そして \file{PACKAGES.gz} ファイルの書き込みに
  対しては
  \code{\link{read.dcf}} と \code{\link{write.dcf}} を見よ．
}
\examples{
\dontrun{
write_PACKAGES("c:/myFolder/myRepository")  # Windows 上
write_PACKAGES("/pub/RWin/bin/windows/contrib/2.9",
               type = "win.binary")  # Linux 上
}}
\keyword{file}
\keyword{utilities}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/tools/man/writePACKAGES.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{write_PACKAGES}
%\alias{write_PACKAGES}
%\title{Generate PACKAGES files}
%\description{
%  Generate \file{PACKAGES} and \file{PACKAGES.gz} files for a
%  repository of source or Mac/Windows binary packages.
%}
%\usage{
%write_PACKAGES(dir = ".", fields = NULL,
%               type = c("source", "mac.binary", "win.binary"),
%               verbose = FALSE, unpacked = FALSE, subdirs = FALSE,
%               latestOnly = TRUE, addFiles = FALSE)
%}
%\arguments{
%  \item{dir}{Character vector describing the location of the repository
%    (directory including source or binary packages) to generate the
%    \file{PACKAGES} and \file{PACKAGES.gz} files from and write them to.
%  }
%  \item{fields}{
%    a character vector giving the fields to be used in the
%    \file{PACKAGES} and \file{PACKAGES.gz} files in addition to the
%    default ones, or \code{NULL} (default).  The default corresponds to
%    the fields needed by \code{\link{available.packages}}:
%    \code{"Package"}, \code{"Version"}, \code{"Priority"},
%    \code{"Depends"}, \code{"Imports"}, \code{"LinkingTo"},
%    \code{"Suggests"}, \code{"Enhances"}, \code{"OS_type"},
%    \code{"License"} and \code{"Archs"}, and those fields will always
%    be included, plus
%    the file name in field \code{"File"} if \code{addFile = TRUE}
%    and the path to the subdirectory in field \code{"Path"} if subdirectories
%    are used.
%  }
%  \item{type}{
%    Type of packages: currently source \file{.tar.\{gz,bz2,xz\}} archives,
%    and OS X or Windows binary (\file{.tgz} or \file{.zip},
%    respectively) packages are supported.  Defaults to
%    \code{"win.binary"} on Windows and to \code{"source"} otherwise.
%  }
%  \item{verbose}{logical.  Should packages be listed as they are
%    processed?}
%  \item{unpacked}{a logical indicating whether the package contents are
%    available in unpacked form or not (default).}
%  \item{subdirs}{either logical (to indicate if subdirectories should be
%    included, recursively) or a character vector of name of subdirectories
%    to include.}
%  \item{latestOnly}{logical: if multiple versions of a package are
%    available should only the latest version be included?}
%  \item{addFiles}{logical: should the filenames be included as field
%    \samp{File} in the \file{PACKAGES} file.}
%}
%\details{
%  \code{write_PACKAGES} scans the named directory for R packages,
%  extracts information from each package's \file{DESCRIPTION} file, and
%  writes this information into the \file{PACKAGES} and
%  \file{PACKAGES.gz} files.
%
%  Including non-latest versions of packages is only useful if they have
%  less constraining version requirements, so for example
%  \code{latestOnly = FALSE} could be used for a source repository when
%  \samp{foo_1.0} depends on \samp{R >= 2.15.0} but \samp{foo_0.9} is
%  available which depends on \samp{R >= 2.11.0}.
%
%  Support for repositories with subdirectories and hence for
%  \code{subdirs != FALSE} depends on recording a \code{"Path"} field in
%  the \file{PACKAGES} file.
%
%  Support for more general file names (e.g., other types of compression)
%  \emph{via} a \code{"File"} field in the \file{PACKAGES} file can be
%  used by \code{\link{download.packages}}.  If the file names are not of
%  the standard form, use \code{addFiles = TRUE}.
%
%  \code{type = "win.binary"} uses \code{\link{unz}} connections to read
%  all \file{DESCRIPTION} files contained in the (zipped) binary packages
%  for Windows in the given directory \code{dir}, and builds files
%  \file{PACKAGES} and \file{PACKAGES.gz} files from this information.
%}
%\value{
%  Invisibly returns the number of packages described in the resulting
%  \file{PACKAGES} and \file{PACKAGES.gz} files.  If \code{0}, no
%  packages were found and no files were written.
%}
%\note{
%  Processing \file{.tar.gz} archives to extract the \file{DESCRIPTION}
%  files is quite slow.
%
%  This function can be useful on other OSes to prepare a repository to
%  be accessed by Windows machines, so \code{type = "win.binary"} should
%  work on all OSes.
%}
%\author{
%  Uwe Ligges and R-core.
%}
%\seealso{
%  See \code{\link{read.dcf}} and \code{\link{write.dcf}} for reading
%  \file{DESCRIPTION} files and writing the \file{PACKAGES} and
%  \file{PACKAGES.gz} files.
%}
%\examples{
%\dontrun{
%write_PACKAGES("c:/myFolder/myRepository")  # on Windows
%write_PACKAGES("/pub/RWin/bin/windows/contrib/2.9",
%               type = "win.binary")  # on Linux
%}}
%\keyword{file}
%\keyword{utilities}
%
%\encoding{UTF8}
%